// Copyright (c) 2013-2016 CoolGames

/******************************************************************************
 * Spine Runtimes Software License
 * Version 2.3
 * 
 * Copyright (c) 2013-2015, Esoteric Software
 * All rights reserved.
 * 
 * You are granted a perpetual, non-exclusive, non-sublicensable and
 * non-transferable license to use, install, execute and perform the Spine
 * Runtimes Software (the "Software") and derivative works solely for personal
 * or internal use. Without the written permission of Esoteric Software (see
 * Section 2 of the Spine Software License Agreement), you may not (a) modify,
 * translate, adapt or otherwise create derivative works, improvements of the
 * Software or develop new applications using the Software or (b) remove,
 * delete, alter or obscure any trademarks or any copyright, trademark, patent
 * or other intellectual property or proprietary rights notices on or in the
 * Software, including any copy thereof. Redistributions in binary or source
 * form must include this license and terms.
 * 
 * THIS SOFTWARE IS PROVIDED BY ESOTERIC SOFTWARE "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL ESOTERIC SOFTWARE BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

var spine = {
	radDeg: 180 / Math.PI,
	degRad: Math.PI / 180,
	temp: [],
    Float32Array: (typeof(Float32Array) === 'undefined') ? Array : Float32Array,
    Uint16Array: (typeof(Uint16Array) === 'undefined') ? Array : Uint16Array
};

spine.BoneData = function (name, parent) {
	this.name = name;
	this.parent = parent;
};
spine.BoneData.prototype = {
	length: 0,
	x: 0, y: 0,
	rotation: 0,
	scaleX: 1, scaleY: 1,
	inheritScale: true,
	inheritRotation: true,
	flipX: false, flipY: false
};

spine.BlendMode = {
	normal: 0,
	additive: 1,
	multiply: 2,
	screen: 3
};

spine.SlotData = function (name, boneData) {
	this.name = name;
	this.boneData = boneData;
};
spine.SlotData.prototype = {
	r: 1, g: 1, b: 1, a: 1,
	attachmentName: null,
	blendMode: spine.BlendMode.normal
};

spine.IkConstraintData = function (name) {
	this.name = name;
	this.bones = [];
};
spine.IkConstraintData.prototype = {
	target: null,
	bendDirection: 1,
	mix: 1
};

spine.Bone = function (boneData, skeleton, parent) {
	this.data = boneData;
	this.skeleton = skeleton;
	this.parent = parent;
	this.setToSetupPose();
};
spine.Bone.yDown = false;
spine.Bone.prototype = {
	x: 0, y: 0,
	rotation: 0, rotationIK: 0,
	scaleX: 1, scaleY: 1,
	flipX: false, flipY: false,
	m00: 0, m01: 0, worldX: 0, // a b x
	m10: 0, m11: 0, worldY: 0, // c d y
	worldRotation: 0,
	worldScaleX: 1, worldScaleY: 1,
	worldFlipX: false, worldFlipY: false,
	updateWorldTransform: function () {
		var parent = this.parent;
		if (parent) {
			this.worldX = this.x * parent.m00 + this.y * parent.m01 + parent.worldX;
			this.worldY = this.x * parent.m10 + this.y * parent.m11 + parent.worldY;
			if (this.data.inheritScale) {
				this.worldScaleX = parent.worldScaleX * this.scaleX;
				this.worldScaleY = parent.worldScaleY * this.scaleY;
			} else {
				this.worldScaleX = this.scaleX;
				this.worldScaleY = this.scaleY;
			}
			this.worldRotation = this.data.inheritRotation ? (parent.worldRotation + this.rotationIK) : this.rotationIK;
			this.worldFlipX = parent.worldFlipX != this.flipX;
			this.worldFlipY = parent.worldFlipY != this.flipY;
		} else {
			var skeletonFlipX = this.skeleton.flipX, skeletonFlipY = this.skeleton.flipY;
			this.worldX = skeletonFlipX ? -this.x : this.x;
			this.worldY = (skeletonFlipY != spine.Bone.yDown) ? -this.y : this.y;
			this.worldScaleX = this.scaleX;
			this.worldScaleY = this.scaleY;
			this.worldRotation = this.rotationIK;
			this.worldFlipX = skeletonFlipX != this.flipX;
			this.worldFlipY = skeletonFlipY != this.flipY;
		}
		var radians = this.worldRotation * spine.degRad;
		var cos = Math.cos(radians);
		var sin = Math.sin(radians);
		if (this.worldFlipX) {
			this.m00 = -cos * this.worldScaleX;
			this.m01 = sin * this.worldScaleY;
		} else {
			this.m00 = cos * this.worldScaleX;
			this.m01 = -sin * this.worldScaleY;
		}
		if (this.worldFlipY != spine.Bone.yDown) {
			this.m10 = -sin * this.worldScaleX;
			this.m11 = -cos * this.worldScaleY;
		} else {
			this.m10 = sin * this.worldScaleX;
			this.m11 = cos * this.worldScaleY;
		}
	},
	setToSetupPose: function () {
		var data = this.data;
		this.x = data.x;
		this.y = data.y;
		this.rotation = data.rotation;
		this.rotationIK = this.rotation;
		this.scaleX = data.scaleX;
		this.scaleY = data.scaleY;
		this.flipX = data.flipX;
		this.flipY = data.flipY;
	},
	worldToLocal: function (world) {
		var dx = world[0] - this.worldX, dy = world[1] - this.worldY;
		var m00 = this.m00, m10 = this.m10, m01 = this.m01, m11 = this.m11;
		if (this.worldFlipX != (this.worldFlipY != spine.Bone.yDown)) {
			m00 = -m00;
			m11 = -m11;
		}
		var invDet = 1 / (m00 * m11 - m01 * m10);
		world[0] = dx * m00 * invDet - dy * m01 * invDet;
		world[1] = dy * m11 * invDet - dx * m10 * invDet;
	},
	localToWorld: function (local) {
		var localX = local[0], localY = local[1];
		local[0] = localX * this.m00 + localY * this.m01 + this.worldX;
		local[1] = localX * this.m10 + localY * this.m11 + this.worldY;
	}
};

spine.Slot = function (slotData, bone) {
	this.data = slotData;
	this.bone = bone;
	this.setToSetupPose();
};
spine.Slot.prototype = {
	r: 1, g: 1, b: 1, a: 1,
	_attachmentTime: 0,
	attachment: null,
	attachmentVertices: [],
	setAttachment: function (attachment) {
		if (this.attachment == attachment) return;
		this.attachment = attachment;
		this._attachmentTime = this.bone.skeleton.time;
		this.attachmentVertices.length = 0;
	},
	setAttachmentTime: function (time) {
		this._attachmentTime = this.bone.skeleton.time - time;
	},
	getAttachmentTime: function () {
		return this.bone.skeleton.time - this._attachmentTime;
	},
	setToSetupPose: function () {
		var data = this.data;
		this.r = data.r;
		this.g = data.g;
		this.b = data.b;
		this.a = data.a;

		if (!data.attachmentName)
			this.setAttachment(null);
		else {
			var slotDatas = this.bone.skeleton.data.slots;
			for (var i = 0, n = slotDatas.length; i < n; i++) {
				if (slotDatas[i] == data) {
					this.attachment = null;
					this.setAttachment(this.bone.skeleton.getAttachmentBySlotIndex(i, data.attachmentName));
					break;
				}
			}
		}
	}
};

spine.IkConstraint = function (data, skeleton) {
	this.data = data;
	this.mix = data.mix;
	this.bendDirection = data.bendDirection;

	this.bones = [];
	for (var i = 0, n = data.bones.length; i < n; i++)
		this.bones.push(skeleton.findBone(data.bones[i].name));
	this.target = skeleton.findBone(data.target.name);
};
spine.IkConstraint.prototype = {
	apply: function () {
		var target = this.target;
		var bones = this.bones;
		switch (bones.length) {
		case 1:
			spine.IkConstraint.apply1(bones[0], target.worldX, target.worldY, this.mix);
			break;
		case 2:
			spine.IkConstraint.apply2(bones[0], bones[1], target.worldX, target.worldY, this.bendDirection, this.mix);
			break;
		}
	}
};
/** Adjusts the bone rotation so the tip is as close to the target position as possible. The target is specified in the world
 * coordinate system. */
spine.IkConstraint.apply1 = function (bone, targetX, targetY, alpha) {
	var parentRotation = (!bone.data.inheritRotation || !bone.parent) ? 0 : bone.parent.worldRotation;
	var rotation = bone.rotation;
	var rotationIK = Math.atan2(targetY - bone.worldY, targetX - bone.worldX) * spine.radDeg;
	if (bone.worldFlipX != (bone.worldFlipY != spine.Bone.yDown)) rotationIK = -rotationIK;
	rotationIK -= parentRotation;
	bone.rotationIK = rotation + (rotationIK - rotation) * alpha;
};
/** Adjusts the parent and child bone rotations so the tip of the child is as close to the target position as possible. The
 * target is specified in the world coordinate system.
 * @param child Any descendant bone of the parent. */
spine.IkConstraint.apply2 = function (parent, child, targetX, targetY, bendDirection, alpha) {
	var childRotation = child.rotation, parentRotation = parent.rotation;
	if (!alpha) {
		child.rotationIK = childRotation;
		parent.rotationIK = parentRotation;
		return;
	}
	var positionX, positionY, tempPosition = spine.temp;
	var parentParent = parent.parent;
	if (parentParent) {
		tempPosition[0] = targetX;
		tempPosition[1] = targetY;
		parentParent.worldToLocal(tempPosition);
		targetX = (tempPosition[0] - parent.x) * parentParent.worldScaleX;
		targetY = (tempPosition[1] - parent.y) * parentParent.worldScaleY;
	} else {
		targetX -= parent.x;
		targetY -= parent.y;
	}
	if (child.parent == parent) {
		positionX = child.x;
		positionY = child.y;
	} else {
		tempPosition[0] = child.x;
		tempPosition[1] = child.y;
		child.parent.localToWorld(tempPosition);
		parent.worldToLocal(tempPosition);
		positionX = tempPosition[0];
		positionY = tempPosition[1];
	}
	var childX = positionX * parent.worldScaleX, childY = positionY * parent.worldScaleY;
	var offset = Math.atan2(childY, childX);
	var len1 = Math.sqrt(childX * childX + childY * childY), len2 = child.data.length * child.worldScaleX;
	// Based on code by Ryan Juckett with permission: Copyright (c) 2008-2009 Ryan Juckett, http://www.ryanjuckett.com/
	var cosDenom = 2 * len1 * len2;
	if (cosDenom < 0.0001) {
		child.rotationIK = childRotation + (Math.atan2(targetY, targetX) * spine.radDeg - parentRotation - childRotation) * alpha;
		return;
	}
	var cos = (targetX * targetX + targetY * targetY - len1 * len1 - len2 * len2) / cosDenom;
	if (cos < -1)
		cos = -1;
	else if (cos > 1)
		cos = 1;
	var childAngle = Math.acos(cos) * bendDirection;
	var adjacent = len1 + len2 * cos, opposite = len2 * Math.sin(childAngle);
	var parentAngle = Math.atan2(targetY * adjacent - targetX * opposite, targetX * adjacent + targetY * opposite);
	var rotation = (parentAngle - offset) * spine.radDeg - parentRotation;
	if (rotation > 180)
		rotation -= 360;
	else if (rotation < -180) //
		rotation += 360;
	parent.rotationIK = parentRotation + rotation * alpha;
	rotation = (childAngle + offset) * spine.radDeg - childRotation;
	if (rotation > 180)
		rotation -= 360;
	else if (rotation < -180) //
		rotation += 360;
	child.rotationIK = childRotation + (rotation + parent.worldRotation - child.parent.worldRotation) * alpha;
};

spine.Skin = function (name) {
	this.name = name;
	this.attachments = {};
};
spine.Skin.prototype = {
	addAttachment: function (slotIndex, name, attachment) {
		this.attachments[slotIndex + ":" + name] = attachment;
	},
	getAttachment: function (slotIndex, name) {
		return this.attachments[slotIndex + ":" + name];
	},
	_attachAll: function (skeleton, oldSkin) {
		for (var key in oldSkin.attachments) {
			var colon = key.indexOf(":");
			var slotIndex = parseInt(key.substring(0, colon));
			var name = key.substring(colon + 1);
			var slot = skeleton.slots[slotIndex];
			if (slot.attachment && slot.attachment.name == name) {
				var attachment = this.getAttachment(slotIndex, name);
				if (attachment) slot.setAttachment(attachment);
			}
		}
	}
};

spine.Animation = function (name, timelines, duration) {
	this.name = name;
	this.timelines = timelines;
	this.duration = duration;
};
spine.Animation.prototype = {
	apply: function (skeleton, lastTime, time, loop, events) {
		if (loop && this.duration != 0) {
			time %= this.duration;
			lastTime %= this.duration;
		}
		var timelines = this.timelines;
		for (var i = 0, n = timelines.length; i < n; i++)
			timelines[i].apply(skeleton, lastTime, time, events, 1);
	},
	mix: function (skeleton, lastTime, time, loop, events, alpha) {
		if (loop && this.duration != 0) {
			time %= this.duration;
			lastTime %= this.duration;
		}
		var timelines = this.timelines;
		for (var i = 0, n = timelines.length; i < n; i++)
			timelines[i].apply(skeleton, lastTime, time, events, alpha);
	}
};
spine.Animation.binarySearch = function (values, target, step) {
	var low = 0;
	var high = Math.floor(values.length / step) - 2;
	if (!high) return step;
	var current = high >>> 1;
	while (true) {
		if (values[(current + 1) * step] <= target)
			low = current + 1;
		else
			high = current;
		if (low == high) return (low + 1) * step;
		current = (low + high) >>> 1;
	}
};
spine.Animation.binarySearch1 = function (values, target) {
	var low = 0;
	var high = values.length - 2;
	if (!high) return 1;
	var current = high >>> 1;
	while (true) {
		if (values[current + 1] <= target)
			low = current + 1;
		else
			high = current;
		if (low == high) return low + 1;
		current = (low + high) >>> 1;
	}
};
spine.Animation.linearSearch = function (values, target, step) {
	for (var i = 0, last = values.length - step; i <= last; i += step)
		if (values[i] > target) return i;
	return -1;
};

spine.Curves = function (frameCount) {
	this.curves = []; // type, x, y, ...
	//this.curves.length = (frameCount - 1) * 19/*BEZIER_SIZE*/;
};
spine.Curves.prototype = {
	setLinear: function (frameIndex) {
		this.curves[frameIndex * 19/*BEZIER_SIZE*/] = 0/*LINEAR*/;
	},
	setStepped: function (frameIndex) {
		this.curves[frameIndex * 19/*BEZIER_SIZE*/] = 1/*STEPPED*/;
	},
	/** Sets the control handle positions for an interpolation bezier curve used to transition from this keyframe to the next.
	 * cx1 and cx2 are from 0 to 1, representing the percent of time between the two keyframes. cy1 and cy2 are the percent of
	 * the difference between the keyframe's values. */
	setCurve: function (frameIndex, cx1, cy1, cx2, cy2) {
		var subdiv1 = 1 / 10/*BEZIER_SEGMENTS*/, subdiv2 = subdiv1 * subdiv1, subdiv3 = subdiv2 * subdiv1;
		var pre1 = 3 * subdiv1, pre2 = 3 * subdiv2, pre4 = 6 * subdiv2, pre5 = 6 * subdiv3;
		var tmp1x = -cx1 * 2 + cx2, tmp1y = -cy1 * 2 + cy2, tmp2x = (cx1 - cx2) * 3 + 1, tmp2y = (cy1 - cy2) * 3 + 1;
		var dfx = cx1 * pre1 + tmp1x * pre2 + tmp2x * subdiv3, dfy = cy1 * pre1 + tmp1y * pre2 + tmp2y * subdiv3;
		var ddfx = tmp1x * pre4 + tmp2x * pre5, ddfy = tmp1y * pre4 + tmp2y * pre5;
		var dddfx = tmp2x * pre5, dddfy = tmp2y * pre5;

		var i = frameIndex * 19/*BEZIER_SIZE*/;
		var curves = this.curves;
		curves[i++] = 2/*BEZIER*/;
		
		var x = dfx, y = dfy;
		for (var n = i + 19/*BEZIER_SIZE*/ - 1; i < n; i += 2) {
			curves[i] = x;
			curves[i + 1] = y;
			dfx += ddfx;
			dfy += ddfy;
			ddfx += dddfx;
			ddfy += dddfy;
			x += dfx;
			y += dfy;
		}
	},
	getCurvePercent: function (frameIndex, percent) {
		percent = percent < 0 ? 0 : (percent > 1 ? 1 : percent);
		var curves = this.curves;
		var i = frameIndex * 19/*BEZIER_SIZE*/;
		var type = curves[i];
		if (type === 0/*LINEAR*/) return percent;
		if (type == 1/*STEPPED*/) return 0;
		i++;
		var x = 0;
		for (var start = i, n = i + 19/*BEZIER_SIZE*/ - 1; i < n; i += 2) {
			x = curves[i];
			if (x >= percent) {
				var prevX, prevY;
				if (i == start) {
					prevX = 0;
					prevY = 0;
				} else {
					prevX = curves[i - 2];
					prevY = curves[i - 1];
				}
				return prevY + (curves[i + 1] - prevY) * (percent - prevX) / (x - prevX);
			}
		}
		var y = curves[i - 1];
		return y + (1 - y) * (percent - x) / (1 - x); // Last point is 1,1.
	}
};

spine.RotateTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, angle, ...
	this.frames.length = frameCount * 2;
};
spine.RotateTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, angle) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = angle;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 2]) { // Time is after last frame.
			var amount = bone.data.rotation + frames[frames.length - 1] - bone.rotation;
			while (amount > 180)
				amount -= 360;
			while (amount < -180)
				amount += 360;
			bone.rotation += amount * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 2);
		var prevFrameValue = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex - 2/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 2 - 1, percent);

		var amount = frames[frameIndex + 1/*FRAME_VALUE*/] - prevFrameValue;
		while (amount > 180)
			amount -= 360;
		while (amount < -180)
			amount += 360;
		amount = bone.data.rotation + (prevFrameValue + amount * percent) - bone.rotation;
		while (amount > 180)
			amount -= 360;
		while (amount < -180)
			amount += 360;
		bone.rotation += amount * alpha;
	}
};

spine.TranslateTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, x, y, ...
	this.frames.length = frameCount * 3;
};
spine.TranslateTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, x, y) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = x;
		this.frames[frameIndex + 2] = y;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			bone.x += (bone.data.x + frames[frames.length - 2] - bone.x) * alpha;
			bone.y += (bone.data.y + frames[frames.length - 1] - bone.y) * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameX = frames[frameIndex - 2];
		var prevFrameY = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		bone.x += (bone.data.x + prevFrameX + (frames[frameIndex + 1/*FRAME_X*/] - prevFrameX) * percent - bone.x) * alpha;
		bone.y += (bone.data.y + prevFrameY + (frames[frameIndex + 2/*FRAME_Y*/] - prevFrameY) * percent - bone.y) * alpha;
	}
};

spine.ScaleTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, x, y, ...
	this.frames.length = frameCount * 3;
};
spine.ScaleTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, x, y) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = x;
		this.frames[frameIndex + 2] = y;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			bone.scaleX += (bone.data.scaleX * frames[frames.length - 2] - bone.scaleX) * alpha;
			bone.scaleY += (bone.data.scaleY * frames[frames.length - 1] - bone.scaleY) * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameX = frames[frameIndex - 2];
		var prevFrameY = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		bone.scaleX += (bone.data.scaleX * (prevFrameX + (frames[frameIndex + 1/*FRAME_X*/] - prevFrameX) * percent) - bone.scaleX) * alpha;
		bone.scaleY += (bone.data.scaleY * (prevFrameY + (frames[frameIndex + 2/*FRAME_Y*/] - prevFrameY) * percent) - bone.scaleY) * alpha;
	}
};

spine.ColorTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, r, g, b, a, ...
	this.frames.length = frameCount * 5;
};
spine.ColorTimeline.prototype = {
	slotIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 5;
	},
	setFrame: function (frameIndex, time, r, g, b, a) {
		frameIndex *= 5;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = r;
		this.frames[frameIndex + 2] = g;
		this.frames[frameIndex + 3] = b;
		this.frames[frameIndex + 4] = a;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var r, g, b, a;
		if (time >= frames[frames.length - 5]) {
			// Time is after last frame.
			var i = frames.length - 1;
			r = frames[i - 3];
			g = frames[i - 2];
			b = frames[i - 1];
			a = frames[i];
		} else {
			// Interpolate between the previous frame and the current frame.
			var frameIndex = spine.Animation.binarySearch(frames, time, 5);
			var prevFrameR = frames[frameIndex - 4];
			var prevFrameG = frames[frameIndex - 3];
			var prevFrameB = frames[frameIndex - 2];
			var prevFrameA = frames[frameIndex - 1];
			var frameTime = frames[frameIndex];
			var percent = 1 - (time - frameTime) / (frames[frameIndex - 5/*PREV_FRAME_TIME*/] - frameTime);
			percent = this.curves.getCurvePercent(frameIndex / 5 - 1, percent);

			r = prevFrameR + (frames[frameIndex + 1/*FRAME_R*/] - prevFrameR) * percent;
			g = prevFrameG + (frames[frameIndex + 2/*FRAME_G*/] - prevFrameG) * percent;
			b = prevFrameB + (frames[frameIndex + 3/*FRAME_B*/] - prevFrameB) * percent;
			a = prevFrameA + (frames[frameIndex + 4/*FRAME_A*/] - prevFrameA) * percent;
		}
		var slot = skeleton.slots[this.slotIndex];
		if (alpha < 1) {
			slot.r += (r - slot.r) * alpha;
			slot.g += (g - slot.g) * alpha;
			slot.b += (b - slot.b) * alpha;
			slot.a += (a - slot.a) * alpha;
		} else {
			slot.r = r;
			slot.g = g;
			slot.b = b;
			slot.a = a;
		}
	}
};

spine.AttachmentTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.attachmentNames = [];
	this.attachmentNames.length = frameCount;
};
spine.AttachmentTimeline.prototype = {
	slotIndex: 0,
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, attachmentName) {
		this.frames[frameIndex] = time;
		this.attachmentNames[frameIndex] = attachmentName;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;

		var frameIndex = time >= frames[frames.length - 1] ? frames.length - 1 : spine.Animation.binarySearch1(frames, time) - 1;
		if (frames[frameIndex] < lastTime) return;

		var attachmentName = this.attachmentNames[frameIndex];
		skeleton.slots[this.slotIndex].setAttachment(
			!attachmentName ? null : skeleton.getAttachmentBySlotIndex(this.slotIndex, attachmentName));
	}
};

spine.EventTimeline = function (frameCount) {
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.events = [];
	this.events.length = frameCount;
};
spine.EventTimeline.prototype = {
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, event) {
		this.frames[frameIndex] = time;
		this.events[frameIndex] = event;
	},
	/** Fires events for frames > lastTime and <= time. */
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		if (!firedEvents) return;

		var frames = this.frames;
		var frameCount = frames.length;

		if (lastTime > time) { // Fire events after last time for looped animations.
			this.apply(skeleton, lastTime, Number.MAX_VALUE, firedEvents, alpha);
			lastTime = -1;
		} else if (lastTime >= frames[frameCount - 1]) // Last time is after last frame.
			return;
		if (time < frames[0]) return; // Time is before first frame.

		var frameIndex;
		if (lastTime < frames[0])
			frameIndex = 0;
		else {
			frameIndex = spine.Animation.binarySearch1(frames, lastTime);
			var frame = frames[frameIndex];
			while (frameIndex > 0) { // Fire multiple events with the same frame.
				if (frames[frameIndex - 1] != frame) break;
				frameIndex--;
			}
		}
		var events = this.events;
		for (; frameIndex < frameCount && time >= frames[frameIndex]; frameIndex++)
			firedEvents.push(events[frameIndex]);
	}
};

spine.DrawOrderTimeline = function (frameCount) {
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.drawOrders = [];
	this.drawOrders.length = frameCount;
};
spine.DrawOrderTimeline.prototype = {
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, drawOrder) {
		this.frames[frameIndex] = time;
		this.drawOrders[frameIndex] = drawOrder;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var frameIndex;
		if (time >= frames[frames.length - 1]) // Time is after last frame.
			frameIndex = frames.length - 1;
		else
			frameIndex = spine.Animation.binarySearch1(frames, time) - 1;

		var drawOrder = skeleton.drawOrder;
		var slots = skeleton.slots;
		var drawOrderToSetupIndex = this.drawOrders[frameIndex];
		if (!drawOrderToSetupIndex) {
			for (var i = 0, n = slots.length; i < n; i++)
				drawOrder[i] = slots[i];
		} else {
			for (var i = 0, n = drawOrderToSetupIndex.length; i < n; i++)
				drawOrder[i] = skeleton.slots[drawOrderToSetupIndex[i]];
		}

	}
};

spine.FfdTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = [];
	this.frames.length = frameCount;
	this.frameVertices = [];
	this.frameVertices.length = frameCount;
};
spine.FfdTimeline.prototype = {
	slotIndex: 0,
	attachment: 0,
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, vertices) {
		this.frames[frameIndex] = time;
		this.frameVertices[frameIndex] = vertices;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var slot = skeleton.slots[this.slotIndex];
		if (slot.attachment != this.attachment) return;

		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var frameVertices = this.frameVertices;
		var vertexCount = frameVertices[0].length;

		var vertices = slot.attachmentVertices;
		if (vertices.length != vertexCount) alpha = 1;
		vertices.length = vertexCount;

		if (time >= frames[frames.length - 1]) { // Time is after last frame.
			var lastVertices = frameVertices[frames.length - 1];
			if (alpha < 1) {
				for (var i = 0; i < vertexCount; i++)
					vertices[i] += (lastVertices[i] - vertices[i]) * alpha;
			} else {
				for (var i = 0; i < vertexCount; i++)
					vertices[i] = lastVertices[i];
			}
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch1(frames, time);
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex - 1] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex - 1, percent < 0 ? 0 : (percent > 1 ? 1 : percent));

		var prevVertices = frameVertices[frameIndex - 1];
		var nextVertices = frameVertices[frameIndex];

		if (alpha < 1) {
			for (var i = 0; i < vertexCount; i++) {
				var prev = prevVertices[i];
				vertices[i] += (prev + (nextVertices[i] - prev) * percent - vertices[i]) * alpha;
			}
		} else {
			for (var i = 0; i < vertexCount; i++) {
				var prev = prevVertices[i];
				vertices[i] = prev + (nextVertices[i] - prev) * percent;
			}
		}
	}
};

spine.IkConstraintTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, mix, bendDirection, ...
	this.frames.length = frameCount * 3;
};
spine.IkConstraintTimeline.prototype = {
	ikConstraintIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, mix, bendDirection) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = mix;
		this.frames[frameIndex + 2] = bendDirection;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var ikConstraint = skeleton.ikConstraints[this.ikConstraintIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			ikConstraint.mix += (frames[frames.length - 2] - ikConstraint.mix) * alpha;
			ikConstraint.bendDirection = frames[frames.length - 1];
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameMix = frames[frameIndex + -2/*PREV_FRAME_MIX*/];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		var mix = prevFrameMix + (frames[frameIndex + 1/*FRAME_MIX*/] - prevFrameMix) * percent;
		ikConstraint.mix += (mix - ikConstraint.mix) * alpha;
		ikConstraint.bendDirection = frames[frameIndex + -1/*PREV_FRAME_BEND_DIRECTION*/];
	}
};

spine.FlipXTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, flip, ...
	this.frames.length = frameCount * 2;
};
spine.FlipXTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, flip) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = flip ? 1 : 0;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;
		var frameIndex = (time >= frames[frames.length - 2] ? frames.length : spine.Animation.binarySearch(frames, time, 2)) - 2;
		if (frames[frameIndex] < lastTime) return;
		skeleton.bones[this.boneIndex].flipX = frames[frameIndex + 1] != 0;
	}
};

spine.FlipYTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, flip, ...
	this.frames.length = frameCount * 2;
};
spine.FlipYTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, flip) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = flip ? 1 : 0;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;
		var frameIndex = (time >= frames[frames.length - 2] ? frames.length : spine.Animation.binarySearch(frames, time, 2)) - 2;
		if (frames[frameIndex] < lastTime) return;
		skeleton.bones[this.boneIndex].flipY = frames[frameIndex + 1] != 0;
	}
};

spine.SkeletonData = function () {
	this.bones = [];
	this.slots = [];
	this.skins = [];
	this.events = [];
	this.animations = [];
	this.ikConstraints = [];
};
spine.SkeletonData.prototype = {
	name: null,
	defaultSkin: null,
	width: 0, height: 0,
	version: null, hash: null,
	/** @return May be null. */
	findBone: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].name == boneName) return bones[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findBoneIndex: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].name == boneName) return i;
		return -1;
	},
	/** @return May be null. */
	findSlot: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++) {
			if (slots[i].name == slotName) return slot[i];
		}
		return null;
	},
	/** @return -1 if the bone was not found. */
	findSlotIndex: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].name == slotName) return i;
		return -1;
	},
	/** @return May be null. */
	findSkin: function (skinName) {
		var skins = this.skins;
		for (var i = 0, n = skins.length; i < n; i++)
			if (skins[i].name == skinName) return skins[i];
		return null;
	},
	/** @return May be null. */
	findEvent: function (eventName) {
		var events = this.events;
		for (var i = 0, n = events.length; i < n; i++)
			if (events[i].name == eventName) return events[i];
		return null;
	},
	/** @return May be null. */
	findAnimation: function (animationName) {
		var animations = this.animations;
		for (var i = 0, n = animations.length; i < n; i++)
			if (animations[i].name == animationName) return animations[i];
		return null;
	},
	/** @return May be null. */
	findIkConstraint: function (ikConstraintName) {
		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++)
			if (ikConstraints[i].name == ikConstraintName) return ikConstraints[i];
		return null;
	}
};

spine.Skeleton = function (skeletonData) {
	this.data = skeletonData;

	this.bones = [];
	for (var i = 0, n = skeletonData.bones.length; i < n; i++) {
		var boneData = skeletonData.bones[i];
		var parent = !boneData.parent ? null : this.bones[skeletonData.bones.indexOf(boneData.parent)];
		this.bones.push(new spine.Bone(boneData, this, parent));
	}

	this.slots = [];
	this.drawOrder = [];
	for (var i = 0, n = skeletonData.slots.length; i < n; i++) {
		var slotData = skeletonData.slots[i];
		var bone = this.bones[skeletonData.bones.indexOf(slotData.boneData)];
		var slot = new spine.Slot(slotData, bone);
		this.slots.push(slot);
		this.drawOrder.push(slot);
	}
	
	this.ikConstraints = [];
	for (var i = 0, n = skeletonData.ikConstraints.length; i < n; i++)
		this.ikConstraints.push(new spine.IkConstraint(skeletonData.ikConstraints[i], this));

	this.boneCache = [];
	this.updateCache();
};
spine.Skeleton.prototype = {
	x: 0, y: 0,
	skin: null,
	r: 1, g: 1, b: 1, a: 1,
	time: 0,
	flipX: false, flipY: false,
	/** Caches information about bones and IK constraints. Must be called if bones or IK constraints are added or removed. */
	updateCache: function () {
		var ikConstraints = this.ikConstraints;
		var ikConstraintsCount = ikConstraints.length;

		var arrayCount = ikConstraintsCount + 1;
		var boneCache = this.boneCache;
		if (boneCache.length > arrayCount) boneCache.length = arrayCount;
		for (var i = 0, n = boneCache.length; i < n; i++)
			boneCache[i].length = 0;
		while (boneCache.length < arrayCount)
			boneCache[boneCache.length] = [];

		var nonIkBones = boneCache[0];
		var bones = this.bones;

		outer:
		for (var i = 0, n = bones.length; i < n; i++) {
			var bone = bones[i];
			var current = bone;
			do {
				for (var ii = 0; ii < ikConstraintsCount; ii++) {
					var ikConstraint = ikConstraints[ii];
					var parent = ikConstraint.bones[0];
					var child= ikConstraint.bones[ikConstraint.bones.length - 1];
					while (true) {
						if (current == child) {
							boneCache[ii].push(bone);
							boneCache[ii + 1].push(bone);
							continue outer;
						}
						if (child == parent) break;
						child = child.parent;
					}
				}
				current = current.parent;
			} while (current);
			nonIkBones[nonIkBones.length] = bone;
		}
	},
	/** Updates the world transform for each bone. */
	updateWorldTransform: function () {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++) {
			var bone = bones[i];
			bone.rotationIK = bone.rotation;
		}
		var i = 0, last = this.boneCache.length - 1;
		while (true) {
			var cacheBones = this.boneCache[i];
			for (var ii = 0, nn = cacheBones.length; ii < nn; ii++)
				cacheBones[ii].updateWorldTransform();
			if (i == last) break;
			this.ikConstraints[i].apply();
			i++;
		}
	},
	/** Sets the bones and slots to their setup pose values. */
	setToSetupPose: function () {
		this.setBonesToSetupPose();
		this.setSlotsToSetupPose();
	},
	setBonesToSetupPose: function () {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			bones[i].setToSetupPose();

		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++) {
			var ikConstraint = ikConstraints[i];
			ikConstraint.bendDirection = ikConstraint.data.bendDirection;
			ikConstraint.mix = ikConstraint.data.mix;
		}
	},
	setSlotsToSetupPose: function () {
		var slots = this.slots;
		var drawOrder = this.drawOrder;
		for (var i = 0, n = slots.length; i < n; i++) {
			drawOrder[i] = slots[i];
			slots[i].setToSetupPose(i);
		}
	},
	/** @return May return null. */
	getRootBone: function () {
		return this.bones.length ? this.bones[0] : null;
	},
	/** @return May be null. */
	findBone: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].data.name == boneName) return bones[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findBoneIndex: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].data.name == boneName) return i;
		return -1;
	},
	/** @return May be null. */
	findSlot: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].data.name == slotName) return slots[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findSlotIndex: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].data.name == slotName) return i;
		return -1;
	},
	setSkinByName: function (skinName) {
		var skin = this.data.findSkin(skinName);
		if (!skin) throw "Skin not found: " + skinName;
		this.setSkin(skin);
	},
	/** Sets the skin used to look up attachments before looking in the {@link SkeletonData#getDefaultSkin() default skin}. 
	 * Attachments from the new skin are attached if the corresponding attachment from the old skin was attached. If there was 
	 * no old skin, each slot's setup mode attachment is attached from the new skin.
	 * @param newSkin May be null. */
	setSkin: function (newSkin) {
		if (newSkin) {
			if (this.skin)
				newSkin._attachAll(this, this.skin);
			else {
				var slots = this.slots;
				for (var i = 0, n = slots.length; i < n; i++) {
					var slot = slots[i];
					var name = slot.data.attachmentName;
					if (name) {
						var attachment = newSkin.getAttachment(i, name);
						if (attachment) slot.setAttachment(attachment);
					}
				}
			}
		}
		this.skin = newSkin;
	},
	/** @return May be null. */
	getAttachmentBySlotName: function (slotName, attachmentName) {
		return this.getAttachmentBySlotIndex(this.data.findSlotIndex(slotName), attachmentName);
	},
	/** @return May be null. */
	getAttachmentBySlotIndex: function (slotIndex, attachmentName) {
		if (this.skin) {
			var attachment = this.skin.getAttachment(slotIndex, attachmentName);
			if (attachment) return attachment;
		}
		if (this.data.defaultSkin) return this.data.defaultSkin.getAttachment(slotIndex, attachmentName);
		return null;
	},
	/** @param attachmentName May be null. */
	setAttachment: function (slotName, attachmentName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++) {
			var slot = slots[i];
			if (slot.data.name == slotName) {
				var attachment = null;
				if (attachmentName) {
					attachment = this.getAttachmentBySlotIndex(i, attachmentName);
					if (!attachment) throw "Attachment not found: " + attachmentName + ", for slot: " + slotName;
				}
				slot.setAttachment(attachment);
				return;
			}
		}
		throw "Slot not found: " + slotName;
	},
	/** @return May be null. */
	findIkConstraint: function (ikConstraintName) {
		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++)
			if (ikConstraints[i].data.name == ikConstraintName) return ikConstraints[i];
		return null;
	},
	update: function (delta) {
		this.time += delta;
	}
};

spine.EventData = function (name) {
	this.name = name;
};
spine.EventData.prototype = {
	intValue: 0,
	floatValue: 0,
	stringValue: null
};

spine.Event = function (data) {
	this.data = data;
};
spine.Event.prototype = {
	intValue: 0,
	floatValue: 0,
	stringValue: null
};

spine.AttachmentType = {
	region: 0,
	boundingbox: 1,
	mesh: 2,
	skinnedmesh: 3
};

spine.RegionAttachment = function (name) {
	this.name = name;
	this.offset = [];
	this.offset.length = 8;
	this.uvs = [];
	this.uvs.length = 8;
};
spine.RegionAttachment.prototype = {
	type: spine.AttachmentType.region,
	x: 0, y: 0,
	rotation: 0,
	scaleX: 1, scaleY: 1,
	width: 0, height: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	setUVs: function (u, v, u2, v2, rotate) {
		var uvs = this.uvs;
		if (rotate) {
			uvs[2/*X2*/] = u;
			uvs[3/*Y2*/] = v2;
			uvs[4/*X3*/] = u;
			uvs[5/*Y3*/] = v;
			uvs[6/*X4*/] = u2;
			uvs[7/*Y4*/] = v;
			uvs[0/*X1*/] = u2;
			uvs[1/*Y1*/] = v2;
		} else {
			uvs[0/*X1*/] = u;
			uvs[1/*Y1*/] = v2;
			uvs[2/*X2*/] = u;
			uvs[3/*Y2*/] = v;
			uvs[4/*X3*/] = u2;
			uvs[5/*Y3*/] = v;
			uvs[6/*X4*/] = u2;
			uvs[7/*Y4*/] = v2;
		}
	},
	updateOffset: function () {
		var regionScaleX = this.width / this.regionOriginalWidth * this.scaleX;
		var regionScaleY = this.height / this.regionOriginalHeight * this.scaleY;
		var localX = -this.width / 2 * this.scaleX + this.regionOffsetX * regionScaleX;
		var localY = -this.height / 2 * this.scaleY + this.regionOffsetY * regionScaleY;
		var localX2 = localX + this.regionWidth * regionScaleX;
		var localY2 = localY + this.regionHeight * regionScaleY;
		var radians = this.rotation * spine.degRad;
		var cos = Math.cos(radians);
		var sin = Math.sin(radians);
		var localXCos = localX * cos + this.x;
		var localXSin = localX * sin;
		var localYCos = localY * cos + this.y;
		var localYSin = localY * sin;
		var localX2Cos = localX2 * cos + this.x;
		var localX2Sin = localX2 * sin;
		var localY2Cos = localY2 * cos + this.y;
		var localY2Sin = localY2 * sin;
		var offset = this.offset;
		offset[0/*X1*/] = localXCos - localYSin;
		offset[1/*Y1*/] = localYCos + localXSin;
		offset[2/*X2*/] = localXCos - localY2Sin;
		offset[3/*Y2*/] = localY2Cos + localXSin;
		offset[4/*X3*/] = localX2Cos - localY2Sin;
		offset[5/*Y3*/] = localY2Cos + localX2Sin;
		offset[6/*X4*/] = localX2Cos - localYSin;
		offset[7/*Y4*/] = localYCos + localX2Sin;
	},
	computeVertices: function (x, y, bone, vertices) {
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var offset = this.offset;
		vertices[0/*X1*/] = offset[0/*X1*/] * m00 + offset[1/*Y1*/] * m01 + x;
		vertices[1/*Y1*/] = offset[0/*X1*/] * m10 + offset[1/*Y1*/] * m11 + y;
		vertices[2/*X2*/] = offset[2/*X2*/] * m00 + offset[3/*Y2*/] * m01 + x;
		vertices[3/*Y2*/] = offset[2/*X2*/] * m10 + offset[3/*Y2*/] * m11 + y;
		vertices[4/*X3*/] = offset[4/*X3*/] * m00 + offset[5/*X3*/] * m01 + x;
		vertices[5/*X3*/] = offset[4/*X3*/] * m10 + offset[5/*X3*/] * m11 + y;
		vertices[6/*X4*/] = offset[6/*X4*/] * m00 + offset[7/*Y4*/] * m01 + x;
		vertices[7/*Y4*/] = offset[6/*X4*/] * m10 + offset[7/*Y4*/] * m11 + y;
	}
};

spine.MeshAttachment = function (name) {
	this.name = name;
};
spine.MeshAttachment.prototype = {
	type: spine.AttachmentType.mesh,
	vertices: null,
	uvs: null,
	regionUVs: null,
	triangles: null,
	hullLength: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionU: 0, regionV: 0, regionU2: 0, regionV2: 0, regionRotate: false,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	edges: null,
	width: 0, height: 0,
	updateUVs: function () {
		var width = this.regionU2 - this.regionU, height = this.regionV2 - this.regionV;
		var n = this.regionUVs.length;
		if (!this.uvs || this.uvs.length != n) {
            this.uvs = new spine.Float32Array(n);
		}
		if (this.regionRotate) {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i + 1] * width;
                this.uvs[i + 1] = this.regionV + height - this.regionUVs[i] * height;
			}
		} else {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i] * width;
                this.uvs[i + 1] = this.regionV + this.regionUVs[i + 1] * height;
			}
		}
	},
	computeWorldVertices: function (x, y, slot, worldVertices) {
		var bone = slot.bone;
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var vertices = this.vertices;
		var verticesCount = vertices.length;
		if (slot.attachmentVertices.length == verticesCount) vertices = slot.attachmentVertices;
		for (var i = 0; i < verticesCount; i += 2) {
			var vx = vertices[i];
			var vy = vertices[i + 1];
			worldVertices[i] = vx * m00 + vy * m01 + x;
			worldVertices[i + 1] = vx * m10 + vy * m11 + y;
		}
	}
};

spine.SkinnedMeshAttachment = function (name) {
	this.name = name;
};
spine.SkinnedMeshAttachment.prototype = {
	type: spine.AttachmentType.skinnedmesh,
	bones: null,
	weights: null,
	uvs: null,
	regionUVs: null,
	triangles: null,
	hullLength: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionU: 0, regionV: 0, regionU2: 0, regionV2: 0, regionRotate: false,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	edges: null,
	width: 0, height: 0,
	updateUVs: function (u, v, u2, v2, rotate) {
		var width = this.regionU2 - this.regionU, height = this.regionV2 - this.regionV;
		var n = this.regionUVs.length;
		if (!this.uvs || this.uvs.length != n) {
            this.uvs = new spine.Float32Array(n);
		}
		if (this.regionRotate) {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i + 1] * width;
                this.uvs[i + 1] = this.regionV + height - this.regionUVs[i] * height;
			}
		} else {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i] * width;
                this.uvs[i + 1] = this.regionV + this.regionUVs[i + 1] * height;
			}
		}
	},
	computeWorldVertices: function (x, y, slot, worldVertices) {
		var skeletonBones = slot.bone.skeleton.bones;
		var weights = this.weights;
		var bones = this.bones;

		var w = 0, v = 0, b = 0, f = 0, n = bones.length, nn;
		var wx, wy, bone, vx, vy, weight;
		if (!slot.attachmentVertices.length) {
			for (; v < n; w += 2) {
				wx = 0;
				wy = 0;
				nn = bones[v++] + v;
				for (; v < nn; v++, b += 3) {
					bone = skeletonBones[bones[v]];
					vx = weights[b];
					vy = weights[b + 1];
					weight = weights[b + 2];
					wx += (vx * bone.m00 + vy * bone.m01 + bone.worldX) * weight;
					wy += (vx * bone.m10 + vy * bone.m11 + bone.worldY) * weight;
				}
				worldVertices[w] = wx + x;
				worldVertices[w + 1] = wy + y;
			}
		} else {
			var ffd = slot.attachmentVertices;
			for (; v < n; w += 2) {
				wx = 0;
				wy = 0;
				nn = bones[v++] + v;
				for (; v < nn; v++, b += 3, f += 2) {
					bone = skeletonBones[bones[v]];
					vx = weights[b] + ffd[f];
					vy = weights[b + 1] + ffd[f + 1];
					weight = weights[b + 2];
					wx += (vx * bone.m00 + vy * bone.m01 + bone.worldX) * weight;
					wy += (vx * bone.m10 + vy * bone.m11 + bone.worldY) * weight;
				}
				worldVertices[w] = wx + x;
				worldVertices[w + 1] = wy + y;
			}
		}
	}
};

spine.BoundingBoxAttachment = function (name) {
	this.name = name;
	this.vertices = [];
};
spine.BoundingBoxAttachment.prototype = {
	type: spine.AttachmentType.boundingbox,
	computeWorldVertices: function (x, y, bone, worldVertices) {
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var vertices = this.vertices;
		for (var i = 0, n = vertices.length; i < n; i += 2) {
			var px = vertices[i];
			var py = vertices[i + 1];
			worldVertices[i] = px * m00 + py * m01 + x;
			worldVertices[i + 1] = px * m10 + py * m11 + y;
		}
	}
};

spine.AnimationStateData = function (skeletonData) {
	this.skeletonData = skeletonData;
	this.animationToMixTime = {};
};
spine.AnimationStateData.prototype = {
	defaultMix: 0,
	setMixByName: function (fromName, toName, duration) {
		var from = this.skeletonData.findAnimation(fromName);
		if (!from) throw "Animation not found: " + fromName;
		var to = this.skeletonData.findAnimation(toName);
		if (!to) throw "Animation not found: " + toName;
		this.setMix(from, to, duration);
	},
	setMix: function (from, to, duration) {
		this.animationToMixTime[from.name + ":" + to.name] = duration;
	},
	getMix: function (from, to) {
		var key = from.name + ":" + to.name;
		return this.animationToMixTime.hasOwnProperty(key) ? this.animationToMixTime[key] : this.defaultMix;
	}
};

spine.TrackEntry = function () {};
spine.TrackEntry.prototype = {
	next: null, previous: null,
	animation: null,
	loop: false,
	delay: 0, time: 0, lastTime: -1, endTime: 0,
	timeScale: 1,
	mixTime: 0, mixDuration: 0, mix: 1,
	onStart: null, onEnd: null, onComplete: null, onEvent: null
};

spine.AnimationState = function (stateData) {
	this.data = stateData;
	this.tracks = [];
	this.events = [];
};
spine.AnimationState.prototype = {
	onStart: null,
	onEnd: null,
	onComplete: null,
	onEvent: null,
	timeScale: 1,
	update: function (delta) {
		delta *= this.timeScale;
		for (var i = 0; i < this.tracks.length; i++) {
			var current = this.tracks[i];
			if (!current) continue;

			current.time += delta * current.timeScale;
			if (current.previous) {
				var previousDelta = delta * current.previous.timeScale;
				current.previous.time += previousDelta;
				current.mixTime += previousDelta;
			}

			var next = current.next;
			if (next) {
				next.time = current.lastTime - next.delay;
				if (next.time >= 0) this.setCurrent(i, next);
			} else {
				// End non-looping animation when it reaches its end time and there is no next entry.
				if (!current.loop && current.lastTime >= current.endTime) this.clearTrack(i);
			}
		}
	},
	apply: function (skeleton) {
		for (var i = 0; i < this.tracks.length; i++) {
			var current = this.tracks[i];
			if (!current) continue;

			this.events.length = 0;

			var time = current.time;
			var lastTime = current.lastTime;
			var endTime = current.endTime;
			var loop = current.loop;
			if (!loop && time > endTime) time = endTime;

			var previous = current.previous;
			if (!previous) {
				if (current.mix == 1)
					current.animation.apply(skeleton, current.lastTime, time, loop, this.events);
				else
					current.animation.mix(skeleton, current.lastTime, time, loop, this.events, current.mix);
			} else {
				var previousTime = previous.time;
				if (!previous.loop && previousTime > previous.endTime) previousTime = previous.endTime;
				previous.animation.apply(skeleton, previousTime, previousTime, previous.loop, null);

				var alpha = current.mixTime / current.mixDuration * current.mix;
				if (alpha >= 1) {
					alpha = 1;
					current.previous = null;
				}
				current.animation.mix(skeleton, current.lastTime, time, loop, this.events, alpha);
			}

			for (var ii = 0, nn = this.events.length; ii < nn; ii++) {
				var event = this.events[ii];
				if (current.onEvent) current.onEvent(i, event);
				if (this.onEvent) this.onEvent(i, event);
			}

			// Check if completed the animation or a loop iteration.
			if (loop ? (lastTime % endTime > time % endTime) : (lastTime < endTime && time >= endTime)) {
				var count = Math.floor(time / endTime);
				if (current.onComplete) current.onComplete(i, count);
				if (this.onComplete) this.onComplete(i, count);
			}

			current.lastTime = current.time;
		}
	},
	clearTracks: function () {
		for (var i = 0, n = this.tracks.length; i < n; i++)
			this.clearTrack(i);
		this.tracks.length = 0; 
	},
	clearTrack: function (trackIndex) {
		if (trackIndex >= this.tracks.length) return;
		var current = this.tracks[trackIndex];
		if (!current) return;

		if (current.onEnd) current.onEnd(trackIndex);
		if (this.onEnd) this.onEnd(trackIndex);

		this.tracks[trackIndex] = null;
	},
	_expandToIndex: function (index) {
		if (index < this.tracks.length) return this.tracks[index];
		while (index >= this.tracks.length)
			this.tracks.push(null);
		return null;
	},
	setCurrent: function (index, entry) {
		var current = this._expandToIndex(index);
		if (current) {
			var previous = current.previous;
			current.previous = null;

			if (current.onEnd) current.onEnd(index);
			if (this.onEnd) this.onEnd(index);

			entry.mixDuration = this.data.getMix(current.animation, entry.animation);
			if (entry.mixDuration > 0) {
				entry.mixTime = 0;
				// If a mix is in progress, mix from the closest animation.
				if (previous && current.mixTime / current.mixDuration < 0.5)
					entry.previous = previous;
				else
					entry.previous = current;
			}
		}

		this.tracks[index] = entry;

		if (entry.onStart) entry.onStart(index);
		if (this.onStart) this.onStart(index);
	},
	setAnimationByName: function (trackIndex, animationName, loop) {
		var animation = this.data.skeletonData.findAnimation(animationName);
		if (!animation) throw "Animation not found: " + animationName;
		return this.setAnimation(trackIndex, animation, loop);
	},
	/** Set the current animation. Any queued animations are cleared. */
	setAnimation: function (trackIndex, animation, loop) {
		var entry = new spine.TrackEntry();
		entry.animation = animation;
		entry.loop = loop;
		entry.endTime = animation.duration;
		this.setCurrent(trackIndex, entry);
		return entry;
	},
	addAnimationByName: function (trackIndex, animationName, loop, delay) {
		var animation = this.data.skeletonData.findAnimation(animationName);
		if (!animation) throw "Animation not found: " + animationName;
		return this.addAnimation(trackIndex, animation, loop, delay);
	},
	/** Adds an animation to be played delay seconds after the current or last queued animation.
	 * @param delay May be <= 0 to use duration of previous animation minus any mix duration plus the negative delay. */
	addAnimation: function (trackIndex, animation, loop, delay) {
		var entry = new spine.TrackEntry();
		entry.animation = animation;
		entry.loop = loop;
		entry.endTime = animation.duration;

		var last = this._expandToIndex(trackIndex);
		if (last) {
			while (last.next)
				last = last.next;
			last.next = entry;
		} else
			this.tracks[trackIndex] = entry;

		if (delay <= 0) {
			if (last)
				delay += last.endTime - this.data.getMix(last.animation, animation);
			else
				delay = 0;
		}
		entry.delay = delay;

		return entry;
	},
	/** May be null. */
	getCurrent: function (trackIndex) {
		if (trackIndex >= this.tracks.length) return null;
		return this.tracks[trackIndex];
	}
};

spine.SkeletonJson = function (attachmentLoader) {
	this.attachmentLoader = attachmentLoader;
};
spine.SkeletonJson.prototype = {
	scale: 1,
	readSkeletonData: function (root, name) {
		var skeletonData = new spine.SkeletonData();
		skeletonData.name = name;

		// Skeleton.
		var skeletonMap = root["skeleton"];
		if (skeletonMap) {
			skeletonData.hash = skeletonMap["hash"];
			skeletonData.version = skeletonMap["spine"];
			skeletonData.width = skeletonMap["width"] || 0;
			skeletonData.height = skeletonMap["height"] || 0;
		}

		// Bones.
		var bones = root["bones"];
		for (var i = 0, n = bones.length; i < n; i++) {
			var boneMap = bones[i];
			var parent = null;
			if (boneMap["parent"]) {
				parent = skeletonData.findBone(boneMap["parent"]);
				if (!parent) throw "Parent bone not found: " + boneMap["parent"];
			}
			var boneData = new spine.BoneData(boneMap["name"], parent);
			boneData.length = (boneMap["length"] || 0) * this.scale;
			boneData.x = (boneMap["x"] || 0) * this.scale;
			boneData.y = (boneMap["y"] || 0) * this.scale;
			boneData.rotation = (boneMap["rotation"] || 0);
			boneData.scaleX = boneMap.hasOwnProperty("scaleX") ? boneMap["scaleX"] : 1;
			boneData.scaleY = boneMap.hasOwnProperty("scaleY") ? boneMap["scaleY"] : 1;
			boneData.inheritScale = boneMap.hasOwnProperty("inheritScale") ? boneMap["inheritScale"] : true;
			boneData.inheritRotation = boneMap.hasOwnProperty("inheritRotation") ? boneMap["inheritRotation"] : true;
			skeletonData.bones.push(boneData);
		}

		// IK constraints.
		var ik = root["ik"];
		if (ik) {
			for (var i = 0, n = ik.length; i < n; i++) {
				var ikMap = ik[i];
				var ikConstraintData = new spine.IkConstraintData(ikMap["name"]);

				var bones = ikMap["bones"];
				for (var ii = 0, nn = bones.length; ii < nn; ii++) {
					var bone = skeletonData.findBone(bones[ii]);
					if (!bone) throw "IK bone not found: " + bones[ii];
					ikConstraintData.bones.push(bone);
				}

				ikConstraintData.target = skeletonData.findBone(ikMap["target"]);
				if (!ikConstraintData.target) throw "Target bone not found: " + ikMap["target"];

				ikConstraintData.bendDirection = (!ikMap.hasOwnProperty("bendPositive") || ikMap["bendPositive"]) ? 1 : -1;
				ikConstraintData.mix = ikMap.hasOwnProperty("mix") ? ikMap["mix"] : 1;

				skeletonData.ikConstraints.push(ikConstraintData);
			}
		}

		// Slots.
		var slots = root["slots"];
		for (var i = 0, n = slots.length; i < n; i++) {
			var slotMap = slots[i];
			var boneData = skeletonData.findBone(slotMap["bone"]);
			if (!boneData) throw "Slot bone not found: " + slotMap["bone"];
			var slotData = new spine.SlotData(slotMap["name"], boneData);

			var color = slotMap["color"];
			if (color) {
				slotData.r = this.toColor(color, 0);
				slotData.g = this.toColor(color, 1);
				slotData.b = this.toColor(color, 2);
				slotData.a = this.toColor(color, 3);
			}

			slotData.attachmentName = slotMap["attachment"];
			slotData.blendMode = spine.BlendMode[slotMap["blend"] || "normal"];

			skeletonData.slots.push(slotData);
		}

		// Skins.
		var skins = root["skins"];
		for (var skinName in skins) {
			if (!skins.hasOwnProperty(skinName)) continue;
			var skinMap = skins[skinName];
			var skin = new spine.Skin(skinName);
			for (var slotName in skinMap) {
				if (!skinMap.hasOwnProperty(slotName)) continue;
				var slotIndex = skeletonData.findSlotIndex(slotName);
				var slotEntry = skinMap[slotName];
				for (var attachmentName in slotEntry) {
					if (!slotEntry.hasOwnProperty(attachmentName)) continue;
					var attachment = this.readAttachment(skin, attachmentName, slotEntry[attachmentName]);
					if (attachment) skin.addAttachment(slotIndex, attachmentName, attachment);
				}
			}
			skeletonData.skins.push(skin);
			if (skin.name == "default") skeletonData.defaultSkin = skin;
		}

		// Events.
		var events = root["events"];
		for (var eventName in events) {
			if (!events.hasOwnProperty(eventName)) continue;
			var eventMap = events[eventName];
			var eventData = new spine.EventData(eventName);
			eventData.intValue = eventMap["int"] || 0;
			eventData.floatValue = eventMap["float"] || 0;
			eventData.stringValue = eventMap["string"] || null;
			skeletonData.events.push(eventData);
		}

		// Animations.
		var animations = root["animations"];
		for (var animationName in animations) {
			if (!animations.hasOwnProperty(animationName)) continue;
			this.readAnimation(animationName, animations[animationName], skeletonData);
		}

		return skeletonData;
	},
	readAttachment: function (skin, name, map) {
		name = map["name"] || name;

		var type = spine.AttachmentType[map["type"] || "region"];
		var path = map["path"] || name;
		
		var scale = this.scale;
		if (type == spine.AttachmentType.region) {
			var region = this.attachmentLoader.newRegionAttachment(skin, name, path);
			if (!region) return null;
			region.path = path;
			region.x = (map["x"] || 0) * scale;
			region.y = (map["y"] || 0) * scale;
			region.scaleX = map.hasOwnProperty("scaleX") ? map["scaleX"] : 1;
			region.scaleY = map.hasOwnProperty("scaleY") ? map["scaleY"] : 1;
			region.rotation = map["rotation"] || 0;
			region.width = (map["width"] || 0) * scale;
			region.height = (map["height"] || 0) * scale;

			var color = map["color"];
			if (color) {
				region.r = this.toColor(color, 0);
				region.g = this.toColor(color, 1);
				region.b = this.toColor(color, 2);
				region.a = this.toColor(color, 3);
			}

			region.updateOffset();
			return region;
		} else if (type == spine.AttachmentType.mesh) {
			var mesh = this.attachmentLoader.newMeshAttachment(skin, name, path);
			if (!mesh) return null;
			mesh.path = path; 
			mesh.vertices = this.getFloatArray(map, "vertices", scale);
			mesh.triangles = this.getIntArray(map, "triangles");
			mesh.regionUVs = this.getFloatArray(map, "uvs", 1);
			mesh.updateUVs();

			color = map["color"];
			if (color) {
				mesh.r = this.toColor(color, 0);
				mesh.g = this.toColor(color, 1);
				mesh.b = this.toColor(color, 2);
				mesh.a = this.toColor(color, 3);
			}

			mesh.hullLength = (map["hull"] || 0) * 2;
			if (map["edges"]) mesh.edges = this.getIntArray(map, "edges");
			mesh.width = (map["width"] || 0) * scale;
			mesh.height = (map["height"] || 0) * scale;
			return mesh;
		} else if (type == spine.AttachmentType.skinnedmesh) {
			var mesh = this.attachmentLoader.newSkinnedMeshAttachment(skin, name, path);
			if (!mesh) return null;
			mesh.path = path;

			var uvs = this.getFloatArray(map, "uvs", 1);
			var vertices = this.getFloatArray(map, "vertices", 1);
			var weights = [];
			var bones = [];
			for (var i = 0, n = vertices.length; i < n; ) {
				var boneCount = vertices[i++] | 0;
				bones[bones.length] = boneCount;
				for (var nn = i + boneCount * 4; i < nn; ) {
					bones[bones.length] = vertices[i];
					weights[weights.length] = vertices[i + 1] * scale;
					weights[weights.length] = vertices[i + 2] * scale;
					weights[weights.length] = vertices[i + 3];
					i += 4;
				}
			}
			mesh.bones = bones;
			mesh.weights = weights;
			mesh.triangles = this.getIntArray(map, "triangles");
			mesh.regionUVs = uvs;
			mesh.updateUVs();
			
			color = map["color"];
			if (color) {
				mesh.r = this.toColor(color, 0);
				mesh.g = this.toColor(color, 1);
				mesh.b = this.toColor(color, 2);
				mesh.a = this.toColor(color, 3);
			}
			
			mesh.hullLength = (map["hull"] || 0) * 2;
			if (map["edges"]) mesh.edges = this.getIntArray(map, "edges");
			mesh.width = (map["width"] || 0) * scale;
			mesh.height = (map["height"] || 0) * scale;
			return mesh;
		} else if (type == spine.AttachmentType.boundingbox) {
			var attachment = this.attachmentLoader.newBoundingBoxAttachment(skin, name);
			var vertices = map["vertices"];
			for (var i = 0, n = vertices.length; i < n; i++)
				attachment.vertices.push(vertices[i] * scale);
			return attachment;
		}
		throw "Unknown attachment type: " + type;
	},
	readAnimation: function (name, map, skeletonData) {
		var timelines = [];
		var duration = 0;

		var slots = map["slots"];
		for (var slotName in slots) {
			if (!slots.hasOwnProperty(slotName)) continue;
			var slotMap = slots[slotName];
			var slotIndex = skeletonData.findSlotIndex(slotName);

			for (var timelineName in slotMap) {
				if (!slotMap.hasOwnProperty(timelineName)) continue;
				var values = slotMap[timelineName];
				if (timelineName == "color") {
					var timeline = new spine.ColorTimeline(values.length);
					timeline.slotIndex = slotIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var color = valueMap["color"];
						var r = this.toColor(color, 0);
						var g = this.toColor(color, 1);
						var b = this.toColor(color, 2);
						var a = this.toColor(color, 3);
						timeline.setFrame(frameIndex, valueMap["time"], r, g, b, a);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 5 - 5]);

				} else if (timelineName == "attachment") {
					var timeline = new spine.AttachmentTimeline(values.length);
					timeline.slotIndex = slotIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex++, valueMap["time"], valueMap["name"]);
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);

				} else
					throw "Invalid timeline type for a slot: " + timelineName + " (" + slotName + ")";
			}
		}

		var bones = map["bones"];
		for (var boneName in bones) {
			if (!bones.hasOwnProperty(boneName)) continue;
			var boneIndex = skeletonData.findBoneIndex(boneName);
			if (boneIndex == -1) throw "Bone not found: " + boneName;
			var boneMap = bones[boneName];

			for (var timelineName in boneMap) {
				if (!boneMap.hasOwnProperty(timelineName)) continue;
				var values = boneMap[timelineName];
				if (timelineName == "rotate") {
					var timeline = new spine.RotateTimeline(values.length);
					timeline.boneIndex = boneIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex, valueMap["time"], valueMap["angle"]);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 2 - 2]);

				} else if (timelineName == "translate" || timelineName == "scale") {
					var timeline;
					var timelineScale = 1;
					if (timelineName == "scale")
						timeline = new spine.ScaleTimeline(values.length);
					else {
						timeline = new spine.TranslateTimeline(values.length);
						timelineScale = this.scale;
					}
					timeline.boneIndex = boneIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var x = (valueMap["x"] || 0) * timelineScale;
						var y = (valueMap["y"] || 0) * timelineScale;
						timeline.setFrame(frameIndex, valueMap["time"], x, y);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 3 - 3]);

				} else if (timelineName == "flipX" || timelineName == "flipY") {
					var x = timelineName == "flipX";
					var timeline = x ? new spine.FlipXTimeline(values.length) : new spine.FlipYTimeline(values.length);
					timeline.boneIndex = boneIndex;

					var field = x ? "x" : "y";
					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex, valueMap["time"], valueMap[field] || false);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 2 - 2]);
				} else
					throw "Invalid timeline type for a bone: " + timelineName + " (" + boneName + ")";
			}
		}

		var ikMap = map["ik"];
		for (var ikConstraintName in ikMap) {
			if (!ikMap.hasOwnProperty(ikConstraintName)) continue;
			var ikConstraint = skeletonData.findIkConstraint(ikConstraintName);
			var values = ikMap[ikConstraintName];
			var timeline = new spine.IkConstraintTimeline(values.length);
			timeline.ikConstraintIndex = skeletonData.ikConstraints.indexOf(ikConstraint);
			var frameIndex = 0;
			for (var i = 0, n = values.length; i < n; i++) {
				var valueMap = values[i];
				var mix = valueMap.hasOwnProperty("mix") ? valueMap["mix"] : 1;
				var bendDirection = (!valueMap.hasOwnProperty("bendPositive") || valueMap["bendPositive"]) ? 1 : -1;
				timeline.setFrame(frameIndex, valueMap["time"], mix, bendDirection);
				this.readCurve(timeline, frameIndex, valueMap);
				frameIndex++;
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.frameCount * 3 - 3]);
		}

		var ffd = map["ffd"];
		for (var skinName in ffd) {
			var skin = skeletonData.findSkin(skinName);
			var slotMap = ffd[skinName];
			for (slotName in slotMap) {
				var slotIndex = skeletonData.findSlotIndex(slotName);
				var meshMap = slotMap[slotName];
				for (var meshName in meshMap) {
					var values = meshMap[meshName];
					var timeline = new spine.FfdTimeline(values.length);
					var attachment = skin.getAttachment(slotIndex, meshName);
					if (!attachment) throw "FFD attachment not found: " + meshName;
					timeline.slotIndex = slotIndex;
					timeline.attachment = attachment;
					
					var isMesh = attachment.type == spine.AttachmentType.mesh;
					var vertexCount;
					if (isMesh)
						vertexCount = attachment.vertices.length;
					else
						vertexCount = attachment.weights.length / 3 * 2;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var vertices;
						if (!valueMap["vertices"]) {
							if (isMesh)
								vertices = attachment.vertices;
							else {
								vertices = [];
								vertices.length = vertexCount;
							}
						} else {
							var verticesValue = valueMap["vertices"];
							var vertices = [];
							vertices.length = vertexCount;
							var start = valueMap["offset"] || 0;
							var nn = verticesValue.length;
							if (this.scale == 1) {
								for (var ii = 0; ii < nn; ii++)
									vertices[ii + start] = verticesValue[ii];
							} else {
								for (var ii = 0; ii < nn; ii++)
									vertices[ii + start] = verticesValue[ii] * this.scale;
							}
							if (isMesh) {
								var meshVertices = attachment.vertices;
								for (var ii = 0, nn = vertices.length; ii < nn; ii++)
									vertices[ii] += meshVertices[ii];
							}
						}
						
						timeline.setFrame(frameIndex, valueMap["time"], vertices);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines[timelines.length] = timeline;
					duration = Math.max(duration, timeline.frames[timeline.frameCount - 1]);
				}
			}
		}

		var drawOrderValues = map["drawOrder"];
		if (!drawOrderValues) drawOrderValues = map["draworder"];
		if (drawOrderValues) {
			var timeline = new spine.DrawOrderTimeline(drawOrderValues.length);
			var slotCount = skeletonData.slots.length;
			var frameIndex = 0;
			for (var i = 0, n = drawOrderValues.length; i < n; i++) {
				var drawOrderMap = drawOrderValues[i];
				var drawOrder = null;
				if (drawOrderMap["offsets"]) {
					drawOrder = [];
					drawOrder.length = slotCount;
					for (var ii = slotCount - 1; ii >= 0; ii--)
						drawOrder[ii] = -1;
					var offsets = drawOrderMap["offsets"];
					var unchanged = [];
					unchanged.length = slotCount - offsets.length;
					var originalIndex = 0, unchangedIndex = 0;
					for (var ii = 0, nn = offsets.length; ii < nn; ii++) {
						var offsetMap = offsets[ii];
						var slotIndex = skeletonData.findSlotIndex(offsetMap["slot"]);
						if (slotIndex == -1) throw "Slot not found: " + offsetMap["slot"];
						// Collect unchanged items.
						while (originalIndex != slotIndex)
							unchanged[unchangedIndex++] = originalIndex++;
						// Set changed items.
						drawOrder[originalIndex + offsetMap["offset"]] = originalIndex++;
					}
					// Collect remaining unchanged items.
					while (originalIndex < slotCount)
						unchanged[unchangedIndex++] = originalIndex++;
					// Fill in unchanged items.
					for (var ii = slotCount - 1; ii >= 0; ii--)
						if (drawOrder[ii] == -1) drawOrder[ii] = unchanged[--unchangedIndex];
				}
				timeline.setFrame(frameIndex++, drawOrderMap["time"], drawOrder);
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);
		}

		var events = map["events"];
		if (events) {
			var timeline = new spine.EventTimeline(events.length);
			var frameIndex = 0;
			for (var i = 0, n = events.length; i < n; i++) {
				var eventMap = events[i];
				var eventData = skeletonData.findEvent(eventMap["name"]);
				if (!eventData) throw "Event not found: " + eventMap["name"];
				var event = new spine.Event(eventData);
				event.intValue = eventMap.hasOwnProperty("int") ? eventMap["int"] : eventData.intValue;
				event.floatValue = eventMap.hasOwnProperty("float") ? eventMap["float"] : eventData.floatValue;
				event.stringValue = eventMap.hasOwnProperty("string") ? eventMap["string"] : eventData.stringValue;
				timeline.setFrame(frameIndex++, eventMap["time"], event);
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);
		}

		skeletonData.animations.push(new spine.Animation(name, timelines, duration));
	},
	readCurve: function (timeline, frameIndex, valueMap) {
		var curve = valueMap["curve"];
		if (!curve) 
			timeline.curves.setLinear(frameIndex);
		else if (curve == "stepped")
			timeline.curves.setStepped(frameIndex);
		else if (curve instanceof Array)
			timeline.curves.setCurve(frameIndex, curve[0], curve[1], curve[2], curve[3]);
	},
	toColor: function (hexString, colorIndex) {
		if (hexString.length != 8) throw "Color hexidecimal length must be 8, recieved: " + hexString;
		return parseInt(hexString.substring(colorIndex * 2, (colorIndex * 2) + 2), 16) / 255;
	},
	getFloatArray: function (map, name, scale) {
		var list = map[name];
		var values = new spine.Float32Array(list.length);
		var i = 0, n = list.length;
		if (scale == 1) {
			for (; i < n; i++)
				values[i] = list[i];
		} else {
			for (; i < n; i++)
				values[i] = list[i] * scale;
		}
		return values;
	},
	getIntArray: function (map, name) {
		var list = map[name];
		var values = new spine.Uint16Array(list.length);
		for (var i = 0, n = list.length; i < n; i++)
			values[i] = list[i] | 0;
		return values;
	}
};

spine.Atlas = function (atlasText, textureLoader) {
	this.textureLoader = textureLoader;
	this.pages = [];
	this.regions = [];

	var reader = new spine.AtlasReader(atlasText);
	var tuple = [];
	tuple.length = 4;
	var page = null;
	while (true) {
		var line = reader.readLine();
		if (line === null) break;
		line = reader.trim(line);
		if (!line.length)
			page = null;
		else if (!page) {
			page = new spine.AtlasPage();
			page.name = line;

			if (reader.readTuple(tuple) == 2) { // size is only optional for an atlas packed with an old TexturePacker.
				page.width = parseInt(tuple[0]);
				page.height = parseInt(tuple[1]);
				reader.readTuple(tuple);
			}
			page.format = spine.Atlas.Format[tuple[0]];

			reader.readTuple(tuple);
			page.minFilter = spine.Atlas.TextureFilter[tuple[0]];
			page.magFilter = spine.Atlas.TextureFilter[tuple[1]];

			var direction = reader.readValue();
			page.uWrap = spine.Atlas.TextureWrap.clampToEdge;
			page.vWrap = spine.Atlas.TextureWrap.clampToEdge;
			if (direction == "x")
				page.uWrap = spine.Atlas.TextureWrap.repeat;
			else if (direction == "y")
				page.vWrap = spine.Atlas.TextureWrap.repeat;
			else if (direction == "xy")
				page.uWrap = page.vWrap = spine.Atlas.TextureWrap.repeat;

			textureLoader.load(page, line, this);

			this.pages.push(page);

		} else {
			var region = new spine.AtlasRegion();
			region.name = line;
			region.page = page;

			region.rotate = reader.readValue() == "true";

			reader.readTuple(tuple);
			var x = parseInt(tuple[0]);
			var y = parseInt(tuple[1]);

			reader.readTuple(tuple);
			var width = parseInt(tuple[0]);
			var height = parseInt(tuple[1]);

			region.u = x / page.width;
			region.v = y / page.height;
			if (region.rotate) {
				region.u2 = (x + height) / page.width;
				region.v2 = (y + width) / page.height;
			} else {
				region.u2 = (x + width) / page.width;
				region.v2 = (y + height) / page.height;
			}
			region.x = x;
			region.y = y;
			region.width = Math.abs(width);
			region.height = Math.abs(height);

			if (reader.readTuple(tuple) == 4) { // split is optional
				region.splits = [parseInt(tuple[0]), parseInt(tuple[1]), parseInt(tuple[2]), parseInt(tuple[3])];

				if (reader.readTuple(tuple) == 4) { // pad is optional, but only present with splits
					region.pads = [parseInt(tuple[0]), parseInt(tuple[1]), parseInt(tuple[2]), parseInt(tuple[3])];

					reader.readTuple(tuple);
				}
			}

			region.originalWidth = parseInt(tuple[0]);
			region.originalHeight = parseInt(tuple[1]);

			reader.readTuple(tuple);
			region.offsetX = parseInt(tuple[0]);
			region.offsetY = parseInt(tuple[1]);

			region.index = parseInt(reader.readValue());

			this.regions.push(region);
		}
	}
};
spine.Atlas.prototype = {
	findRegion: function (name) {
		var regions = this.regions;
		for (var i = 0, n = regions.length; i < n; i++)
			if (regions[i].name == name) return regions[i];
		return null;
	},
	dispose: function () {
		var pages = this.pages;
		for (var i = 0, n = pages.length; i < n; i++)
			this.textureLoader.unload(pages[i].rendererObject);
	},
	updateUVs: function (page) {
		var regions = this.regions;
		for (var i = 0, n = regions.length; i < n; i++) {
			var region = regions[i];
			if (region.page != page) continue;
			region.u = region.x / page.width;
			region.v = region.y / page.height;
			if (region.rotate) {
				region.u2 = (region.x + region.height) / page.width;
				region.v2 = (region.y + region.width) / page.height;
			} else {
				region.u2 = (region.x + region.width) / page.width;
				region.v2 = (region.y + region.height) / page.height;
			}
		}
	}
};

spine.Atlas.Format = {
	alpha: 0,
	intensity: 1,
	luminanceAlpha: 2,
	rgb565: 3,
	rgba4444: 4,
	rgb888: 5,
	rgba8888: 6
};

spine.Atlas.TextureFilter = {
	nearest: 0,
	linear: 1,
	mipMap: 2,
	mipMapNearestNearest: 3,
	mipMapLinearNearest: 4,
	mipMapNearestLinear: 5,
	mipMapLinearLinear: 6
};

spine.Atlas.TextureWrap = {
	mirroredRepeat: 0,
	clampToEdge: 1,
	repeat: 2
};

spine.AtlasPage = function () {};
spine.AtlasPage.prototype = {
	name: null,
	format: null,
	minFilter: null,
	magFilter: null,
	uWrap: null,
	vWrap: null,
	rendererObject: null,
	width: 0,
	height: 0
};

spine.AtlasRegion = function () {};
spine.AtlasRegion.prototype = {
	page: null,
	name: null,
	x: 0, y: 0,
	width: 0, height: 0,
	u: 0, v: 0, u2: 0, v2: 0,
	offsetX: 0, offsetY: 0,
	originalWidth: 0, originalHeight: 0,
	index: 0,
	rotate: false,
	splits: null,
	pads: null
};

spine.AtlasReader = function (text) {
	this.lines = text.split(/\r\n|\r|\n/);
};
spine.AtlasReader.prototype = {
	index: 0,
	trim: function (value) {
		return value.replace(/^\s+|\s+$/g, "");
	},
	readLine: function () {
		if (this.index >= this.lines.length) return null;
		return this.lines[this.index++];
	},
	readValue: function () {
		var line = this.readLine();
		var colon = line.indexOf(":");
		if (colon == -1) throw "Invalid line: " + line;
		return this.trim(line.substring(colon + 1));
	},
	/** Returns the number of tuple values read (1, 2 or 4). */
	readTuple: function (tuple) {
		var line = this.readLine();
		var colon = line.indexOf(":");
		if (colon == -1) throw "Invalid line: " + line;
		var i = 0, lastMatch = colon + 1;
		for (; i < 3; i++) {
			var comma = line.indexOf(",", lastMatch);
			if (comma == -1) break;
			tuple[i] = this.trim(line.substr(lastMatch, comma - lastMatch));
			lastMatch = comma + 1;
		}
		tuple[i] = this.trim(line.substring(lastMatch));
		return i + 1;
	}
};

spine.AtlasAttachmentLoader = function (atlas) {
	this.atlas = atlas;
};
spine.AtlasAttachmentLoader.prototype = {
	newRegionAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (region attachment: " + name + ")";
		var attachment = new spine.RegionAttachment(name);
		attachment.rendererObject = region;
		attachment.setUVs(region.u, region.v, region.u2, region.v2, region.rotate);
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newMeshAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (mesh attachment: " + name + ")";
		var attachment = new spine.MeshAttachment(name);
		attachment.rendererObject = region;
		attachment.regionU = region.u;
		attachment.regionV = region.v;
		attachment.regionU2 = region.u2;
		attachment.regionV2 = region.v2;
		attachment.regionRotate = region.rotate;
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newSkinnedMeshAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (skinned mesh attachment: " + name + ")";
		var attachment = new spine.SkinnedMeshAttachment(name);
		attachment.rendererObject = region;
		attachment.regionU = region.u;
		attachment.regionV = region.v;
		attachment.regionU2 = region.u2;
		attachment.regionV2 = region.v2;
		attachment.regionRotate = region.rotate;
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newBoundingBoxAttachment: function (skin, name) {
		return new spine.BoundingBoxAttachment(name);
	}
};

spine.SkeletonBounds = function () {
	this.polygonPool = [];
	this.polygons = [];
	this.boundingBoxes = [];
};
spine.SkeletonBounds.prototype = {
	minX: 0, minY: 0, maxX: 0, maxY: 0,
	update: function (skeleton, updateAabb) {
		var slots = skeleton.slots;
		var slotCount = slots.length;
		var x = skeleton.x, y = skeleton.y;
		var boundingBoxes = this.boundingBoxes;
		var polygonPool = this.polygonPool;
		var polygons = this.polygons;

		boundingBoxes.length = 0;
		for (var i = 0, n = polygons.length; i < n; i++)
			polygonPool.push(polygons[i]);
		polygons.length = 0;

		for (var i = 0; i < slotCount; i++) {
			var slot = slots[i];
			var boundingBox = slot.attachment;
			if (boundingBox.type != spine.AttachmentType.boundingbox) continue;
			boundingBoxes.push(boundingBox);

			var poolCount = polygonPool.length, polygon;
			if (poolCount > 0) {
				polygon = polygonPool[poolCount - 1];
				polygonPool.splice(poolCount - 1, 1);
			} else
				polygon = [];
			polygons.push(polygon);

			polygon.length = boundingBox.vertices.length;
			boundingBox.computeWorldVertices(x, y, slot.bone, polygon);
		}

		if (updateAabb) this.aabbCompute();
	},
	aabbCompute: function () {
		var polygons = this.polygons;
		var minX = Number.MAX_VALUE, minY = Number.MAX_VALUE, maxX = Number.MIN_VALUE, maxY = Number.MIN_VALUE;
		for (var i = 0, n = polygons.length; i < n; i++) {
			var vertices = polygons[i];
			for (var ii = 0, nn = vertices.length; ii < nn; ii += 2) {
				var x = vertices[ii];
				var y = vertices[ii + 1];
				minX = Math.min(minX, x);
				minY = Math.min(minY, y);
				maxX = Math.max(maxX, x);
				maxY = Math.max(maxY, y);
			}
		}
		this.minX = minX;
		this.minY = minY;
		this.maxX = maxX;
		this.maxY = maxY;
	},
	/** Returns true if the axis aligned bounding box contains the point. */
	aabbContainsPoint: function (x, y) {
		return x >= this.minX && x <= this.maxX && y >= this.minY && y <= this.maxY;
	},
	/** Returns true if the axis aligned bounding box intersects the line segment. */
	aabbIntersectsSegment: function (x1, y1, x2, y2) {
		var minX = this.minX, minY = this.minY, maxX = this.maxX, maxY = this.maxY;
		if ((x1 <= minX && x2 <= minX) || (y1 <= minY && y2 <= minY) || (x1 >= maxX && x2 >= maxX) || (y1 >= maxY && y2 >= maxY))
			return false;
		var m = (y2 - y1) / (x2 - x1);
		var y = m * (minX - x1) + y1;
		if (y > minY && y < maxY) return true;
		y = m * (maxX - x1) + y1;
		if (y > minY && y < maxY) return true;
		var x = (minY - y1) / m + x1;
		if (x > minX && x < maxX) return true;
		x = (maxY - y1) / m + x1;
		if (x > minX && x < maxX) return true;
		return false;
	},
	/** Returns true if the axis aligned bounding box intersects the axis aligned bounding box of the specified bounds. */
	aabbIntersectsSkeleton: function (bounds) {
		return this.minX < bounds.maxX && this.maxX > bounds.minX && this.minY < bounds.maxY && this.maxY > bounds.minY;
	},
	/** Returns the first bounding box attachment that contains the point, or null. When doing many checks, it is usually more
	 * efficient to only call this method if {@link #aabbContainsPoint(float, float)} returns true. */
	containsPoint: function (x, y) {
		var polygons = this.polygons;
		for (var i = 0, n = polygons.length; i < n; i++)
			if (this.polygonContainsPoint(polygons[i], x, y)) return this.boundingBoxes[i];
		return null;
	},
	/** Returns the first bounding box attachment that contains the line segment, or null. When doing many checks, it is usually
	 * more efficient to only call this method if {@link #aabbIntersectsSegment(float, float, float, float)} returns true. */
	intersectsSegment: function (x1, y1, x2, y2) {
		var polygons = this.polygons;
		for (var i = 0, n = polygons.length; i < n; i++)
			if (polygons[i].intersectsSegment(x1, y1, x2, y2)) return this.boundingBoxes[i];
		return null;
	},
	/** Returns true if the polygon contains the point. */
	polygonContainsPoint: function (polygon, x, y) {
		var nn = polygon.length;
		var prevIndex = nn - 2;
		var inside = false;
		for (var ii = 0; ii < nn; ii += 2) {
			var vertexY = polygon[ii + 1];
			var prevY = polygon[prevIndex + 1];
			if ((vertexY < y && prevY >= y) || (prevY < y && vertexY >= y)) {
				var vertexX = polygon[ii];
				if (vertexX + (y - vertexY) / (prevY - vertexY) * (polygon[prevIndex] - vertexX) < x) inside = !inside;
			}
			prevIndex = ii;
		}
		return inside;
	},
	/** Returns true if the polygon contains the line segment. */
	polygonIntersectsSegment: function (polygon, x1, y1, x2, y2) {
		var nn = polygon.length;
		var width12 = x1 - x2, height12 = y1 - y2;
		var det1 = x1 * y2 - y1 * x2;
		var x3 = polygon[nn - 2], y3 = polygon[nn - 1];
		for (var ii = 0; ii < nn; ii += 2) {
			var x4 = polygon[ii], y4 = polygon[ii + 1];
			var det2 = x3 * y4 - y3 * x4;
			var width34 = x3 - x4, height34 = y3 - y4;
			var det3 = width12 * height34 - height12 * width34;
			var x = (det1 * width34 - width12 * det2) / det3;
			if (((x >= x3 && x <= x4) || (x >= x4 && x <= x3)) && ((x >= x1 && x <= x2) || (x >= x2 && x <= x1))) {
				var y = (det1 * height34 - height12 * det2) / det3;
				if (((y >= y3 && y <= y4) || (y >= y4 && y <= y3)) && ((y >= y1 && y <= y2) || (y >= y2 && y <= y1))) return true;
			}
			x3 = x4;
			y3 = y4;
		}
		return false;
	},
	getPolygon: function (attachment) {
		var index = this.boundingBoxes.indexOf(attachment);
		return index == -1 ? null : this.polygons[index];
	},
	getWidth: function () {
		return this.maxX - this.minX;
	},
	getHeight: function () {
		return this.maxY - this.minY;
	}
};
var e,aa=document.getElementById("canvasBackground"),ba="big gameui_difficulty endscreen_difficulty levelselectscreen game_mahjong theme_ducklings coolmath final".split(" ");function f(a,b){var c=a.userAgent.match(b);return c&&1<c.length&&c[1]||""}
var m=new function(){this.userAgent=void 0;void 0===this.userAgent&&(this.userAgent=void 0!==navigator?navigator.userAgent:"");var a=f(this,/(ipod|iphone|ipad)/i).toLowerCase(),b=!/like android/i.test(this.userAgent)&&/android/i.test(this.userAgent),c=f(this,/version\/(\d+(\.\d+)?)/i),d=/tablet/i.test(this.userAgent),g=!d&&/[^-]mobi/i.test(this.userAgent);this.u={};this.La={};this.Ad={};/opera|opr/i.test(this.userAgent)?(this.name="Opera",this.u.opera=!0,this.u.version=c||f(this,/(?:opera|opr)[\s\/](\d+(\.\d+)?)/i)):
/windows phone/i.test(this.userAgent)?(this.name="Windows Phone",this.La.$o=!0,this.u.Xk=!0,this.u.version=f(this,/iemobile\/(\d+(\.\d+)?)/i)):/msie|trident/i.test(this.userAgent)?(this.name="Internet Explorer",this.u.Xk=!0,this.u.version=f(this,/(?:msie |rv:)(\d+(\.\d+)?)/i)):/chrome|crios|crmo/i.test(this.userAgent)?(this.name="Chrome",this.u.chrome=!0,this.u.version=f(this,/(?:chrome|crios|crmo)\/(\d+(\.\d+)?)/i)):a?(this.name="iphone"==a?"iPhone":"ipad"==a?"iPad":"iPod",c&&(this.u.version=c)):
/sailfish/i.test(this.userAgent)?(this.name="Sailfish",this.u.KA=!0,this.u.version=f(this,/sailfish\s?browser\/(\d+(\.\d+)?)/i)):/seamonkey\//i.test(this.userAgent)?(this.name="SeaMonkey",this.u.LA=!0,this.u.version=f(this,/seamonkey\/(\d+(\.\d+)?)/i)):/firefox|iceweasel/i.test(this.userAgent)?(this.name="Firefox",this.u.sq=!0,this.u.version=f(this,/(?:firefox|iceweasel)[ \/](\d+(\.\d+)?)/i),/\((mobile|tablet);[^\)]*rv:[\d\.]+\)/i.test(this.userAgent)&&(this.La.Mz=!0)):/silk/i.test(this.userAgent)?
(this.name="Amazon Silk",this.u.ps=!0,this.u.version=f(this,/silk\/(\d+(\.\d+)?)/i)):b?(this.name="Android",this.u.ah=!0,this.u.version=c):/phantom/i.test(this.userAgent)?(this.name="PhantomJS",this.u.tA=!0,this.u.version=f(this,/phantomjs\/(\d+(\.\d+)?)/i)):/blackberry|\bbb\d+/i.test(this.userAgent)||/rim\stablet/i.test(this.userAgent)?(this.name="BlackBerry",this.u.Kp=!0,this.u.version=c||f(this,/blackberry[\d]+\/(\d+(\.\d+)?)/i)):/(web|hpw)os/i.test(this.userAgent)?(this.name="WebOS",this.u.yt=
!0,this.u.version=c||f(this,/w(?:eb)?osbrowser\/(\d+(\.\d+)?)/i),/touchpad\//i.test(this.userAgent)&&(this.Ad.My=!0)):/bada/i.test(this.userAgent)?(this.name="Bada",this.u.Jp=!0,this.u.version=f(this,/dolfin\/(\d+(\.\d+)?)/i)):/tizen/i.test(this.userAgent)?(this.name="Tizen",this.u.Ky=!0,this.u.version=f(this,/(?:tizen\s?)?browser\/(\d+(\.\d+)?)/i)||c):/safari/i.test(this.userAgent)&&(this.name="Safari",this.u.qo=!0,this.u.version=c);/(apple)?webkit/i.test(this.userAgent)?(this.name=this.name||"Webkit",
this.u.aB=!0,!this.u.version&&c&&(this.u.version=c)):!this.opera&&/gecko\//i.test(this.userAgent)&&(this.name=this.name||"Gecko",this.u.Sz=!0,this.u.version=this.u.version||f(this,/gecko\/(\d+(\.\d+)?)/i));b||this.ps?this.La.kz=!0:a&&(this.La.Ek=!0);c="";a?(c=f(this,/os (\d+([_\s]\d+)*) like mac os x/i),c=c.replace(/[_\s]/g,".")):b?c=f(this,/android[ \/-](\d+(\.\d+)*)/i):this.$o?c=f(this,/windows phone (?:os)?\s?(\d+(\.\d+)*)/i):this.yt?c=f(this,/(?:web|hpw)os\/(\d+(\.\d+)*)/i):this.Kp?c=f(this,/rim\stablet\sos\s(\d+(\.\d+)*)/i):
this.Jp?c=f(this,/bada\/(\d+(\.\d+)*)/i):this.Ky&&(c=f(this,/tizen[\/\s](\d+(\.\d+)*)/i));c&&(this.La.version=c);c=c.split(".")[0];if(d||"ipad"==a||b&&(3==c||4==c&&!g)||this.ps)this.Ad.Mo=!0;else if(g||"iphone"==a||"ipod"==a||b||this.Kp||this.yt||this.Jp)this.Ad.Qn=!0;this.ve={Jh:!1,Sh:!1,x:!1};this.Xk&&10<=this.u.version||this.chrome&&20<=this.u.version||this.sq&&20<=this.u.version||this.qo&&6<=this.u.version||this.opera&&10<=this.u.version||this.Ek&&this.La.version&&6<=this.La.version.split(".")[0]?
this.ve.Jh=!0:this.Xk&&10>this.u.version||this.chrome&&20>this.u.version||this.sq&&20>this.u.version||this.qo&&6>this.u.version||this.opera&&10>this.u.version||this.Ek&&this.La.version&&6>this.La.version.split(".")[0]?this.ve.Sh=!0:this.ve.x=!0;try{this.u.he=this.u.version?parseFloat(this.u.version.match(/\d+(\.\d+)?/)[0],10):0}catch(h){this.u.he=0}try{this.La.he=this.La.version?parseFloat(this.La.version.match(/\d+(\.\d+)?/)[0],10):0}catch(k){this.La.he=0}};function p(a,b){this.x=a;this.y=b}e=p.prototype;
e.length=function(){return Math.sqrt(this.x*this.x+this.y*this.y)};e.dq=function(a){var b=this.x-a.x;a=this.y-a.y;return Math.sqrt(b*b+a*a)};e.K=function(){return new p(this.x,this.y)};e.add=function(a){return new p(this.x+a.x,this.y+a.y)};e.scale=function(a){return new p(a*this.x,a*this.y)};e.rotate=function(a){var b=Math.sin(a*Math.PI/180);a=Math.cos(a*Math.PI/180);return new p(a*this.x+b*this.y,-b*this.x+a*this.y)};
e.normalize=function(){var a=Math.sqrt(this.x*this.x+this.y*this.y);return 0===a?new p(0,0):new p(this.x/a,this.y/a)};function da(a){return(new p(a.y,-a.x)).normalize()}
e.dc=function(a,b,c){var d=Math.min(8,this.length()/4),g;g=this.normalize().scale(2*d);g=new p(this.x-g.x,this.y-g.y);var h=g.add(da(this).scale(d)),d=g.add(da(this).scale(-d)),k=r.context;k.strokeStyle=c;k.beginPath();k.moveTo(a,b);k.lineTo(a+g.x,b+g.y);k.lineTo(a+h.x,b+h.y);k.lineTo(a+this.x,b+this.y);k.lineTo(a+d.x,b+d.y);k.lineTo(a+g.x,b+g.y);k.stroke()};function ea(a){this.Ai=4294967296;this.Jh=1664525;this.Sh=1013904223;this.state=void 0===a?Math.floor(Math.random()*(this.Ai-1)):a}
ea.prototype.K=function(){var a=new ea;a.Ai=this.Ai;a.Jh=this.Jh;a.Sh=this.Sh;a.state=this.state;return a};ea.prototype.random=function(a){var b=1;void 0!==a&&(b=a);this.state=(this.Jh*this.state+this.Sh)%this.Ai;return this.state/this.Ai*b};new ea;function fa(){this.ke="";this.gm=[];this.Ih=[];this.Ne=[];this.bg=[];this.xc=[];this.sa("start");this.sa("load");this.sa("game")}function ga(a){var b=ha;b.ke=a;""!==b.ke&&"/"!==b.ke[b.ke.length-1]&&(b.ke+="/")}e=fa.prototype;
e.sa=function(a){this.xc[a]||(this.Ih[a]=0,this.Ne[a]=0,this.bg[a]=0,this.xc[a]=[],this.gm[a]=!1)};e.loaded=function(a){return this.xc[a]?this.Ne[a]:0};e.Gc=function(a){return this.xc[a]?this.bg[a]:0};e.complete=function(a){return this.xc[a]?this.Ne[a]+this.bg[a]===this.Ih[a]:!0};function ia(a){var b=ha;return b.xc[a]?100*(b.Ne[a]+b.bg[a])/b.Ih[a]:100}function ja(a){var b=ha;b.Ne[a]+=1;b.complete(a)&&ka("Load Complete",{Ua:a})}function la(a){var b=ha;b.bg[a]+=1;ka("Load Failed",{Ua:a})}
function ma(a,b,c){var d=ha;d.xc[b]||d.sa(b);d.xc[b].push(a);d.Ih[b]+=c}e.Fd=function(a){var b;if(!this.gm[a])if(this.gm[a]=!0,this.xc[a]&&0!==this.xc[a].length)for(b=0;b<this.xc[a].length;b+=1)this.xc[a][b].Fd(a,this.ke);else ka("Load Complete",{Ua:a})};var ha=new fa;function na(a){this.context=this.canvas=void 0;this.height=this.width=0;a&&this.jb(a)}na.prototype.jb=function(a){this.canvas=a;this.context=a.getContext("2d");this.width=a.width;this.height=a.height};
na.prototype.clear=function(){this.context.clearRect(0,0,this.width,this.height);this.context.beginPath();this.context.moveTo(0,0);this.context.lineTo(-1,-1);this.context.closePath();this.context.stroke()};
function oa(a,b,c,d,g,h){var k=r;k.context.save();!1===h?(k.context.fillStyle=g,k.context.fillRect(a,b,c,d)):!0===h?(k.context.strokeStyle=g,k.context.strokeRect(a,b,c,d)):(void 0!==g&&(k.context.fillStyle=g,k.context.fillRect(a,b,c,d)),void 0!==h&&(k.context.strokeStyle=h,k.context.strokeRect(a,b,c,d)));k.context.restore()}
function pa(a,b,c,d){var g=r;g.context.save();g.context.beginPath();g.context.moveTo(a,b);g.context.lineTo(c,d);g.context.lineWidth=1;g.context.strokeStyle="green";g.context.stroke();g.context.restore()}
na.prototype.jc=function(a,b,c,d,g,h,k){this.context.save();this.context.font=g;!1===h?(this.context.fillStyle=d,this.context.fillText(a,b,c)):!0===h?(this.context.strokeStyle=d,this.context.strokeText(a,b,c)):(void 0!==d&&(this.context.fillStyle=d,this.context.fillText(a,b,c)),void 0!==h&&(k&&(this.context.lineWidth=k),this.context.strokeStyle=h,this.context.strokeText(a,b,c)));this.context.restore()};na.prototype.ba=function(a,b){this.context.font=b;return this.context.measureText(a).width};
var r=new na(aa);function qa(a,b,c){this.name=a;this.F=b;this.yv=c;this.yc=[];this.Sm=[];ma(this,this.yv,this.F)}qa.prototype.Fd=function(a,b){function c(){la(a)}function d(){ja(a)}var g,h;for(g=0;g<this.yc.length;g+=1)h=this.Sm[g],0!==h.toLowerCase().indexOf("http:")&&0!==h.toLowerCase().indexOf("https:")&&(h=b+h),this.yc[g].src=h,this.yc[g].addEventListener("load",d,!1),this.yc[g].addEventListener("error",c,!1)};
qa.prototype.complete=function(){var a;for(a=0;a<this.yc.length;a+=1)if(!this.yc[a].complete||0===this.yc[a].width)return!1;return!0};function ra(a,b,c){0<=b&&b<a.F&&(a.yc[b]=new Image,a.Sm[b]=c)}qa.prototype.d=function(a,b){0<=a&&a<this.F&&(this.yc[a]=b,this.Sm[a]="")};qa.prototype.ka=function(a,b,c,d,g,h,k,l,n){this.yc[a]&&this.yc[a].complete&&(void 0===l&&(l=d),void 0===n&&(n=g),0>=d||0>=g||0!==Math.round(l)&&0!==Math.round(n)&&r.context.drawImage(this.yc[a],b,c,d,g,h,k,l,n))};
function x(a,b,c,d,g,h,k,l,n,q){this.name=a;this.Kd=b;this.F=c;this.width=d;this.height=g;this.Gb=h;this.Hb=k;this.Vh=l;this.ng=n;this.Pg=q;this.Gd=[];this.Hd=[];this.Id=[];this.Rc=[];this.Qc=[];this.od=[];this.pd=[]}e=x.prototype;e.d=function(a,b,c,d,g,h,k,l){0<=a&&a<this.F&&(this.Gd[a]=b,this.Hd[a]=c,this.Id[a]=d,this.Rc[a]=g,this.Qc[a]=h,this.od[a]=k,this.pd[a]=l)};e.complete=function(){return this.Kd.complete()};
e.o=function(a,b,c){a=(Math.round(a)%this.F+this.F)%this.F;this.Kd.ka(this.Gd[a],this.Hd[a],this.Id[a],this.Rc[a],this.Qc[a],b-this.Gb+this.od[a],c-this.Hb+this.pd[a])};e.bd=function(a,b,c,d){var g=r.context,h=g.globalAlpha;g.globalAlpha=d;a=(Math.round(a)%this.F+this.F)%this.F;this.Kd.ka(this.Gd[a],this.Hd[a],this.Id[a],this.Rc[a],this.Qc[a],b-this.Gb+this.od[a],c-this.Hb+this.pd[a]);g.globalAlpha=h};
e.za=function(a,b,c,d,g,h,k){var l=r.context;1E-4>Math.abs(d)||1E-4>Math.abs(g)||(a=(Math.round(a)%this.F+this.F)%this.F,l.save(),l.translate(b,c),l.rotate(-h*Math.PI/180),l.scale(d,g),l.globalAlpha=k,this.Kd.ka(this.Gd[a],this.Hd[a],this.Id[a],this.Rc[a],this.Qc[a],this.od[a]-this.Gb,this.pd[a]-this.Hb),l.restore())};
e.hq=function(a,b,c,d,g,h){var k=r.context,l=k.globalAlpha;0!==this.width&&0!==this.height&&(a=(Math.round(a)%this.F+this.F)%this.F,k.globalAlpha=h,d/=this.width,g/=this.height,this.Kd.ka(this.Gd[a],this.Hd[a],this.Id[a],this.Rc[a],this.Qc[a],b+d*this.od[a],c+g*this.pd[a],d*this.Rc[a],g*this.Qc[a]),k.globalAlpha=l)};
e.ka=function(a,b,c,d,g,h,k,l){var n=r.context,q=n.globalAlpha,w,A,E,s;a=(Math.round(a)%this.F+this.F)%this.F;w=this.od[a];A=this.pd[a];E=this.Rc[a];s=this.Qc[a];b-=w;c-=A;0>=b+d||0>=c+g||b>=E||c>=s||(0>b&&(d+=b,h-=b,b=0),0>c&&(g+=c,k-=c,c=0),b+d>E&&(d=E-b),c+g>s&&(g=s-c),n.globalAlpha=l,this.Kd.ka(this.Gd[a],this.Hd[a]+b,this.Id[a]+c,d,g,h,k),n.globalAlpha=q)};
e.Km=function(a,b,c,d,g,h,k,l,n,q,w,A){var E,s,t,u,v,I,ca,T,W,ua;if(!(0>=h||0>=k))for(b=Math.round(b)%h,0<b&&(b-=h),c=Math.round(c)%k,0<c&&(c-=k),E=Math.ceil((q-b)/h),s=Math.ceil((w-c)/k),b+=l,c+=n,W=0;W<E;W+=1)for(ua=0;ua<s;ua+=1)v=d,I=g,ca=h,T=k,t=b+W*h,u=c+ua*k,t<l&&(v+=l-t,ca-=l-t,t=l),t+ca>=l+q&&(ca=l+q-t),u<n&&(I+=n-u,T-=n-u,u=n),u+T>=n+w&&(T=n+w-u),0<ca&&0<T&&this.ka(a,v,I,ca,T,t,u,A)};e.Zj=function(a,b,c,d,g,h,k,l,n,q){this.Km(a,0,0,b,c,d,g,h,k,l,n,q)};
e.Yj=function(a,b,c,d,g,h,k,l,n,q){var w=r.context,A=w.globalAlpha,E,s,t,u,v,I;a=(Math.round(a)%this.F+this.F)%this.F;E=l/d;s=n/g;t=this.od[a];u=this.pd[a];v=this.Rc[a];I=this.Qc[a];b-=t;c-=u;0>=b+d||0>=c+g||b>=v||c>=I||(0>b&&(d+=b,l+=E*b,h-=E*b,b=0),0>c&&(g+=c,n+=s*c,k-=s*c,c=0),b+d>v&&(l-=E*(d-v+b),d=v-b),c+g>I&&(n-=s*(g-I+c),g=I-c),w.globalAlpha=q,this.Kd.ka(this.Gd[a],this.Hd[a]+b,this.Id[a]+c,d,g,h,k,l,n),w.globalAlpha=A)};
e.gq=function(a,b,c,d,g,h,k,l,n,q,w){var A=r.context,E,s,t,u,v,I;0===Math.round(d)||0===Math.round(g)||1E-4>Math.abs(l)||1E-4>Math.abs(n)||(a=(Math.round(a)%this.F+this.F)%this.F,t=this.od[a],u=this.pd[a],v=this.Rc[a],I=this.Qc[a],s=E=0,b-=t,c-=u,0>=b+d||0>=c+g||b>=v||c>=I||(0>b&&(d+=b,E-=b,b=0),0>c&&(g+=c,s-=c,c=0),b+d>v&&(d=v-b),c+g>I&&(g=I-c),A.save(),A.translate(h,k),A.rotate(-q*Math.PI/180),A.scale(l,n),A.globalAlpha=w,this.Kd.ka(this.Gd[a],this.Hd[a]+b,this.Id[a]+c,d,g,E,s),A.restore()))};
function sa(a,b,c){var d,g,h;for(d=0;d<a.F;d+=1)g=b+d%a.Pg*a.width,h=c+a.height*Math.floor(d/a.Pg),a.Kd.ka(a.Gd[d],a.Hd[d],a.Id[d],a.Rc[d],a.Qc[d],g-a.Gb+a.od[d],h-a.Hb+a.pd[d])}function y(a,b){this.canvas=document.createElement("canvas");this.context=this.canvas.getContext("2d");this.width=a;this.height=b;this.Hb=this.Gb=0;this.canvas.width=a;this.canvas.height=b;this.clear();this.Zk=void 0}e=y.prototype;
e.K=function(){var a=new y(this.width,this.height);a.Gb=this.Gb;a.Hb=this.Hb;z(a);this.o(0,0);B(a);return a};function z(a){a.Zk=r.canvas;r.jb(a.canvas)}function B(a){r.canvas===a.canvas&&void 0!==a.Zk&&(r.jb(a.Zk),a.Zk=void 0)}e.clear=function(){this.context.clearRect(0,0,this.canvas.width,this.canvas.height)};e.o=function(a,b){r.context.drawImage(this.canvas,a-this.Gb,b-this.Hb)};
e.bd=function(a,b,c){var d=r.context,g=d.globalAlpha;d.globalAlpha=c;r.context.drawImage(this.canvas,a-this.Gb,b-this.Hb);d.globalAlpha=g};e.za=function(a,b,c,d,g,h){var k=r.context;1E-4>Math.abs(c)||1E-4>Math.abs(d)||(k.save(),k.translate(a,b),k.rotate(-g*Math.PI/180),k.scale(c,d),k.globalAlpha=h,r.context.drawImage(this.canvas,-this.Gb,-this.Hb),k.restore())};
e.hq=function(a,b,c,d,g){var h=r.context,k=h.globalAlpha;0!==this.width&&0!==this.height&&0!==Math.round(c)&&0!==Math.round(d)&&(h.globalAlpha=g,r.context.drawImage(this.canvas,a,b,c,d),h.globalAlpha=k)};e.ka=function(a,b,c,d,g,h,k){var l=r.context,n=l.globalAlpha;0>=c||0>=d||(a+c>this.width&&(c=this.width-a),b+d>this.height&&(d=this.height-b),l.globalAlpha=k,r.context.drawImage(this.canvas,a,b,c,d,g,h,c,d),l.globalAlpha=n)};
e.Km=function(a,b,c,d,g,h,k,l,n,q,w){var A,E,s,t,u,v,I,ca,T,W;if(!(0>=g||0>=h))for(c+g>this.width&&(g=this.width-c),d+h>this.height&&(h=this.height-d),a=Math.round(a)%g,0<a&&(a-=g),b=Math.round(b)%h,0<b&&(b-=h),A=Math.ceil((n-a)/g),E=Math.ceil((q-b)/h),a+=k,b+=l,T=0;T<A;T+=1)for(W=0;W<E;W+=1)u=c,v=d,I=g,ca=h,s=a+T*g,t=b+W*h,s<k&&(u+=k-s,I-=k-s,s=k),s+I>=k+n&&(I=k+n-s),t<l&&(v+=l-t,ca-=l-t,t=l),t+ca>=l+q&&(ca=l+q-t),0<I&&0<ca&&this.ka(u,v,I,ca,s,t,w)};
e.Zj=function(a,b,c,d,g,h,k,l,n){this.Km(0,0,a,b,c,d,g,h,k,l,n)};e.Yj=function(a,b,c,d,g,h,k,l,n){var q=r.context,w=q.globalAlpha;0>=c||0>=d||(a+c>this.width&&(c=this.width-a),b+d>this.height&&(d=this.height-b),0!==Math.round(k)&&0!==Math.round(l)&&(q.globalAlpha=n,r.context.drawImage(this.canvas,a,b,c,d,g,h,k,l),q.globalAlpha=w))};
e.gq=function(a,b,c,d,g,h,k,l,n,q){var w=r.context;0>=c||0>=d||(a+c>this.width&&(c=this.width-a),b+d>this.height&&(d=this.height-b),1E-4>Math.abs(k)||1E-4>Math.abs(l)||(w.save(),w.translate(g,h),w.rotate(-n*Math.PI/180),w.scale(k,l),w.globalAlpha=q,r.context.drawImage(this.canvas,a,b,c,d,0,0,c,d),w.restore()))};
function ta(a,b,c,d){this.v=a;this.dz=b;this.Oy=c;this.kj=[{text:"MiHhX!@v&Qq",width:-1,font:"sans-serif"},{text:"MiHhX!@v&Qq",width:-1,font:"serif"},{text:"AaMm#@!Xx67",width:-1,font:"sans-serif"},{text:"AaMm#@!Xx67",width:-1,font:"serif"}];this.Ks=!1;ma(this,d,1)}function va(a,b,c){r.context.save();r.context.font="250pt "+a+", "+b;a=r.context.measureText(c).width;r.context.restore();return a}
function wa(a){var b,c,d;for(b=0;b<a.kj.length;b+=1)if(c=a.kj[b],d=va(a.v,c.font,c.text),c.width!==d){ja(a.xv);document.body.removeChild(a.ie);a.Ks=!0;return}window.setTimeout(function(){wa(a)},33)}
ta.prototype.Fd=function(a,b){var c="@font-face {font-family: "+this.v+";src: url('"+b+this.dz+"') format('woff'), url('"+b+this.Oy+"') format('truetype');}",d=document.createElement("style");d.id=this.v+"_fontface";d.type="text/css";d.styleSheet?d.styleSheet.cssText=c:d.appendChild(document.createTextNode(c));document.getElementsByTagName("head")[0].appendChild(d);this.ie=document.createElement("span");this.ie.style.position="absolute";this.ie.style.left="-9999px";this.ie.style.top="-9999px";this.ie.style.visibility=
"hidden";this.ie.style.fontSize="250pt";this.ie.id=this.v+"_loader";document.body.appendChild(this.ie);for(c=0;c<this.kj.length;c+=1)d=this.kj[c],d.width=va(d.font,d.font,d.text);this.xv=a;wa(this)};ta.prototype.complete=function(){return this.Ks};
function xa(a,b){this.v=a;this.di=b;this.fontWeight=this.fontStyle="";this.vg="normal";this.fontSize=12;this.fill=!0;this.Ya=1;this.Hc=0;this.fillColor="black";this.ed={e:void 0,Eb:0,ko:!0,lo:!0};this.Sa={dj:!0,F:3,Pj:["red","white","blue"],size:.6,offset:0};this.fillStyle=void 0;this.stroke=!1;this.$a=1;this.bh=0;this.strokeColor="black";this.strokeStyle=void 0;this.Pc=1;this.ee=!1;this.Pf="miter";this.T={k:!1,color:"rgba(10, 10, 10, 0.3)",offsetX:3,offsetY:3,blur:1};this.align="left";this.h="top";
this.fa=this.Va=0}e=xa.prototype;
e.K=function(){var a=new xa(this.v,this.di);a.fontStyle=this.fontStyle;a.fontWeight=this.fontWeight;a.vg=this.vg;a.fontSize=this.fontSize;a.fill=this.fill;a.Ya=this.Ya;a.Hc=this.Hc;a.fillColor=this.fillColor;a.ed={e:this.ed.e,ko:this.ed.ko,lo:this.ed.lo};a.Sa={dj:this.Sa.dj,F:this.Sa.F,Pj:this.Sa.Pj.slice(0),size:this.Sa.size,offset:this.Sa.offset};a.fillStyle=this.fillStyle;a.stroke=this.stroke;a.$a=this.$a;a.bh=this.bh;a.strokeColor=this.strokeColor;a.strokeStyle=this.strokeStyle;a.Pc=this.Pc;a.ee=
this.ee;a.Pf=this.Pf;a.T={k:this.T.k,color:this.T.color,offsetX:this.T.offsetX,offsetY:this.T.offsetY,blur:this.T.blur};a.align=this.align;a.h=this.h;a.Va=this.Va;a.fa=this.fa;return a};
function C(a,b){void 0!==b.v&&(a.v=b.v);void 0!==b.di&&(a.di=b.di);void 0!==b.fontStyle&&(a.fontStyle=b.fontStyle);void 0!==b.fontWeight&&(a.fontWeight=b.fontWeight);void 0!==b.vg&&(a.vg=b.vg);void 0!==b.fontSize&&(a.fontSize=b.fontSize);void 0!==b.fill&&(a.fill=b.fill);void 0!==b.Ya&&(a.Ya=b.Ya);void 0!==b.fillColor&&(a.Hc=0,a.fillColor=b.fillColor);void 0!==b.ed&&(a.Hc=1,a.ed=b.ed);void 0!==b.Sa&&(a.Hc=2,a.Sa=b.Sa);void 0!==b.fillStyle&&(a.Hc=3,a.fillStyle=b.fillStyle);void 0!==b.stroke&&(a.stroke=
b.stroke);void 0!==b.$a&&(a.$a=b.$a);void 0!==b.strokeColor&&(a.bh=0,a.strokeColor=b.strokeColor);void 0!==b.strokeStyle&&(a.bh=3,a.strokeStyle=b.strokeStyle);void 0!==b.Pc&&(a.Pc=b.Pc);void 0!==b.ee&&(a.ee=b.ee);void 0!==b.Pf&&(a.Pf=b.Pf);void 0!==b.T&&(a.T=b.T);void 0!==b.align&&(a.align=b.align);void 0!==b.h&&(a.h=b.h);void 0!==b.Va&&(a.Va=b.Va);void 0!==b.fa&&(a.fa=b.fa)}function ya(a){a.fontWeight="normal"}function D(a,b){a.fontSize=void 0===b?12:b}
e.setFillColor=function(a){this.Hc=0;this.fillColor=void 0===a?"black":a};function Aa(a,b,c,d,g){a.Hc=2;a.Sa.dj=!0;a.Sa.F=b;a.Sa.Pj=c.slice(0);a.Sa.size=void 0===d?.6:d;a.Sa.offset=void 0===g?0:g}function Ba(a,b){a.stroke=void 0===b?!1:b}e.setStrokeColor=function(a){this.bh=0;this.strokeColor=void 0===a?"black":a};function Ca(a,b){a.Pc=void 0===b?1:b}function Da(a,b){a.ee=void 0===b?!1:b}function Ea(a,b){a.Pf=void 0===b?"miter":b}
function Fa(a,b,c){void 0===b?a.T.k=!0:a.T={k:!0,color:b,offsetX:0,offsetY:c,blur:2}}function F(a,b){a.align=void 0===b?"left":b}function G(a,b){a.h=void 0===b?"top":b}function Ga(a){return a.fontStyle+" "+a.fontWeight+" "+a.fontSize+"px "+a.v+", "+a.di}function Ha(a){var b=0,c;for(c=0;c<a.length;c+=1)b=Math.max(b,a[c].width);return b}function Ia(a,b){return a.fontSize*b.length+a.fa*(b.length-1)}
function Ja(a,b,c){var d,g,h,k,l,n,q=[],w=r.context;w.font=Ga(a);switch(a.vg){case "upper":b=b.toUpperCase();break;case "lower":b=b.toLowerCase()}if(void 0===c){n=b.split("\n");for(a=0;a<n.length;a+=1)q.push({text:n[a],width:w.measureText(n[a]).width});return q}n=b.split("\n");h=w.measureText(" ").width;for(a=0;a<n.length;a+=1){g=n[a].split(" ");d=g[0];l=w.measureText(g[0]).width;for(b=1;b<g.length;b+=1)k=w.measureText(g[b]).width,l+h+k<c?(d+=" "+g[b],l+=h+k):(q.push({text:d,width:l}),d=g[b],l=k);
q.push({text:d,width:l})}return q}e.ba=function(a,b){var c;r.context.save();c=Ha(Ja(this,a,b));r.context.restore();return c};e.V=function(a,b){var c;r.context.save();c=Ia(this,Ja(this,a,b));r.context.restore();return c};function Ka(a,b,c,d,g,h){var k=a.fontSize;a.fontSize=b;b=h?Ja(a,c,d):Ja(a,c);d=Ha(b)<=d&&Ia(a,b)<=g;a.fontSize=k;return d}
function H(a,b,c,d,g){var h=0,k=32;void 0===g&&(g=!1);for(r.context.save();Ka(a,h+k,b,c,d,g);)h+=k;for(;2<=k;)k/=2,Ka(a,h+k,b,c,d,g)&&(h+=k);r.context.restore();return Math.max(4,h)}function La(a,b,c,d,g){var h=Math.max(.01,a.Sa.size),k=a.Sa.offset;a.Sa.dj?(k=g/2+k*g,h=.5*h*g,b=r.context.createLinearGradient(b,c+k-h,b,c+k+h)):(k=d/2+k*d,h=.5*h*d,b=r.context.createLinearGradient(b+k-h,c,b+k+h,c));c=1/(a.Sa.F-1);for(d=0;d<a.Sa.F;d+=1)b.addColorStop(d*c,a.Sa.Pj[d]);return b}
function Ma(a,b,c,d,g,h,k){var l,n;!a.fill&&a.T.k?(b.shadowColor=a.T.color,b.shadowOffsetX=a.T.offsetX,b.shadowOffsetY=a.T.offsetY,b.shadowBlur=a.T.blur):(b.shadowColor=void 0,b.shadowOffsetX=0,b.shadowOffsetY=0,b.shadowBlur=0);b.globalAlpha=k*a.$a;switch(a.bh){case 0:b.strokeStyle=a.strokeColor;break;case 3:b.strokeStyle=a.strokeStyle}b.lineWidth=a.Pc;b.lineJoin=a.Pf;for(k=0;k<c.length;k+=1){l=0;switch(a.align){case "right":l=h-c[k].width;break;case "center":l=(h-c[k].width)/2}n=a.fontSize*(k+1)+
a.fa*k;b.strokeText(c[k].text,d+l,g+n)}}
function Na(a,b,c,d,g,h,k){c=Ja(a,c,k);k=Ha(c);var l=Ia(a,c);b.textAlign="left";b.textBaseline="bottom";switch(a.align){case "right":d+=-k;break;case "center":d+=-k/2}switch(a.h){case "base":case "bottom":g+=-l+Math.round(a.Va*a.fontSize);break;case "middle":g+=-l/2+Math.round(a.Va*a.fontSize/2)}b.font=Ga(a);a.stroke&&a.ee&&Ma(a,b,c,d,g,k,h);if(a.fill){var n=d,q=g,w,A;a.T.k?(b.shadowColor=a.T.color,b.shadowOffsetX=a.T.offsetX,b.shadowOffsetY=a.T.offsetY,b.shadowBlur=a.T.blur):(b.shadowColor=void 0,
b.shadowOffsetX=0,b.shadowOffsetY=0,b.shadowBlur=0);b.globalAlpha=h*a.Ya;switch(a.Hc){case 0:b.fillStyle=a.fillColor;break;case 1:l=a.ed.e;A=new y(l.width,l.height);var E=a.ed.ko,s=a.ed.lo;E&&s?w="repeat":E&&!s?w="repeat-x":!E&&s?w="repeat-y":E||s||(w="no-repeat");z(A);l.o(a.ed.Eb,0,0);B(A);w=r.context.createPattern(A.canvas,w);b.fillStyle=w;break;case 2:b.fillStyle=La(a,n,q,k,l);break;case 3:b.fillStyle=a.fillStyle;break;default:b.fillStyle=a.fillColor}for(w=0;w<c.length;w+=1){l=0;switch(a.align){case "right":l=
k-c[w].width;break;case "center":l=(k-c[w].width)/2}A=a.fontSize*(w+1)+a.fa*w;2===a.Hc&&a.Sa.dj&&(b.fillStyle=La(a,n,q+A-a.fontSize,k,a.fontSize));b.fillText(c[w].text,n+l,q+A)}}a.stroke&&!a.ee&&Ma(a,b,c,d,g,k,h)}e.o=function(a,b,c,d){var g=r.context;this.fill&&1===this.Hc?this.za(a,b,c,1,1,0,1,d):(g.save(),Na(this,g,a,b,c,1,d),g.restore())};e.bd=function(a,b,c,d,g){var h=r.context;this.fill&&1===this.Hc?this.za(a,b,c,1,1,0,d,g):(h.save(),Na(this,h,a,b,c,d,g),h.restore())};
e.za=function(a,b,c,d,g,h,k,l){var n=r.context;n.save();n.translate(b,c);n.rotate(-h*Math.PI/180);n.scale(d,g);try{Na(this,n,a,0,0,k,l)}catch(q){}n.restore()};
function Oa(){this.Pv=10;this.oj=-1;this.Kt="stop_lowest_prio";this.Gp=this.Ra=this.kb=!1;var a,b=this,c="undefined"!==typeof AudioContext?AudioContext:"undefined"!==typeof webkitAudioContext?webkitAudioContext:void 0;if(c)this.kb=!0;else if("undefined"!==typeof Audio)try{"undefined"!==typeof(new Audio).canPlayType&&(this.Ra=!0)}catch(d){}this.Gp=this.kb||this.Ra;this.Ra&&m.u.ah&&(this.oj=1);if(this.Gp)try{a=new Audio,this.mp={ogg:!!a.canPlayType('audio/ogg; codecs="vorbis"').replace(/^no$/,""),mp3:!!a.canPlayType("audio/mpeg;").replace(/^no$/,
""),opus:!!a.canPlayType('audio/ogg; codecs="opus"').replace(/^no$/,""),wav:!!a.canPlayType('audio/wav; codecs="1"').replace(/^no$/,""),m4a:!!(a.canPlayType("audio/x-m4a;")||a.canPlayType("audio/aac;")).replace(/^no$/,""),mp4:!!(a.canPlayType("audio/x-mp4;")||a.canPlayType("audio/aac;")).replace(/^no$/,""),weba:!!a.canPlayType('audio/webm; codecs="vorbis"').replace(/^no$/,"")}}catch(g){this.mp={ogg:!1,mp3:!0,opus:!1,wav:!1,m4a:!1,mp4:!1,weba:!1}}this.Zb=[];this.Me={};this.bb={};this.Xc={};this.Md=
[];this.hc=0;this.kb?(this.Ld=new c,this.np="function"===typeof this.Ld.createGain?function(){return b.Ld.createGain()}:"function"===typeof this.Ld.createGainNode?function(){return b.Ld.createGainNode()}:function(){},this.Le={},this.nj=this.np(),void 0===this.nj?(this.Ra=!0,this.uh=Oa.prototype.fm):(this.nj.connect(this.Ld.destination),this.Le.master=this.nj,this.uh=Oa.prototype.Jt)):this.uh=this.Ra?Oa.prototype.fm:function(){}}
function Pa(a){var b=J,c,d,g,h,k;for(c=0;c<b.Zb.length;c+=1)if((d=b.Zb[c])&&0===d.Pm)if(d.paused)d.rp&&(d.hm+=a,d.hm>=d.rp&&b.Ii(d.id));else if(d.jm+=a,d.ag&&d.jm>=d.ys)d.ag=!1,Qa(b,d,d.Od);else if(d.sc&&b.Ra&&b.mn(d.id)>=d.duration)if(d.In)try{d.J.pause(),d.J.currentTime=d.Od/1E3,4===d.J.readyState?d.J.play():(g=function(){var a=d;return{ready:function(){a.J.play();a.J.removeEventListener("canplaythrough",g.ready,!1)}}}(),d.J.addEventListener("canplaythrough",g.ready,!1))}catch(l){}else d.J.pause(),
Ra(d);for(c=b.Md.length-1;0<=c;c-=1)h=b.Md[c],b.ar(h.id)||0!==h.Pm||(h.m+=a,h.m>=h.duration?(Sa(J,h.id,h.Si),void 0!==b.Xc[h.id]&&(b.Xc[h.id]=h.Si),h.mb&&h.mb(),b.Md.splice(c,1)):(k=h.cb(h.m,h.start,h.Si-h.start,h.duration),Sa(J,h.id,k),void 0!==b.Xc[h.id]&&(b.Xc[h.id]=k)))}function Ta(a,b){a.Me[b.uc.s.name]?a.Me[b.uc.s.name].length<a.Pv&&a.Me[b.uc.s.name].push(b.J):a.Me[b.uc.s.name]=[b.J]}
function Ua(a,b){var c,d,g;g=[];for(c=0;c<a.Zb.length;c+=1)(d=a.Zb[c])&&0<=d.xa.indexOf(b)&&g.push(d);return g}function Va(a,b){if(0<a.oj&&a.hc>=a.oj)switch(a.Kt){case "cancel_new":return!1;case "stop_lowest_prio":var c,d,g;for(c=0;c<a.Zb.length;c+=1)(d=a.Zb[c])&&d.sc&&!d.paused&&(void 0===g||g.kl<d.kl)&&(g=d);if(g.kl>b.Eh){a.stop(g.id);break}return!1}return!0}
function Wa(a,b){var c,d=1;for(c=0;c<b.xa.length;c+=1)void 0!==J.bb[b.xa[c]]&&(d*=J.bb[b.xa[c]]);c=a.np();c.gain.value=d;c.connect(a.nj);a.Le[b.id]=c;b.J.connect(c)}function Xa(a,b){b.J.disconnect(0);a.Le[b.id]&&(a.Le[b.id].disconnect(0),delete a.Le[b.id])}function Ya(a,b){var c;if(b.s&&b.s.Nb){if(a.kb)return c=a.Ld.createBufferSource(),c.buffer=b.s.Nb,c.loopStart=b.startOffset/1E3,c.loopEnd=(b.startOffset+b.duration)/1E3,c;if(a.Ra)return c=b.s.Nb.cloneNode(!0),c.volume=0,c}}
function Za(a,b){var c,d;if(a.kb)(c=Ya(a,b))&&(d=new $a(b,c));else if(a.Ra){c=a.Me[b.s.name];if(!c)return;0<c.length?d=new $a(b,c.pop()):(c=Ya(a,b))&&(d=new $a(b,c))}if(d){a.kb&&Wa(a,d);for(c=0;c<a.Zb.length;c+=1)if(void 0===a.Zb[c])return a.Zb[c]=d;a.Zb.push(d)}return d}function ab(a){var b=J,c,d;for(c=0;c<a.length;c+=1)if(d=a[c].split(".").pop(),b.mp[d])return a[c];return!1}e=Oa.prototype;
e.fm=function(a,b,c){function d(){var b;a.loaded=!0;ja(c);a.duration=Math.ceil(1E3*a.Nb.duration);a.Nb.removeEventListener("canplaythrough",d,!1);a.Nb.removeEventListener("error",g,!1);b=a.Nb.cloneNode(!0);J.Me[a.name].push(b)}function g(){la(c)}(b=ab(b))?(a.Nb=new Audio,a.Nb.src=b,a.Nb.autoplay=!1,a.Nb.uA="auto",a.Nb.addEventListener("canplaythrough",d,!1),a.Nb.addEventListener("error",g,!1),a.Nb.load()):g()};
e.Jt=function(a,b,c){var d=ab(b),g=new XMLHttpRequest;g.open("GET",d,!0);g.responseType="arraybuffer";g.onload=function(){J.Ld.decodeAudioData(g.response,function(b){b&&(a.Nb=b,a.duration=1E3*b.duration,a.loaded=!0,ja(c))},function(){la(c)})};g.onerror=function(){"undefined"!==typeof Audio&&(J.kb=!1,J.Ra=!0,J.uh=Oa.prototype.fm,J.uh(a,b,c))};try{g.send()}catch(h){}};
e.play=function(a,b,c,d){if(a instanceof bb){if(Va(this,a)){a=Za(this,a);if(!a)return-1;a.ys=b||0;a.ag=0<b;a.pb=c||0;a.Vd=d||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b};a.ag||Qa(this,a,a.Od);return a.id}return-1}};
function Qa(a,b,c){var d;"number"!==typeof c&&(c=0);cb(a,b.id);0<b.pb&&(d=db(a,b.id),Sa(a,b.id,0),eb(a,b.id,d,b.pb,b.Vd),b.pb=0,b.Vd=void 0);if(a.kb){d=c-b.Od;b.Lt=1E3*a.Ld.currentTime-d;b.J.onended=function(){Ra(b)};try{b.J.start?b.J.start(0,c/1E3,(b.duration-d)/1E3):b.J.noteGrainOn&&b.J.noteGrainOn(0,c/1E3,(b.duration-d)/1E3),b.td=!0,b.sc=!0,a.hc+=1,b.J.loop=b.In}catch(g){}}else if(a.Ra){if(4!==b.J.readyState){var h=function(){return{ready:function(){b.J.currentTime=c/1E3;b.J.play();b.td=!0;b.J.removeEventListener("canplaythrough",
h.ready,!1)}}}();b.J.addEventListener("canplaythrough",h.ready,!1)}else b.J.currentTime=c/1E3,b.J.play(),b.td=!0;b.sc=!0;a.hc+=1}}
e.Ii=function(a,b,c,d){var g,h,k,l,n=Ua(this,a);for(g=0;g<n.length;g+=1)if(h=n[g],(h.paused||!h.sc)&&!d||!h.paused&&d){if(!d){for(g=this.Md.length-1;0<=g;g-=1)if(a=this.Md[g],a.id===h.id){l=a;b=0;c=void 0;break}h.paused=!1;h.pb=b||0;h.Vd=c||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b};h.sh&&(void 0===b&&(h.pb=h.sh.duration),void 0===c&&(h.Vd=h.sh.cb),k=h.sh.gain,h.sh=void 0)}this.kb&&(a=Ya(this,h.uc))&&(h.J=a,Wa(this,h));void 0!==k&&Sa(J,h.id,k);Qa(this,h,h.Od+(h.pj||0));void 0!==l&&
(Sa(J,h.id,l.cb(l.m,l.start,l.Si-l.start,l.duration)),eb(J,h.id,l.Si,l.duration-l.m,l.cb,l.mb))}};
e.pause=function(a,b,c,d,g){var h,k,l=Ua(this,a);for(a=0;a<l.length;a+=1)if(h=l[a],!h.paused)if(h.pb=c||0,0<h.pb)h.Vd=d||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b},h.sh={gain:fb(h.id),duration:h.pb,cb:h.Vd},eb(J,h.id,0,h.pb,h.Vd,function(){J.pause(h.id,b)});else if(k=this.mn(h.id),h.pj=k,g||(h.paused=!0,h.hm=0,h.rp=b,this.hc-=1),this.kb){h.J.onended=function(){};if(h.sc&&h.td){try{h.J.stop?h.J.stop(0):h.J.noteOff&&h.J.noteOff(0)}catch(n){}h.td=!1}Xa(this,h)}else this.Ra&&h.J.pause()};
function Ra(a){var b=J;b.bb[a.id]&&delete b.bb[a.id];a.paused||(b.hc-=1);b.kb?(a.td=!1,a.sc=!1,Xa(b,a)):b.Ra&&Ta(b,a);b.Zb[b.Zb.indexOf(a)]=void 0}
e.stop=function(a,b,c){var d,g=Ua(this,a);for(a=0;a<g.length;a+=1)if(d=g[a],d.pb=b||0,0<d.pb)d.Vd=c||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b},eb(J,d.id,0,d.pb,d.Vd,function(){J.stop(d.id)});else{this.bb[d.id]&&delete this.bb[d.id];d.sc&&!d.paused&&(this.hc-=1);if(this.kb){if(d.sc&&!d.paused&&!d.ag){if(d.td){try{d.J.stop?d.J.stop(0):d.J.noteOff&&d.J.noteOff(0)}catch(h){}d.td=!1}Xa(this,d)}}else this.Ra&&(d.ag||d.J.pause(),Ta(this,d));this.Zb[this.Zb.indexOf(d)]=void 0;d.sc=!1}};
function eb(a,b,c,d,g,h){var k;for(k=0;k<a.Md.length;k+=1)if(a.Md[k].id===b){a.Md.splice(k,1);break}a.Md.push({id:b,Si:c,cb:g||function(a,b,c,d){return a==d?b+c:c*(-Math.pow(2,-10*a/d)+1)+b},duration:d,m:0,start:db(a,b),mb:h,Pm:0})}function gb(a){var b=J,c;void 0===b.Xc[a]&&(c=void 0!==b.bb[a]?b.bb[a]:1,Sa(b,a,0),b.Xc[a]=c)}function hb(a){var b=J;void 0!==b.Xc[a]&&(Sa(b,a,b.Xc[a]),delete b.Xc[a])}
e.position=function(a,b){var c,d,g,h,k=Ua(this,a);if(!isNaN(b)&&0<=b)for(c=0;c<k.length;c++)if(d=k[c],b%=d.duration,this.kb)if(d.paused)d.pj=b;else{d.J.onended=function(){};if(d.td){try{d.J.stop?d.J.stop(0):d.J.noteOff&&d.J.noteOff(0)}catch(l){}d.td=!1}Xa(this,d);this.hc-=1;if(g=Ya(this,d.uc))d.J=g,Wa(this,d),Qa(this,d,d.Od+b)}else this.Ra&&(4===d.J.readyState?d.J.currentTime=(d.Od+b)/1E3:(h=function(){var a=d,c=b;return{Lq:function(){a.J.currentTime=(a.Od+c)/1E3;a.J.removeEventListener("canplaythrough",
h.Lq,!1)}}}(),d.J.addEventListener("canplaythrough",h.Lq,!1)))};e.no=function(a){J.position(a,0)};e.ns=function(a,b){var c,d=Ua(this,a);for(c=0;c<d.length;c+=1)d[c].In=b,this.kb&&(d[c].J.loop=b)};function db(a,b){return void 0!==a.bb[b]?a.bb[b]:1}function fb(a){var b=J,c=1,d=Ua(b,a)[0];if(d)for(a=0;a<d.xa.length;a+=1)void 0!==b.bb[d.xa[a]]&&(c*=b.bb[d.xa[a]]);return Math.round(100*c)/100}
function Sa(a,b,c){var d,g,h=1,k=Ua(a,b);a.bb[b]=c;a.Xc[b]&&delete a.Xc[b];for(c=0;c<k.length;c+=1)if(d=k[c],0<=d.xa.indexOf(b)){for(g=0;g<d.xa.length;g+=1)void 0!==a.bb[d.xa[g]]&&(h*=a.bb[d.xa[g]]);h=Math.round(100*h)/100;a.kb?a.Le[d.id].gain.value=h:a.Ra&&(d.J.volume=h)}}function cb(a,b){var c,d,g,h=1,k=Ua(a,b);for(c=0;c<k.length;c+=1){d=k[c];for(g=0;g<d.xa.length;g+=1)void 0!==a.bb[d.xa[g]]&&(h*=a.bb[d.xa[g]]);h=Math.round(100*h)/100;a.kb?a.Le[d.id].gain.value=h:a.Ra&&(d.J.volume=h)}}
e.Bp=function(a,b){var c,d,g,h=Ua(this,a);for(c=0;c<h.length;c+=1)for(d=h[c],b=[].concat(b),g=0;g<b.length;g+=1)0>d.xa.indexOf(b[g])&&d.xa.push(b[g]);cb(this,a)};e.ar=function(a){if(a=Ua(this,a)[0])return a.paused};e.mn=function(a){if(a=Ua(this,a)[0]){if(this.kb)return a.paused?a.pj:(1E3*J.Ld.currentTime-a.Lt)%a.duration;if(J.Ra)return Math.ceil(1E3*a.J.currentTime-a.Od)}};var J=new Oa;function ib(a,b,c,d){this.name=a;this.tw=b;this.Jw=c;this.qc=d;this.loaded=!1;this.Nb=null;ma(this,this.qc,1)}
ib.prototype.Fd=function(a,b){var c,d;c=this.tw;0!==c.toLowerCase().indexOf("http:")&&0!==c.toLowerCase().indexOf("https:")&&(c=b+c);d=this.Jw;0!==d.toLowerCase().indexOf("http:")&&0!==d.toLowerCase().indexOf("https:")&&(d=b+d);J.Me[this.name]=[];J.uh(this,[d,c],a)};ib.prototype.complete=function(){return this.loaded};
function bb(a,b,c,d,g,h,k){this.name=a;this.s=b;this.startOffset=c;this.duration=d;Sa(J,this.name,void 0!==g?g:1);this.Eh=void 0!==h?h:10;this.xa=[];k&&(this.xa=this.xa.concat(k));0>this.xa.indexOf(this.name)&&this.xa.push(this.name)}bb.prototype.complete=function(){return this.s.complete()};bb.prototype.kl=function(a){void 0!==a&&(this.Eh=a);return this.Eh};bb.prototype.Bp=function(a){var b;a=[].concat(a);for(b=0;b<a.length;b+=1)0>this.xa.indexOf(a[b])&&this.xa.push(a[b])};
function $a(a,b){this.uc=a;this.Od=this.uc.startOffset;this.J=b;this.duration=this.uc.duration;this.dm()}$a.prototype.dm=function(){this.id=Math.round(Date.now()*Math.random())+"";this.xa=["master",this.id].concat(this.uc.xa);this.kl=void 0!==this.uc.Eh?this.uc.Eh:10;this.paused=this.sc=this.In=!1;this.jm=this.Pm=0;this.td=this.ag=!1;this.ys=this.pj=0;var a,b=1;for(a=0;a<this.xa.length;a+=1)void 0!==J.bb[this.xa[a]]&&(b*=J.bb[this.xa[a]]);!J.kb&&J.Ra&&(this.J.volume=b)};
function jb(a){this.name=a;this.text="";this.Gc=this.complete=!1}jb.prototype.Ne=function(a){4===a.readyState&&(this.complete=!0,(this.Gc=200!==a.status)?ka("Get Failed",{name:this.name}):(this.text=a.responseText,ka("Get Complete",{name:this.name})))};
function kb(a,b){var c=new XMLHttpRequest;a.complete=!1;c.open("POST",b);c.setRequestHeader("Content-Type","text/plain;charset=UTF-8");c.onreadystatechange=function(){4===c.readyState&&(a.complete=!0,a.Gc=200!==c.status,a.Gc?ka("Post Failed",{name:a.name}):ka("Post Complete",{name:a.name}))};c.send(a.text)}function lb(a,b){var c=new XMLHttpRequest;c.open("GET",b,!1);try{c.send()}catch(d){return!1}a.complete=!0;a.Gc=200!==c.status;if(a.Gc)return!1;a.text=c.responseText;return!0}
function mb(a){a&&(this.Zd=a);this.clear();this.Bh=this.dg=this.Wc=this.Ah=this.zh=this.Dh=this.wh=this.Ch=this.Nd=this.yh=this.xh=0;nb(this,this);ob(this,this);pb(this,this);this.je=[];this.oh=[];this.Gh=[];this.N=0;this.sp=!1;this.Ik=this.startTime=Date.now();this.Of=this.nk=0;this.Qv=200;this.qc="";window.hj(window.jp)}mb.prototype.clear=function(){this.H=[];this.Hh=!1;this.ub=[];this.cm=!1};
function nb(a,b){window.addEventListener("click",function(a){var d,g,h;if(void 0!==b.Zd&&!(0<b.N)&&(d=b.Zd,g=d.getBoundingClientRect(),h=d.width/g.width*(a.clientX-g.left),d=d.height/g.height*(a.clientY-g.top),a.preventDefault(),b.$f.x=h,b.$f.y=d,b.qh.push({x:b.$f.x,y:b.$f.y}),0<b.Ah))for(a=b.H.length-1;0<=a&&!((h=b.H[a])&&h.k&&0>=h.N&&h.rn&&(h=h.rn(b.$f.x,b.$f.y),!0===h));a-=1);},!1);qb(a)}function qb(a){a.$f={x:0,y:0};a.qh=[]}
function ob(a,b){window.addEventListener("mousedown",function(a){0<b.N||(a.preventDefault(),window.focus(),b.qp>=Date.now()-1E3||(rb(b,0,a.clientX,a.clientY),sb(b,0)))},!1);window.addEventListener("mouseup",function(a){0<b.N||(a.preventDefault(),b.mj>=Date.now()-1E3||(rb(b,0,a.clientX,a.clientY),ub(b,0)))},!1);window.addEventListener("mousemove",function(a){0<b.N||(a.preventDefault(),rb(b,0,a.clientX,a.clientY))},!1);window.addEventListener("touchstart",function(a){var d=a.changedTouches;b.qp=Date.now();
if(!(0<b.N))for(a.preventDefault(),window.focus(),a=0;a<d.length;a+=1)rb(b,d[a].identifier,d[a].clientX,d[a].clientY),sb(b,d[a].identifier)},!1);window.addEventListener("touchend",function(a){var d=a.changedTouches;b.mj=Date.now();if(!(0<b.N))for(a.preventDefault(),a=0;a<d.length;a+=1)rb(b,d[a].identifier,d[a].clientX,d[a].clientY),ub(b,d[a].identifier)},!1);window.addEventListener("touchmove",function(a){var d=a.changedTouches;if(!(0<b.N))for(a.preventDefault(),a=0;a<d.length;a+=1)rb(b,d[a].identifier,
d[a].clientX,d[a].clientY)},!1);window.addEventListener("touchleave",function(a){var d=a.changedTouches;b.mj=Date.now();if(!(0<b.N))for(a.preventDefault(),a=0;a<d.length;a+=1)rb(b,d[a].identifier,d[a].clientX,d[a].clientY),ub(b,d[a].identifier)},!1);window.addEventListener("touchcancel",function(a){var d=a.changedTouches;b.mj=Date.now();if(!(0<b.N))for(a.preventDefault(),a=0;a<d.length;a+=1)rb(b,d[a].identifier,d[a].clientX,d[a].clientY),ub(b,d[a].identifier)},!1);window.addEventListener("mousewheel",
function(a){vb(b,a)},!1);window.addEventListener("DOMMouseScroll",function(a){vb(b,a)},!1);wb(a);a.qp=0;a.mj=0}function wb(a){var b;a.ha=[];for(b=0;16>b;b+=1)a.ha[b]={id:-1,ob:!1,x:0,y:0};a.Pe=[]}function xb(a,b){var c=-1,d;for(d=0;16>d;d+=1)if(a.ha[d].id===b){c=d;break}if(-1===c)for(d=0;16>d;d+=1)if(!a.ha[d].ob){c=d;a.ha[d].id=b;break}return c}
function rb(a,b,c,d){var g,h;void 0!==a.Zd&&(b=xb(a,b),-1!==b&&(g=a.Zd,h=g.getBoundingClientRect(),a.ha[b].x=g.width/h.width*(c-h.left),a.ha[b].y=g.height/h.height*(d-h.top)))}function sb(a,b){var c=xb(a,b),d,g;if(-1!==c&&!a.ha[c].ob&&(a.Pe.push({ef:c,x:a.ha[c].x,y:a.ha[c].y,ob:!0}),a.ha[c].ob=!0,0<a.Wc))for(d=a.H.length-1;0<=d&&!((g=a.H[d])&&g.k&&0>=g.N&&g.zg&&(g=g.zg(c,a.ha[c].x,a.ha[c].y),!0===g));d-=1);}
function ub(a,b){var c=xb(a,b),d,g;if(-1!==c&&a.ha[c].ob&&(a.Pe.push({ef:c,x:a.ha[c].x,y:a.ha[c].y,ob:!1}),a.ha[c].ob=!1,0<a.Wc))for(d=a.H.length-1;0<=d&&!((g=a.H[d])&&g.k&&0>=g.N&&g.Ag&&(g=g.Ag(c,a.ha[c].x,a.ha[c].y),!0===g));d-=1);}
function vb(a,b){var c;if(!(0<a.N)){b.preventDefault();window.focus();c=Math.max(-1,Math.min(1,b.wheelDelta||-b.detail));var d,g;a.Pe.push({ef:0,x:a.ha[0].x,y:a.ha[0].y,wheelDelta:c});if(0<a.Wc)for(d=a.H.length-1;0<=d&&!((g=a.H[d])&&g.k&&0>=g.N&&g.un&&(g=g.un(c,a.ha[0].x,a.ha[0].y),!0===g));d-=1);}}
function pb(a,b){window.addEventListener("keydown",function(a){0<b.N||(-1<[32,37,38,39,40].indexOf(a.keyCode)&&a.preventDefault(),yb(b,a.keyCode))},!1);window.addEventListener("keyup",function(a){0<b.N||(-1<[32,37,38,39,40].indexOf(a.keyCode)&&a.preventDefault(),zb(b,a.keyCode))},!1);Ab(a)}function Ab(a){var b;a.th=[];for(b=0;256>b;b+=1)a.th[b]=!1;a.cg=[]}
function yb(a,b){var c,d;if(!a.th[b]&&(a.cg.push({key:b,ob:!0}),a.th[b]=!0,0<a.dg))for(c=0;c<a.H.length&&!((d=a.H[c])&&d.k&&0>=d.N&&d.sn&&(d=d.sn(b),!0===d));c+=1);}function zb(a,b){var c,d;if(a.th[b]&&(a.cg.push({key:b,ob:!1}),a.th[b]=!1,0<a.dg))for(c=0;c<a.H.length&&!((d=a.H[c])&&d.k&&0>=d.N&&d.tn&&(d=d.tn(b),!0===d));c+=1);}function Cb(){var a=K,b;for(b=0;b<a.je.length;b+=1)a.je[b].paused+=1}
function ka(a,b){var c,d=K,g,h;void 0===c&&(c=null);d.Gh.push({id:a,Ot:b,ih:c});if(0<d.Bh)for(g=0;g<d.H.length&&(!((h=d.H[g])&&h.k&&0>=h.N&&h.vn)||null!==c&&c!==h||(h=h.vn(a,b),!0!==h));g+=1);}
function Db(a,b){var c=a.ub[b];c.visible&&(void 0!==c.canvas&&c.canvas!==r.canvas&&r.jb(c.canvas),!1!==r.canvas.Z||!0===c.Rb)&&(0===c.pp&&(0>=c.N&&(c.Eb+=c.Qd*a.Of/1E3),1===c.Xl&&1===c.Yl&&0===c.Na?1===c.alpha?c.e.o(c.Eb,c.x,c.y):c.e.bd(c.Eb,c.x,c.y,c.alpha):c.e.za(c.Eb,c.x,c.y,c.Xl,c.Yl,c.Na,c.alpha)),1===c.pp&&(1===c.Xl&&1===c.Yl&&0===c.Na?1===c.alpha?c.font.o(c.text,c.x,c.y):c.font.bd(c.text,c.x,c.y,c.alpha):c.font.za(c.text,c.x,c.y,c.Xl,c.Yl,c.Na,c.alpha)))}
function Eb(a,b){var c=a.H[b];if(c.visible&&(void 0!==c.canvas&&c.canvas!==r.canvas&&r.jb(c.canvas),(!1!==r.canvas.Z||!0===c.Rb)&&c.Pa))return c.Pa()}function Fb(a){for(var b=0,c=0;b<a.H.length||c<a.ub.length;)if(c===a.ub.length){if(!0===Eb(a,b))break;b+=1}else if(b===a.H.length)Db(a,c),c+=1;else if(a.ub[c].Fa>a.H[b].Fa||a.ub[c].Fa===a.H[b].Fa&&a.ub[c].depth>a.H[b].depth)Db(a,c),c+=1;else{if(!0===Eb(a,b))break;b+=1}}mb.prototype.pause=function(a){this.N+=1;void 0===a&&(a=!1);this.sp=a};
mb.prototype.Ii=function(){0!==this.N&&(this.Ik=Date.now(),this.N-=1)};mb.prototype.ar=function(){return 0<this.N};window.$l=0;window.Zl=0;window.kp=0;window.Ct=0;window.lp=0;window.Et=60;window.Ft=0;window.Dt=!1;
window.jp=function(){window.$l=Date.now();window.Ct=window.$l-window.Zl;var a=K,b;if(0<a.N)a.sp&&(Gb(a),Fb(a));else{b=Date.now();"number"!==typeof b&&(b=a.Ik);a.Of=Math.min(a.Qv,b-a.Ik);a.nk+=a.Of;""===a.qc&&(a.qc="start",ha.Fd(a.qc));"start"===a.qc&&ha.complete(a.qc)&&(a.qc="load",ha.Fd(a.qc));"load"===a.qc&&ha.complete(a.qc)&&(a.qc="game",ha.Fd(a.qc));"undefined"!==typeof J&&Pa(a.Of);var c,d;if(0<a.xh)for(c=0;c<a.H.length&&!((d=a.H[c])&&d.pa&&d.k&&0>=d.N&&!0===d.pa(a.Of));c+=1);var g,h;if(0!==a.qh.length){if(0<
a.yh)for(d=a.H.length-1;0<=d;d-=1)if((g=a.H[d])&&g.k&&0>=g.N&&g.pn)for(c=0;c<a.qh.length;c+=1)h=a.qh[c],!0!==h.Ic&&(h.Ic=g.pn(h.x,h.y));a.qh=[]}if(0!==a.Pe.length){if(0<a.Nd)for(d=a.H.length-1;0<=d;d-=1)if((g=a.H[d])&&g.k&&0>=g.N&&(g.zb||g.Tb||g.vk))for(c=0;c<a.Pe.length;c+=1)h=a.Pe[c],!0!==h.Ic&&(void 0!==h.wheelDelta&&g.vk?h.Ic=g.vk(h.wheelDelta,h.x,h.y):h.ob&&g.zb?h.Ic=g.zb(h.ef,h.x,h.y):void 0!==h.ob&&!h.ob&&g.Tb&&(h.Ic=g.Tb(h.ef,h.x,h.y)));a.Pe=[]}if(0!==a.cg.length){if(0<a.Ch)for(d=0;d<a.H.length;d+=
1)if((g=a.H[d])&&g.k&&0>=g.N&&(g.uk||g.Bg))for(c=0;c<a.cg.length;c+=1)h=a.cg[c],!0!==h.Ic&&(h.ob&&g.uk?h.Ic=void 0:!h.ob&&g.Bg&&(h.Ic=g.Bg(h.key)));a.cg=[]}c=a.Of;for(d=a.oh.length=0;d<a.je.length;d+=1)g=a.je[d],void 0!==g.id&&0===g.paused&&(0<g.fh||0<g.mo)&&(g.fh-=c,0>=g.fh&&(a.oh.push({id:g.id,ih:g.ih}),0<g.mo?(g.mo-=1,g.fh+=g.time):g.fh=0));if(0<a.wh&&0<a.oh.length)for(c=0;c<a.H.length;c+=1)if((d=a.H[c])&&d.on&&d.k)for(g=0;g<a.oh.length;g+=1)h=a.oh[g],!0===h.Ic||null!==h.ih&&h.ih!==d||(h.Ic=d.on(h.id));
if(0<a.Dh&&0<a.Gh.length)for(c=0;c<a.H.length;c+=1)if((g=a.H[c])&&g.gd&&g.k&&0>=g.N)for(d=0;d<a.Gh.length;d+=1)h=a.Gh[d],!0===h.Ic||null!==h.ih&&h.ih!==g||(h.Ic=g.gd(h.id,h.Ot));a.Gh.length=0;if(0<a.zh)for(c=0;c<a.H.length&&!((d=a.H[c])&&d.mc&&d.k&&0>=d.N&&!0===d.mc(a.Of));c+=1);Gb(a);Fb(a);a.Ik=b}window.Zl=Date.now();window.kp=window.Zl-window.$l;window.lp=Math.max(window.Ft,1E3/window.Et-window.kp);window.hj(window.jp)};window.hj=function(a){window.setTimeout(a,window.lp)};
window.Dt||(window.hj=window.requestAnimationFrame||window.webkitRequestAnimationFrame||window.mozRequestAnimationFrame||window.msRequestAnimationFrame||window.oRequestAnimationFrame||window.hj);
function Gb(a){function b(a,b){return a.Fa===b.Fa?b.depth-a.depth:a.Fa>b.Fa?-1:1}var c,d;for(c=d=0;c<a.H.length;c+=1)a.H[c]&&(a.H[c].am&&(a.H[c].am=!1,a.H[c].k=!0),a.H[d]=a.H[c],d+=1);a.H.length=d;a.Hh&&a.H.sort(b);a.Hh=!1;for(c=d=0;c<a.ub.length;c+=1)a.ub[c]&&(a.ub[d]=a.ub[c],d+=1);a.ub.length=d;a.cm&&a.ub.sort(b);a.cm=!1}
function L(a,b){var c=K;void 0===a.group&&(a.group=0);void 0===a.visible&&(a.visible=!0);void 0===a.k&&(a.k=!0);void 0===a.depth&&(a.depth=0);void 0===a.Fa&&(a.Fa=0);void 0===a.N&&(a.N=0);void 0===a.Oe&&(a.Oe=[]);a.am=!1;void 0!==b&&!1===b&&(a.am=!0,a.k=!1);c.H.push(a);c.Hh=!0;a.pa&&(c.xh+=1);a.pn&&(c.yh+=1);if(a.zb||a.Tb)c.Nd+=1;a.vk&&(c.Nd+=1);if(a.uk||a.Bg)c.Ch+=1;a.on&&(c.wh+=1);a.gd&&(c.Dh+=1);a.mc&&(c.zh+=1);a.rn&&(c.Ah+=1);if(a.zg||a.Ag)c.Wc+=1;a.un&&(c.Wc+=1);if(a.sn||a.tn)c.dg+=1;a.vn&&(c.Bh+=
1);a.Sb&&a.Sb()}function Hb(a,b){var c=K;a.depth!==b&&(c.Hh=!0);a.depth=b}function Ib(a,b){var c;b=[].concat(b);void 0===a.Oe&&(a.Oe=[]);for(c=b.length-1;0<=c;c-=1)0>a.Oe.indexOf(b[c])&&a.Oe.push(b[c])}
function Jb(a){var b=K,c=[],d,g;if(void 0===a||"all"===a||"master"===a)for(d=0;d<b.H.length;d+=1)g=b.H[d],void 0!==g&&c.push(g);else if("function"===typeof a)for(d=0;d<b.H.length;d+=1)g=b.H[d],void 0!==g&&a(g)&&c.push(g);else for(d=0;d<b.H.length;d+=1)g=b.H[d],void 0!==g&&0<=g.Oe.indexOf(a)&&c.push(g);return c}function Kb(a){var b=Jb(a);for(a=0;a<b.length;a+=1){var c=b[a];c.N+=1}}function Lb(a){var b=Jb(a);for(a=0;a<b.length;a+=1){var c=b[a];c.N=Math.max(0,c.N-1)}}
mb.prototype.p=function(a){a=this.H.indexOf(a);if(!(0>a)){this.H[a].yb&&this.H[a].yb();var b=this.H[a];b.pa&&(this.xh-=1);b.pn&&(this.yh-=1);if(b.zb||b.Tb)this.Nd-=1;b.vk&&(this.Nd-=1);if(b.uk||b.Bg)this.Ch-=1;b.on&&(this.wh-=1);b.gd&&(this.Dh-=1);b.mc&&(this.zh-=1);b.rn&&(this.Ah-=1);if(b.zg||b.Ag)this.Wc-=1;b.un&&(this.Wc-=1);if(b.sn||b.tn)this.dg-=1;b.vn&&(this.Bh-=1);this.H[a]=void 0}};mb.prototype.d=function(a,b,c,d,g,h,k){return Mb(this,a,b,c,d,g,h,k)};
function Mb(a,b,c,d,g,h,k,l){void 0===l&&(l=0);a.ub.push({pp:0,e:b,Eb:c,Qd:d,visible:!0,x:g,y:h,Xl:1,Yl:1,Na:0,alpha:1,depth:k,Fa:l,N:0,Oe:[]});a.cm=!0;return a.ub[a.ub.length-1]}var K=new mb(aa);
function Nb(a,b){var c;this.kind=a;this.B=null;switch(this.kind){case 0:this.B={x:[b.x],y:[b.y]};this.Ba=b.x;this.Oa=b.y;this.Wa=b.x;this.wb=b.y;break;case 2:this.B={x:[b.x,b.x+b.tb-1,b.x+b.tb-1,b.x,b.x],y:[b.y,b.y,b.y+b.xb-1,b.y+b.xb-1,b.y]};this.Ba=b.x;this.Oa=b.y;this.Wa=b.x+b.tb-1;this.wb=b.y+b.xb-1;break;case 3:this.B={x:[],y:[]};this.Ba=b.x-b.pl;this.Oa=b.y-b.pl;this.Wa=b.x+b.pl;this.wb=b.y+b.pl;break;case 1:this.B={x:[b.dp,b.ep],y:[b.gp,b.hp]};this.Ba=Math.min(b.dp,b.ep);this.Oa=Math.min(b.gp,
b.hp);this.Wa=Math.max(b.dp,b.ep);this.wb=Math.max(b.gp,b.hp);break;case 4:this.B={x:[],y:[]};this.Ba=b.x[0];this.Oa=b.y[0];this.Wa=b.x[0];this.wb=b.y[0];for(c=0;c<b.x.length;c+=1)this.B.x.push(b.x[c]),this.B.y.push(b.y[c]),this.Ba=Math.min(this.Ba,b.x[c]),this.Oa=Math.min(this.Oa,b.y[c]),this.Wa=Math.max(this.Wa,b.x[c]),this.wb=Math.max(this.wb,b.y[c]);this.B.x.push(b.x[0]);this.B.y.push(b.y[0]);break;default:this.Oa=this.Ba=0,this.wb=this.Wa=-1}}
function Ob(a,b,c,d){return new Nb(2,{x:a,y:b,tb:c,xb:d})}function Pb(a){var b=1E6,c=-1E6,d=1E6,g=-1E6,h,k,l,n,q;for(h=0;h<a.F;h+=1)k=a.od[h]-a.Gb,l=k+a.Rc[h]-1,n=a.pd[h]-a.Hb,q=n+a.Qc[h]-1,k<b&&(b=k),l>c&&(c=l),n<d&&(d=n),q>g&&(g=q);return new Nb(2,{x:b,y:d,tb:c-b+1,xb:g-d+1})}e=Nb.prototype;
e.K=function(){var a=new Nb(-1,{}),b;a.kind=this.kind;a.Ba=this.Ba;a.Wa=this.Wa;a.Oa=this.Oa;a.wb=this.wb;a.B={x:[],y:[]};for(b=0;b<this.B.x.length;b+=1)a.B.x[b]=this.B.x[b];for(b=0;b<this.B.y.length;b+=1)a.B.y[b]=this.B.y[b];return a};e.translate=function(a,b){var c=this.K(),d;c.Ba+=a;c.Wa+=a;c.Oa+=b;c.wb+=b;for(d=0;d<c.B.x.length;d+=1)c.B.x[d]+=a;for(d=0;d<c.B.y.length;d+=1)c.B.y[d]+=b;return c};
e.scale=function(a){var b=this.K(),c;b.Ba*=a;b.Wa*=a;b.Oa*=a;b.wb*=a;for(c=0;c<b.B.x.length;c+=1)b.B.x[c]*=a;for(c=0;c<b.B.y.length;c+=1)b.B.y[c]*=a;return b};
e.rotate=function(a){var b,c,d,g;switch(this.kind){case 0:return b=new p(this.B.x[0],this.B.y[0]),b=b.rotate(a),new Nb(0,{x:b.x,y:b.y});case 1:return b=new p(this.B.x[0],this.B.y[0]),b=b.rotate(a),c=new p(this.B.x[1],this.B.y[1]),c=c.rotate(a),new Nb(1,{dp:b.x,gp:b.y,ep:c.x,hp:c.y});case 3:return b=(this.Wa-this.Ba)/2,c=new p(this.Ba+b,this.Oa+b),c=c.rotate(a),new Nb(3,{x:c.x,y:c.y,pl:b});default:c=[];d=[];for(g=0;g<this.B.x.length-1;g+=1)b=new p(this.B.x[g],this.B.y[g]),b=b.rotate(a),c.push(b.x),
d.push(b.y);return new Nb(4,{x:c,y:d})}};
function Qb(a,b,c,d,g){var h,k,l,n,q;if(d<b+a.Ba||d>b+a.Wa||g<c+a.Oa||g>c+a.wb)return!1;switch(a.kind){case 0:case 2:return!0;case 3:return l=(a.Wa-a.Ba)/2,d-=b+a.Ba+l,g-=c+a.Oa+l,d*d+g*g<=l*l;case 1:return l=b+a.B.x[0],n=c+a.B.y[0],b+=a.B.x[1],a=c+a.B.y[1],d===l?g===n:d===b?g===a:1>Math.abs(n+(d-l)*(a-n)/(b-l)-g);case 4:n=new p(0,0);q=new p(0,0);l=[];for(k=0;k<a.B.x.length-1;k+=1)n.x=a.B.x[k],n.y=a.B.y[k],q.x=a.B.x[k+1],q.y=a.B.y[k+1],l.push(da(new p(n.x-q.x,n.y-q.y)));for(n=0;n<l.length;n+=1){q=
new p(d,g);k=l[n];q=q.x*k.x+q.y*k.y;h=a;var w=b,A=c,E=l[n],s=new p(0,0),t=void 0,u=1E9;k=-1E10;for(var v=void 0,v=0;v<h.B.x.length;v+=1)s.x=w+h.B.x[v],s.y=A+h.B.y[v],t=s.x*E.x+s.y*E.y,u=Math.min(u,t),k=Math.max(k,t);h=u;if(q<h||k<q)return!1}return!0;default:return!1}}
e.dc=function(a,b,c){var d=r.context;d.fillStyle=c;d.strokeStyle=c;switch(this.kind){case 0:d.fillRect(a+this.Ba-1,b+this.Oa-1,3,3);break;case 2:d.fillRect(a+this.Ba,b+this.Oa,this.Wa-this.Ba+1,this.wb-this.Oa+1);break;case 3:c=(this.Wa-this.Ba)/2;d.beginPath();d.arc(a+this.Ba+c,b+this.Oa+c,c,0,2*Math.PI,!1);d.closePath();d.fill();break;case 1:d.beginPath();d.moveTo(a+this.B.x[0],b+this.B.y[0]);d.lineTo(a+this.B.x[1],b+this.B.y[1]);d.stroke();break;case 4:d.beginPath();d.moveTo(a+this.B.x[0],b+this.B.y[0]);
for(c=1;c<this.B.x.length-1;c+=1)d.lineTo(a+this.B.x[c],b+this.B.y[c]);d.closePath();d.fill()}};function Rb(){this.depth=1E7;this.visible=!1;this.k=!0;this.group="Engine";this.ja=[];this.vh=this.N=this.Fh=!1;this.le=1;this.ac=-1;this.na=-1E6}e=Rb.prototype;e.K=function(){var a=new Rb,b;for(b=0;b<this.ja.length;b+=1)a.ja.push({Ua:this.ja[b].Ua,action:this.ja[b].action});a.vh=this.vh;return a};
e.sa=function(a,b){var c,d;if(0===this.ja.length||this.ja[this.ja.length-1].Ua<=a)this.ja.push({Ua:a,action:b});else{for(c=0;this.ja[c].Ua<=a;)c+=1;for(d=this.ja.length;d>c;d-=1)this.ja[d]=this.ja[d-1];this.ja[c]={Ua:a,action:b}}this.na=-1E6};e.start=function(){this.Fh=!0;this.N=!1;this.ac=0>this.le&&0<this.ja.length?this.ja[this.ja.length-1].Ua+1:-1;this.na=-1E6;K.p(this);L(this)};
e.no=function(){if(0>this.le&&0<this.ja.length){var a=this.ja[this.ja.length-1].Ua;this.ac=0>this.le?a+1:a-1}else this.ac=0>this.le?1:-1;this.na=-1E6};e.stop=function(){this.Fh=!1;K.p(this)};e.be=function(){return this.Fh};e.pause=function(){this.N=!0;K.p(this)};e.Ii=function(){this.N=!1;K.p(this);L(this)};e.paused=function(){return this.Fh&&this.N};e.ns=function(a){this.vh=a};
e.pa=function(a){if(this.Fh&&!this.N&&0!==this.le)if(0<this.le){0>this.na&&(this.na=0);for(;this.na<this.ja.length&&this.ja[this.na].Ua<=this.ac;)this.na+=1;for(this.ac+=this.le*a;0<=this.na&&this.na<this.ja.length&&this.ja[this.na].Ua<=this.ac;)this.ja[this.na].action(this.ja[this.na].Ua,this),this.na+=1;this.na>=this.ja.length&&(this.vh?this.no():this.stop())}else{0>this.na&&(this.na=this.ja.length-1);for(;0<=this.na&&this.ja[this.na].Ua>=this.ac;)this.na-=1;for(this.ac+=this.le*a;0<=this.na&&this.ja[this.na].Ua>=
this.ac;)this.ja[this.na].action(this.ja[this.na].Ua,this),this.na-=1;0>this.na&&0>=this.ac&&(this.vh?this.no():this.stop())}};function Sb(){this.depth=1E7;this.visible=!1;this.k=!0;this.group="Engine";this.Mb=[];this.Ke=[];this.clear();this.Rx=!1;L(this)}e=Sb.prototype;e.pa=function(){var a,b,c,d,g;if(this.Rx)for(a=0;16>a;a+=1)K.ha[a].ob&&(b=K.ha[a].x,c=K.ha[a].y,d=this.Ke[a],g=this.Mb[d],!(0<=d&&g&&g.selected)||g&&Qb(g.Kc,0,0,b,c)||(zb(K,g.keyCode),g.selected=!1,this.Ke[a]=-1),this.zb(a,b,c))};
e.zb=function(a,b,c){var d;if(!(0<=this.Ke[a]))for(d=0;d<this.Mb.length;d+=1){var g;if(g=this.Mb[d])g=(g=this.Mb[d])?Qb(g.Kc,0,0,b,c):!1;if(g&&!this.Mb[d].selected){yb(K,this.Mb[d].keyCode);this.Mb[d].selected=!0;this.Ke[a]=d;break}}};e.Tb=function(a){var b=this.Ke[a];0<=b&&this.Mb[b]&&this.Mb[b].selected&&(zb(K,this.Mb[b].keyCode),this.Mb[b].selected=!1);this.Ke[a]=-1};function Tb(a,b,c,d,g,h,k){c=Ob(c,d,g,h);a.Mb.push({keyCode:k,Kc:c,id:b,selected:!1})}
e.clear=function(){var a;for(a=this.Mb.length=0;16>a;a+=1)this.Ke[a]=-1};e.dc=function(a,b,c){var d,g,h,k;for(d=0;d<this.Mb.length;d+=1)if(g=this.Mb[d])g.selected?g.Kc.dc(0,0,b):g.Kc.dc(0,0,a),h=(g.Kc.Ba+g.Kc.Wa)/2,k=(g.Kc.Oa+g.Kc.wb)/2,r.jc("id: "+g.id,h-20,k-10,c,"16px Arial"),r.jc("key: "+g.keyCode,h-20,k+10,c,"16px Arial")};new ea;function Ub(a,b){return b}function M(a,b,c,d){return b+a/d*c}function Vb(a,b,c,d,g){void 0===g&&(g=3);return b+c*Math.pow(a/d,g)}
function Wb(a,b,c,d){return Vb(a,b,c,d,2)}function Xb(a,b,c,d){return b+c*Vb(d-a,1,-1,d,2)}function Yb(a,b,c,d){return Vb(a,b,c,d,3)}function Zb(a,b,c,d){return b+c*Vb(d-a,1,-1,d,3)}function $b(a,b,c,d){return b+c*(a<d/2?Vb(a,0,.5,d/2,3):Vb(d-a,1,-.5,d/2,3))}function ac(a,b,c,d,g){a=d-a;var h=3,k=g;void 0===h&&(h=3);void 0===k&&(k=8);g=Math.sin(2*(1-a/d)*Math.PI*h+Math.PI/2);h=k;void 0===h&&(h=8);k=Math.pow(2,-h);g*=0+(Math.pow(2,h*a/d-h)-k)/(1-k)*1;return b+c*(1+-1*g)}
function bc(a,b,c,d,g){void 0===g&&(g=1.70158);return b+c*((1+g)*Math.pow(a/d,3)-g*Math.pow(a/d,2))}function N(a,b,c,d,g){return b+c*bc(d-a,1,-1,d,g)}
function cc(a){switch(1){case 0:return function(b,c,d,g,h,k,l){return 0>b?c:b>g?c+d:a(b,c,d,g,h,k,l)};case 1:return function(b,c,d,g,h,k,l){return a(b-Math.floor(b/g)*g,c,d,g,h,k,l)};case 2:return function(b,c,d,g,h,k,l){b=0===Math.floor(b/g)%2?a(b-Math.floor(b/g)*g,0,1,g,h,k,l):a(g-b+Math.floor(b/g)*g,0,1,g,h,k,l);return c+d*b};case 3:return function(b,c,d,g,h,k,l){h=a(b-Math.floor(b/g)*g,0,1,g,h,k,l);0!==Math.floor(b/g)%2&&(h=1-h);return c+d*h};case 4:return function(b,c,d,g,h,k,l){var n=Math.floor(b/
g);b=a(b-Math.floor(b/g)*g,0,1,g,h,k,l);return c+d*(n+b)};case 5:return function(b,c,d,g,h,k,l){var n=Math.floor(b/g);b=0===Math.floor(b/g)%2?a(b-Math.floor(b/g)*g,0,1,g,h,k,l):a(g-b+Math.floor(b/g)*g,1,-1,g,h,k,l);return c+d*(n+b)};default:return function(b,c,d,g,h,k,l){return a(b,c,d,g,h,k,l)}}}
function dc(a,b,c){var d,g=0,h=1,k=[0],l=[0];for(void 0===b&&(b=[]);b.length<a.length;)b.push(!1);for(void 0===c&&(c=[]);c.length<a.length;)c.push(1/a.length);for(d=0;d<a.length;d+=1)g+=c[d];for(d=0;d<a.length;d+=1)c[d]/=g;for(d=0;d<a.length;d+=1)l.push(l[d]+c[d]),g=a[d]===Ub?0:b[d]?-1:1,k.push(k[d]+g),h=Math.max(h,k[d+1]);return function(d,g,w,A,E,s,t){var u,v;u=a.length-1;for(v=0;v<a.length;v+=1)if(d/A<=l[v+1]){u=v;break}d=a[u](d/A-l[u],0,1,c[u],E,s,t);b[u]&&(d=-d);return g+(k[u]+d)*w/h}}
var O=window.TG_InitSettings||{};O.size=void 0!==O.size?O.size:"big";O.qt=O.usesFullScreen;O.ro="big"===O.size?1:.5;O.ff=20;O.ji=10;O.gf=0;O.ok=-10;O.Xm=-20;O.qb=-30;O.Wd=-40;
function P(a,b){var c;if("number"===typeof a){a:switch(b){case "floor":c=Math.floor(O.ro*a);break a;case "round":c=Math.round(O.ro*a);break a;default:c=O.ro*a}return c}if("[object Array]"===Object.prototype.toString.call(a)){for(c=0;c<a.length;c++)a[c]=P(a[c],b);return a}if("object"===typeof a){for(c in a)a.hasOwnProperty(c)&&(a[c]=P(a[c],b));return a}}function Q(a){return"big"===O.size?void 0!==a.big?a.big:a:void 0!==a.small?a.small:a}
window.throbber=new function(a,b,c){this.name=a;this.fileName=b;this.info=c}("throbber","media/throbber.png");var ec=new qa("StartTexture",2,"start");window.StartTexture=ec;ra(ec,0,"media/StartTexture0.png");ra(ec,1,"media/StartTexture1.png");var fc=new qa("StartScreenTexture",1,"load");window.StartScreenTexture=fc;ra(fc,0,"media/StartScreenTexture0.png");var R=new qa("LevelMapScreenTexture",2,"load");window.LevelMapScreenTexture=R;ra(R,0,"media/LevelMapScreenTexture0.png");ra(R,1,"media/LevelMapScreenTexture1.png");
var gc=new qa("LevelEndTexture",2,"load");window.LevelEndTexture=gc;ra(gc,0,"media/LevelEndTexture0.png");ra(gc,1,"media/LevelEndTexture1.png");var S=new qa("MenuTexture",2,"load");window.MenuTexture=S;ra(S,0,"media/MenuTexture0.png");ra(S,1,"media/MenuTexture1.png");var U=new qa("GameTexture",1,"load");window.GameTexture=U;ra(U,0,"media/GameTexture0.png");var hc=new qa("GameStaticTexture",3,"load");window.GameStaticTexture=hc;ra(hc,0,"media/GameStaticTexture0.png");ra(hc,1,"media/GameStaticTexture1.png");
ra(hc,2,"media/GameStaticTexture2.png");var ic=new x("s_loadingbar_background",fc,1,42,32,0,0,42,32,1);window.s_loadingbar_background=ic;ic.d(0,0,681,161,42,32,0,0);var jc=new x("s_loadingbar_fill",fc,1,20,12,0,0,20,12,1);window.s_loadingbar_fill=jc;jc.d(0,0,729,161,20,12,0,0);var kc=new x("s_level_0",R,1,125,140,0,0,125,140,1);window.s_level_0=kc;kc.d(0,0,649,1,125,140,0,0);var lc=new x("s_level_1",R,1,125,140,0,0,125,140,1);window.s_level_1=lc;lc.d(0,0,649,145,125,140,0,0);
var mc=new x("s_level_2",R,1,125,140,0,0,125,140,1);window.s_level_2=mc;mc.d(0,0,777,1,125,140,0,0);var nc=new x("s_level_3",R,1,125,140,0,0,125,140,1);window.s_level_3=nc;nc.d(0,0,777,145,125,140,0,0);var oc=new x("s_level_lock",R,1,48,70,0,0,48,70,1);window.s_level_lock=oc;oc.d(0,0,969,225,48,69,0,1);var pc=new x("s_level_stars",R,1,126,46,0,0,126,46,1);window.s_level_stars=pc;pc.d(0,0,649,289,126,45,0,1);var qc=new x("s_level2_0",R,1,84,87,0,0,84,87,1);window.s_level2_0=qc;
qc.d(0,0,649,497,84,87,0,0);var rc=new x("s_level2_1",R,1,84,87,0,0,84,87,1);window.s_level2_1=rc;rc.d(0,0,713,401,84,87,0,0);var sc=new x("s_level2_2",R,1,84,87,0,0,84,87,1);window.s_level2_2=sc;sc.d(0,0,889,433,84,87,0,0);var tc=new x("s_level2_3",R,1,84,87,0,0,84,87,1);window.s_level2_3=tc;tc.d(0,0,801,401,84,87,0,0);var uc=new x("s_level2_arrow_right",R,2,60,108,0,0,60,216,1);window.s_level2_arrow_right=uc;uc.d(0,0,841,289,60,108,0,0);uc.d(1,0,777,289,60,108,0,0);
var vc=new x("s_level2_arrow_left",R,2,60,108,0,0,60,216,1);window.s_level2_arrow_left=vc;vc.d(0,0,649,337,60,108,0,0);vc.d(1,0,905,225,60,108,0,0);var wc=new x("s_level2_lock",R,1,84,87,0,0,84,87,1);window.s_level2_lock=wc;wc.d(0,0,905,337,84,87,0,0);var xc=new x("s_pop_medal",gc,8,378,378,189,189,3024,378,8);window.s_pop_medal=xc;xc.d(0,0,625,1,349,241,3,69);xc.d(1,0,625,529,346,267,5,54);xc.d(2,0,625,249,348,276,20,56);xc.d(3,1,1,1,342,288,26,50);xc.d(4,1,689,1,319,292,22,46);
xc.d(5,1,1,297,337,304,14,41);xc.d(6,0,1,681,343,305,12,41);xc.d(7,1,345,1,341,304,13,41);var yc=new x("s_medal_shadow",gc,1,195,208,0,0,195,208,1);window.s_medal_shadow=yc;yc.d(0,1,745,513,189,204,3,1);var zc=new x("s_medal_shine",gc,6,195,208,0,0,1170,208,6);window.s_medal_shine=zc;zc.d(0,1,545,513,193,207,1,1);zc.d(1,1,345,313,193,207,1,1);zc.d(2,0,353,681,193,207,1,1);zc.d(3,1,689,297,193,207,1,1);zc.d(4,0,553,801,193,207,1,1);zc.d(5,0,753,801,193,207,1,1);
var Ac=new x("s_icon_toggle_hard",S,1,67,67,0,0,67,67,1);window.s_icon_toggle_hard=Ac;Ac.d(0,0,929,713,67,67,0,0);var Bc=new x("s_icon_toggle_medium",S,1,67,67,0,0,67,67,1);window.s_icon_toggle_medium=Bc;Bc.d(0,0,929,785,67,67,0,0);var Cc=new x("s_icon_toggle_easy",S,1,67,67,0,0,67,67,1);window.s_icon_toggle_easy=Cc;Cc.d(0,0,337,785,67,67,0,0);var Dc=new x("s_flagIcon_us",S,1,48,48,0,0,48,48,1);window.s_flagIcon_us=Dc;Dc.d(0,0,737,809,48,36,0,6);var Ec=new x("s_flagIcon_gb",S,1,48,48,0,0,48,48,1);
window.s_flagIcon_gb=Ec;Ec.d(0,0,681,809,48,36,0,6);var Fc=new x("s_flagIcon_nl",S,1,48,48,0,0,48,48,1);window.s_flagIcon_nl=Fc;Fc.d(0,0,625,809,48,36,0,6);var Gc=new x("s_flagIcon_tr",S,1,48,48,0,0,48,48,1);window.s_flagIcon_tr=Gc;Gc.d(0,0,849,809,48,36,0,6);var Hc=new x("s_flagIcon_de",S,1,48,48,0,0,48,48,1);window.s_flagIcon_de=Hc;Hc.d(0,0,625,849,48,36,0,6);var Ic=new x("s_flagIcon_fr",S,1,48,48,0,0,48,48,1);window.s_flagIcon_fr=Ic;Ic.d(0,0,849,849,48,36,0,6);
var Jc=new x("s_flagIcon_br",S,1,48,48,0,0,48,48,1);window.s_flagIcon_br=Jc;Jc.d(0,0,793,849,48,36,0,6);var Kc=new x("s_flagIcon_es",S,1,48,48,0,0,48,48,1);window.s_flagIcon_es=Kc;Kc.d(0,0,337,857,48,36,0,6);var Lc=new x("s_flagIcon_jp",S,1,48,48,0,0,48,48,1);window.s_flagIcon_jp=Lc;Lc.d(0,0,681,849,48,36,0,6);var Mc=new x("s_flagIcon_ru",S,1,48,48,0,0,48,48,1);window.s_flagIcon_ru=Mc;Mc.d(0,0,961,665,48,36,0,6);var Nc=new x("s_flagIcon_ar",S,1,48,48,0,0,48,48,1);window.s_flagIcon_ar=Nc;
Nc.d(0,0,737,849,48,36,0,6);var Oc=new x("s_flagIcon_kr",S,1,48,48,0,0,48,48,1);window.s_flagIcon_kr=Oc;Oc.d(0,0,793,809,48,36,0,6);var Pc=new x("s_tutorialButton_close",S,1,66,65,0,0,66,65,1);window.s_tutorialButton_close=Pc;Pc.d(0,0,553,809,65,65,0,0);var Qc=new x("s_tutorialButton_next",S,1,66,65,0,0,66,65,1);window.s_tutorialButton_next=Qc;Qc.d(0,0,481,809,66,65,0,0);var Rc=new x("s_tutorialButton_previous",S,1,66,65,0,0,66,65,1);window.s_tutorialButton_previous=Rc;Rc.d(0,0,409,809,66,65,0,0);
var Sc=new x("s_logo_tinglygames",S,1,240,240,0,0,240,240,1);window.s_logo_tinglygames=Sc;Sc.d(0,0,625,177,240,240,0,0);var Tc=new x("s_logo_coolgames",S,1,240,240,0,0,240,240,1);window.s_logo_coolgames=Tc;Tc.d(0,0,625,1,240,167,0,36);var Uc=new x("s_logo_tinglygames_start",fc,1,156,54,0,0,156,54,1);window.s_logo_tinglygames_start=Uc;Uc.d(0,0,529,1,156,53,0,0);var Vc=new x("s_logo_coolgames_start",fc,1,300,104,0,0,300,104,1);window.s_logo_coolgames_start=Vc;Vc.d(0,0,529,57,150,104,75,0);
var Wc=new x("s_coolmath_logo",ec,1,500,500,0,0,500,500,1);window.s_coolmath_logo=Wc;Wc.d(0,1,1,1,500,500,0,0);var Xc=new x("s_ui_cup_highscore",U,1,32,28,0,0,32,28,1);window.s_ui_cup_highscore=Xc;Xc.d(0,0,929,169,32,28,0,0);var Yc=new x("s_ui_cup_score",U,1,28,24,0,0,28,24,1);window.s_ui_cup_score=Yc;Yc.d(0,0,617,121,28,24,0,0);var Zc=new x("s_ui_difficulty_background",U,1,640,118,0,0,640,118,1);window.s_ui_difficulty_background=Zc;Zc.d(0,0,1,1,640,117,0,0);
var $c=new x("s_ui_smiley_hard",U,1,22,22,0,0,22,22,1);window.s_ui_smiley_hard=$c;$c.d(0,0,1001,1,22,22,0,0);var ad=new x("s_ui_smiley_medium",U,1,22,22,0,0,22,22,1);window.s_ui_smiley_medium=ad;ad.d(0,0,1001,25,22,22,0,0);var bd=new x("s_ui_smiley_easy",U,1,22,22,0,0,22,22,1);window.s_ui_smiley_easy=bd;bd.d(0,0,1001,49,22,22,0,0);var cd=new x("s_ui_crown",U,1,24,20,0,0,24,20,1);window.s_ui_crown=cd;cd.d(0,0,929,233,24,20,0,0);var dd=new x("s_ui_heart",U,1,28,24,0,0,28,24,1);window.s_ui_heart=dd;
dd.d(0,0,929,201,26,23,1,1);var ed=new x("s_ui_background_blank",hc,1,640,118,0,0,640,118,1);window.s_ui_background_blank=ed;ed.d(0,1,1,1,640,117,0,0);var fd=new x("s_ui_highscore",hc,1,26,36,13,12,26,36,1);window.s_ui_highscore=fd;fd.d(0,0,993,569,26,36,0,0);var gd=new x("s_level_preview_frame_locked",R,1,108,110,0,0,108,110,1);window.s_level_preview_frame_locked=gd;gd.d(0,0,905,1,108,110,0,0);var hd=new x("s_level_preview_frame",R,1,108,110,0,0,108,110,1);window.s_level_preview_frame=hd;
hd.d(0,0,905,113,108,110,0,0);var id=new x("s_icon_toggle_sfx_on",S,1,67,67,0,0,67,67,1);window.s_icon_toggle_sfx_on=id;id.d(0,0,929,385,49,31,7,17);var jd=new x("s_icon_toggle_sfx_off",S,1,67,67,0,0,67,67,1);window.s_icon_toggle_sfx_off=jd;jd.d(0,0,873,385,53,31,7,17);var kd=new x("s_icon_toggle_music_on",S,1,67,67,0,0,67,67,1);window.s_icon_toggle_music_on=kd;kd.d(0,0,977,1,38,41,13,16);var ld=new x("s_icon_toggle_music_off",S,1,67,67,0,0,67,67,1);window.s_icon_toggle_music_off=ld;
ld.d(0,0,961,617,51,41,8,16);var md=new x("s_btn_small_exit",S,2,100,92,0,0,200,92,2);window.s_btn_small_exit=md;md.d(0,0,873,97,100,92,0,0);md.d(1,0,873,1,100,92,0,0);var nd=new x("s_btn_small_pause",U,2,100,92,0,0,200,92,2);window.s_btn_small_pause=nd;nd.d(0,0,825,265,100,92,0,0);nd.d(1,0,825,169,100,92,0,0);var od=new x("s_btn_small_options",S,2,100,92,0,0,200,92,2);window.s_btn_small_options=od;od.d(0,0,873,193,100,92,0,0);od.d(1,0,873,289,100,92,0,0);
var pd=new x("s_btn_small_retry",gc,2,100,92,0,0,200,92,2);window.s_btn_small_retry=pd;pd.d(0,0,353,897,100,92,0,0);pd.d(1,1,889,297,100,92,0,0);var qd=new x("s_btn_standard",S,2,96,92,0,0,192,92,2);window.s_btn_standard=qd;qd.d(0,0,233,785,96,92,0,0);qd.d(1,0,857,617,96,92,0,0);var rd=new x("s_btn_toggle",S,2,162,92,0,0,324,92,2);window.s_btn_toggle=rd;rd.d(0,0,857,425,162,92,0,0);rd.d(1,0,857,521,162,92,0,0);var sd=new x("s_icon_toggle_fxoff",S,2,227,92,0,0,454,92,2);
window.s_icon_toggle_fxoff=sd;sd.d(0,0,1,785,227,92,0,0);sd.d(1,0,625,617,227,92,0,0);var td=new x("s_icon_toggle_fxon",S,2,227,92,0,0,454,92,2);window.s_icon_toggle_fxon=td;td.d(0,0,233,689,227,92,0,0);td.d(1,0,697,713,227,92,0,0);var ud=new x("s_icon_toggle_musicoff",S,2,227,92,0,0,454,92,2);window.s_icon_toggle_musicoff=ud;ud.d(0,0,465,713,227,92,0,0);ud.d(1,0,1,689,227,92,0,0);var vd=new x("s_icon_toggle_musicon",S,2,227,92,0,0,454,92,2);window.s_icon_toggle_musicon=vd;
vd.d(0,0,625,425,227,92,0,0);vd.d(1,0,625,521,227,92,0,0);var wd=new x("s_btn_big_start",gc,2,154,152,0,0,308,152,2);window.s_btn_big_start=wd;wd.d(0,1,321,689,154,152,0,0);wd.d(1,1,161,609,154,152,0,0);var xd=new x("s_btn_bigtext",fc,2,153,152,0,0,306,152,2);window.s_btn_bigtext=xd;xd.d(0,0,849,1,153,152,0,0);xd.d(1,0,689,1,153,152,0,0);var zd=new x("s_btn_big_restart",gc,2,154,152,0,0,308,152,2);window.s_btn_big_restart=zd;zd.d(0,1,345,529,154,152,0,0);zd.d(1,1,1,609,154,152,0,0);
var Ad=new x("s_overlay_assignment",hc,1,605,348,0,0,605,348,1);window.s_overlay_assignment=Ad;Ad.d(0,2,1,1,605,348,0,0);var Bd=new x("s_overlay_options",S,1,616,679,0,0,616,679,1);window.s_overlay_options=Bd;Bd.d(0,0,1,1,616,679,0,0);var Dd=new x("s_screen_start",ec,1,640,960,0,0,640,960,1);window.s_screen_start=Dd;Dd.d(0,0,1,1,640,960,0,0);var Ed=new x("s_tutorial",S,1,524,561,0,0,524,561,1);window.s_tutorial=Ed;Ed.d(0,1,1,1,524,561,0,0);
var Fd=new x("s_overlay_dialog",hc,1,616,554,0,0,616,554,1);window.s_overlay_dialog=Fd;Fd.d(0,1,1,121,616,554,0,0);var Gd=new x("s_overlay_difficulty",gc,1,616,675,0,0,616,675,1);window.s_overlay_difficulty=Gd;Gd.d(0,0,1,1,616,675,0,0);var Hd=new x("s_screen_levelselect",R,1,640,960,0,0,640,960,1);window.s_screen_levelselect=Hd;Hd.d(0,0,1,1,640,960,0,0);var Id=new x("s_seasons_01_red_01",U,1,88,98,0,0,88,98,1);window.s_seasons_01_red_01=Id;Id.d(0,0,769,585,88,97,0,0);
var Jd=new x("s_seasons_01_red_02",U,1,88,98,0,0,88,98,1);window.s_seasons_01_red_02=Jd;Jd.d(0,0,673,569,88,97,0,0);var Kd=new x("s_seasons_01_red_03",U,1,88,98,0,0,88,98,1);window.s_seasons_01_red_03=Kd;Kd.d(0,0,385,585,88,97,0,0);var Ld=new x("s_seasons_01_red_04",U,1,88,98,0,0,88,98,1);window.s_seasons_01_red_04=Ld;Ld.d(0,0,97,593,88,97,0,0);var Md=new x("s_seasons_02_green_01",U,1,88,98,0,0,88,98,1);window.s_seasons_02_green_01=Md;Md.d(0,0,481,609,88,97,0,0);
var Nd=new x("s_seasons_02_green_02",U,1,88,98,0,0,88,98,1);window.s_seasons_02_green_02=Nd;Nd.d(0,0,865,585,88,97,0,0);var Od=new x("s_seasons_02_green_03",U,1,88,98,0,0,88,98,1);window.s_seasons_02_green_03=Od;Od.d(0,0,769,689,88,97,0,0);var Pd=new x("s_seasons_02_green_04",U,1,88,98,0,0,88,98,1);window.s_seasons_02_green_04=Pd;Pd.d(0,0,289,585,88,97,0,0);var Qd=new x("s_logo",fc,1,524,258,0,0,524,258,1);window.s_logo=Qd;Qd.d(0,0,1,1,524,258,0,0);
var Rd=new x("ImgTileOverlay",U,1,88,98,0,0,88,98,1);window.ImgTileOverlay=Rd;Rd.d(0,0,1,809,58,81,1,1);var Sd=new x("s_effect_hint",U,9,106,106,0,0,954,106,9);window.s_effect_hint=Sd;Sd.d(0,0,961,673,61,84,17,8);Sd.d(1,0,937,793,63,86,16,7);Sd.d(2,0,393,793,67,90,14,5);Sd.d(3,0,249,793,68,91,14,5);Sd.d(4,0,745,169,78,101,9,0);Sd.d(5,0,1,705,72,95,12,3);Sd.d(6,0,865,793,67,90,14,5);Sd.d(7,0,81,801,63,86,16,7);Sd.d(8,0,961,585,61,84,17,8);var Td=new x("s_effect_select",U,7,164,164,0,0,1148,164,7);
window.s_effect_select=Td;Td.d(0,0,697,777,68,92,48,34);Td.d(1,0,625,777,68,92,48,34);Td.d(2,0,97,697,72,95,46,33);Td.d(3,0,177,761,70,93,48,34);Td.d(4,0,553,713,69,93,47,33);Td.d(5,0,321,793,69,91,47,35);Td.d(6,0,481,713,70,93,47,34);var Ud=new x("s_tutorial_01",hc,1,350,190,0,0,350,190,1);window.s_tutorial_01=Ud;Ud.d(0,1,625,569,246,137,52,27);var Vd=new x("s_tutorial_02",hc,1,350,190,0,0,350,190,1);window.s_tutorial_02=Vd;Vd.d(0,1,1,681,246,137,52,27);
var Wd=new x("s_tutorial_03",hc,1,350,190,0,0,350,190,1);window.s_tutorial_03=Wd;Wd.d(0,0,649,745,246,186,51,4);var Xd=new x("s_tutorial_04",hc,1,350,190,0,0,350,190,1);window.s_tutorial_04=Xd;Xd.d(0,0,649,569,282,171,34,19);var Yd=new x("ImgTileBamboo1",U,1,88,98,0,0,88,98,1);window.ImgTileBamboo1=Yd;Yd.d(0,0,577,609,88,97,0,0);var Zd=new x("ImgTileBamboo2",U,1,88,98,0,0,88,98,1);window.ImgTileBamboo2=Zd;Zd.d(0,0,193,657,88,97,0,0);var $d=new x("ImgTileBamboo3",U,1,88,98,0,0,88,98,1);
window.ImgTileBamboo3=$d;$d.d(0,0,865,689,88,97,0,0);var ae=new x("ImgTileBamboo4",U,1,88,98,0,0,88,98,1);window.ImgTileBamboo4=ae;ae.d(0,0,385,689,88,97,0,0);var be=new x("ImgTileBamboo5",U,1,88,98,0,0,88,98,1);window.ImgTileBamboo5=be;be.d(0,0,673,673,88,97,0,0);var ce=new x("ImgTileBamboo6",U,1,88,98,0,0,88,98,1);window.ImgTileBamboo6=ce;ce.d(0,0,289,689,88,97,0,0);var de=new x("ImgTileBamboo7",U,1,88,98,0,0,88,98,1);window.ImgTileBamboo7=de;de.d(0,0,1,601,88,97,0,0);
var ee=new x("ImgTileBamboo8",U,1,88,98,0,0,88,98,1);window.ImgTileBamboo8=ee;ee.d(0,0,825,481,88,97,0,0);var fe=new x("ImgTileBamboo9",U,1,88,98,0,0,88,98,1);window.ImgTileBamboo9=fe;fe.d(0,0,249,345,88,97,0,0);var ge=new x("ImgTileChar1",U,1,88,98,0,0,88,98,1);window.ImgTileChar1=ge;ge.d(0,0,809,361,88,97,0,0);var he=new x("ImgTileChar2",U,1,88,98,0,0,88,98,1);window.ImgTileChar2=he;he.d(0,0,345,377,88,97,0,0);var ie=new x("ImgTileChar3",U,1,88,98,0,0,88,98,1);window.ImgTileChar3=ie;
ie.d(0,0,441,377,88,97,0,0);var je=new x("ImgTileChar4",U,1,88,98,0,0,88,98,1);window.ImgTileChar4=je;je.d(0,0,905,377,88,97,0,0);var ke=new x("ImgTileChar5",U,1,88,98,0,0,88,98,1);window.ImgTileChar5=ke;ke.d(0,0,713,297,88,97,0,0);var le=new x("ImgTileChar6",U,1,88,98,0,0,88,98,1);window.ImgTileChar6=le;le.d(0,0,617,297,88,97,0,0);var me=new x("ImgTileChar7",U,1,88,98,0,0,88,98,1);window.ImgTileChar7=me;me.d(0,0,521,273,88,97,0,0);var ne=new x("ImgTileChar8",U,1,88,98,0,0,88,98,1);
window.ImgTileChar8=ne;ne.d(0,0,929,273,88,97,0,0);var oe=new x("ImgTileChar9",U,1,88,98,0,0,88,98,1);window.ImgTileChar9=oe;oe.d(0,0,153,281,88,97,0,0);var pe=new x("ImgTileCircle1",U,1,88,98,0,0,88,98,1);window.ImgTileCircle1=pe;pe.d(0,0,1,289,88,97,0,0);var qe=new x("ImgTileCircle2",U,1,88,98,0,0,88,98,1);window.ImgTileCircle2=qe;qe.d(0,0,97,385,88,97,0,0);var re=new x("ImgTileCircle3",U,1,88,98,0,0,88,98,1);window.ImgTileCircle3=re;re.d(0,0,1,393,88,97,0,0);
var se=new x("ImgTileCircle4",U,1,88,98,0,0,88,98,1);window.ImgTileCircle4=se;se.d(0,0,537,401,88,97,0,0);var te=new x("ImgTileCircle5",U,1,88,98,0,0,88,98,1);window.ImgTileCircle5=te;te.d(0,0,97,489,88,97,0,0);var ue=new x("ImgTileCircle6",U,1,88,98,0,0,88,98,1);window.ImgTileCircle6=ue;ue.d(0,0,1,497,88,97,0,0);var ve=new x("ImgTileCircle7",U,1,88,98,0,0,88,98,1);window.ImgTileCircle7=ve;ve.d(0,0,481,505,88,97,0,0);var we=new x("ImgTileCircle8",U,1,88,98,0,0,88,98,1);window.ImgTileCircle8=we;
we.d(0,0,577,505,88,97,0,0);var xe=new x("ImgTileCircle9",U,1,88,98,0,0,88,98,1);window.ImgTileCircle9=xe;xe.d(0,0,921,481,88,97,0,0);var ye=new x("ImgTileDragon1",U,1,88,98,0,0,88,98,1);window.ImgTileDragon1=ye;ye.d(0,0,425,273,88,97,0,0);var ze=new x("ImgTileDragon2",U,1,88,98,0,0,88,98,1);window.ImgTileDragon2=ze;ze.d(0,0,385,481,88,97,0,0);var Ae=new x("ImgTileDragon3",U,1,88,98,0,0,88,98,1);window.ImgTileDragon3=Ae;Ae.d(0,0,633,401,88,97,0,0);
var Be=new x("ImgTileHonor1",U,1,88,98,0,0,88,98,1);window.ImgTileHonor1=Be;Be.d(0,0,193,449,88,97,0,0);var Ce=new x("ImgTileHonor2",U,1,88,98,0,0,88,98,1);window.ImgTileHonor2=Ce;Ce.d(0,0,729,465,88,97,0,0);var De=new x("ImgTileHonor3",U,1,88,98,0,0,88,98,1);window.ImgTileHonor3=De;De.d(0,0,289,481,88,97,0,0);var Ee=new x("ImgTileHonor4",U,1,88,98,0,0,88,98,1);window.ImgTileHonor4=Ee;Ee.d(0,0,193,553,88,97,0,0);var Fe=new x("ImgDissapear",U,13,164,164,40,35,2132,164,13);window.ImgDissapear=Fe;
Fe.d(0,0,985,153,29,116,70,28);Fe.d(1,0,985,1,7,149,79,12);Fe.d(2,0,1,121,48,161,57,2);Fe.d(3,0,57,121,94,161,42,2);Fe.d(4,0,617,169,120,125,21,16);Fe.d(5,0,321,121,149,147,7,9);Fe.d(6,0,153,121,159,158,2,0);Fe.d(7,0,817,1,162,162,1,1);Fe.d(8,0,649,1,162,164,1,0);Fe.d(9,0,473,121,137,145,11,5);Fe.d(10,0,465,809,79,62,38,50);Fe.d(11,0,769,793,90,76,37,43);Fe.d(12,0,321,273,98,70,40,40);var Ge=new x("s_background",hc,1,640,960,0,0,640,960,1);window.s_background=Ge;Ge.d(0,0,1,1,640,960,0,0);
var He=new x("s_refresh_icon",hc,1,84,84,42,42,84,84,1);window.s_refresh_icon=He;He.d(0,0,937,569,52,58,16,13);var Ie=new x("s_refresh_left",hc,1,361,560,0,0,361,560,1);window.s_refresh_left=Ie;Ie.d(0,0,649,1,361,560,0,0);var Je=new x("s_refresh_right",hc,1,320,560,0,0,320,560,1);window.s_refresh_right=Je;Je.d(0,1,649,1,320,560,0,0);var Ke=new x("s_levelicon_0",R,1,84,84,0,0,84,84,1);window.s_levelicon_0=Ke;Ke.d(0,0,825,793,84,84,0,0);var Le=new x("s_levelicon_1",R,1,84,84,0,0,84,84,1);
window.s_levelicon_1=Le;Le.d(0,0,825,881,84,84,0,0);var Me=new x("s_levelicon_10",R,1,84,84,0,0,84,84,1);window.s_levelicon_10=Me;Me.d(0,0,649,857,84,84,0,0);var Ne=new x("s_levelicon_11",R,1,84,84,0,0,84,84,1);window.s_levelicon_11=Ne;Ne.d(0,0,649,769,84,84,0,0);var Oe=new x("s_levelicon_12",R,1,84,84,0,0,84,84,1);window.s_levelicon_12=Oe;Oe.d(0,0,913,793,84,84,0,0);var Pe=new x("s_levelicon_13",R,1,84,84,0,0,84,84,1);window.s_levelicon_13=Pe;Pe.d(0,0,737,937,84,84,0,0);
var Qe=new x("s_levelicon_14",R,1,84,84,0,0,84,84,1);window.s_levelicon_14=Qe;Qe.d(0,1,89,1,84,84,0,0);var Re=new x("s_levelicon_15",R,1,84,84,0,0,84,84,1);window.s_levelicon_15=Re;Re.d(0,1,353,1,84,84,0,0);var Se=new x("s_levelicon_16",R,1,84,84,0,0,84,84,1);window.s_levelicon_16=Se;Se.d(0,1,265,1,84,84,0,0);var Te=new x("s_levelicon_17",R,1,84,84,0,0,84,84,1);window.s_levelicon_17=Te;Te.d(0,1,177,1,84,84,0,0);var Ue=new x("s_levelicon_18",R,1,84,84,0,0,84,84,1);window.s_levelicon_18=Ue;
Ue.d(0,1,1,1,84,84,0,0);var Ve=new x("s_levelicon_19",R,1,84,84,0,0,84,84,1);window.s_levelicon_19=Ve;Ve.d(0,0,913,881,84,84,0,0);var We=new x("s_levelicon_2",R,1,84,84,0,0,84,84,1);window.s_levelicon_2=We;We.d(0,0,737,761,84,84,0,0);var Xe=new x("s_levelicon_20",R,1,84,84,0,0,84,84,1);window.s_levelicon_20=Xe;Xe.d(0,0,649,593,84,84,0,0);var Ye=new x("s_levelicon_21",R,1,84,84,0,0,84,84,1);window.s_levelicon_21=Ye;Ye.d(0,0,737,585,84,84,0,0);var Ze=new x("s_levelicon_22",R,1,84,84,0,0,84,84,1);
window.s_levelicon_22=Ze;Ze.d(0,0,913,529,84,84,0,0);var $e=new x("s_levelicon_23",R,1,84,84,0,0,84,84,1);window.s_levelicon_23=$e;$e.d(0,0,825,529,84,84,0,0);var af=new x("s_levelicon_24",R,1,84,84,0,0,84,84,1);window.s_levelicon_24=af;af.d(0,0,825,617,84,84,0,0);var bf=new x("s_levelicon_3",R,1,84,84,0,0,84,84,1);window.s_levelicon_3=bf;bf.d(0,0,913,617,84,84,0,0);var cf=new x("s_levelicon_4",R,1,84,84,0,0,84,84,1);window.s_levelicon_4=cf;cf.d(0,0,737,673,84,84,0,0);
var df=new x("s_levelicon_5",R,1,84,84,0,0,84,84,1);window.s_levelicon_5=df;df.d(0,0,737,497,84,84,0,0);var ef=new x("s_levelicon_6",R,1,84,84,0,0,84,84,1);window.s_levelicon_6=ef;ef.d(0,0,913,705,84,84,0,0);var ff=new x("s_levelicon_7",R,1,84,84,0,0,84,84,1);window.s_levelicon_7=ff;ff.d(0,0,825,705,84,84,0,0);var gf=new x("s_levelicon_8",R,1,84,84,0,0,84,84,1);window.s_levelicon_8=gf;gf.d(0,0,649,681,84,84,0,0);var hf=new x("s_levelicon_9",R,1,84,84,0,0,84,84,1);window.s_levelicon_9=hf;
hf.d(0,0,737,849,84,84,0,0);var jf=new ta("f_default","fonts/f_default.woff","fonts/f_default.ttf","fonts");window.f_defaultLoader=jf;var V=new xa("f_default","Arial");window.f_default=V;D(V,12);V.fill=!0;V.setFillColor("Black");V.Ya=1;Ba(V,!1);V.setStrokeColor("Black");Ca(V,1);Ea(V,"miter");V.$a=1;Da(V,!1);F(V,"left");G(V,"top");V.Va=0;V.fa=0;var kf=new ta("ff_opensans_extrabold","fonts/ff_opensans_extrabold.woff","fonts/ff_opensans_extrabold.ttf","fonts");window.ff_opensans_extraboldLoader=kf;
var lf=new ta("ff_dimbo_regular","fonts/ff_dimbo_regular.woff","fonts/ff_dimbo_regular.ttf","fonts");window.ff_dimbo_regularLoader=lf;var mf=new ta("ff_opensans_bold","fonts/ff_opensans_bold.woff","fonts/ff_opensans_bold.ttf","fonts");window.ff_opensans_boldLoader=mf;var nf=new ta("ff_opensans_bolditalic","fonts/ff_opensans_bolditalic.woff","fonts/ff_opensans_bolditalic.ttf","fonts");window.ff_opensans_bolditalicLoader=nf;var of=new xa("ff_opensans_bold","Arial");window.f_game_ui_tiny=of;D(of,11);
of.fill=!0;of.setFillColor("#799EC5");of.Ya=1;Ba(of,!1);of.setStrokeColor("White");Ca(of,1);Ea(of,"miter");of.$a=1;Da(of,!1);F(of,"center");G(of,"middle");of.Va=0;of.fa=0;var pf=new xa("ff_opensans_bold","Arial");window.f_game_ui=pf;D(pf,23);pf.fill=!0;pf.setFillColor("#799EC5");pf.Ya=1;Ba(pf,!1);pf.setStrokeColor("Black");Ca(pf,1);Ea(pf,"miter");pf.$a=1;Da(pf,!1);F(pf,"center");G(pf,"middle");pf.Va=0;pf.fa=0;var qf=new xa("ff_opensans_bolditalic","Arial");window.f_game_ui_large=qf;D(qf,52);
qf.fill=!0;qf.setFillColor("#172348");qf.Ya=1;Ba(qf,!1);qf.setStrokeColor("Black");Ca(qf,1);Ea(qf,"miter");qf.$a=1;Da(qf,!1);F(qf,"center");G(qf,"middle");qf.Va=0;qf.fa=0;var rf=new ta("floaterFontFace","fonts/floaterFontFace.woff","fonts/floaterFontFace.ttf","fonts");window.floaterFontFaceLoader=rf;var sf=new ta("floaterNumberFontFace","fonts/floaterNumberFontFace.woff","fonts/floaterNumberFontFace.ttf","fonts");window.floaterNumberFontFaceLoader=sf;var tf=new xa("floaterFontFace","Arial");
window.floaterFontText1=tf;D(tf,24);ya(tf);tf.fill=!0;tf.setFillColor("#FFDE00");tf.Ya=1;Ba(tf,!0);tf.setStrokeColor("#6F1F00");Ca(tf,4);Ea(tf,"miter");tf.$a=1;Da(tf,!0);Fa(tf,"rgba(57,0,0,0.46)",4);F(tf,"left");G(tf,"top");tf.Va=0;tf.fa=0;var uf=new xa("floaterFontFace","Arial");window.floaterFontText2=uf;D(uf,28);ya(uf);uf.fill=!0;Aa(uf,2,["#FFF600","#00DB48","blue"],.65,.02);uf.Ya=1;Ba(uf,!0);uf.setStrokeColor("#073400");Ca(uf,4);Ea(uf,"miter");uf.$a=1;Da(uf,!0);Fa(uf,"rgba(0,57,43,0.47)",4);
F(uf,"left");G(uf,"top");uf.Va=0;uf.fa=0;var vf=new xa("floaterFontFace","Arial");window.floaterFontText3=vf;D(vf,30);ya(vf);vf.fill=!0;Aa(vf,3,["#FFF600","#FF8236","#FF0096"],.71,-.1);vf.Ya=1;Ba(vf,!0);vf.setStrokeColor("#4F0027");Ca(vf,4);Ea(vf,"miter");vf.$a=1;Da(vf,!0);Fa(vf,"rgba(41,0,0,0.48)",5);F(vf,"left");G(vf,"top");vf.Va=0;vf.fa=0;var wf=new xa("floaterFontFace","Arial");window.floaterFontText4=wf;D(wf,34);ya(wf);wf.fill=!0;Aa(wf,3,["#00FCFF","#893DFB","#FF00E4"],.72,-.04);wf.Ya=1;
Ba(wf,!0);wf.setStrokeColor("#001637");Ca(wf,4);Ea(wf,"miter");wf.$a=1;Da(wf,!0);Fa(wf,"rgba(0,35,75,0.49)",6);F(wf,"left");G(wf,"top");wf.Va=0;wf.fa=0;var xf=new xa("floaterNumberFontFace","Arial");window.floaterFontNumberPositive=xf;D(xf,30);xf.fill=!0;xf.setFillColor("White");xf.Ya=1;Ba(xf,!0);xf.setStrokeColor("#00106F");Ca(xf,2);Ea(xf,"miter");xf.$a=1;Da(xf,!1);Fa(xf,"rgba(0,4,57,0.51)",4);F(xf,"left");G(xf,"top");xf.Va=0;xf.fa=0;var yf=new xa("floaterNumberFontFace","Arial");
window.floaterFontNumberNegative=yf;D(yf,30);ya(yf);yf.fill=!0;yf.setFillColor("#FF1E00");yf.Ya=1;Ba(yf,!0);yf.setStrokeColor("#3F0000");Ca(yf,2);Ea(yf,"miter");yf.$a=1;Da(yf,!1);Fa(yf,"rgba(57,0,0,0.49)",4);F(yf,"left");G(yf,"top");yf.Va=0;yf.fa=0;var zf=new ta("f_themeDefault","fonts/f_themeDefault.woff","fonts/f_themeDefault.ttf","fonts");window.f_themeDefaultLoader=zf;var X=new xa("f_themeDefault","Arial");window.f_themeDefault=X;D(X,12);X.fill=!0;X.setFillColor("Black");X.Ya=1;Ba(X,!1);X.setStrokeColor("White");
Ca(X,5);Ea(X,"miter");X.$a=1;Da(X,!0);F(X,"left");G(X,"top");X.Va=0;X.fa=0;var Af=new xa("ff_opensans_bolditalic","Arial");window.f_awesome=Af;D(Af,25);ya(Af);Af.fill=!0;Aa(Af,3,["#00FCFF","#893DFB","#FF00E4"],.72,-.04);Af.Ya=1;Ba(Af,!0);Af.setStrokeColor("#001637");Ca(Af,4);Ea(Af,"round");Af.$a=1;Da(Af,!0);Fa(Af,"rgba(0,35,75,0.49)",3);F(Af,"left");G(Af,"top");Af.Va=0;Af.fa=0;var Bf=new xa("ff_opensans_bolditalic","Arial");window.f_great=Bf;D(Bf,24);ya(Bf);Bf.fill=!0;
Aa(Bf,3,["#FFF600","#FF8236","#FF0096"],.71,-.1);Bf.Ya=1;Ba(Bf,!0);Bf.setStrokeColor("#4F0027");Ca(Bf,4);Ea(Bf,"round");Bf.$a=1;Da(Bf,!0);Fa(Bf,"rgba(41,0,0,0.48)",3);F(Bf,"left");G(Bf,"top");Bf.Va=0;Bf.fa=0;var Cf=new xa("ff_opensans_bolditalic","Arial");window.f_nice=Cf;D(Cf,24);ya(Cf);Cf.fill=!0;Aa(Cf,2,["#FFF600","#00DB48","blue"],.65,.02);Cf.Ya=1;Ba(Cf,!0);Cf.setStrokeColor("#073400");Ca(Cf,4);Ea(Cf,"round");Cf.$a=1;Da(Cf,!0);Fa(Cf,"rgba(0,57,43,0.47)",2);F(Cf,"left");G(Cf,"top");Cf.Va=0;
Cf.fa=0;var Df=new ib("as_music","audio/as_music.mp3","audio/as_music.ogg","audio_music");window.as_music=Df;var Ef=new ib("audioSprite","audio/audioSprite.mp3","audio/audioSprite.ogg","audio");window.audioSprite=Ef;var Ff=new bb("a_music",Df,0,36571,1,1,["music"]);window.a_music=Ff;var Gf=new bb("a_tileSelection_first",Ef,0,352,1,10,["game"]);window.a_tileSelection_first=Gf;var Hf=new bb("a_tileSelection_second",Ef,2E3,529,1,10,["game"]);window.a_tileSelection_second=Hf;
var If=new bb("a_tileRemove",Ef,4E3,869,1,10,["game"]);window.a_tileRemove=If;var Jf=new bb("a_tileShuffle",Ef,6E3,736,1,10,["game"]);window.a_tileShuffle=Jf;var Kf=new bb("a_doorsClose",Ef,8E3,1062,1,10,["game"]);window.a_doorsClose=Kf;var Lf=new bb("a_doorsOpen",Ef,11E3,902,1,10,["game"]);window.a_doorsOpen=Lf;var Mf=new bb("a_levelStart",Ef,13E3,1002,1,10,["sfx"]);window.a_levelStart=Mf;var Nf=new bb("a_levelComplete",Ef,16E3,1002,1,10,["sfx"]);window.a_levelComplete=Nf;
var Of=new bb("a_mouseDown",Ef,19E3,471,1,10,["sfx"]);window.a_mouseDown=Of;var Pf=new bb("a_levelend_star_01",Ef,21E3,1161,1,10,["sfx"]);window.a_levelend_star_01=Pf;var Qf=new bb("a_levelend_star_02",Ef,24E3,1070,1,10,["sfx"]);window.a_levelend_star_02=Qf;var Sf=new bb("a_levelend_star_03",Ef,27E3,1039,1,10,["sfx"]);window.a_levelend_star_03=Sf;var Tf=new bb("a_levelend_fail",Ef,3E4,1572,1,10,["sfx"]);window.a_levelend_fail=Tf;var Uf=new bb("a_levelend_score_counter",Ef,33E3,54,1,10,["sfx"]);
window.a_levelend_score_counter=Uf;var Vf=new bb("a_levelend_score_end",Ef,35E3,888,1,10,["sfx"]);window.a_levelend_score_end=Vf;var Wf=new bb("a_medal",Ef,37E3,1225,1,10,["sfx"]);window.a_medal=Wf;var Y=Y||{};Y["nl-nl"]=Y["nl-nl"]||{};Y["nl-nl"].game_ui_SCORE="SCORE";Y["nl-nl"].game_ui_STAGE="LEVEL";Y["nl-nl"].game_ui_LIVES="LEVENS";Y["nl-nl"].game_ui_TIME="TIJD";Y["nl-nl"].game_ui_HIGHSCORE="HIGH SCORE";Y["nl-nl"].game_ui_LEVEL="LEVEL";Y["nl-nl"].game_ui_time_left="Resterende tijd";
Y["nl-nl"].game_ui_TIME_TO_BEAT="DOELTIJD";Y["nl-nl"].game_ui_SCORE_TO_BEAT="DOELSCORE";Y["nl-nl"].game_ui_HIGHSCORE_break="HIGH\nSCORE";Y["en-us"]=Y["en-us"]||{};Y["en-us"].game_ui_SCORE="SCORE";Y["en-us"].game_ui_STAGE="STAGE";Y["en-us"].game_ui_LIVES="LIVES";Y["en-us"].game_ui_TIME="TIME";Y["en-us"].game_ui_HIGHSCORE="HIGH SCORE";Y["en-us"].game_ui_LEVEL="LEVEL";Y["en-us"].game_ui_time_left="Time left";Y["en-us"].game_ui_TIME_TO_BEAT="TIME TO BEAT";Y["en-us"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";
Y["en-us"].game_ui_HIGHSCORE_break="HIGH\nSCORE";Y["en-gb"]=Y["en-gb"]||{};Y["en-gb"].game_ui_SCORE="SCORE";Y["en-gb"].game_ui_STAGE="STAGE";Y["en-gb"].game_ui_LIVES="LIVES";Y["en-gb"].game_ui_TIME="TIME";Y["en-gb"].game_ui_HIGHSCORE="HIGH SCORE";Y["en-gb"].game_ui_LEVEL="LEVEL";Y["en-gb"].game_ui_time_left="Time left";Y["en-gb"].game_ui_TIME_TO_BEAT="TIME TO BEAT";Y["en-gb"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";Y["en-gb"].game_ui_HIGHSCORE_break="HIGH\nSCORE";Y["de-de"]=Y["de-de"]||{};
Y["de-de"].game_ui_SCORE="PUNKTE";Y["de-de"].game_ui_STAGE="STUFE";Y["de-de"].game_ui_LIVES="LEBEN";Y["de-de"].game_ui_TIME="ZEIT";Y["de-de"].game_ui_HIGHSCORE="HIGHSCORE";Y["de-de"].game_ui_LEVEL="LEVEL";Y["de-de"].game_ui_time_left="Restzeit";Y["de-de"].game_ui_TIME_TO_BEAT="ZEITVORGABE";Y["de-de"].game_ui_SCORE_TO_BEAT="Zu schlagende Punktzahl";Y["de-de"].game_ui_HIGHSCORE_break="HIGHSCORE";Y["fr-fr"]=Y["fr-fr"]||{};Y["fr-fr"].game_ui_SCORE="SCORE";Y["fr-fr"].game_ui_STAGE="SC\u00c8NE";
Y["fr-fr"].game_ui_LIVES="VIES";Y["fr-fr"].game_ui_TIME="TEMPS";Y["fr-fr"].game_ui_HIGHSCORE="MEILLEUR SCORE";Y["fr-fr"].game_ui_LEVEL="NIVEAU";Y["fr-fr"].game_ui_time_left="Temps restant";Y["fr-fr"].game_ui_TIME_TO_BEAT="TEMPS \u00c0 BATTRE";Y["fr-fr"].game_ui_SCORE_TO_BEAT="SCORE \u00c0 BATTRE";Y["fr-fr"].game_ui_HIGHSCORE_break="MEILLEUR\nSCORE";Y["pt-br"]=Y["pt-br"]||{};Y["pt-br"].game_ui_SCORE="PONTOS";Y["pt-br"].game_ui_STAGE="FASE";Y["pt-br"].game_ui_LIVES="VIDAS";Y["pt-br"].game_ui_TIME="TEMPO";
Y["pt-br"].game_ui_HIGHSCORE="RECORDE";Y["pt-br"].game_ui_LEVEL="N\u00cdVEL";Y["pt-br"].game_ui_time_left="Tempo restante";Y["pt-br"].game_ui_TIME_TO_BEAT="HORA DE ARRASAR";Y["pt-br"].game_ui_SCORE_TO_BEAT="RECORDE A SER SUPERADO";Y["pt-br"].game_ui_HIGHSCORE_break="RECORDE";Y["es-es"]=Y["es-es"]||{};Y["es-es"].game_ui_SCORE="PUNTOS";Y["es-es"].game_ui_STAGE="FASE";Y["es-es"].game_ui_LIVES="VIDAS";Y["es-es"].game_ui_TIME="TIEMPO";Y["es-es"].game_ui_HIGHSCORE="R\u00c9CORD";
Y["es-es"].game_ui_LEVEL="NIVEL";Y["es-es"].game_ui_time_left="Tiempo restante";Y["es-es"].game_ui_TIME_TO_BEAT="TIEMPO OBJETIVO";Y["es-es"].game_ui_SCORE_TO_BEAT="PUNTUACI\u00d3N OBJETIVO";Y["es-es"].game_ui_HIGHSCORE_break="R\u00c9CORD";Y["tr-tr"]=Y["tr-tr"]||{};Y["tr-tr"].game_ui_SCORE="SKOR";Y["tr-tr"].game_ui_STAGE="B\u00d6L\u00dcM";Y["tr-tr"].game_ui_LIVES="HAYATLAR";Y["tr-tr"].game_ui_TIME="S\u00dcRE";Y["tr-tr"].game_ui_HIGHSCORE="Y\u00dcKSEK SKOR";Y["tr-tr"].game_ui_LEVEL="SEV\u0130YE";
Y["tr-tr"].game_ui_time_left="Kalan zaman";Y["tr-tr"].game_ui_TIME_TO_BEAT="B\u0130T\u0130RME ZAMANI";Y["tr-tr"].game_ui_SCORE_TO_BEAT="B\u0130T\u0130RME PUANI";Y["tr-tr"].game_ui_HIGHSCORE_break="Y\u00dcKSEK\nSKOR";Y["ru-ru"]=Y["ru-ru"]||{};Y["ru-ru"].game_ui_SCORE="\u0420\u0415\u0417\u0423\u041b\u042c\u0422\u0410\u0422";Y["ru-ru"].game_ui_STAGE="\u042d\u0422\u0410\u041f";Y["ru-ru"].game_ui_LIVES="\u0416\u0418\u0417\u041d\u0418";Y["ru-ru"].game_ui_TIME="\u0412\u0420\u0415\u041c\u042f";
Y["ru-ru"].game_ui_HIGHSCORE="\u0420\u0415\u041a\u041e\u0420\u0414";Y["ru-ru"].game_ui_LEVEL="\u0423\u0420\u041e\u0412\u0415\u041d\u042c";Y["ru-ru"].game_ui_time_left="Time left";Y["ru-ru"].game_ui_TIME_TO_BEAT="TIME TO BEAT";Y["ru-ru"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";Y["ru-ru"].game_ui_HIGHSCORE_break="\u0420\u0415\u041a\u041e\u0420\u0414";Y["ar-eg"]=Y["ar-eg"]||{};Y["ar-eg"].game_ui_SCORE="\u0627\u0644\u0646\u062a\u064a\u062c\u0629";Y["ar-eg"].game_ui_STAGE="\u0645\u0631\u062d\u0644\u0629";
Y["ar-eg"].game_ui_LIVES="\u0639\u062f\u062f \u0627\u0644\u0645\u062d\u0627\u0648\u0644\u0627\u062a";Y["ar-eg"].game_ui_TIME="\u0627\u0644\u0648\u0642\u062a";Y["ar-eg"].game_ui_HIGHSCORE="\u0623\u0639\u0644\u0649 \u0646\u062a\u064a\u062c\u0629";Y["ar-eg"].game_ui_LEVEL="\u0645\u0633\u062a\u0648\u0649";Y["ar-eg"].game_ui_time_left="Time left";Y["ar-eg"].game_ui_TIME_TO_BEAT="TIME TO BEAT";Y["ar-eg"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";Y["ar-eg"].game_ui_HIGHSCORE_break="\u0623\u0639\u0644\u0649 \u0646\u062a\u064a\u062c\u0629";
Y["ko-kr"]=Y["ko-kr"]||{};Y["ko-kr"].game_ui_SCORE="\uc810\uc218";Y["ko-kr"].game_ui_STAGE="\uc2a4\ud14c\uc774\uc9c0";Y["ko-kr"].game_ui_LIVES="\uae30\ud68c";Y["ko-kr"].game_ui_TIME="\uc2dc\uac04";Y["ko-kr"].game_ui_HIGHSCORE="\ucd5c\uace0 \uc810\uc218";Y["ko-kr"].game_ui_LEVEL="\ub808\ubca8";Y["ko-kr"].game_ui_time_left="Time left";Y["ko-kr"].game_ui_TIME_TO_BEAT="TIME TO BEAT";Y["ko-kr"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";Y["ko-kr"].game_ui_HIGHSCORE_break="\ucd5c\uace0 \uc810\uc218";
Y["jp-jp"]=Y["jp-jp"]||{};Y["jp-jp"].game_ui_SCORE="\u30b9\u30b3\u30a2";Y["jp-jp"].game_ui_STAGE="\u30b9\u30c6\u30fc\u30b8";Y["jp-jp"].game_ui_LIVES="\u30e9\u30a4\u30d5";Y["jp-jp"].game_ui_TIME="\u6642\u9593";Y["jp-jp"].game_ui_HIGHSCORE="\u30cf\u30a4\u30b9\u30b3\u30a2";Y["jp-jp"].game_ui_LEVEL="\u30ec\u30d9\u30eb";Y["jp-jp"].game_ui_time_left="\u6b8b\u308a\u6642\u9593";Y["jp-jp"].game_ui_TIME_TO_BEAT="TIME TO BEAT";Y["jp-jp"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";
Y["jp-jp"].game_ui_HIGHSCORE_break="HIGH\nSCORE";var Xf={};
function Yf(){Xf={Yd:{Bk:"en-us",Aj:"en-us en-gb nl-nl de-de fr-fr pt-br es-es tr-tr ru-ru ar-eg ko-kr jp-jp".split(" ")},wd:{Cc:P(1040),$p:P(960),Qb:P(640),og:P(640),cf:P(0),Uk:P(-80),bf:0,minHeight:P(780),Cm:{id:"canvasBackground",depth:50},Ac:{id:"canvasGame",depth:100,top:P(200,"round"),left:P(40,"round"),width:P(560,"round"),height:P(560,"round")},Bc:{id:"canvasGameUI",depth:150,top:0,left:0,height:P(120,"round")},Xe:{id:"canvasMain",depth:200}},Dm:{Cc:P(640),$p:P(640),Qb:P(1152),og:P(1152),
cf:P(0),Uk:P(0),bf:0,minHeight:P(640),minWidth:P(850),Cm:{id:"canvasBackground",depth:50},Ac:{id:"canvasGame",depth:100,top:P(40,"round"),left:P(296,"round"),width:P(560,"round"),height:P(560,"round")},Bc:{id:"canvasGameUI",depth:150,top:0,left:P(151),width:P(140)},Xe:{id:"canvasMain",depth:200}},Ob:{bigPlay:{type:"text",s:xd,qa:P(38),ib:P(99),font:{align:"center",h:"middle",fontSize:Q({big:46,small:30}),fillColor:"#01198a",T:{k:!0,color:"#7bfdff",offsetX:0,offsetY:2,blur:0}},Sc:2,Tc:P(30),fontSize:Q({big:46,
small:30})},difficulty_toggle:{type:"toggleText",s:rd,qa:P(106),ib:P(40),font:{align:"center",h:"middle",fontSize:Q({big:40,small:20}),fillColor:"#018a17",T:{k:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},U:[{id:"0",s:Cc,M:"optionsDifficulty_easy"},{id:"1",s:Bc,M:"optionsDifficulty_medium"},{id:"2",s:Ac,M:"optionsDifficulty_hard"}],gh:P(30),hh:P(12),Qf:P(10),Sc:2,Tc:P(30),fontSize:Q({big:40,small:20})},music_toggle:{type:"toggle",s:rd,qa:P(106),ib:P(40),font:{align:"center",h:"middle",fontSize:Q({big:40,
small:20}),fillColor:"#018a17",T:{k:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},U:[{id:"on",s:vd,M:"optionsMusic_on"},{id:"off",s:ud,M:"optionsMusic_off"}],gh:P(30),hh:P(12),Qf:0,Sc:2,Tc:P(30)},sfx_toggle:{type:"toggle",s:rd,qa:P(106),ib:P(40),font:{align:"center",h:"middle",fontSize:Q({big:40,small:20}),fillColor:"#018a17",T:{k:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},U:[{id:"on",s:td,M:"optionsSFX_on"},{id:"off",s:sd,M:"optionsSFX_off"}],gh:P(30),hh:P(12),Qf:0,Sc:2,Tc:P(30)},music_big_toggle:{type:"toggleText",
s:rd,qa:P(106),ib:P(40),font:{align:"center",h:"middle",fontSize:Q({big:40,small:20}),fillColor:"#018a17",T:{k:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},U:[{id:"on",s:"undefined"!==typeof kd?kd:void 0,M:"optionsMusic_on"},{id:"off",s:"undefined"!==typeof ld?ld:void 0,M:"optionsMusic_off"}],gh:P(28,"round"),hh:P(10),Qf:P(10),Sc:2,Tc:P(30),fontSize:Q({big:40,small:20})},sfx_big_toggle:{type:"toggleText",s:rd,qa:P(106),ib:P(40),font:{align:"center",h:"middle",fontSize:Q({big:40,small:20}),fillColor:"#018a17",
T:{k:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},U:[{id:"on",s:"undefined"!==typeof id?id:void 0,M:"optionsSFXBig_on"},{id:"off",s:"undefined"!==typeof jd?jd:void 0,M:"optionsSFXBig_off"}],gh:P(33,"round"),hh:P(12),Qf:P(10),Sc:2,Tc:P(30),fontSize:Q({big:40,small:20})},language_toggle:{type:"toggleText",s:rd,qa:P(106),ib:P(40),font:{align:"center",h:"middle",fontSize:Q({big:40,small:20}),fillColor:"#018a17",T:{k:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},U:[{id:"en-us",s:Dc,M:"optionsLang_en-us"},
{id:"en-gb",s:Ec,M:"optionsLang_en-gb"},{id:"nl-nl",s:Fc,M:"optionsLang_nl-nl"},{id:"de-de",s:Hc,M:"optionsLang_de-de"},{id:"fr-fr",s:Ic,M:"optionsLang_fr-fr"},{id:"pt-br",s:Jc,M:"optionsLang_pt-br"},{id:"es-es",s:Kc,M:"optionsLang_es-es"},{id:"ru-ru",s:Mc,M:"optionsLang_ru-ru"},{id:"ar-eg",s:Nc,M:"optionsLang_ar-eg"},{id:"ko-kr",s:Oc,M:"optionsLang_ko-kr"},{id:"tr-tr",s:Gc,M:"optionsLang_tr-tr"},{id:"jp-jp",s:Lc,M:"optionsLang_jp-jp"}],gh:P(40),hh:P(20),Qf:P(10),Sc:2,Tc:P(30),fontSize:Q({big:40,
small:20})},default_text:{type:"text",s:qd,qa:P(40),ib:P(40),font:{align:"center",h:"middle",fontSize:Q({big:40,small:20}),fillColor:"#018a17",T:{k:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},Sc:2,Tc:P(30),fontSize:Q({big:40,small:20})},default_image:{type:"image",s:qd,qa:P(40),ib:P(40),Tc:P(6)},options:{type:"image",s:od}},Am:{bigPlay:{type:"text",s:xd,qa:P(40),ib:P(76),font:{align:"center",h:"middle",fontSize:Q({big:40,small:20}),fillColor:"#01198a",T:{k:!0,color:"#7bfdff",offsetX:0,offsetY:2,
blur:0}},Sc:2,Tc:P(30),fontSize:Q({big:40,small:20})}},Ij:{green:{font:{align:"center",h:"middle",fillColor:"#018a17",T:{k:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}}},blue:{font:{align:"center",h:"middle",fillColor:"#01198a",T:{k:!0,color:"#7bfdff",offsetX:0,offsetY:2,blur:0}}},bluegreen:{font:{align:"center",h:"middle",fillColor:"#004f89",T:{k:!0,color:"#7bffca",offsetX:0,offsetY:2,blur:0}}},orange:{font:{align:"center",h:"middle",fillColor:"#9a1900",T:{k:!0,color:"#ffb986",offsetX:0,offsetY:2,
blur:0}}},orangeyellow:{font:{align:"center",h:"middle",fillColor:"#8d2501",T:{k:!0,color:"#ffbe60",offsetX:0,offsetY:2,blur:0}}},pink:{font:{align:"center",h:"middle",fillColor:"#c6258f",T:{k:!0,color:"#ffbde9",offsetX:0,offsetY:2,blur:0}}},white:{font:{align:"center",h:"middle",fillColor:"#ffffff"}},pastel_pink:{font:{align:"center",h:"middle",fillColor:"#83574f"}},whiteWithRedBorder:{font:{align:"center",h:"middle",fillColor:"#ffffff",T:{k:!0,color:"#4c0200",offsetX:0,offsetY:2,blur:0}}},whiteWithBlueBorder:{font:{align:"center",
h:"middle",fillColor:"#ffffff",T:{k:!0,color:"#002534",offsetX:0,offsetY:2,blur:0}}}},buttons:{default_color:"green"},Aa:{Iy:20},Jc:{backgroundImage:"undefined"!==typeof Dd?Dd:void 0,lw:0,Yt:500,Pk:5E3,Rv:5E3,zo:-1,Ay:12,zy:100,fe:P(78),No:{align:"center"},Pl:P(560),Dg:P(400),Eg:{align:"center"},sf:P(680),ze:P(16),Cn:P(18),wi:P(8),ur:P(8),vr:P(9),wr:P(9),Ti:{align:"center",fillColor:"#3B0057",fontSize:P(24)},Rs:{align:"center"},Ss:P(620),Ol:P(500),xi:"center",uf:P(500),zi:P(60),Ab:{align:"center"},
rc:{align:"bottom",offset:P(20)},Hn:P(806),Fn:500,Gv:P(20)},En:{xi:"right",Pl:P(280),sf:P(430),uf:P(340),Ab:{align:"right",offset:P(32)},rc:P(560),Hn:P(560)},Cl:{ym:P(860),backgroundImage:void 0!==typeof Dd?Dd:void 0,Mu:700,Pr:1800,cw:700,Xw:2600,yg:void 0!==typeof Dd?Qd:void 0,fd:700,li:{align:"center"},kk:{align:"center"},mi:void 0!==typeof Qd?-Qd.height:0,ki:{align:"top",offset:P(20)},dn:1,Aq:1,en:1,Bq:1,cn:1,zq:1,Qu:M,Ru:N,Ou:M,Pu:M,Nu:M,Ww:{align:"center"},hl:P(656),Ei:P(300),fl:700,Vw:700,cq:P(368),
Xj:P(796),ai:P(440),bq:700,Nn:P(36),Sk:P(750),bw:500,xi:"center",uf:P(500),zi:P(60),Ab:{align:"center"},rc:{align:"bottom",offset:P(20)},Hn:P(806),Fn:500,Gv:P(20)},Go:{ym:P(0),hl:P(456),Ei:P(320),cq:{align:"center"},Xj:P(346),ai:P(460),Nn:{align:"left",offset:P(32)},Sk:P(528),xi:"right",uf:P(340),Ab:{align:"right",offset:P(32)},rc:P(560),Hn:P(560)},of:{Lw:{align:"center",offset:P(-230)},Xn:{align:"top",offset:P(576)},Kw:"options",Yb:{h:"bottom"},He:{align:"center"},Uc:{align:"top",offset:P(35,"round")},
rd:P(232),ge:P(98),fz:{align:"center",offset:P(-206)},cp:{align:"top",offset:P(30)},ez:{align:"center",offset:P(206)},bp:{align:"top",offset:P(30)},type:"grid",Hw:3,oA:3,Iw:5,pA:4,fq:!0,Bu:!0,nn:P(78),Fq:{align:"top",offset:P(140)},Hq:{align:"top",offset:P(140)},Gq:P(20),Yu:P(18),Zu:P(18),tv:{jn:{fontSize:Q({big:60,small:30}),fillColor:"#3F4F5E",align:"center",h:"middle",T:{k:!0,color:"#D0D8EA",offsetX:0,offsetY:P(6),blur:0}}},uv:{jn:{fontSize:Q({big:32,small:16}),fillColor:"#3F4F5E",align:"center",
h:"middle",T:{k:!0,color:"#D0D8EA",offsetX:0,offsetY:P(2),blur:0}}},pr:P(438),qr:P(438),hr:{align:"center"},ir:{align:"center"},yr:{align:"center"},zr:{align:"center",offset:P(-22)},lr:{align:"center"},mr:{align:"center",offset:P(-10)},Yx:{align:"center",offset:P(216)},ws:{align:"top",offset:P(574)},vs:{fontSize:Q({big:24,small:12}),fillColor:"#3F4F5E",align:"center"},xs:P(10),co:{fontSize:Q({big:24,small:12}),fillColor:"#3F4F5E",align:"center"},Yr:{align:"center"},Zr:{align:"top",offset:P(588)},
$w:P(160),Zw:P(40),backgroundImage:"undefined"!==typeof Hd?Hd:void 0,uy:P(10),vy:200,ty:P(200),lA:P(600),qw:800,pw:500},jr:{cp:{align:"top",offset:P(20)},bp:{align:"top",offset:P(20)},Uc:{align:"top",offset:P(25,"round")},nn:P(234),Fq:{align:"top",offset:P(110)},Hq:{align:"top",offset:P(110)},ws:{align:"top",offset:P(536)},Zr:{align:"top",offset:P(550)},Xn:{align:"top",offset:P(538)}},vv:{Lc:"undefined"!==typeof Ad?Ad:void 0,Tr:{align:"center"},$n:"undefined"!==typeof Ad?-Ad.height:void 0,Qw:[{type:"y",
ya:0,duration:800,end:{align:"center",offset:P(-142)},cb:N,uc:Mf}],rA:[{type:"y",ya:0,duration:600,end:"undefined"!==typeof Ad?-Ad.height:void 0,cb:bc,tz:!0}],Pt:{align:"center",h:"middle"},St:{align:"center"},Tt:0,Rt:P(500),Qt:P(80),ev:{align:"center",h:"middle"},fv:{align:"center"},gv:0,Wz:P(560),Vz:P(80),Wr:3500},kA:{Qw:[{type:"y",ya:0,duration:800,end:{align:"center"},cb:N,uc:Mf}]},Nj:{Lc:"undefined"!==typeof s_overlay_challenge_start?s_overlay_challenge_start:void 0,Tr:{align:"center"},$n:P(56),
Af:0,Ng:0,Yb:{align:"center",h:"top"},rd:P(500),ge:P(100),He:{align:"center"},Uc:P(90),Lr:{align:"center",h:"middle"},yw:P(500),xw:P(80),Bw:{align:"center"},Cw:P(250),fs:{align:"center",h:"top"},ux:P(500),tx:P(40),vx:{align:"center"},wx:P(348),es:{align:"center",h:"top"},zx:P(500),yx:P(50),Bx:{align:"center"},Cx:P(388),At:{align:"center",h:"top"},Ty:P(500),Sy:P(40),Uy:{align:"center"},Vy:P(442),eB:0,fB:0,zt:{align:"center",h:"top"},Xy:P(500),Wy:P(50),Yy:{align:"center"},Zy:P(482),dB:P(10),bB:0,cB:0,
ne:800,wj:N,xj:600,yj:bc,Wr:3500},Mj:{Cp:500,ne:800,Fw:1500,Sn:500,Ax:2500,so:500,Dx:3200,Ex:800,Tk:4200,Gg:300,ju:4500,Sw:{align:"center"},Tw:P(-800),Mg:{align:"center"},zf:P(52),Af:0,Ng:0,ci:.8,Rm:"#000000",vf:{align:"center",h:"middle"},Pn:P(360),Hr:P(120),ew:P(4),fw:P(4),jw:{align:"center"},kw:P(340),my:{align:"center"},Hs:P(600),Io:P(500),Gs:P(120),ly:{align:"center",h:"middle"},fj:{align:"center",h:"middle"},ap:P(360),Bt:P(60),$y:P(4),az:P(4),bz:{align:"center"},cz:P(480),Ml:P(460),py:{align:"center"},
qy:P(400),ku:{align:"center"},lu:P(500),Rn:{align:"center",h:"middle"},Ew:P(75,"round"),Dw:P(48),Gw:P(120),Nr:P(214,"round"),Mr:P(40),vw:P(4),ww:P(4),zw:0,Aw:0,Lm:{align:"center",h:"middle"},Gu:P(220),Fu:P(180),kq:P(80),jq:P(4),Eu:P(4)},la:{al:{I:"undefined"!==typeof Gd?Gd:void 0,Iu:"undefined"!==typeof s_overlay_endless?s_overlay_endless:void 0,wv:"undefined"!==typeof s_overlay_level_win?s_overlay_level_win:void 0,sv:"undefined"!==typeof s_overlay_level_fail?s_overlay_level_fail:void 0},yy:500,ne:800,
wj:N,xj:800,yj:Yb,Xb:{align:"center"},Db:0,Yb:{align:"center",h:"middle",fontSize:Q({big:26,small:13})},He:{align:"center"},Uc:P(58),rd:P(500),ge:P(100),Is:{align:"center",h:"middle",fontSize:Q({big:56,small:28})},ny:{align:"center"},oy:P(236),Mm:{align:"center",h:"top",fontSize:Q({big:24,small:12})},lq:{align:"center"},Nm:P(144),bi:{align:"center",h:"top",fontSize:Q({big:56,small:28})},ek:{align:"center"},sg:P(176),dk:P(200),ck:P(60),Qi:{align:"center",h:"top",fontSize:Q({big:24,small:12})},Fe:{align:"center"},
Nf:P(286),Ds:P(0),vq:!1,md:P(14),Il:P(10),Mf:{align:"center",h:"top",fontSize:Q({big:24,small:12})},Yg:P(10),Zg:P(4),$g:P(200),TA:P(50),Wt:{align:"center",offset:P(12)},Hp:P(549),Lu:{align:"center",offset:P(162)},wq:P(489),Th:{align:"center",offset:P(250)},mg:P(10),lg:P(90),$e:P(90),Ao:{align:"center",offset:P(-177,"round")},Bo:P(120),Co:{align:"center"},Do:P(96),Eo:{align:"center",offset:P(179,"round")},Fo:P(120),RA:200,Ux:500,ss:800,us:0,Xx:0,Wx:300,Vx:200,ts:300,ci:.8,pb:800,Rm:"#000000",Ln:P(508),
Bi:P(394),Cr:P(96),Dr:P(74),Qk:3,Fg:400,Sv:2500,nA:0,Vv:P(100),Er:1.5,$v:{align:"center"},aw:P(76),Rk:P(180),Zv:P(36),Fr:{align:"center",h:"middle",fontSize:Q({big:22,small:12}),v:"ff_opensans_extrabold",fillColor:"#1d347f",T:{k:!0,color:"#68cbfa",offsetY:P(2)}},Br:500,Tv:500,Uv:P(-30),Xv:500,Wv:0,Yv:4E3,Sl:600,Ly:1500,Np:500,gg:750,hv:{align:"center"},iv:P(290),Rq:P(350),nw:1E3,type:{level:{Ej:"level",Nc:!0,Ug:!0,Vi:"title_level",Ge:"totalScore",Bj:"retry",gk:"next"},failed:{Ej:"failed",Nc:!1,Ug:!1,
Vi:"title_level",Js:"subtitle_failed",Bj:"exit",gk:"retry"},endless:{Ej:"endless",Nc:!1,Ug:!0,Vi:"title_endless",Om:"totalScore",Ge:"highScore",Bj:"exit",gk:"retry"},difficulty:{Ej:"difficulty",Nc:!1,Ug:!0,Vi:"title_difficulty",Om:"timeLeft",Ge:["totalScore","timeBonus"],Bj:"exit",gk:"retry"}}},gr:{mg:P(0),Uc:P(30),Nm:P(114),sg:P(146),Nf:P(266),Hp:P(488),wq:P(428),Ln:{align:"center",offset:P(220)},Bi:P(260)},si:{backgroundImage:"undefined"!==typeof Ge?Ge:void 0},options:{backgroundImage:Bd,Xb:{align:"center"},
Db:0,Yb:{},He:{align:"center"},Uc:P(58),rd:P(500),ge:P(100),Kj:P(460,"round"),Jj:{align:"center"},jg:{align:"center",offset:P(36)},vd:P(10,"round"),Th:P(510),mg:P(10),lg:P(130),$e:P(90),buttons:{startScreen:["tutorial",["music","sfx"],"language","moreGames","about"],levelMapScreen:["startScreen",["music","sfx"],"language","moreGames","about"],inGame:["resume","tutorial",["music","sfx"],"moreGames","quit"]},xf:800,yf:N,Kg:600,Lg:Yb,Yp:{align:"center"},Tj:P(260),Xh:P(460),Sj:P(300),Xp:{align:"center"},
Rj:P(460),Wp:{align:"center"},Qj:P(560,"round"),Wh:P(460,"round"),ol:{},sd:"undefined"!==typeof Ed?Ed:void 0,Ul:{align:"center"},Ie:P(84,"round"),Zi:{align:"center",h:"top"},Vl:P(480),Uo:P(46),jt:{align:"center"},Vo:P(110,"round"),gt:{align:"center"},So:P(160,"round"),it:{align:"center"},To:P(446,"round"),Yi:{h:"middle",align:"center",fontSize:Q({big:36,small:18})},lh:P(480),ht:P(160),ft:{align:"center",offset:P(-80,"round")},Ro:P(556,"round"),et:{align:"center",offset:P(80,"round")},Qo:P(556,"round"),
tp:{align:"center",h:"top",fillColor:"#3C0058",fontSize:Q({big:26,small:13}),fa:P(6)},vp:P(480),up:P(50),wp:{align:"center"},lm:P(106,"round"),xp:{align:"center",h:"top",fillColor:"#3C0058",fontSize:Q({big:26,small:13}),fa:P(6)},sj:P(480),Lh:P(110),nm:{align:"center"},Mh:P(396,"round"),mm:{align:"center"},rj:P(140),km:{align:"center"},qj:P(500),Kh:P(480),om:{align:"center",h:"top",fillColor:"#808080",fontSize:Q({big:12,small:8})},Ap:{align:"center"},pm:P(610),zp:P(440),yp:P(20),eg:P(200),tj:P(200),
ut:P(80),vt:P(140),tt:P(10)},Mw:{Uc:P(12),jg:{align:"center",offset:P(16)},Tj:P(200),Sj:P(300),Rj:P(400),Qj:P(500,"round"),Ie:P(60,"round"),Vo:P(80,"round"),So:P(134,"round"),To:P(410,"round"),Ro:P(500,"round"),Qo:P(500,"round"),lm:P(86,"round"),rj:P(126),Mh:P(392,"round"),qj:P(490),pm:P(590)},Yn:{backgroundImage:"undefined"!==typeof s_overlay_challenge_options?s_overlay_challenge_options:Bd,Xb:{align:"center"},Db:P(120),Yb:{},He:{align:"center"},Uc:P(200),Kj:P(460,"round"),Jj:{align:"center"},jg:{align:"center",
offset:P(140)},vd:P(10,"round"),Th:P(510),mg:P(10),lg:P(130),$e:P(90),buttons:{startScreen:["tutorial",["music","sfx"],"language","about"],inGame_challengee:["resume","tutorial",["music","sfx"],"forfeitChallenge"],inGame_challenger:["resume","tutorial",["music","sfx"],"cancelChallenge"]},xf:800,yf:N,Kg:600,Lg:Yb,ol:{},EA:{align:"center"},FA:P(360),DA:P(460),CA:P(300),yA:"default_text",zA:{align:"center"},AA:P(630),vA:"default_text",wA:{align:"center"},xA:P(730,"round"),BA:P(460,"round"),Em:{},Yp:{align:"center"},
Tj:P(200),Xh:P(460),Sj:P(250),Xp:{align:"center"},Rj:P(520),Wp:{align:"center"},Qj:P(620,"round"),Wh:P(460,"round"),vf:{},hw:{align:"center"},iw:P(200),On:P(460),gw:P(300),sd:"undefined"!==typeof Ed?Ed:void 0,Ul:{align:"center"},Ie:P(0,"round"),Zi:{align:"center",h:"top"},Vl:P(480),Uo:P(50),jt:{align:"center"},Vo:P(20,"round"),gt:{align:"center"},So:P(70,"round"),it:{align:"center"},To:P(356,"round"),Yi:{h:"middle",align:"center",fontSize:Q({big:36,small:18})},lh:P(480),ht:P(150),ft:P(224,"round"),
Ro:P(636,"round"),et:P(350,"round"),Qo:P(636,"round"),tp:{align:"center",h:"top",fillColor:"#3C0058",fontSize:Q({big:26,small:13}),fa:P(6)},vp:P(480),up:P(50),wp:{align:"center"},lm:P(26,"round"),xp:{align:"center",h:"top",fillColor:"#3C0058",fontSize:Q({big:26,small:13}),fa:P(6)},sj:P(480),Lh:P(110),nm:{align:"center"},Mh:P(316,"round"),mm:{align:"center"},rj:P(60),km:{align:"center"},qj:P(420),Kh:P(480),om:{align:"center",h:"top",fillColor:"#808080",fontSize:Q({big:12,small:8})},Ap:{align:"center"},
pm:P(530),zp:P(440),yp:P(20),eg:P(200),tj:P(200),ut:P(80),vt:P(100),tt:P(10)},$c:{backgroundImage:"undefined"!==typeof Fd?Fd:Bd,Xb:{align:"center"},Db:P(120),Kj:P(460,"round"),Jj:{align:"center"},jg:{align:"bottom",offset:P(20)},vd:P(10,"round"),Th:P(510),mg:P(10),lg:P(130),$e:P(90),xf:800,yf:N,Kg:600,Lg:Yb,fo:{},hx:{align:"center"},as:{align:"center",offset:P(40)},nl:P(460),ml:P(300),Jo:{},fx:{align:"center"},gx:{align:"center",offset:P(160)},ex:P(460),dx:P(200)},ik:{backgroundImage:"undefined"!==
typeof s_screen_end?s_screen_end:void 0,Rs:{align:"center"},Ss:P(152),Ol:P(560),xy:P(560),font:{align:"center",h:"middle",fontSize:Q({big:52,small:26}),fillColor:"#FFFFFF"},hu:{align:"center"},Qp:P(600),Pp:P(460),Op:"default_text"},Ym:{Qp:P(520)}}}
var Zf={bx:"coolmath",Ny:!1,Ni:{Ev:!1,Hm:"37d007a56d816107ce5b52c10342db37 a148ee16bf50a87a3441ab01d892bd30 d3be8d51902c506af88504926f2cd036 7974c30f88003a48e16e1f3c1a1f1444 f244898f801ef0cacb05c1aea9a6ea21 a2cdd22b638b907753cc9b09ae74047d 86b07e66612f96ac67db91a7ca1d9bfe".split(" ")},Yd:{Bk:"en-us",Aj:["en-us"]},Jc:{zo:3E3}},Y=Y||{};Y["en-us"]=Y["en-us"]||{};Y["en-us"].ShuffleConfirmationText="There are no more possible matches. Would you like to reshuffle the board?";
Y["en-us"].ShuffleConfirmationTitle="Reshuffle";Y["en-us"].ShuffleConfirmBtnText="Reshuffle";Y["en-us"].ShuffleConfirmBtnTitle="Continue by reshuffling the board";Y["en-us"].ShuffleRestartBtnText="Restart";Y["en-us"].ShuffleRestartBtnTitle="Try again by restarting the game";Y["en-us"].TutorialText_0="Find 2 identical tiles.";Y["en-us"].TutorialText_1="#touch{Remove the identical tiles by clicking on them.}{Remove the identical tiles by tapping on them.}";Y["en-us"].TutorialText_2="You can only remove tiles that can be moved to the right...";
Y["en-us"].TutorialText_3="...or left without disturbing other tiles.";Y["en-us"].TutorialText_4="Complete the game by removing all the tiles.";Y["en-us"].TutorialTitle_0="How to play";Y["en-us"].TutorialTitle_1="Removing tiles";Y["en-us"].TutorialTitle_2="Pay attention!";Y["en-us"].TutorialTitle_3="Pay attention!";Y["en-us"].TutorialTitle_4="Completing the game";Y["en-us"].levelMapScreenWorld_1="Level 13-24";Y["en-us"].levelMapScreenWorld_0="Level 1-12";Y["en-us"].floater_0="Good";
Y["en-us"].floater_1="Nice!";Y["en-us"].floater_2="Great!";Y["en-us"].floater_3="Awesome!";Y["en-us"].levelMapScreenWorld_5="Level 61-72";Y["en-us"].levelMapScreenWorld_4="Level 49-60";Y["en-us"].levelMapScreenWorld_3="Level 37-48";Y["en-us"].levelMapScreenWorld_2="Level 25-36";Y["jp-jp"]=Y["jp-jp"]||{};Y["jp-jp"].ShuffleConfirmationText="\u3053\u308c\u4ee5\u4e0a\u6d88\u305b\u308b\u724c\u304c\u3042\u308a\u307e\u305b\u3093\u3002\u518d\u30b7\u30e3\u30c3\u30d5\u30eb\u3057\u307e\u3059\u304b\uff1f";
Y["jp-jp"].ShuffleConfirmationTitle="\u518d\u30b7\u30e3\u30c3\u30d5\u30eb";Y["jp-jp"].ShuffleConfirmBtnText="\u518d\u30b7\u30e3\u30c3\u30d5\u30eb";Y["jp-jp"].ShuffleConfirmBtnTitle="\u518d\u30b7\u30e3\u30c3\u30d5\u30eb\u3057\u3066\u7d9a\u3051\u308b";Y["jp-jp"].ShuffleRestartBtnText="\u518d\u30b9\u30bf\u30fc\u30c8";Y["jp-jp"].ShuffleRestartBtnTitle="\u30b2\u30fc\u30e0\u3092\u518d\u958b\u3057\u3001\u3082\u3046\u4e00\u5ea6\u6311\u6226\u3059\u308b";Y["jp-jp"].TutorialText_0="\u540c\u3058\u7d75\u67c4\u306e\u724c\u3092\u898b\u3064\u3051\u3088\u3046";
Y["jp-jp"].TutorialText_1="#touch{\u540c\u3058\u7d75\u67c4\u306e\u724c\u3092\u30af\u30ea\u30c3\u30af\u3059\u308b\u3068\u6d88\u305b\u307e\u3059}{\u540c\u3058\u7d75\u67c4\u306e\u724c\u3092\u30bf\u30c3\u30d7\u3059\u308b\u3068\u6d88\u305b\u307e\u3059}";Y["jp-jp"].TutorialText_2="\u5de6\u53f3\u3084\u4e0a\u306b\u724c\u306e\u306a\u3044";Y["jp-jp"].TutorialText_3="\u81ea\u7531\u724c\u306e\u307f\u6d88\u3059\u3053\u3068\u304c\u3067\u304d\u307e\u3059";Y["jp-jp"].TutorialText_4="\u724c\u3092\u5168\u3066\u6d88\u3059\u3068\u30b9\u30c6\u30fc\u30b8\u30af\u30ea\u30a2\uff01";
Y["jp-jp"].TutorialTitle_0="\u3042\u305d\u3073\u65b9";Y["jp-jp"].TutorialTitle_1="\u724c\u3092\u6d88\u3059";Y["jp-jp"].TutorialTitle_2="\u6ce8\u610f\uff01";Y["jp-jp"].TutorialTitle_3="\u6ce8\u610f\uff01";Y["jp-jp"].TutorialTitle_4="\u30b2\u30fc\u30e0\u30af\u30ea\u30a2";Y["jp-jp"].levelMapScreenWorld_1="\u30ec\u30d9\u30eb 13-24";Y["jp-jp"].levelMapScreenWorld_0="\u30ec\u30d9\u30eb 1-12";Y["jp-jp"].floater_0="Good";Y["jp-jp"].floater_1="Nice!";Y["jp-jp"].floater_2="Great!";Y["jp-jp"].floater_3="Awesome!";
Y["jp-jp"].levelMapScreenWorld_5="\u30ec\u30d9\u30eb 61-72";Y["jp-jp"].levelMapScreenWorld_4="\u30ec\u30d9\u30eb 49-60";Y["jp-jp"].levelMapScreenWorld_3="\u30ec\u30d9\u30eb 37-48";Y["jp-jp"].levelMapScreenWorld_2="\u30ec\u30d9\u30eb 25-36";var $f=$f||{};$f.ii={jk:"8d65b6b1bc2f9af242a45a429c07a6c7",wl:"16691e664c4c5804c5ccb640b137bec48ebf5d95"};var ag={};
function bg(){ag={n:{Cq:"DuckpondMahjong"},buttons:{default_color:"green",bigPlay:"blue"},Wb:{wm:.2},Cl:{Zt:[{s:Dd,x:0,y:0},{s:"undefined"!==typeof Qd?Qd:void 0,y:P(20,"round"),x:{align:"center"}}]},of:{Zt:[{s:"undefined"!==typeof Hd?Hd:void 0,x:0,y:0}],Yb:{v:X.v,align:"center",h:"middle",fillColor:"#6d3206",fontSize:P(36)},vs:{v:X.v,fontSize:P(30),fillColor:"#6d3206",align:"center"},co:{v:X.v,fontSize:P(30),fillColor:"#6d3206",align:"center"}},vv:{$n:-Ad.height,Pt:{v:X.v,align:"center",h:"top",fontSize:P(26),
fillColor:"#6d3206"},St:{align:"center"},Tt:P(212,"round"),Rt:P(300),Qt:P(80),ev:{v:X.v,fontSize:P(36),fillColor:"#6d3206",align:"center",h:"middle"},fv:{align:"center"},gv:P(180,"round")},Nj:{Yb:{v:X.v,align:"center",h:"top",fillColor:"#8D331C",fontSize:P(40)},Lr:{align:"center",h:"middle",fillColor:"#8D331C",fontSize:P(30)},fs:{align:"center",h:"top",fontSize:P(26),fillColor:"#A96F5F"},es:{align:"center",h:"top",fontSize:P(30),fillColor:"#8D331C"},At:{align:"center",h:"top",fontSize:P(26),fillColor:"#A96F5F"},
zt:{fontSize:P(30),fillColor:"#8D331C"}},Mj:{vf:{v:X.v,align:"center",h:"middle",fillColor:"#8D331C",fontSize:P(40),fa:P(6)},Rn:{align:"center",h:"middle",fontSize:P(26),fillColor:"#A96F5F"},Lm:{align:"center",h:"middle",fontSize:P(30),fillColor:"#8D331C"},fj:{align:"center",h:"middle",fontSize:P(30),fillColor:"#A96F5F"},ly:{v:X.v,align:"center",h:"middle",fillColor:"#8D331C",fontSize:P(32),fa:P(6)},Hs:P(540)},la:{Db:P(10),Yb:{v:X.v,align:"center",h:"middle",fontSize:P(38),fillColor:"#6d3206"},YA:!1,
Mm:{v:X.v,align:"center",h:"top",fillColor:"#d68d46",fontSize:P(34)},sg:P(194),bi:{v:X.v,align:"center",h:"top",fillColor:"#6d3206",fontSize:P(64)},Qi:{v:X.v,h:"bottom",fillColor:"#d68d46",fontSize:P(32)},md:P(4),Mf:{v:X.v,h:"bottom",fillColor:"#6d3206",fontSize:P(26)},Is:{v:X.v,align:"center",h:"middle",fontSize:P(64),fillColor:"#01513d"},Bi:P(230)},options:{Db:P(10),xf:800,yf:N,Kg:600,Lg:Yb,ol:{v:X.v,align:"center",h:"middle",fontSize:P(30),fillColor:"#6d3206",fa:P(6)},Yb:{v:X.v,align:"center",
h:"middle",fontSize:P(38),fillColor:"#6d3206"},Yi:{h:"middle",align:"center",fontSize:Q({big:26,small:13}),fillColor:"#004f5d"},Zi:{align:"center",h:"top",fontSize:Q({big:36,small:18}),fillColor:"#004f5d"}},Yn:{xf:800,yf:N,Kg:600,Lg:Yb,Em:{v:X.v,align:"center",h:"middle",fontSize:P(30),fillColor:"#6d3206",fa:P(6)},vf:{v:X.v,align:"center",h:"middle",fontSize:P(30),fillColor:"#6d3206",fa:P(6)},Yb:{v:X.v,align:"center",h:"middle",fontSize:P(38),fillColor:"#6d3206"},Yi:{h:"middle",align:"center",fontSize:Q({big:26,
small:13}),fillColor:"#004f5d"},Zi:{align:"center",h:"top",fontSize:Q({big:36,small:18}),fillColor:"#004f5d"},Tj:P(220),Xh:P(460),Sj:P(250),Rj:P(460),Qj:P(560,"round")},$c:{xf:800,yf:N,Kg:600,Lg:Yb,fo:{v:X.v,align:"center",h:"middle",fontSize:P(30),fillColor:"#6d3206",fa:P(6)},Jo:{v:X.v,align:"center",h:"middle",fontSize:P(24),fillColor:"#A96F5F",fa:P(6)},nl:P(460),ml:P(210),jg:{align:"bottom",offset:P(-30)},as:{align:"center",offset:P(70)}},ik:{font:{v:X.v,align:"center",h:"middle",fontSize:Q({big:72,
small:36}),fillColor:"#037564",stroke:!0,Pc:P(5,"round"),strokeColor:"#ffffff",ee:!0}}}}var cg=null;
function dg(){cg={wd:{Ac:{id:"canvasGame",depth:100,top:P(200,"round"),left:P(0,"round"),width:P(640,"round"),height:P(560,"round")}},wg:{pg:"unlocked",yq:"Mahjong",Bd:"difficulty",S:[12,12],Ki:!1,If:!0},mf:{Qd:100,ya:10,Lz:2,Vq:3E3,m:2,fp:P(18,"round"),ip:P(8,"round")},Ok:{nz:.1,vu:.5,zu:4,Ku:2,Su:2,Ur:P(-10,"round"),Rw:P(-10,"round"),qx:2,Qx:.5,Cy:P(-15,"round"),Dy:P(-16,"round"),eh:P(93),Ey:P(44.5,"round"),Fy:P(44.5,"round"),Tf:P(70)},px:{Qd:80,Fx:100},Hi:{Ar:4,Ir:2,cs:0},sx:{pb:1E3,eo:1E3},uo:{Qd:100,
fp:P(52,"round"),ip:P(39,"round")},wy:{pb:1E3,eo:1E3},Qz:{Yz:!1},wa:{gu:2,By:10},iA:24,rf:[{name:"level_1",width:10,height:6,icon:"undefined"!==typeof Ke?Ke:void 0,Ja:"NNNNNNNNNN;N NNNNNN N;F FNNNNF F;   NNQN   ;N NNNNNN N;NNNNNNNNNN".split(";"),Ka:" 22333322 ;   2332   ;2  2332  2;   2332   ;   2332   ; 22333332 ".split(";"),wa:{time:24E4},I:{I:0}},{name:"level_2",width:10,height:6,icon:"undefined"!==typeof Le?Le:void 0,Ja:"  NN  NN  ;NNNNNNNNNN;  NN  NN  ;  NN  NN  ;NNNNNNNNNN;  NN  NN  ".split(";"),
Ka:"  22  22  ; 23344332 ;  22  22  ;  22  22  ; 23344332 ;  22  22  ".split(";"),wa:{time:24E4},I:{I:0}},{name:"level_3",width:10,height:6,icon:"undefined"!==typeof We?We:void 0,Ja:"N N N N N ; N N N N N;N N N N N ; N N N N N;N N N N N ; N N N N N".split(";"),Ka:"3 4 3 2 3 ; 2 3 4 3 2;3 4 3 2 3 ; 2 3 4 2 2;3 4 3 2 3 ; 2 3 4 3 2".split(";"),wa:{time:24E4},I:{I:0}},{name:"level_4",width:10,height:6,icon:"undefined"!==typeof bf?bf:void 0,Ja:" NNNNNNNN ; NQQQNQQQ ; NQQQQQQQ ; NQQQQQQQ ;   NQQQ   ;    NQ    ".split(";"),
Ka:" 22222222 ; 22222222 ; 22222222 ; 22222222 ;   2222   ;    22    ".split(";"),wa:{time:24E4},I:{I:0}},{name:"level_5",width:10,height:6,icon:"undefined"!==typeof cf?cf:void 0,Ja:"NNNNNNNNNN;N  NNNN  N;N NNNNNN N;N NQNNNQ N;N  NNNN  N;NNNNNNNNNN".split(";"),Ka:"22  22  22;2   33   2;  334433  ;  334433  ;2   33   2;22  22  22".split(";"),wa:{time:24E4},I:{I:1}},{name:"level_6",width:10,height:6,icon:"undefined"!==typeof df?df:void 0,Ja:"N        N;N  NNNN  N;NFNNNNNNFN;N NNNQNN N;N  NNNN  N;N        N".split(";"),
Ka:"          ;2  2222  2;22233332 2;2 233332 2;2  2222  2;          ".split(";"),wa:{time:24E4},I:{I:1}},{name:"level_7",width:10,height:6,icon:"undefined"!==typeof ef?ef:void 0,Ja:"NNNNNNNNNN;  NNQNQN  ;FNNNNNNNNF; NNQNNNQN ;  NNNNNN  ;NNNNQNQNNN".split(";"),Ka:"   2222   ;   2222   ;  223322  ;  223322  ;   2222   ;   2222   ".split(";"),wa:{time:24E4},I:{I:1}},{name:"level_8",width:10,height:6,icon:"undefined"!==typeof ff?ff:void 0,Ja:"FFNNNNNNFF;  NNNNNN  ;FFNNNNNNFF;  NNNNNN  ;FFNNNNNNFF;  NNNNNN  ".split(";"),
Ka:"  2    2  ;  234432  ;  2    2  ;  2    2  ;  234432  ;  2    2  ".split(";"),wa:{time:24E4},I:{I:1}},{name:"level_9",width:10,height:6,icon:"undefined"!==typeof gf?gf:void 0,Ja:" NNNNNNNN ;NNNNNNNNNN;NNNN  NNNN;NNNN  NNNN;NNNNNNNNNN; NNNNNNNN ".split(";"),Ka:"          ; 22344322 ; 234  432 ; 234  432 ; 22344322 ;          ".split(";"),wa:{time:24E4},I:{I:2}},{name:"level_10",width:10,height:6,icon:"undefined"!==typeof hf?hf:void 0,Ja:" FNNNNF N ;N  FF  NNN;N N  N NNN;N NFFNFNNN;NF      NN;  NNNNN N ".split(";"),
Ka:" 222223   ;2  22  2  ;2 2  2 2  ;2 222222  ;22        ;  22234   ".split(";"),wa:{time:24E4},I:{I:2}},{name:"level_11",width:10,height:6,icon:"undefined"!==typeof Me?Me:void 0,Ja:" NNNNNNNN ;FNQQQQQQQF;FNQNNNNNQF;FNQNNNNNQF; NQNNNNNQ ; NQQQQQQQ ".split(";"),Ka:" 22222222 ; 22222222 ; 22344322 ; 22344322 ; 22222222 ; 22222222 ".split(";"),wa:{time:24E4},I:{I:2}},{name:"level_12",width:10,height:6,icon:"undefined"!==typeof Ne?Ne:void 0,Ja:" NNNNNNNN ;FNQNNQNNQF; NN NN NN ;FNN NN NNF; NNNNNNNN ; NQNNQNNQ ".split(";"),
Ka:" 22233222 ;222 33 222; 33 44 33 ;233 44 332; 22 33 22 ; 22233222 ".split(";"),wa:{time:24E4},I:{I:2}},{name:"level_13_aries",width:10,height:6,icon:"undefined"!==typeof Oe?Oe:void 0,Ja:" NN    NN ;N  N  N  N; N  NN  N ;    NN    ;    NN    ;    NN    ".split(";"),Ka:" 33    33 ;2  4  4  2; 2  44  2 ;    44    ;    44    ;    44    ".split(";"),wa:{time:24E4},I:{I:-1}},{name:"level_14_taurus",width:10,height:6,icon:"undefined"!==typeof Pe?Pe:void 0,Ja:"NN      NN;  NNNNNN  ;   NNNN   ;  NN  NN  ;  NN  NN  ;   NNNN   ".split(";"),
Ka:"22      22;  333333  ;   4444   ;  44  44  ;  44  44  ;   4444   ".split(";"),wa:{time:24E4},I:{I:-1}},{name:"level_15_gemini",width:10,height:6,icon:"undefined"!==typeof Qe?Qe:void 0,Ja:"NNNNNNNNNN;  NN  NN  ;  NQ  NQ  ;  NQ  NQ  ;  NQ  NQ  ;NNNNNNNNNN".split(";"),Ka:"2222222222;  44  44  ;  44  44  ;  44  44  ;  44  44  ;2222222222".split(";"),wa:{time:24E4},I:{I:-1}},{name:"level_16_cancer",width:10,height:6,icon:"undefined"!==typeof Re?Re:void 0,Ja:"NNNNNNNNN ;N  N    NN;NNNN      ;      NNNN;NN    N  N; NNNNNNNNN".split(";"),
Ka:"222222222 ;2  4    22;2334      ;      4332;22    4  2; 222222222".split(";"),wa:{time:24E4},I:{I:-1}},{name:"level_17_leo",width:10,height:6,icon:"undefined"!==typeof Se?Se:void 0,Ja:"    NN    ;   N  N   ; NNN  N   ;N  N  N  N;N  N  N  N; NN    NN ".split(";"),Ka:"    33    ;   3  3   ; 223  3   ;2  2  3  4;2  2  4  4; 22    34 ".split(";"),wa:{time:24E4},I:{I:-1}},{name:"level_18_virgo",width:10,height:6,icon:"undefined"!==typeof Te?Te:void 0,Ja:" NN NN    ;N  N  N N ;N  N  NN N;N  N  N  N;N  N  N N ;N  N NNN  ".split(";"),
Ka:" 22 22    ;2  2  2 4 ;2  2  24 4;2  2  3  4;2  2  3 4 ;2  2 444  ".split(";"),wa:{time:24E4},I:{I:-1}},{name:"level_19_libra",width:10,height:6,icon:"undefined"!==typeof Ue?Ue:void 0,Ja:"   NNNN   ;  NN  NN  ;NNNN  NNNN;          ;NNNNNNNNNN;          ".split(";"),Ka:"   4444   ;  34  43  ;2233  3322;          ;2233443322;          ".split(";"),wa:{time:24E4},I:{I:-1}},{name:"level_20_scorpio",width:10,height:6,icon:"undefined"!==typeof Ve?Ve:void 0,Ja:" NN NN    ;N  N  N   ;N  N  N   ;N  N  N  N;N  N  N  N;N  N  NNNN".split(";"),
Ka:" 34 43    ;2  4  4   ;2  4  4   ;2  4  4  4;2  4  4  2;2  4  4332".split(";"),wa:{time:24E4},I:{I:-1}},{name:"level_21_sagittarius",width:10,height:6,icon:"undefined"!==typeof Xe?Xe:void 0,Ja:"      NNNN;  N    FNN;   N FN  N;   FN     ; FN  N    ;N     N   ".split(";"),Ka:"      4444;  2    334;   2 33  4;   33     ; 33  2    ;2     2   ".split(";"),wa:{time:24E4},I:{I:-1}},{name:"level_22_capricorn",width:10,height:6,icon:"undefined"!==typeof Ye?Ye:void 0,Ja:" N NN     ;N N  N NN ;  N  NN  N;     NN  N;     N NN ;   NN     ".split(";"),
Ka:" 3 33     ;3 3  3 44 ;  3  34  4;     34  4;     3 44 ;   33     ".split(";"),wa:{time:24E4},I:{I:-1}},{name:"level_23_aquarius",width:10,height:6,icon:"undefined"!==typeof Ze?Ze:void 0,Ja:"  NNN NNN ; NN NNN NN;          ;  NNN NNN ; NN NNN NN;          ".split(";"),Ka:"  344 344 ; 22 322 32;          ;  344 344 ; 22 322 32;          ".split(";"),wa:{time:24E4},I:{I:-1}},{name:"level_24_pisces",width:10,height:6,icon:"undefined"!==typeof $e?$e:void 0,Ja:" NN     NN;   N   N  ;FFFNFFFNFF;   N   N  ;   N   N  ; NN     NN".split(";"),
Ka:" 33     33;   4   4  ;3334333433;   4   4  ;   4   4  ; 33     33".split(";"),wa:{time:24E4},I:{I:-1}}]}}O.t=O.t||{};O.t.tk=function(){eg()};O.t.fA=function(){};O.t.Bv=function(){};O.t.qn=function(){eg()};O.t.$z=function(){};O.t.Zz=function(){};O.t.eA=function(){};O.t.cA=function(){};O.t.Wq=function(){};O.t.aA=function(){};O.t.bA=function(){};O.t.av=function(){eg()};O.t.bv=function(){eg()};O.t.pi=function(){eg()};O.t.$u=function(){eg()};
O.t.Vu=function(a){void 0===O.f.Di&&(O.f.Di=new fg(!0));gg(a)};O.t.lt=function(){var a=O.f.Oc;void 0===O.f.Di&&(O.f.Di=new fg(!0));hg(a)};O.t.hd=function(a){window.open(a)};O.t.rk=function(){return[{e:Vc,url:O.A.Tq}]};O.t.dA=function(){};O.Pd=O.Pd||{};O.Pd.tk=function(){O.f.ej=!1};O.Pd.Bv=function(){};O.Pd.qn=function(){O.f.ej=!1};O.Pd.pi=function(){O.f.ej=!1};function ig(a,b){for(var c in a.prototype)b.prototype[c]=a.prototype[c]}
function jg(a,b,c,d){this.Ql=this.xg=a;this.qu=b;this.duration=1;this.Up=d;this.se=c;this.Lj=null;this.jh=0}function kg(a,b){a.jh+=b;a.jh>a.duration&&a.Lj&&(a.Lj(),a.Lj=null)}jg.prototype.da=function(){if(this.jh>=this.duration)return this.se(this.duration,this.xg,this.Ql-this.xg,this.duration);var a=this.se(this.jh,this.xg,this.Ql-this.xg,this.duration);this.Up&&(a=this.Up(a));return a};function lg(a,b){a.xg=a.da();a.Ql=b;a.duration=a.qu;a.Lj=void 0;a.jh=0}
O.Ju=void 0!==O.environment?O.environment:"development";O.jz=void 0!==O.ga?O.ga:O.Ju;"undefined"!==typeof O.mediaUrl?ga(O.mediaUrl):ga(O.size);O.Vt="backButton";O.nf="languageSet";O.Ee="resizeEvent";O.version={builder:"1.8.3.0","build-time":"11:12:57","build-date":"07-09-2016",audio:J.kb?"web audio api":J.Ra?"html5 audio":"no audio"};
O.uz=new function(){this.ve=this.Nv=3;m.u.ah&&(this.ve=3>m.La.he?1:4.4>m.La.he?2:3);m.La.Ek&&(this.ve=7>m.La.he?2:3);m.La.$o&&(this.ve=8>m.La.he?2:3);O.version.browser_name=m.name;O.version.browser_version=m.u.version;O.version.os_version=m.La.version;O.version.browser_grade=this.ve};O.a={};"function"===typeof Yf&&Yf();"function"===typeof dg&&dg();"function"===typeof bg&&bg();"function"===typeof initGameThemeSettings&&initGameThemeSettings();O.a.C="undefined"!==typeof Xf?Xf:{};
O.a.n="undefined"!==typeof cg?cg:{};O.a.P="undefined"!==typeof ag?ag:{};O.a.Nz="undefined"!==typeof gameThemeSettingsVar?gameThemeSettingsVar:{};O.Rg=window.publisherSettings;O.A="undefined"!==typeof game_configuration?game_configuration:{};"undefined"!==typeof Zf&&(O.A=Zf);if("undefined"!==typeof $f)for(var mg in $f)O.A[mg]=$f[mg];
(function(){var a,b,c,d,g;O.i={};O.i.op="undefined"!==typeof Y?Y:{};O.i.Ib=void 0!==O.A.Yd&&void 0!==O.A.Yd.Aj?O.A.Yd.Aj:O.a.C.Yd.Aj;if(O.A.ry)for(b=O.i.Ib.length-1;0<=b;b--)0>O.A.ry.indexOf(O.i.Ib[b])&&O.i.Ib.splice(b,1);try{if(d=function(){var a,b,c,d,g;b={};if(a=window.location.search.substring(1))for(a=a.split("&"),d=0,g=a.length;d<g;d++)c=a[d].split("="),b[c[0]]=c[1];return b}(),d.lang)for(c=d.lang.toLowerCase().split("+"),b=O.i.Ib.length-1;0<=b;b--)0>c.indexOf(O.i.Ib[b])&&O.i.Ib.splice(b,1)}catch(h){}0===
O.i.Ib.length&&O.i.Ib.push("en-us");c=navigator.languages?navigator.languages:[navigator.language||navigator.userLanguage];for(b=0;b<c.length;b++)if("string"===typeof c[b]){g=c[b].toLowerCase();for(d=0;d<O.i.Ib.length;d++)if(0<=O.i.Ib[d].search(g)){a=O.i.Ib[d];break}if(void 0!==a)break}void 0===a&&(a=void 0!==O.A.Yd&&void 0!==O.A.Yd.Bk?O.A.Yd.Bk:O.a.C.Yd.Bk);O.i.em=0<=O.i.Ib.indexOf(a)?a:O.i.Ib[0];O.i.lj=O.i.op[O.i.em];if(void 0!==O.a.C.Ob.language_toggle&&void 0!==O.a.C.Ob.language_toggle.U){a=O.a.C.Ob.language_toggle.U;
c=[];for(b=0;b<a.length;b++)0<=O.i.Ib.indexOf(a[b].id)&&c.push(a[b]);O.a.C.Ob.language_toggle.U=c}O.i.r=function(a,b){var c,d,g,h;if(void 0!==O.i.lj&&void 0!==O.i.lj[a]){c=O.i.lj[a];if(d=c.match(/#touch{.*}\s*{.*}/g))for(h=0;h<d.length;h++)g=(g=m.Ad.Mo||m.Ad.Qn)?d[h].match(/{[^}]*}/g)[1]:d[h].match(/{[^}]*}/g)[0],g=g.substring(1,g.length-1),c=c.replace(d[h],g);return c}return b};O.i.ms=function(a){O.i.em=a;O.i.lj=O.i.op[a];ka(O.nf,a)};O.i.ln=function(){return O.i.em};O.i.Uu=function(){return O.i.Ib};
O.i.rv=function(a){return 0<=O.i.Ib.indexOf(a)}})();O.xu={La:"",Ow:"",Pw:"",wu:""};O.b={};O.b.createEvent=function(a,b){var c,d,g,h;d=b.detail||{};g=b.bubbles||!1;h=b.cancelable||!1;if("function"===typeof CustomEvent)c=new CustomEvent(a,{detail:d,bubbles:g,cancelable:h});else try{c=document.createEvent("CustomEvent"),c.initCustomEvent(a,g,h,d)}catch(k){c=document.createEvent("Event"),c.initEvent(a,g,h),c.data=d}return c};
O.b.Hy=function(a){var b=Math.floor(a%6E4/1E3);return(0>a?"-":"")+Math.floor(a/6E4)+(10>b?":0":":")+b};O.b.ui=function(a){function b(){}b.prototype=ng.prototype;a.prototype=new b};O.b.Jx=function(a,b,c,d,g,h){var k=!1,l=document.getElementById(a);l||(k=!0,l=document.createElement("canvas"),l.id=a);l.style.zIndex=b;l.style.top=c+"px";l.style.left=d+"px";l.width=g;l.height=h;k&&((a=document.getElementById("viewport"))?a.appendChild(l):document.body.appendChild(l));O.wd.push(l);return l};
(function(){var a,b,c,d,g,h,k;O.dr=0;O.er=0;O.vl=!1;O.Ry=m.u.ah&&m.u.he&&4<=m.u.he;O.gj=!1;O.qt=m.Ad.Mo||m.Ad.Qn;O.orientation=0<=ba.indexOf("landscape")?"landscape":"portrait";k="landscape"===O.orientation?O.a.C.Dm:O.a.C.wd;h="landscape"===O.orientation?O.a.n.Dm:O.a.n.wd;if(void 0!==h){if(void 0!==h.Ac)for(a in h.Ac)k.Ac[a]=h.Ac[a];if(void 0!==h.Bc)for(a in h.Bc)k.Bc[a]=h.Bc[a]}b=function(){var a,b,c,d;if(O.Ry&&!O.gj){O.gj=!0;if(a=document.getElementsByTagName("canvas"))for(b=0;b<a.length;b++)if(c=
a[b],!c.getContext||!c.getContext("2d")){O.gj=!1;return}b=document.createEvent("Event");b.sA=[!1];b.initEvent("gameSetPause",!1,!1);window.dispatchEvent(b);d=[];for(b=0;b<a.length;b++){c=a[b];var g=c.getContext("2d");try{var h=g.getImageData(0,0,c.width,c.height);d.push(h)}catch(k){}g.clearRect(0,0,c.width,c.height);c.style.visibility="hidden"}setTimeout(function(){for(var b=0;b<a.length;b++)a[b].style.visibility="visible"},1);setTimeout(function(){for(var b=0;b<a.length;b++){var c=a[b].getContext("2d");
try{c.putImageData(d[b],0,0)}catch(g){}}b=document.createEvent("Event");b.initEvent("gameResume",!1,!1);window.dispatchEvent(b);O.gj=!1},100)}};c=function(){var a,c,d,g,h,E,s,t,u;"landscape"===O.orientation?(a=[window.innerWidth,window.innerHeight],c=[k.og,k.Cc],d=k.minWidth):(a=[window.innerHeight,window.innerWidth],c=[k.Cc,k.Qb],d=k.minHeight);g=c[0]/c[1];h=a[0]/a[1];E=d/c[1];h<g?(h=h<E?Math.floor(a[0]/E):a[1],g=a[0]):(h=a[1],g=Math.floor(a[1]*g));s=h/c[1];!O.qt&&1<s&&(g=Math.min(a[0],c[0]),h=Math.min(a[1],
c[1]),s=1);a="landscape"===O.orientation?g:h;c="landscape"===O.orientation?h:g;u=t=0;window.innerHeight<Math.floor(k.Cc*s)&&(t=Math.max(k.Uk,window.innerHeight-Math.floor(k.Cc*s)));window.innerWidth<Math.floor(k.Qb*s)&&(u=Math.floor(Math.max(k.og-k.Qb,(window.innerWidth-Math.floor(k.Qb*s))/s)),window.innerWidth<Math.floor(k.Qb*s)+u*s&&(u+=Math.floor(Math.max((d-k.og)/2,(window.innerWidth-(k.Qb*s+u*s))/2/s))));O.Fj=k.Cc-k.$p;O.$t=k.Qb-k.og;O.oa=t;O.wz=u;O.vz=Math.min(O.$t,-1*O.xz);O.ue=(k.Bc.top||
k.cf)-O.oa;O.Y={top:-1*t,left:-1*u,height:Math.min(k.Cc,Math.round(Math.min(c,window.innerHeight)/s)),width:Math.min(k.Qb,Math.round(Math.min(a,window.innerWidth)/s))};O.JA="landscape"===O.orientation?{top:0,left:Math.floor((k.og-k.minWidth)/2),width:k.minWidth,height:k.minHeight}:{top:Math.abs(k.Uk),left:k.bf,width:k.Qb,height:k.minHeight};d=Math.min(window.innerHeight,c);a=Math.min(window.innerWidth,a);"landscape"===O.orientation?document.getElementById("viewport").setAttribute("style","position:fixed; overflow:hidden; z-index: 0; width:"+
a+"px; left:50%; margin-left:"+-a/2+"px; height: "+d+"px; top:50%; margin-top:"+-d/2+"px"):document.getElementById("viewport").setAttribute("style","position:absolute; overflow:hidden; z-index: 0; width:"+a+"px; left:50%; margin-left:"+-a/2+"px; height: "+d+"px");d=function(a,b,c,d){var g,h,l,n;g=void 0!==b.top?b.top:k.cf;h=void 0!==b.left?b.left:k.bf;l=void 0!==b.width?b.width:k.Qb;n=void 0!==b.height?b.height:k.Cc;a.Hz=Math.floor(s*g);a.Gz=Math.floor(s*h);a.Iz=Math.floor(s*l);a.Fz=Math.floor(s*
n);!1!==c&&(g+=t);!1!==d&&(h+=u);a.setAttribute("style","position:absolute; left:"+Math.floor(s*h)+"px; top:"+Math.floor(s*g)+"px; width:"+Math.floor(s*l)+"px; height:"+Math.floor(s*n)+"px; z-index: "+b.depth)};d(O.um,k.Cm);d(O.Wm,k.Ac);d(O.gn,k.Bc,!1,!0);d(O.Zd,k.Xe);b();setTimeout(b,5E3);setTimeout(b,1E4);setTimeout(b,2E4);ka(O.Ee)};a=function(){if(O.dr===window.innerHeight&&O.er===window.innerWidth||O.vl)return!1;document.documentElement.style["min-height"]=5E3;d=window.innerHeight;g=40;O.vl=window.setInterval(function(){document.documentElement.style.minHeight=
"";document.documentElement.style["min-height"]="";window.scrollTo(0,m.u.ah?1:0);g--;if((m.u.ah?0:window.innerHeight>d)||0>g)O.er=window.innerWidth,O.dr=window.innerHeight,clearInterval(O.vl),O.vl=!1,document.documentElement.style["min-height"]=window.innerHeight+"px",document.getElementById("viewport").style.height=window.innerHeight+"px",c()},10)};O.ni=k.Ac.left||k.bf;O.oi=k.Ac.top||k.cf;O.hn=k.Ac.width||k.Qb;O.Zm=k.Ac.height||k.Cc;O.jf=k.Bc.left||k.bf;O.ue=k.Bc.top||k.cf;O.Pz=k.Bc.width||k.Qb;
O.Oz=k.Bc.height||k.Cc;O.Jv=k.Xe.left||k.bf;O.Kv=k.Xe.top||k.cf;O.Lv=k.Xe.width||k.Qb;O.Iv=k.Xe.height||k.Cc;h=function(a){return O.b.Jx(a.id,a.depth,void 0!==a.top?a.top:k.cf,void 0!==a.left?a.left:k.bf,void 0!==a.width?a.width:k.Qb,void 0!==a.height?a.height:k.Cc)};O.wd=[];O.um=h(k.Cm);O.Wm=h(k.Ac);O.gn=h(k.Bc);O.Zd=h(k.Xe);c();document.body.addEventListener("touchmove",function(a){a.preventDefault()},!0);document.body.addEventListener("touchstart",a,!0);window.addEventListener("resize",a,!0);window.setInterval(a,
200);O.pc={};O.pc[O.ji]=O.um;O.pc[O.gf]=O.Wm;O.pc[O.ok]=O.gn;O.pc[O.Xm]=O.Zd;O.pc[O.ff]=O.um;O.pc[O.qb]=O.Zd;O.pc[O.Wd]=O.Zd})();
O.b.Mt=function(){var a,b;if(b=document.getElementById("viewport"))a=document.createElement("img"),a.className="banner",a.src=ha.ke+"/media/banner_game_640x100.png",a.style.position="absolute",a.style.bottom="0px",a.style.width="100%",a.style.zIndex=300,b.appendChild(a),O.cu=!0,O.Qh=!0,b=function(a){O.cu&&O.Qh&&(O.t.hd("http://www.tinglygames.com/html5-games/"),a.preventDefault(),a.stopPropagation?a.stopPropagation():a.cancelBubble=!0)},a.addEventListener("mouseup",b,!0),a.addEventListener("touchend",
b,!0),a.addEventListener("mousedown",function(a){O.Qh&&(a.preventDefault(),a.stopPropagation?a.stopPropagation():a.cancelBubble=!0)},!0),a.addEventListener("touchstart",function(a){O.Qh&&(a.preventDefault(),a.stopPropagation?a.stopPropagation():a.cancelBubble=!0)},!0)};O.b.OA=function(){var a,b=document.getElementsByClassName("banner");if(b){for(a=0;a<b.length;a++)b[a].style.display="inline";O.Qh=!0}};
O.b.Xz=function(){var a,b=document.getElementsByClassName("banner");if(b){for(a=0;a<b.length;a++)b[a].style.display="none";O.Qh=!1}};O.b.kn=function(a){return a===O.Wm?{x:O.ni,y:O.oi}:a===O.gn?{x:O.jf,y:O.ue}:{x:O.Jv,y:O.Kv}};O.b.Xd=function(a){return O.pc[a]};O.b.jb=function(a){return O.pc[a]?(r.canvas!==O.pc[a]&&r.jb(O.pc[a]),!0):!1};O.b.Za=function(a,b){if(O.pc[b]){var c=K;a.Fa!==b&&(c.Hh=!0);a.Fa=b;a.canvas=O.pc[b]}};
O.b.g=function(a,b,c,d){var g;b=b||0;c=c||0;d=d||0;if("number"===typeof a)return a;if("object"===typeof a)switch(g=a.offset||0,a.align){case "center":return Math.round(b/2-(c/2-d))+g;case "left":case "top":return g-d;case "right":case "bottom":return b-c-g-d;default:return g+0}return 0};
O.b.ca=function(a,b,c,d){var g;b=b||0;c=c||0;if("number"===typeof a)return a;if("object"===typeof a)switch(g=a.offset||0,a.align){case "center":return"center"===d||"middle"===d?Math.round(b/2)+g:"left"===d||"top"===d?Math.round(b/2-c/2)+g:Math.round(b/2+c/2)-g;case "left":case "top":return"center"===d||"middle"===d?Math.round(c/2)+g:"left"===d||"top"===d?g:c+g;case "right":case "bottom":return"center"===d||"middle"===d?b-Math.round(c/2)-g:"left"===d||"top"===d?b-Math.round(c/2)-g:b-g;default:return g+
0}return 0};O.b.Az=function(a,b,c,d){switch(d){case "center":case "middle":return Math.round(b/2)+a;case "left":case "top":return a;case "right":case "bottom":return c+a}return 0};O.bc=O.bc||{};O.bc.Lx=!1;O.bc.Zq=function(a){a instanceof Array&&(this.jk=a[0],this.wl=a[1],this.du="http://api.gameanalytics.com/1/"+this.jk,this.$q=!0)};
O.bc.im=function(a,b){var c,d=JSON.stringify(b),g=og(d+this.wl),h=this.du+"/"+a;try{c=new XMLHttpRequest,c.open("POST",h,!0),this.Lx&&(c.onreadystatechange=function(){4===c.readyState&&(200===c.status?(console.log("GOOD! statusText: "+c.statusText),console.log(b)):console.log("ERROR ajax call error: "+c.statusText+", url: "+h))}),c.setRequestHeader("Content-Type","text/plain"),c.setRequestHeader("Authorization",g),c.send(d)}catch(k){}};
O.bc.bm=function(){return{user_id:this.Yo,session_id:this.Ix,build:this.iu}};
O.bc.fy=function(){var a;a=pg();var b=O.A.bx,c=qg(),d=rg("userId","");""===d&&(d=pg(),sg("userId",d));var g={Yo:d},d=O.xu;this.Ix=a;g&&"object"===typeof g&&(this.Yo=g.Yo);this.iu=c;this.k=!0;this.$q&&(a=this.bm(),a.device=d.wu,a.platform=d.La,a.os_major=d.Ow,a.os_minor=d.Pw,a.install_publisher=b,a.install_site=window.location!==window.parent.location?document.referrer:document.location.href,this.im("user",a));this.Qa("start","session")};O.bc.Kz=function(){this.k=!1;this.Qa("end","session")};
O.bc.Qa=function(a,b,c){if(this.k&&this.$q){var d="";b&&(d=b instanceof Array?b.toString().replace(",",":"):d+b);b=this.bm();b.event_id=d+":"+a;b.value=c;this.im("design",b)}};O.bc.IA=function(a,b,c){this.Qa(a,b,c)};O.bc.bs=function(a,b){var c=this.bm();c.message=a;c.severity=b;this.im("error",c)};function tg(){this.Fa=this.depth=0;this.visible=!1;this.k=!0;this.a=O.a.C.Aa;this.ax=this.a.Iy;L(this);Ib(this,"system")}
function pg(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(a){var b=16*Math.random()|0;return("x"===a?b:b&3|8).toString(16)})}e=tg.prototype;e.start=function(a){O.bc.Zq(a);O.bc.fy()};e.Qa=function(a,b,c){O.bc.Qa(a,b,c)};function ug(a,b,c,d){var g,h;for(g=0;g<a.$.length;g++)void 0!==a.$[g]&&a.$[g].tag===b&&(h=a.$[g],a.Qa(void 0!==c?c:h.oq,void 0!==d?d:h.Vr,h.m),h.k=!1)}
function vg(){var a=O.Aa,b=O.f.Vf,c;for(c=0;c<a.$.length;c++)void 0!==a.$[c]&&a.$[c].tag===b&&(a.$[c].paused+=1)}e.bs=function(a,b){O.bc.bs(a,b)};e.Sb=function(){this.$=[]};e.pa=function(a){var b,c=0;for(b=0;b<this.$.length;b++)this.$[b].k&&(0===this.$[b].paused&&(this.$[b].m+=a),c=b);c<this.$.length-1&&(a=this.$.length-Math.max(this.ax,c+1),0<a&&this.$.splice(this.$.length-a,a))};
function fg(a,b,c){this.xr=a||!1;this.host=b||"http://localhost:8080";this.Hx=c||this.host+"/services/storage/gamestate";this.Ls="undefined"!==typeof window.localStorage;this.zn=this.Wo=!1;var d=this;window.parent!==window&&(m.u.qo||m.La.Ek)&&(window.addEventListener("message",function(a){a=a.data;var b=a.command;"init"===b?d.Wo="ok"===a.result:"getItem"===b&&d.pk&&("ok"===a.result?d.pk(a.value):d.pk(a.defaultValue))},!1),this.pk=null,window.parent.postMessage({command:"init"},"*"));this.Ci=[];window.setTimeout(function(){d.zn=
!0;for(var a=0;a<d.Ci.length;++a)d.Ci[a]();d.Ci=[]},2E3)}function wg(){return"string"===typeof O.A.Es&&""!==O.A.Es?O.A.Es:void 0!==O.a.n.wg&&void 0!==O.a.n.wg.yq?O.a.n.wg.yq:"0"}function gg(a){var b=O.f.Di;"function"===typeof a&&(b.zn?xg(b,a):b.Ci.push(function(){xg(b,a)}))}function hg(a){var b=O.f.Di;b.zn?yg(b,a):b.Ci.push(function(){yg(b,a)})}
function yg(a,b){var c=null,d=wg();try{c=JSON.stringify({lastChanged:new Date,gameState:JSON.stringify(b)})}catch(g){}if(a.Wo)window.parent.postMessage({command:"setItem",key:"TG_"+d,value:c},"*");else{if(a.Ls)try{window.localStorage.setItem(d,c)}catch(h){}a.xr||(c=new jb("gameState_"+d),c.text=void 0===JSON?"":JSON.stringify(b),kb(c,a.Hx+"/my_ip/"+d))}}
function xg(a,b){var c=null,d=null,g=wg();if(a.Wo)a.pk=function(a){var d;try{c=JSON.parse(a),d=JSON.parse(c.gameState)}catch(g){d=null}b(d)},window.parent.postMessage({command:"getItem",key:"TG_"+g},"*");else{if(a.Ls)try{(c=window.localStorage.getItem(g))&&(c=JSON.parse(c))}catch(h){b(null);return}if(!a.xr){var k=new jb("gameState_"+g),d=null;lb(k,fg.GA+"/my_ip/"+g)&&(d=void 0===JSON?{}:JSON.parse(k.text))}try{if(c){if(d&&Date.parse(d.lastChanged)>Date.parse(c.lastChanged)){b(JSON.parse(d.gameState));
return}b(JSON.parse(c.gameState));return}if(d){b(JSON.parse(d.gameState));return}}catch(l){b(null);return}b(null)}}
function zg(a,b,c){console&&console.log&&console.log("Hosted on: "+(window.location.origin?window.location.origin:window.location.protocol+"//"+window.location.hostname));this.depth=1E3;this.Rb=this.visible=!1!==c;this.k=!0;O.b.Za(this,O.qb);var d;this.a=O.a.C.Jc;if("landscape"===O.orientation&&O.a.C.En)for(d in O.a.C.En)this.a[d]=O.a.C.En[d];for(d in O.a.P.Jc)this.a[d]=O.a.P.Jc[d];if(O.A.Jc)for(d in O.A.Jc)this.a[d]=O.A.Jc[d];this.mb=a;this.Sp=b;this.eq=!1;this.Ph=0;this.vm=!1;this.Dj=0;this.Cj=
this.a.Yt;this.ho=!0;this.Dv=.6/Math.log(this.a.Pk+1);this.xt=void 0!==O.A.Cv?O.A.Cv:this.a.lw;this.Ov=this.xt+this.a.Rv;L(this)}e=zg.prototype;e.xo=function(a){var b;O.b.jb(O.ff);oa(0,0,this.canvas.width,this.canvas.height,"white",!1);b=V.K();(O.A.Jc&&O.A.Jc.Ti||this.a.Ti)&&C(b,O.A.Jc&&O.A.Jc.Ti?O.A.Jc.Ti:this.a.Ti);a=O.i.r(a,"<"+a.toUpperCase()+">");b.o(a,this.canvas.width/2,this.canvas.height/2,this.a.Ol);this.error=!0;this.visible=this.Rb=!1;this.canvas.Z=!0};
e.ae=function(){this.ma&&(this.Ab=O.b.g(this.a.Ab,O.Y.width,this.ma.width)+O.Y.left,this.rc=O.b.g(this.a.rc,O.Y.height,this.ma.height)+O.Y.top)};
e.Fm=function(){var a,b,c,d,g,h;if("function"===typeof O.t.rk&&(h=this.a.uf,(this.va=O.t.rk())&&0<this.va.length)){this.ma?this.ma.clear():this.ma=new y(this.a.uf,this.a.zi);z(this.ma);h/=this.va.length;for(c=0;c<this.va.length;c++)try{g=this.va[c].e,d=Math.min(1,Math.min((h-20)/g.width,this.a.zi/g.height)),a="center"===this.a.xi?h*c+Math.round((h-g.width*d)/2):h*c+Math.round(h-g.width*d)-10,b=this.ma.height-g.height*d,g instanceof x?g.za(0,a,b,d,d,0,1):r.context.drawImage(g,a,b,g.width*d,g.height*
d)}catch(k){}B(this.ma);this.Nk=0;this.Gn=!0;this.yi=0;this.tf=Ob(0,0,this.ma.width,this.ma.height);this.ae()}};
e.Da=function(){var a,b,c,d;this.ho?r.clear():O.b.jb(O.ff);if(this.a.backgroundImage)if(d=this.a.backgroundImage,a=Math.abs(O.oa),1<d.F){c=(r.canvas.height-a)/d.ng;b=-(d.Vh*c-r.canvas.width)/2;c=r.context;var g=c.globalAlpha,h,k,l;c.globalAlpha=this.Ph;for(h=0;h<d.F;h+=1)k=b+h%d.Pg*d.width,l=a+d.height*Math.floor(h/d.Pg),d.Kd.ka(d.Gd[h],d.Hd[h],d.Id[h],d.Rc[h],d.Qc[h],k-d.Gb+d.od[h],l-d.Hb+d.pd[h]);c.globalAlpha=g}else c=(this.canvas.height-a)/d.height,b=-Math.floor((d.width*c-this.canvas.width)/
2),d instanceof x?d.za(0,b,a,c,c,0,this.Ph):d instanceof y&&d.za(b,a,c,c,0,this.Ph);d=this.a.ze+this.a.Cn+this.a.Dg;b=ic.height;a=ic.width-(this.a.ze+this.a.Cn);this.Eg=O.b.g(this.a.Eg,r.canvas.width,d);this.sf=O.b.g(this.a.sf,r.canvas.height,b);ic.ka(0,0,0,this.a.ze,b,this.Eg,this.sf,1);ic.Zj(0,this.a.ze,0,a,b,this.Eg+this.a.ze,this.sf,this.a.Dg,b,1);ic.ka(0,this.a.ze+a,0,this.a.Cn,b,this.Eg+this.a.ze+this.a.Dg,this.sf,1)};
function Ag(a){a.ho&&(a.vm=!0);a.visible&&(a.Da(),a.Fm(),"function"===typeof O.t.qk&&(a.ce=O.t.qk(),a.ce instanceof y&&(a.Xg=!0,a.qs=Math.floor((a.canvas.width-a.ce.width)/2),a.rs=Math.floor((a.canvas.height-a.ce.height)/2))));O.f.Mk&&ha.Fd("audio");O.f.Lk&&ha.Fd("audio_music");ha.Fd("fonts")}
e.Sb=function(){var a,b=!1;if(void 0!==O.A.Ni)if(!1===O.A.Ni.Ev)b=!0;else{if(void 0!==O.A.Ni.Hm)for(a=0;a<O.A.Ni.Hm.length;a++){var c;a:{c=O.A.Ni.Hm[a];var d=void 0,g=void 0,h=d=void 0,g=void 0,g=window.location.origin?window.location.origin:window.location.protocol+"//"+window.location.hostname;if(0===g.indexOf("file://")&&c===og("file://"))c=!0;else{g=g.split(".");d=g.shift().split("://");d[0]+="://";g=d.concat(g);h="";for(d=g.length-1;0<=d;d--)if(h=g[d]+(0<d&&d<g.length-1?".":"")+h,og(h)===c){c=
!0;break a}c=!1}}if(c){b=!0;break}}}else b=!0;b&&"number"===typeof O.A.Gy&&(new Date).getTime()>O.A.Gy&&(b=!1);b?(this.ig=[],this.error=!1,this.Us=this.Vm=this.zj=this.m=0,this.ready=this.Xg=!1,this.zv=void 0!==this.a.vr?this.a.vr:this.a.ze-this.a.wi,this.Av=void 0!==this.a.wr?this.a.wr:Math.floor((ic.height-jc.height)/2),this.Dn=jc.width-(this.a.wi+this.a.ur),this.Um=this.Kr=this.Fp=!1,(this.Pi=ha.complete("start"))&&Ag(this),this.tr=ha.complete("load"),this.visible&&(this.Vs=document.getElementById("throbber_image"),
this.fe=this.a.fe,this.No=O.b.g(this.a.No,this.canvas.width,this.fe),this.Pl=O.b.g(this.a.Pl,this.canvas.height,this.fe))):K.pause()};
e.pa=function(a){this.m+=a;"function"===typeof O.t.qk&&void 0===this.ce&&(this.ce=O.t.qk(),this.ce instanceof y&&(this.Xg=!0,this.qs=Math.floor((this.canvas.width-this.ce.width)/2),this.rs=Math.floor((this.canvas.height-this.ce.height)/2)));this.Xg&&0<=this.a.zo&&this.m>=this.a.zo&&(this.Xg=!1);this.vm&&(this.Dj+=a,this.Dj>=this.Cj?(this.vm=!1,this.Ph=1):this.Ph=Yb(this.Dj,0,1,this.Cj));this.Pi&&(this.zj+=a,this.Vm+=a);this.Us=Math.round(this.m/this.a.zy%(this.a.Ay-1));this.Gn&&(this.Nk=0+this.yi/
this.a.Fn*1,this.yi+=a,this.yi>=this.a.Fn&&(this.Gn=!1,this.Nk=1));"function"===typeof this.Sp&&this.Sp(Math.round((ia("load")+ia("audio")+ia("audio_music"))/2));!this.ready&&this.tr&&(this.Um||this.Vm>=this.a.Pk)&&(!O.f.Mk||this.Fp||J.Ra&&this.zj>=this.a.Pk)&&(!O.f.Lk||this.Kr||J.Ra&&this.zj>=this.a.Pk)&&(this.ready=!0);if(a=!this.eq&&!this.error&&this.ready&&this.m>=this.xt)a=O.f,a=(a.ic&&a.Xa&&!a.Xa.qv()?!1:!0)||this.m>=this.Ov;a&&(this.eq=!0,this.mb())};
e.zg=function(a,b,c){!this.Xg&&this.tf&&Qb(this.tf,this.Ab,this.rc,b,c)&&(this.gb=Math.floor((b-this.Ab)/(this.ma.width/this.va.length)))};e.Ag=function(a,b,c){void 0!==this.gb&&(this.va[this.gb].url||this.va[this.gb].action)&&Qb(this.tf,this.Ab,this.rc,b,c)&&(b-=this.Ab,b>=this.ma.width/this.va.length*this.gb&&b<this.ma.width/this.va.length*(this.gb+1)&&(this.va[this.gb].url?O.t.hd(this.va[this.gb].url):this.va[this.gb].action()));this.gb=void 0};
e.gd=function(a,b){"Load Complete"===a&&"start"===b.Ua?(this.Pi=!0,Ag(this)):"Load Complete"===a&&"load"===b.Ua?this.tr=!0:"Load Complete"===a&&"audio"===b.Ua?this.Fp=!0:"Load Complete"===a&&"audio_music"===b.Ua?this.Kr=!0:"Load Complete"===a&&"fonts"===b.Ua&&(this.Um=!0);a===O.Ee&&this.ae()};
e.Pa=function(){if(!this.error){this.ho&&this.Pi?this.Da():r.clear();try{this.Vs&&r.context.drawImage(this.Vs,this.fe*this.Us,0,this.fe,this.fe,this.No,this.Pl,this.fe,this.fe)}catch(a){}if(this.Pi){var b=0,c=this.Eg+this.zv,d=this.sf+this.Av,g=jc.height;jc.ka(0,b,0,this.a.wi,g,c,d,1);b+=this.a.wi;c+=this.a.wi;this.ready?(jc.Zj(0,b,0,this.Dn,g,c,d,this.a.Dg,g,1),b+=this.Dn,c+=this.a.Dg,jc.ka(0,b,0,this.a.ur,g,c,d,1)):jc.Zj(0,b,0,this.Dn,g,c,d,Math.floor(Math.min((ia("load")+ia("audio"))/500+this.Dv*
Math.log(this.m+1),1)*this.a.Dg),g,1);this.ma&&this.ma.bd(this.Ab,this.rc,this.Nk)}this.Xg&&this.ce.o(this.qs,this.rs)}};
function Bg(){var a,b;b=this;this.depth=100;this.k=this.visible=!0;O.b.Za(this,O.qb);this.a=O.a.C.Cl;if("landscape"===O.orientation&&O.a.C.Go)for(a in O.a.C.Go)this.a[a]=O.a.C.Go[a];this.Ob=O.a.C.Ob;if("landscape"===O.orientation&&O.a.C.Am)for(a in O.a.C.Am)this.Ob[a]=O.a.C.Am[a];for(a in O.a.P.Cl)this.a[a]=O.a.P.Cl[a];this.ig=[];a=Cg(O.f);this.Tp=void 0!==a&&null!==a;this.W=new Rb;this.W.sa(this.a.Mu,function(){b.zs.call(b)});this.W.sa(this.a.Pr,function(){b.Bs.call(b)});this.W.sa(O.j.Ki&&!this.Tp?
this.a.Xw:this.a.Pr,function(){b.Cs.call(b)});this.W.sa(this.a.cw,function(){b.As.call(b)});L(this,!1)}e=Bg.prototype;e.zs=function(){this.lk=!0;this.a.yg&&(this.li=O.b.g(this.a.li,this.canvas.width,Qd.width),this.kk=O.b.g(this.a.kk,this.canvas.width,Qd.width),this.mi=O.b.g(this.a.mi,this.canvas.height,Qd.height),this.ki=O.b.g(this.a.ki,this.canvas.height,Qd.height),this.fn=this.li,this.mk=this.mi,this.an=this.a.dn,this.bn=this.a.en,this.$m=this.a.cn,this.lc=0,this.ae())};
e.Bs=function(a){function b(a,b,c,d){return ac(a,b,c,d,15)}var c,d;O.j.Ki&&!this.Tp&&(c=O.b.g(this.a.cq,this.canvas.width,this.a.ai,Math.floor(this.a.ai/2)),d=O.b.g(this.a.Xj,this.canvas.height,rd.height,Math.floor(rd.height/2)),c=new Dg("difficulty_toggle",c,d,this.depth-20,Eg()+"",this.a.ai,{R:function(a){Fg(parseInt(a,10));return!0},Ub:!0}),c.fc=Math.floor(this.a.ai/2),c.gc=Math.floor(rd.height/2),!1!==a&&(Gg(c,"xScale",b,0,1,this.a.bq),Gg(c,"yScale",b,0,1,this.a.bq)),this.Wj=c,this.Xj=c.y,this.ig.push(c),
this.ae())};
e.Cs=function(a){function b(a,b,c,d){return ac(a,b,c,d,15)}var c,d=this;this.bo=!0;c=new Hg("bigPlay",O.b.g(this.a.Ww,this.canvas.width,this.a.Ei,Math.floor(this.a.Ei/2)),O.b.g(this.a.hl,this.canvas.height,xd.height,Math.floor(xd.height/2)),this.depth-20,"startScreenPlay",this.a.Ei,{R:function(){K.p(d);var a=O.f,b,c,l;void 0===O.f.Wb&&(void 0!==O.a.P.Wb&&(void 0!==O.a.P.Wb.au&&(b=O.a.P.Wb.au),void 0!==O.a.P.Wb.wm&&(Sa(J,"music",O.a.P.Wb.wm),a.Bf()||gb("music"),O.f.uw=O.a.P.Wb.wm),c=void 0!==O.a.P.Wb.Xt?
O.a.P.Wb.Xt:0,l=void 0!==O.a.P.Wb.Cj?O.a.P.Wb.Cj:0),void 0===b&&"undefined"!==typeof Ff&&(b=Ff),void 0!==b&&(O.f.Wb=J.play(b,c,l),O.f.Wb&&(J.Bp(O.f.Wb,"music"),J.ns(O.f.Wb,!0))));O.j.If&&!a.ic?a.screen=new Ig:Jg(a,0);return!0},Ub:!0});c.fc=Math.floor(this.a.Ei/2);c.gc=Math.floor(xd.height/2);!1!==a?(Gg(c,"xScale",b,0,1,this.a.fl),Gg(c,"yScale",b,0,1,this.a.fl),this.gl=0):this.gl=this.a.fl;this.el=c;this.hl=c.y;this.ig.push(c);this.ae()};
function Kg(a){var b=dc([N,function(a,b,g,h){return ac(a,b,g,h,2)},Ub],[!0,!1,!1],[.02,.1,.88]);a.Xr=!0;Gg(a.el,"xScale",cc(b),1,.25,4E3);Gg(a.el,"yScale",cc(b),1,-.1,4E3)}e.As=function(a){var b;this.Gr=!0;b=new ng(O.b.g(this.a.Nn,this.canvas.width,od.width),O.b.g(this.a.Sk,this.canvas.height,od.height),this.depth-20,new Pb(od),[od],{R:O.f.Vg,Ub:!0});!1!==a&&Gg(b,"alpha",M,0,1,this.a.bw);this.Mn=b;this.Sk=b.y;this.ig.push(b);this.ae()};
e.Da=function(){var a,b,c,d;if(a=this.a.backgroundImage)O.b.jb(O.ff),c=Math.abs(O.oa),1<a.F?(b=(r.canvas.height-c)/a.ng,d=-(a.Vh*b-r.canvas.width)/2,sa(a,d,c)):(b=(r.canvas.height-c)/a.height,d=-Math.floor((a.width*b-this.canvas.width)/2),a.za(0,d,c,b,b,0,1))};
e.Fm=function(){var a,b,c,d,g,h;if("function"===typeof O.t.rk&&(h=this.a.uf,(this.va=O.t.rk())&&0<this.va.length)){this.ma?this.ma.clear():this.ma=new y(this.a.uf,this.a.zi);z(this.ma);h/=this.va.length;for(c in this.va)try{g=this.va[c].e,d=Math.min(1,Math.min((h-20)/g.width,this.a.zi/g.height)),a="center"===this.a.xi?h*c+Math.round((h-g.width*d)/2):h*c+Math.round(h-g.width*d)-10,b=this.ma.height-g.height*d,g instanceof x?g.za(0,a,b,d,d,0,1):r.context.drawImage(g,a,b,g.width*d,g.height*d)}catch(k){}B(this.ma);
this.Nk=0;this.Gn=!0;this.yi=0;this.tf=Ob(0,0,this.ma.width,this.ma.height);this.ae()}};e.ae=function(){var a;a=0;O.Y.height<this.a.ym&&(a=this.a.ym-O.Y.height);this.bo&&(this.el.y=this.hl-a);this.Gr&&(this.Mn.y=this.Sk-a,this.Mn.x=O.b.g(this.a.Nn,O.Y.width,od.width)+O.Y.left);this.Wj&&(this.Wj.y=this.Xj-a);this.lk&&this.lc>=this.a.fd&&(this.mk=this.ki-O.oa);this.ma&&(this.Ab=O.b.g(this.a.Ab,O.Y.width,this.ma.width)+O.Y.left,this.rc=O.b.g(this.a.rc,O.Y.height,this.ma.height)+O.Y.top)};
e.Sb=function(){this.Da();this.a.yg&&(O.b.jb(O.qb),this.a.yg.o(0,0,-this.a.yg.height-10));this.Fm();this.W.start()};e.yb=function(){var a;for(a=0;a<this.ig.length;a++)K.p(this.ig[a])};
e.pa=function(a){this.canvas.Z=!0;this.lk&&this.lc<this.a.fd&&(this.fn=this.a.Qu(this.lc,this.li,this.kk-this.li,this.a.fd),this.mk=this.a.Ru(this.lc,this.mi,this.ki-this.mi,this.a.fd)-O.oa,this.an=this.a.Ou(this.lc,this.a.dn,this.a.Aq-this.a.dn,this.a.fd),this.bn=this.a.Pu(this.lc,this.a.en,this.a.Bq-this.a.en,this.a.fd),this.$m=this.a.Nu(this.lc,this.a.cn,this.a.zq-this.a.cn,this.a.fd),this.lc+=a,this.lc>=this.a.fd&&(this.fn=this.kk,this.mk=this.ki-O.oa,this.an=this.a.Aq,this.bn=this.a.Bq,this.$m=
this.a.zq));this.bo&&(!this.Xr&&this.gl>=this.a.fl+this.a.Vw&&Kg(this),this.gl+=a)};e.zg=function(a,b,c){this.tf&&Qb(this.tf,this.Ab,this.rc,b,c)&&(this.gb=Math.floor((b-this.Ab)/(this.ma.width/this.va.length)))};
e.Ag=function(a,b,c){void 0!==this.gb&&(this.va[this.gb].url||this.va[this.gb].action)&&Qb(this.tf,this.Ab,this.rc,b,c)&&(b-=this.Ab,b>=this.ma.width/this.va.length*this.gb&&b<this.ma.width/this.va.length*(this.gb+1)&&(this.va[this.gb].url?O.t.hd(this.va[this.gb].url):this.va[this.gb].action()));this.gb=void 0};e.zb=function(){this.ob=!0};
e.Tb=function(){this.ob&&(this.W.stop(),this.lk?this.lc<this.a.fd&&(this.lc=this.a.fd-1):(this.zs(),this.lc=this.a.fd-1),this.Wj?Lg(this.Wj):this.Bs(!1),this.Gr?Lg(this.Mn):this.As(!1),this.bo?(Lg(this.el),this.Xr&&Kg(this)):this.Cs(!1),this.ob=!1)};e.gd=function(a){a===O.Ee&&(this.Da(),this.ae())};e.Pa=function(){this.lk&&this.a.yg&&this.a.yg.za(0,this.fn,this.mk,this.an,this.bn,0,this.$m);this.ma&&this.ma.o(this.Ab,this.rc);this.Rb=!1};
function Ig(){this.depth=100;this.k=this.visible=!0;O.b.Za(this,O.qb);var a;this.a=O.a.C.of;if("landscape"===O.orientation)for(a in O.a.C.jr)this.a[a]=O.a.C.jr[a];this.ua=O.a.n.jA;if(O.a.n.of)for(a in O.a.n.of)this.a[a]=O.a.n.of[a];this.cc=O.a.C.Ob;for(var b in O.a.P.of)this.a[b]=O.a.P.of[b];this.qf=-1;this.Ha=0;this.rf=[];L(this)}e=Ig.prototype;
e.Da=function(){var a,b,c,d;O.b.jb(O.ff);if(a=this.a.backgroundImage?this.a.backgroundImage:void 0)c=Math.abs(O.oa),1<a.F?(b=(r.canvas.height-c)/a.ng,d=-(a.Vh*b-r.canvas.width)/2,sa(a,d,c)):(b=(r.canvas.height-c)/a.height,d=-Math.floor((a.width*b-this.canvas.width)/2),a.za(0,d,c,b,b,0,1));var g;b=O.a.C.la.type[O.j.Bd].Nc;O.a.n.la&&O.a.n.la.type&&O.a.n.la.type[O.j.Bd]&&O.a.n.la.type[O.j.Bd]&&(b=!1===O.a.n.la.type[O.j.Bd].Nc?!1:b);void 0!==this.ua&&void 0!==this.ua.Nc&&(b=this.ua.Nc);c=O.b.g(this.a.Yx,
this.canvas.width,pc.width);a=O.b.g(this.a.ws,O.Y.height,pc.height)+O.Y.top;b&&(pc.o(0,c,a),b=V.K(),C(b,this.a.vs),F(b,"center"),b.o(this.L+" / "+this.Po,c+Math.floor(pc.width/2),a+pc.height+this.a.xs));if(void 0!==this.ua&&void 0!==this.ua.Ox?this.ua.Ox:1)b=V.K(),void 0!==this.a.Yw?C(b,this.a.Yw):C(b,this.a.co),c=O.i.r("levelMapScreenTotalScore","<TOTAL SCORE:>"),d=H(b,c,this.a.$w,this.a.Zw),d<b.fontSize&&D(b,d),d=O.b.ca(this.a.Yr,this.canvas.width,b.ba(c),b.align),g=O.b.ca(this.a.Zr,O.Y.height,
b.V(c),b.h)+O.Y.top,b.o(c,d,g),c=""+this.jl,C(b,this.a.co),d=O.b.ca(this.a.Yr,this.canvas.width,b.ba(c),b.align),b.o(c,d,a+pc.height+this.a.xs)};
function Mg(a){if("grid"===a.a.type){z(a.vi);r.clear();a.pf=[];var b;b=function(b,d,g){var h,k,l,n,q,w,A,E,s,t,u,v,I,ca,T,W,ua,za,yd,Bb,Cd,tb,Rf;k=O.j.S[b];yd=a.Lb?a.a.Yu:a.a.Zu;Bb=a.a.nn;Cd=yd;if(a.a.ou)h=a.a.ou[b];else{za=a.Lb?a.a.Hw:a.a.Iw;for(tb=Math.floor(k/za);1<Math.abs(tb-za);)za-=1,tb=Math.floor(k/za);for(h=[];0<k;)h.push(Math.min(za,k)),k-=za}tb=h.length;ua=Math.round(((a.Lb?a.a.pr:a.a.qr)-(tb+1)*yd)/tb);Rf=a.a.mu?a.a.mu:!1;if(!Rf){za=1;for(k=0;k<tb;k++)za=Math.max(h[k],za);W=Math.round((a.canvas.width-
2*Bb)/za)}for(k=n=0;k<tb;k++){za=h[k];Rf&&(W=Math.round((a.canvas.width-2*Bb)/za));for(l=0;l<za;l++){s=a.a.fq;I=a.a.Bu;u=O.j.pg||"locked";v=0;q=Ng(b,n,void 0,void 0);"object"===typeof q&&null!==q&&(void 0!==q.state&&(u=q.state),"object"===typeof q.stats&&null!==q.stats&&(v=q.stats.stars||0));ca="locked"===u;"function"===typeof O.n.Dq&&(w=O.n.Dq(Og(O.f,b,n),0,0,u))&&(I=ca=s=!1);q=Bb+d;E=Cd;T=t=1;if(!1!==I){A=a.Lb?kc:qc;if("played"===u)switch(v){case 1:A=a.Lb?lc:rc;break;case 2:A=a.Lb?mc:sc;break;case 3:A=
a.Lb?nc:tc}else a.Lb||"locked"!==u||(A=wc);A.width>W&&(T=W/A.width);A.height>ua&&(T=Math.min(t,ua/A.height));q+=Math.round((W-A.width*T)/2);E+=Math.round((ua-A.height*T)/2);A.za(0,q,E,T,T,0,1);g&&(a.pf[n]={x:q,y:E})}w&&(w.width>W&&(t=W/w.width),w.height>ua&&(t=Math.min(t,ua/w.height)),void 0!==A?(v=O.b.g(a.a.hr,A.width*T,w.width*t),I=O.b.g(a.a.ir,A.height*T,w.height*t)):(v=O.b.g(a.a.hr,W,w.width*t),I=O.b.g(a.a.ir,ua,w.height*t),g&&(a.pf[n]={x:q+v,y:E+I})),w instanceof y?w.za(q+v,E+I,t,t,0,1):w.za(0,
q+v,E+I,t,t,0,1));!1===s||ca||(s=""+(O.j.cj?n+1:Og(O.f,b,n)+1),t=a.fonts.jn,"locked"===u&&void 0!==a.fonts.Fv?t=a.fonts.Fv:"unlocked"===u&&void 0!==a.fonts.Qy?t=a.fonts.Qy:"played"===u&&void 0!==a.fonts.played&&(t=a.fonts.played),void 0!==A?(v=O.b.ca(a.a.lr,A.width*T,t.ba(s),t.align),I=O.b.ca(a.a.mr,A.height*T,t.V(s),t.h)):(v=O.b.ca(a.a.lr,W,t.ba(s),t.align),I=O.b.ca(a.a.mr,ua,t.V(s),t.h)),t.o(s,q+v,E+I));a.Lb&&ca&&(void 0!==A?(v=O.b.g(a.a.yr,A.width*T,oc.width),I=O.b.g(a.a.zr,A.height*T,oc.height)):
(v=O.b.g(a.a.yr,W,oc.width),I=O.b.g(a.a.zr,ua,oc.height)),oc.o(0,q+v,E+I));Bb+=W;n++}Bb=a.a.nn;Cd+=ua+yd}};a.ri&&b(a.G-1,0);b(a.G,a.canvas.width,!0);a.qi&&b(a.G+1,2*a.canvas.width);B(a.vi)}}function Pg(a,b){switch(b-a.G){case 0:a.Tn=0;break;case 1:a.Tn=-a.canvas.width;break;case -1:a.Tn=a.canvas.width}a.Hg=!0;a.Wk=0;a.moveStart=a.Ha;a.Jr=a.Tn-a.Ha;a.Vk=Math.min(a.a.qw-a.dh,Math.round(Math.abs(a.Jr)/(a.Kl/1E3)));a.Vk=Math.max(a.a.pw,a.Vk)}
function Qg(a){if(1<O.j.S.length){var b,c;b=O.b.g(a.a.fz,a.canvas.width,vc.width);c=O.b.g(a.a.cp,O.Y.height,vc.height)+O.Y.top;a.Ce=new ng(b,c,a.depth-20,new Pb(vc),[vc],function(){a.Jd="previous";Pg(a,a.G-1);return!0});b=O.b.g(a.a.ez,a.canvas.width,uc.width);c=O.b.g(a.a.bp,O.Y.height,uc.height)+O.Y.top;a.Be=new ng(b,c,a.depth-20,new Pb(uc),[uc],function(){a.Jd="next";Pg(a,a.G+1);return!0});Rg(a)}else a.ye-=a.a.Gq}
function Rg(a){if(1<O.j.S.length){var b;a.ri?(b=[vc],a.Ce.eb=!0):(b=[new y(vc.width,vc.height)],z(b[0]),vc.o(1,0,0),B(b[0]),a.Ce.eb=!1);Sg(a.Ce,b);a.qi?(b=[uc],a.Be.eb=!0):(b=[new y(uc.width,uc.height)],z(b[0]),uc.o(1,0,0),B(b[0]),a.Be.eb=!1);Sg(a.Be,b)}}
function Tg(a){var b,c,d;z(a.Wf);r.clear();b=V.K();a.a.Yb&&C(b,a.a.Yb);F(b,"center");G(b,"middle");c=O.i.r("levelMapScreenWorld_"+a.G,"<LEVELMAPSCREENWORLD_"+a.G+">");d=H(b,c,a.a.rd-(b.stroke?b.Pc:0),a.a.ge-(b.stroke?b.Pc:0),!1);d<b.fontSize&&D(b,d);b.o(c,a.Wf.width/2,a.Wf.height/2);B(a.Wf);a.canvas.Z=!0}
e.Sb=function(){var a,b,c,d=this;this.Lb=this.a.Lb?!0:!1;if(!this.Lb){for(a=0;a<O.j.S.length;a++)if(9<O.j.S[a]){b=!0;break}b||(this.Lb=!0)}this.vi=new y(3*this.canvas.width,this.Lb?this.a.pr:this.a.qr);this.nr=-this.canvas.width;this.or=this.Lb?this.a.Fq:this.a.Hq;this.ye=O.b.g(this.or,O.Y.height,this.vi.height)+O.Y.top;this.Wf=new y(this.a.rd,this.a.ge);this.Jy=O.b.g(this.a.He,this.canvas.width,this.a.rd);this.Xs=O.b.g(this.a.Uc,O.Y.height,this.Wf.height)+O.Y.top;this.kr="undefined"!==typeof s_level_mask?
s_level_mask:this.Lb?Pb(kc):Pb(qc);this.a.fq&&(this.fonts={},a=function(a){var b,c;for(b in a)c=V.K(),C(c,a[b]),d.fonts[b]=c},this.fonts={},this.fonts.jn=V,this.Lb?a(this.a.tv):a(this.a.uv));this.G=O.f.G;this.S=O.j.S[this.G];this.Ll=!1;this.Kl=this.Ko=this.dh=0;this.Lo=this.nr;this.Ha=0;this.ri=0<this.G;this.qi=this.G<O.j.S.length-1;for(b=this.Po=this.jl=this.L=0;b<O.j.S.length;b++)for(a=0;a<O.j.S[b];a++)c=Ug(O.f,void 0,a,b),this.Po+=3,"object"===typeof c&&null!==c&&(this.L+=void 0!==c.stars?c.stars:
0,this.jl+=void 0!==c.highScore?c.highScore:0);O.n.Xu&&(this.jl=O.n.Xu());this.Da();a=this.cc[this.a.Kw];this.Wn=new ng(O.b.g(this.a.Lw,this.canvas.width,a.s.width),O.b.g(this.a.Xn,O.Y.height,a.s.height)+O.Y.top,this.depth-20,new Pb(a.s),[a.s],{R:O.f.Vg,aa:this});Qg(this);Mg(this);Tg(this);this.Rb=!0};e.yb=function(){this.Ce&&K.p(this.Ce);this.Be&&K.p(this.Be);K.p(this.Wn)};
e.zb=function(a,b,c){if(!this.Hg)for(a=0;a<this.pf.length;a++)if(Qb(this.kr,this.pf[a].x-this.canvas.width,this.pf[a].y+this.ye,b,c)){this.qf=a;break}this.Hg=!1;1<O.j.S.length&&(this.Ll=!0,this.dh=0,this.Ns=this.Lo=b,this.Kl=this.Ko=0)};
e.Tb=function(a,b,c){if(!this.Hg&&-1!==this.qf&&Qb(this.kr,this.pf[this.qf].x-this.canvas.width,this.pf[this.qf].y+this.ye,b,c)&&(a=O.j.pg||"locked",b=Ng(this.G,this.qf,void 0,void 0),"object"===typeof b&&null!==b&&void 0!==b.state&&(a=b.state),"locked"!==a))return K.p(this),Jg(O.f,this.qf,this.G),!0;this.qf=-1;this.Ll=!1;1<O.j.S.length&&(Math.abs(this.Ha)>=this.a.uy&&(this.Kl>=this.a.vy||Math.abs(this.Ha)>=this.a.ty)?"previous"===this.Jd?this.ri&&0<=this.Ha&&this.Ha<=this.canvas.width/2?Pg(this,
this.G-1):(0>this.Ha||(this.Jd="next"),Pg(this,this.G)):"next"===this.Jd&&(this.qi&&0>=this.Ha&&this.Ha>=-this.canvas.width/2?Pg(this,this.G+1):(0<this.Ha||(this.Jd="previous"),Pg(this,this.G))):0<Math.abs(this.Ha)&&(this.Jd="next"===this.Jd?"previous":"next",Pg(this,this.G)));return!0};
e.gd=function(a){if(a===O.nf||a===O.Ee)this.canvas.Z=!0,this.Da(),a===O.Ee?(this.Xs=O.b.g(this.a.Uc,O.Y.height,this.Wf.height)+O.Y.top,this.ye=O.b.g(this.or,O.Y.height,this.vi.height)+O.Y.top,this.Wn.y=O.b.g(this.a.Xn,O.Y.height,this.Wn.images[0].height)+O.Y.top,this.Ce&&(this.Ce.y=O.b.g(this.a.cp,O.Y.height,vc.height)+O.Y.top),this.Be&&(this.Be.y=O.b.g(this.a.bp,O.Y.height,uc.height)+O.Y.top),void 0===this.Be&&void 0===this.Ce&&(this.ye-=this.a.Gq)):(Tg(this),Mg(this))};
e.mc=function(a){var b=K.ha[0].x;this.Ll&&(this.Ko=Math.abs(this.Lo-b),0<this.dh&&(this.Kl=this.Ko/(this.dh/1E3)),this.Jd=b>this.Lo?"previous":"next",this.dh+=a,this.Ha+=b-this.Ns,this.Ns=b,this.canvas.Z=!0);this.Hg&&(this.Ha=Xb(this.Wk,this.moveStart,this.Jr,this.Vk),this.Wk>=this.Vk&&(this.Hg=!1,this.Ha=0),this.Wk+=a,this.canvas.Z=!0);if(this.Hg||this.Ll)"previous"===this.Jd&&this.Ha>=this.canvas.width/2?0<=this.G-1?(this.G-=1,this.S=O.j.S[this.G],this.ri=0<this.G,this.qi=this.G<O.j.S.length-1,
Rg(this),this.Ha-=this.canvas.width,Tg(this),Mg(this),this.canvas.Z=!0,this.moveStart-=this.canvas.width):this.Ha=Math.round(this.canvas.width/2):"next"===this.Jd&&this.Ha<=-this.canvas.width/2&&(this.G+1<O.j.S.length?(this.G+=1,this.S=O.j.S[this.G],this.ri=0<this.G,this.qi=this.G<O.j.S.length-1,Rg(this),this.Ha+=this.canvas.width,Tg(this),Mg(this),this.canvas.Z=!0,this.moveStart+=this.canvas.width):this.Ha=Math.round(-this.canvas.width/2))};
e.Pa=function(){this.Wf.o(this.Jy,this.Xs);this.vi.o(Math.round(this.nr+this.Ha),this.ye);this.Rb=!1};
function Vg(a,b,c,d){this.depth=10;this.k=this.visible=!0;O.b.Za(this,O.qb);var g;this.type=b.failed?"failed":a;this.a=O.a.C.la;this.ua=this.a.type[this.type];if("landscape"===O.orientation)for(g in O.a.C.gr)this.a[g]=O.a.C.gr[g];for(g in O.a.P.la)this.a[g]=O.a.P.la[g];if(O.a.P.la&&O.a.P.la.type&&O.a.P.la.type[this.type])for(g in O.a.P.la.type[this.type])this.a[g]=O.a.P.la.type[this.type][g];if("failed"===this.type){if(void 0!==O.a.n.la&&O.a.n.la.type&&void 0!==O.a.n.la.type.failed)for(g in O.a.n.la.type[this.type])this.ua[g]=
O.a.n.la.type[this.type][g]}else{if(void 0!==O.a.n.la&&void 0!==O.a.n.la.type)for(g in O.a.n.la.type[this.type])this.ua[g]=O.a.n.la.type[this.type][g];for(g in O.a.n.la)this.ua[g]=O.a.n.la[g]}this.ra=b;this.R=c;this.aa=d;this.Tx=[Pf,Qf,Sf];this.Ve=[];this.W=new Rb;this.W.parent=this;L(this,!1)}
function Wg(a){var b;for(b=0;b<a.L.length;b++)Xg(a.L[b]);for(b=0;b<a.Kf.length;b++)K.p(a.Kf[b]);a.Kf=[];a.Ga&&Xg(a.Ga);a.Ga=void 0;for(b=0;b<a.buttons.length;b++)a.buttons[b].eb=!1;a.W.stop();a.W=void 0;Yg(a)}
function Zg(a,b){var c;switch(b){case "title_level":c=O.i.r("levelEndScreenTitle_level","<LEVELENDSCREENTITLE_LEVEL>").replace("<VALUE>",a.ra.level);break;case "title_endless":c=O.i.r("levelEndScreenTitle_endless","<LEVELENDSCREENTITLE_ENDLESS>").replace("<VALUE>",a.ra.stage);break;case "title_difficulty":c=O.i.r("levelEndScreenTitle_difficulty","<LEVELENDSCREENTITLE_DIFFICULTY>")}void 0!==c&&a.jc(a.a.Yb,c,a.a.He,a.a.Uc,a.a.rd,a.a.ge)}
function $g(a,b){var c;switch(b){case "subtitle_failed":c=O.i.r("levelEndScreenSubTitle_levelFailed","<LEVEL_FAILED>")}void 0!==c&&a.jc(a.a.Is,c,a.a.ny,a.a.oy)}
function ah(a,b,c){var d,g,h,k,l;g=O.i.r(b.key,"<"+b.key.toUpperCase()+">");d=b.oe?b.toString(b.Lf):b.toString(b.kc);h=a.a.Qi;h.align="left";h.h="top";l=V.K();C(l,h);c?(G(l,"bottom"),h=a.a.Mf,h.align="left",h.h="bottom",c=V.K(),C(c,h),h=k=0,void 0!==g&&(h+=l.ba(g)+a.a.Il),void 0!==d&&(h+=c.ba(d)),h=O.b.g(a.a.Fe,a.canvas.width,h)-a.c.x,void 0!==g&&(l.o(g,h,a.nd+l.fontSize),h+=l.ba(g)+a.a.Il,k+=l.V(g)),void 0!==d&&(b.oe?(d=c.V(d),l=a.nd+l.fontSize-d,b.Yh=new bh(h,l,a.a.$g,d,a.depth-100,b.Lf,c,a.a.Yg,
a.a.Zg,a.c,b.toString),k=Math.max(k,d)):(c.o(d,h,a.nd+l.fontSize+a.a.Ds),k=Math.max(k,c.V(d)))),0<k&&(a.nd+=k+a.a.md)):(void 0!==g&&(a.jc(h,g,a.a.Fe,a.a.Nf),k=a.a.Nf,"object"===typeof k?(k.offset=void 0!==k.offset?k.offset+a.a.md:a.a.md,k.offset+=l.V(g)):"number"===typeof k&&(k+=a.a.md+l.V(g))),void 0!==d&&(h=a.a.Mf,h.h="top",b.oe?(c=V.K(),h.align="center",C(c,h),g=O.b.g(a.a.Fe,a.canvas.width,a.a.$g)-a.c.x,l=k-a.c.y,b.Yh=new bh(g,l,a.a.$g,c.V(d),a.depth-100,b.Lf,c,a.a.Yg,a.a.Zg,a.c,b.toString)):a.jc(h,
d,a.a.Fe,k)))}
function ch(a,b,c){var d,g,h,k,l,n;switch(b){case "totalScore":d=""+a.ra.totalScore;g=O.i.r("levelEndScreenTotalScore","<LEVENENDSCREENTOTALSCORE>");n=0;break;case "highScore":g=O.i.r("levelEndScreenHighScore","<LEVENENDSCREENHIGHSCORE>");d=""+a.ra.highScore;break;case "timeLeft":g=O.i.r("levelEndScreenTimeLeft","<LEVENENDSCREENTIMELEFT>");d=""+a.ra.timeLeft;break;case "timeBonus":g=O.i.r("levelEndScreenTimeBonus","<LEVENENDSCREENTIMEBONUS>"),d=""+a.ra.timeBonus,n=a.ra.timeBonus}h=a.a.Qi;h.align=
"left";h.h="top";l=V.K();C(l,h);c?(G(l,"bottom"),h=a.a.Mf,h.align="left",h.h="bottom",c=V.K(),C(c,h),h=k=0,void 0!==g&&(h+=l.ba(g)+a.a.Il),void 0!==d&&(h+=c.ba(d)),h=O.b.g(a.a.Fe,a.canvas.width,h)-a.c.x,void 0!==g&&(l.o(g,h,a.nd+l.fontSize),h+=l.ba(g)+a.a.Il,k+=l.V(g)),void 0!==d&&(void 0!==n?(d=c.V(d),l=a.nd+l.fontSize-d,n=new bh(h,l,a.a.$g,d,a.depth-100,n,c,a.a.Yg,a.a.Zg,a.c),k=Math.max(k,d)):(c.o(d,h,a.nd+l.fontSize+a.a.Ds),k=Math.max(k,c.V(d)))),0<k&&(a.nd+=k+a.a.md)):(void 0!==g&&(a.jc(h,g,a.a.Fe,
a.a.Nf),k=a.a.Nf,"object"===typeof k?(k.offset=void 0!==k.offset?k.offset+a.a.md:a.a.md,k.offset+=l.V(g)):"number"===typeof k&&(k+=a.a.md+l.V(g))),void 0!==d&&(h=a.a.Mf,h.h="top",void 0!==n?(c=V.K(),h.align="center",C(c,h),g=O.b.g(a.a.Fe,a.canvas.width,a.a.$g)-a.c.x,l=k-a.c.y,n=new bh(g,l,a.a.$g,c.V(d),a.depth-100,n,c,a.a.Yg,a.a.Zg,a.c)):a.jc(h,d,a.a.Fe,k)));n instanceof bh&&("totalScore"===b?a.Yf=n:a.Ve.push(n))}
function dh(a,b){var c,d,g;c=O.i.r(b.key,"<"+b.key.toUpperCase()+">");d=b.oe?b.toString(b.Lf):b.toString(b.kc);void 0!==c&&a.jc(a.a.Mm,c,a.a.lq,a.a.Nm);void 0!==d&&(b.oe?(c=V.K(),d=a.a.bi,a.a.Jz||(d.align="center"),C(c,d),d=O.b.g(a.a.ek,a.canvas.width,a.a.dk)-a.c.x,g=O.b.g(a.a.sg,a.canvas.height,a.a.ck)-a.c.y,b.Yh=new bh(d,g,a.a.dk,a.a.ck,a.depth-100,b.Lf,c,a.a.Yg,a.a.Zg,a.c,b.toString)):a.jc(a.a.bi,d,a.a.ek,a.a.sg))}
function eh(a,b){var c,d,g,h;switch(b){case "totalScore":c=O.i.r("levelEndScreenTotalScore","<LEVENENDSCREENTOTALSCORE>");d=""+a.ra.totalScore;g=0;break;case "timeLeft":c=O.i.r("levelEndScreenTimeLeft","<LEVENENDSCREENTIMELEFT>"),d=""+a.ra.timeLeft}void 0!==c&&a.jc(a.a.Mm,c,a.a.lq,a.a.Nm);void 0!==d&&(void 0!==g?(c=V.K(),d=a.a.bi,d.align="center",C(c,d),d=O.b.g(a.a.ek,a.canvas.width,a.a.dk)-a.c.x,h=O.b.g(a.a.sg,a.canvas.height,a.a.ck)-a.c.y,g=new bh(d,h,a.a.dk,a.a.ck,a.depth-100,g,c,a.a.Yg,a.a.Zg,
a.c)):a.jc(a.a.bi,d,a.a.ek,a.a.sg));g instanceof bh&&("totalScore"===b?a.Yf=g:a.Ve.push(g))}e=Vg.prototype;e.jc=function(a,b,c,d,g,h){var k=V.K();C(k,a);void 0!==g&&void 0!==h&&(a=H(k,b,g,h,g),k.fontSize>a&&D(k,a));a=k.ba(b);h=k.V(b);k.o(b,O.b.ca(c,this.canvas.width,a,k.align)-this.c.x,O.b.ca(d,this.canvas.height,h,k.h)-this.c.y,g)};
function fh(a,b){var c,d,g,h;switch(b){case "retry":c=pd;d=function(){a.re="retry";Wg(a)};break;case "exit":c=md,d=function(){a.re="exit";Wg(a)}}void 0!==c&&(g=O.b.g(a.a.Wt,a.canvas.width,c.width)-a.c.x,h=O.b.g(a.a.Hp,a.canvas.height,c.height)-a.c.y,a.buttons.push(new ng(g,h,a.depth-20,new Pb(c),[c],d,a.c)))}
function gh(a,b){var c,d,g,h;switch(b){case "retry":c=zd;d=function(){a.re="retry";Wg(a)};break;case "exit":c=wd;d=function(){a.re="exit";Wg(a)};break;case "next":c=wd,d=function(){a.re="next";Wg(a)}}void 0!==c&&(g=O.b.g(a.a.Lu,a.canvas.width,c.width)-a.c.x,h=O.b.g(a.a.wq,a.canvas.height,c.height)-a.c.y,a.buttons.push(new ng(g,h,a.depth-20,new Pb(c),[c],d,a.c)))}
e.Sb=function(){this.m=0;this.L=[];this.Kf=[];this.buttons=[];this.canvas.Z=!0;this.re="";this.Gc=this.ra.failed?!0:!1;this.Nc=this.ua.Nc&&!this.Gc;this.Ug=this.ua.Ug&&!this.Gc&&this.ra.Uq;this.rm=this.alpha=this.hg=0;hh(this);var a,b,c,d,g,h,k=this;switch(this.ua.Ej){case "failed":this.e=this.a.al.sv;break;case "level":this.e=this.a.al.wv;break;case "difficulty":this.e=this.a.al.I;break;case "endless":this.e=this.a.al.Iu}this.c=new ih(this.depth-10,this.Fa,new y(this.e.width,this.e.height));this.c.x=
O.b.g(this.a.Xb,this.canvas.width,this.e.width);this.c.y=O.b.g(this.a.Db,this.canvas.height,this.e.height);z(this.c.e);this.e.o(0,0,0);!this.Gc&&this.Nc&&(b=O.b.g(this.a.Ao,this.canvas.width,0)-this.c.x,a=O.b.g(this.a.Bo,this.canvas.height,s_star01_fill.height)-this.c.y+Math.round(s_star01_empty.height/2),s_star01_empty.o(0,b,a),b=O.b.g(this.a.Co,this.canvas.width,0)-this.c.x,a=O.b.g(this.a.Do,this.canvas.height,s_star02_fill.height)-this.c.y+Math.round(s_star02_empty.height/2),s_star02_empty.o(0,
b,a),b=O.b.g(this.a.Eo,this.canvas.width,0)-this.c.x,a=O.b.g(this.a.Fo,this.canvas.height,s_star03_fill.height)-this.c.y+Math.round(s_star03_empty.height/2),s_star03_empty.o(0,b,a));void 0!==this.ua.Vi&&Zg(this,this.ua.Vi);void 0!==this.ua.Js&&$g(this,this.ua.Js);this.sb={};void 0!==this.ra.zd?(c=this.ra.zd,c.visible&&dh(this,c),this.sb[c.id]=c):void 0!==this.ua.Om&&eh(this,this.ua.Om);if(void 0!==this.ra.sb)for(a=this.ra.sb.length,b=V.K(),C(b,this.a.Qi),c=V.K(),C(c,this.a.Mf),b=Math.max(b.V("g"),
c.V("g"))*a+this.a.md*(a-1),this.nd=O.b.g(this.a.Nf,this.canvas.height,b)-this.c.y,b=0;b<a;b++)c=this.ra.sb[b],c.visible&&ah(this,this.ra.sb[b],1<a),this.sb[c.id]=c;else if(void 0!==this.ua.Ge)if("string"===typeof this.ua.Ge)ch(this,this.ua.Ge,this.a.vq);else if(this.ua.Ge instanceof Array)for(a=this.ua.Ge.length,b=V.K(),C(b,this.a.Qi),c=V.K(),C(c,this.a.Mf),b=Math.max(b.V("g"),c.V("g"))*a+this.a.md*(a-1),this.nd=O.b.g(this.a.Nf,this.canvas.height,b)-this.c.y,b=0;b<a;b++)ch(this,this.ua.Ge[b],1<a||
this.a.vq);B(this.c.e);fh(this,this.ua.Bj);gh(this,this.ua.gk);O.f.mt&&(b=O.b.g(k.a.hv,k.canvas.width,k.a.Rq)-this.c.x,a=O.b.g(this.a.iv,this.canvas.height,this.a.$e)-this.c.y,this.Qq=new Hg("default_text",b,a,k.depth-20,"levelEndScreenViewHighscoreBtn",k.a.Rq,{R:function(){void 0!==jh?O.t.hd(O.A.xk.url+"submit/"+jh+"/"+k.ra.totalScore):O.t.hd(O.A.xk.url+"submit/")},Ub:!0},k.c),this.buttons.push(this.Qq),b=function(a){a&&(k.Qq.aj("levelEndScreenSubmitHighscoreBtn"),k.gA=a)},kh(this.ra.totalScore,
b));b=O.b.g(this.a.Th,this.canvas.width,this.a.lg)-this.c.x;a=O.b.g(this.a.mg,this.canvas.height,this.a.$e)-this.c.y;this.buttons.push(new ng(b,a,this.depth-20,new Ob(0,0,this.a.lg,this.a.$e),void 0,function(){k.re="exit";Wg(k)},this.c));for(b=0;b<this.buttons.length;b++)this.buttons[b].eb=!1;this.c.y=-this.c.height;a=this.a.yy;this.W.sa(a,this.cy);a+=this.a.ne;g=0;d=this.a.Ly;this.Nc&&(d=Math.max(d,this.a.ts+this.a.ss*this.ra.stars));if(this.Yf&&(this.W.sa(a+this.a.Sl,function(a,b){lh(b.parent.Yf,
b.parent.ra.totalScore,d)}),g=a+this.a.Sl+d,0<this.Ve.length)){h=function(a,b){var c=b.parent,d=c.Ve[c.hg];lh(c.Yf,c.Yf.value+d.value,c.a.gg);lh(d,0,c.a.gg);c.hg+=1};for(b=0;b<this.Ve.length;b++)g+=this.a.Np,this.W.sa(g,h);g+=this.a.gg}if(void 0!==this.sb&&(g=a,h=function(a,b){var c=b.parent,d=c.Ho[c.hg||0],g=c.sb[d.Hl];void 0!==d.Je&&(g.visible&&g.oe?lh(g.Yh,d.Je(g.Yh.value),c.a.gg):g.kc=d.Je(g.kc));d.visible&&d.oe&&lh(d.Yh,d.kc,c.a.gg);c.hg+=1},this.Ho=[],void 0!==this.ra.zd&&void 0!==this.ra.zd.Je&&
(this.W.sa(a+this.a.Sl,h),this.Ho.push(this.ra.zd),g+=this.a.Sl+bonusCounterDuration),void 0!==this.ra.sb))for(b=0;b<this.ra.sb.length;b++)c=this.ra.sb[b],void 0!==c.Je&&(g+=this.a.Np,this.W.sa(g,h),this.Ho.push(c),g+=this.a.gg);if(this.Nc){for(b=0;b<this.ra.stars;b++)a+=this.a.ss,this.W.sa(a,this.gy),this.W.sa(a,this.hy);a+=this.a.ts}a=Math.max(a,g);this.Ug&&(a+=this.a.Sv,this.W.sa(a,this.by),this.W.sa(a,this.$x),this.W.sa(a+this.a.Tv,this.ay));this.W.sa(a+this.a.nw,O.t.Wq);this.W.start();this.Gc?
J.play(Tf):J.play(Nf)};e.pa=function(a){this.alpha=this.a.ci*this.rm/this.a.pb;this.rm+=a;this.alpha>=this.a.ci&&(this.alpha=this.a.ci,this.k=!1);this.canvas.Z=!0};
e.cy=function(a,b){function c(){var a;for(a=0;a<d.buttons.length;a++)d.buttons[a].eb=!0}var d=b.parent,g,h;switch(d.a.lz){case "fromLeft":h="horizontal";g=O.b.g(d.a.Xb,d.canvas.width,d.c.width);d.c.x=-d.c.width;d.c.y=O.b.g(d.a.Db,d.canvas.height,d.c.height)+Math.abs(O.oa);break;case "fromRight":h="horizontal";g=O.b.g(d.a.Xb,d.canvas.width,d.c.width);d.c.x=d.canvas.width;d.c.y=O.b.g(this.parent.a.Db,d.canvas.height,selft.c.height)+Math.abs(O.oa);break;case "fromBottom":h="vertical";g=O.b.g(d.a.Db,
d.canvas.height,d.c.height)+Math.abs(O.oa);d.c.x=O.b.g(d.a.Xb,d.canvas.width,d.c.width);d.c.y=d.canvas.height+d.c.height;break;default:h="vertical",g=O.b.g(d.a.Db,d.canvas.height,d.c.height)+Math.abs(O.oa),d.c.x=O.b.g(d.a.Xb,d.canvas.width,d.c.width),d.c.y=-d.c.height}"vertical"===h?Z(d.c,"y",g,d.a.ne,d.a.wj,c):Z(d.c,"x",g,d.a.ne,d.a.wj,c)};
function Yg(a){function b(){K.p(a);a.aa?a.R.call(a.aa,a.re):a.R(a.re)}var c,d;switch(a.a.mz){case "toLeft":d="horizontal";c=-a.c.width;break;case "toRight":d="horizontal";c=a.canvas.width;break;case "toBottom":d="vertical";c=a.canvas.height+a.c.height;break;default:d="vertical",c=-a.c.height}"vertical"===d?Z(a.c,"y",c,a.a.xj,a.a.yj,b):Z(a.c,"x",c,a.a.xj,a.a.yj,b)}
e.gy=function(a,b){var c,d=b.parent,g=Math.abs(O.oa);if(d.L.length<d.ra.stars){switch(d.L.length+1){case 1:c=new ih(d.depth-30,O.Wd,s_star01_fill);c.x=O.b.g(d.a.Ao,d.canvas.width,0);c.y=O.b.g(d.a.Bo,d.canvas.height,s_star01_fill.height)+g+Math.round(s_star01_empty.height/2);break;case 2:c=new ih(d.depth-30,O.Wd,s_star02_fill);c.x=O.b.g(d.a.Co,d.canvas.width,0);c.y=O.b.g(d.a.Do,d.canvas.height,s_star02_fill.height)+g+Math.round(s_star02_empty.height/2);break;case 3:c=new ih(d.depth-30,O.Wd,s_star03_fill),
c.x=O.b.g(d.a.Eo,d.canvas.width,0),c.y=O.b.g(d.a.Fo,d.canvas.height,s_star03_fill.height)+g+Math.round(s_star03_empty.height/2)}c.ta=d.a.us;c.Ia=d.a.us;c.alpha=d.a.Xx;Z(c,"scale",1,d.a.Wx,N,function(){var a=d.L.length,b,c,n;z(d.c.e);switch(a){case 1:n=s_star01_fill;b=O.b.g(d.a.Ao,d.canvas.width,0)-d.c.x;c=O.b.g(d.a.Bo,d.canvas.height,s_star01_fill.height)-d.c.y+g+Math.round(s_star01_empty.height/2);break;case 2:n=s_star02_fill;b=O.b.g(d.a.Co,d.canvas.width,0)-d.c.x;c=O.b.g(d.a.Do,d.canvas.height,
s_star01_fill.height)-d.c.y+g+Math.round(s_star02_empty.height/2);break;case 3:n=s_star03_fill,b=O.b.g(d.a.Eo,d.canvas.width,0)-d.c.x,c=O.b.g(d.a.Fo,d.canvas.height,s_star01_fill.height)-d.c.y+g+Math.round(s_star03_empty.height/2)}n.o(0,b,c);B(d.c.e);d.c.Rb=!0;K.p(d.L[a-1])});Z(c,"alpha",1,d.a.Vx,Wb);d.L.push(c);J.play(d.Tx[d.L.length-1])}};
e.hy=function(a,b){var c=b.parent,d,g;d=c.L[c.Kf.length];g=new ih(c.depth-50,O.Wd,s_sfx_star);g.x=d.x;g.y=d.y;Z(g,"subImage",s_sfx_star.F-1,c.a.Ux,void 0,function(){K.p(g)});c.Kf.push(g)};
e.$x=function(a,b){var c=b.parent,d,g,h,k,l,n,q;d=[];h=V.K();k=O.i.r("levelEndScreenMedal","<LEVELENDSCREENMEDAL>");c.a.Fr&&C(h,c.a.Fr);g=H(h,k,c.a.Rk,c.a.Zv,!0);g<h.fontSize&&D(h,g);l=O.b.ca(c.a.$v,zc.width,h.ba(k,c.a.Rk),h.align);n=O.b.ca(c.a.aw,zc.height,h.V(k,c.a.Rk),h.h);for(q=0;q<zc.F;q++)g=new y(zc.width,zc.height),z(g),zc.o(q,0,0),h.o(k,l,n,c.a.Rk),B(g),d.push(g);c.Ga=new ih(c.depth-120,O.Wd,d);c.Ga.fc=c.a.Cr;c.Ga.gc=c.a.Dr;c.Ga.x=O.b.g({align:"center"},c.c.canvas.width,c.Ga.width)-c.c.x;
c.Ga.y=O.b.g(c.a.Bi,c.Ga.canvas.height,c.Ga.height)-c.c.y+Math.abs(O.oa);l=O.b.g(c.a.Ln,c.Ga.canvas.width,c.Ga.width)-c.c.x;c.Ga.ta=c.a.Qk;c.Ga.Ia=c.a.Qk;c.Ga.parent=c.c;c.Ga.alpha=0;c.Ga.yz=!0;Z(c.Ga,"scale",1,c.a.Fg,Wb,function(){K.p(c.hb);c.hb=void 0});Z(c.Ga,"x",l,c.a.Fg,Wb);Z(c.Ga,"alpha",1,0,Wb);Z(c.Ga,"subImage",zc.F,c.a.Xv,Wb,void 0,c.a.Fg+c.a.Br+c.a.Wv,!0,c.a.Yv)};
e.by=function(a,b){var c,d=b.parent;d.hb=new ih(d.depth-110,O.Wd,yc);d.hb.y=O.b.g(d.a.Bi,d.hb.canvas.height,yc.height)-d.c.y+d.a.Vv;d.hb.fc=d.a.Cr;d.hb.gc=d.a.Dr;d.hb.x=O.b.g(d.a.Ln,d.hb.canvas.width,d.hb.width)-d.c.x;c=O.b.g(d.a.Bi,d.hb.canvas.height,yc.height)-d.c.y+Math.abs(O.oa);d.hb.ta=d.a.Qk*d.a.Er;d.hb.Ia=d.a.Qk*d.a.Er;d.hb.alpha=0;d.hb.parent=d.c;Z(d.hb,"y",c,d.a.Fg,Wb);Z(d.hb,"scale",1,d.a.Fg,Wb);Z(d.hb,"alpha",1,d.a.Fg,Wb)};
e.ay=function(a,b){var c=b.parent;c.Ae=new ih(c.depth-130,O.Wd,xc);c.Ae.parent=c.c;c.Ae.x=c.Ga.x;c.Ae.y=c.Ga.y+c.a.Uv;Z(c.Ae,"subImage",xc.F-1,c.a.Br,void 0,function(){K.p(c.Ae);c.Ae=void 0});J.play(Wf)};
e.yb=function(){var a;for(a=0;a<this.buttons.length;a++)K.p(this.buttons[a]);for(a=0;a<this.L.length;a++)K.p(this.L[a]);for(a=0;a<this.Kf.length;a++)K.p(this.Kf[a]);this.Ga&&(K.p(this.Ga),this.Ae&&K.p(this.Ae),this.hb&&K.p(this.hb));K.p(this.c);this.W&&this.W.stop();this.Yf&&K.p(this.Yf);for(a=0;a<this.Ve.length;a++)K.p(this.Ve[a]);mh()};e.Pa=function(){var a=r.context.globalAlpha;r.context.globalAlpha=this.alpha;oa(0,0,r.canvas.width,r.canvas.height,this.a.Rm,!1);r.context.globalAlpha=a};
function nh(a,b,c){this.depth=10;this.visible=!0;this.k=!1;O.b.Za(this,O.qb);this.a=O.a.C.Mj;for(var d in O.a.P.Mj)this.a[d]=O.a.P.Mj[d];this.Jl=b;this.Bm=c;this.ia=Cg(O.f);this.ia.Qg[this.ia.Zc]=a;this.W=new Rb;this.W.parent=this;this.buttons=[];L(this,!1)}e=nh.prototype;
e.ld=function(a){var b,c,d=this;c=function(){Z(d.message,"xScale",1,d.a.Gg,N);Z(d.message,"yScale",1,d.a.Gg,N);Z(d.message,"alpha",1,d.a.Gg,M)};void 0===this.message&&(b=new y(this.a.Pn+2*this.a.ew,this.a.Hr+2*this.a.fw),this.message=new ih(this.depth-20,O.qb,b),this.message.ta=0,this.message.Ia=0,this.message.alpha=0,this.message.fc=Math.floor(b.width/2),this.message.gc=Math.floor(b.height/2),this.message.x=O.b.g(this.a.jw,this.canvas.width,0)-this.Mg,this.message.y=O.b.g(this.a.kw,this.canvas.height,
b.height)+Math.floor(b.height/2)-this.zf,this.message.parent=this.c,this.W.ac>=this.a.Tk?c():this.W.sa(this.a.Tk,c));z(this.message.e);r.clear();b=V.K();void 0!==this.a.vf&&C(b,this.a.vf);F(b,"center");G(b,"middle");c=H(b,a,this.a.Pn,this.a.Hr,!0);c<b.fontSize&&D(b,c);b.o(a,Math.floor(this.message.width/2),Math.floor(this.message.height/2),this.a.Pn);B(this.message.e);0<this.message.ta&&(this.message.Rb=!0)};
function oh(a,b){var c,d,g;c=V.K();void 0!==a.a.fj&&C(c,a.a.fj);d=H(c,b,a.a.Io,a.a.Gs,!0);d<c.fontSize&&D(c,d);d=O.b.ca(a.a.my,a.c.width,a.a.Io,c.align);g=O.b.ca(a.a.Hs,a.c.height,a.a.Gs,c.h);z(a.c.e);c.o(b,d,g,a.a.Io);B(a.c.e)}
function ph(a){var b,c,d;c=function(){Z(a.Fb,"xScale",1,a.a.Gg,N);Z(a.Fb,"yScale",1,a.a.Gg,N);Z(a.Fb,"alpha",1,a.a.Gg,M)};b=new y(a.a.ap+2*a.a.$y,a.a.Bt+2*a.a.az);a.Fb=new ih(a.depth-20,O.qb,b);a.Fb.ta=0;a.Fb.Ia=0;a.Fb.alpha=0;a.Fb.fc=Math.floor(b.width/2);a.Fb.gc=Math.floor(b.height/2);a.Fb.x=O.b.g(a.a.bz,a.canvas.width,0)-a.Mg;a.Fb.y=O.b.g(a.a.cz,a.canvas.height,b.height)+Math.floor(b.height/2)-a.zf;a.Fb.parent=a.c;a.W.ac>=a.a.Tk?c():a.W.sa(a.a.Tk,c);b=O.i.r("challengeEndScreenWinnings","CHALLENGEENDSCREENWINNINGS");
b=b.replace("<AMOUNT>",a.ia.wt);z(a.Fb.e);c=V.K();void 0!==a.a.fj&&C(c,a.a.fj);F(c,"center");G(c,"middle");d=H(c,b,a.a.ap,a.a.Bt,!0);d<c.fontSize&&D(c,d);c.o(b,Math.floor(a.Fb.width/2),Math.floor(a.Fb.height/2),a.a.ap);B(a.Fb.e);0<a.Fb.ta&&(a.Fb.Rb=!0)}e.kt=function(a){if("string"===typeof a){var b=O.i.r("challengeEndScreenOutcomeMessage_"+a,"<CHALLENGEENDSCREEN_CHALLENGE"+a.toUpperCase()+">");this.ld(b);"WON"===a&&ph(this)}};
function qh(a){var b,c;b=O.b.g(a.a.py,a.c.width,a.a.Ml);c=O.b.g(a.a.qy,a.c.height,0);a.buttons.push(new Hg("default_text",b,c,a.depth-20,"challengeEndScreensBtn_submit",a.a.Ml,function(){var b;a.Jl();for(b=0;b<a.buttons.length;b++)K.p(a.buttons[b]);return!0},a.c));b=O.b.g(a.a.ku,a.c.width,a.a.Ml);c=O.b.g(a.a.lu,a.c.height,0);a.buttons.push(new Hg("default_text",b,c,a.depth-20,"challengeEndScreenBtn_cancel",a.a.Ml,function(){var b,c;b=new rh(O.i.r("challengeCancelConfirmText","<CHALLENGECANCELCONFIRMTEXT>"),
[{M:"challengeCancelConfirmBtn_yes",R:function(){b.close();a.Bm();for(c=0;c<a.buttons.length;c++)K.p(a.buttons[c]);return!0}},{M:"challengeCancelConfirmBtn_no",R:function(){b.close()}}],!0)},a.c))}
e.Sb=function(){function a(a){a.ta=0;a.Ia=0;a.fc=Math.floor(a.e.width/2);a.gc=Math.floor(a.e.height/2)}var b,c,d,g,h,k,l=this;hh(this);"undefined"!==typeof s_overlay_challenge_end?(b=new y(s_overlay_challenge_end.width,s_overlay_challenge_end.height),z(b),s_overlay_challenge_end.o(0,0,0),B(b)):b=new y(P(560),P(560));this.c=new ih(this.depth-10,O.qb,b);this.c.x=O.b.g(this.a.Sw,this.canvas.width,this.c.width)+this.a.Af;this.c.y=O.b.g(this.a.Tw,this.canvas.height,this.c.height)+O.Fj+this.a.Ng;this.Mg=
O.b.g(this.a.Mg,this.canvas.width,this.c.width)+this.a.Af;this.zf=O.b.g(this.a.zf,this.canvas.height,this.c.height)+this.a.Ng;h=Array(this.ia.jd.length);c=0;k=[];for(b=0;b<this.ia.jd.length;b++)b!==this.ia.Zc&&(void 0!==this.ia.Qg[b]?(h[b]=c,c++):k.push(b));h[this.ia.Zc]=c;c++;for(b=0;b<k.length;b++)h[k[b]]=c,c++;c=V.K();void 0!==this.a.Rn&&C(c,this.a.Rn);F(c,"center");G(c,"middle");k=[];for(b=0;b<this.ia.jd.length;b++)d=b===this.ia.Zc?O.i.r("challengeEndScreenName_you","<YOU>"):this.ia.jd[b],13<
d.length&&(d=d.substr(0,10)+"..."),k.push(d);d=c.fontSize;for(b=0;b<k.length;b++)d=Math.min(d,H(c,k[b],this.a.Nr,this.a.Mr,!1));d<c.fontSize&&D(c,d);this.$d=[];for(b=0;b<k.length;b++)d=k[b],g=new y(this.a.Nr+2*this.a.vw,this.a.Mr+2*this.a.ww),z(g),c.o(d,Math.floor(g.width/2)+this.a.zw,Math.floor(g.height/2)+this.a.Aw),B(g),d=new ih(this.depth-20,this.Fa,g),d.alpha=0,a(d),d.x=this.a.Ew+h[b]*(g.width+this.a.Dw)+Math.floor(g.width/2)-this.Mg,d.y=O.b.g(this.a.Gw,this.canvas.height,g.height)+Math.floor(g.height/
2)-this.zf,d.parent=this.c,this.$d.push(d);this.df=[];c=V.K();void 0!==this.a.Lm&&C(c,this.a.Lm);F(c,"center");G(c,"middle");for(b=0;b<this.ia.jd.length;b++)d=void 0!==this.ia.Qg[b]?new TG_StatObject("player_"+b,O.j.Ff,"",this.ia.Qg[b]):new TG_StatObject("player_"+b,"text","","?"),h=this.$d[b].x+this.a.jq,k=O.b.g(this.a.Gu,this.canvas.height,this.a.kq)+Math.floor(g.height/2)-this.zf,h=new bh(h,k,this.a.Fu,this.a.kq,this.depth-18,b===this.ia.Zc?0:d.kc,c,this.a.jq,this.a.Eu,this.c,d.toString),a(h.Yc),
h.Yc.alpha=0,this.df.push(h);this.m=0;this.W.sa(this.a.Cp,function(){Z(l.c,"x",l.Mg,l.a.ne,N);Z(l.c,"y",l.zf+O.Fj,l.a.ne,N)});this.W.sa(this.a.Fw,function(){var a;for(a=0;a<l.$d.length;a++)Z(l.$d[a],"xScale",1,l.a.Sn,N),Z(l.$d[a],"yScale",1,l.a.Sn,N),Z(l.$d[a],"alpha",1,l.a.Sn,M)});this.W.sa(this.a.Ax,function(){var a;for(a=0;a<l.$d.length;a++)Z(l.df[a].Yc,"xScale",1,l.a.so,N),Z(l.df[a].Yc,"yScale",1,l.a.so,N),Z(l.df[a].Yc,"alpha",1,l.a.so,M)});this.W.sa(this.a.Dx,function(){lh(l.df[l.ia.Zc],l.ia.Qg[l.ia.Zc],
l.a.Ex)});"function"===typeof this.Jl&&"function"===typeof this.Bm&&this.W.sa(l.a.ju,function(){qh(l)});this.W.sa(this.a.Cp,O.t.Wq);this.W.start();"function"===typeof this.Jl&&"function"!==typeof this.Bm&&this.Jl()};e.yb=function(){var a;this.message&&K.p(this.message);for(a=0;a<this.buttons.length;a++)K.p(this.buttons[a]);for(a=0;a<this.$d.length;a++)K.p(this.$d[a]);for(a=0;a<this.df.length;a++)K.p(this.df[a]);mh()};
e.Pa=function(){var a=r.context.globalAlpha;r.context.globalAlpha=this.a.ci;oa(0,0,r.canvas.width,r.canvas.height,this.a.Rm,!1);r.context.globalAlpha=a};
function sh(a,b,c,d){this.depth=-100;this.visible=!1;this.k=!0;O.b.Za(this,O.qb);var g,h;this.a=c?O.a.C.Yn:O.a.C.options;if("landscape"===O.orientation)for(g in h=c?O.a.C.qA:O.a.C.Mw,h)this.a[g]=h[g];this.cc=O.a.C.Ob;h=c?O.a.P.Yn:O.a.P.options;for(g in h)this.a[g]=h[g];if(O.A.options&&O.A.options.buttons)for(g in O.A.options.buttons)this.a.buttons[g]=O.A.options.buttons[g];this.type=a;this.Py=b;this.ic=c;this.zl=!1!==d;L(this)}e=sh.prototype;
e.Nh=function(a,b,c,d,g){var h=void 0,k=void 0,l=void 0,n=void 0,q=void 0,w=void 0;switch(a){case "music":h="music_toggle";n=this.Zs;l=O.f.Bf()?"on":"off";break;case "music_big":h="music_big_toggle";n=this.Zs;l=O.f.Bf()?"on":"off";break;case "sfx_big":h="sfx_big_toggle";n=this.$s;l=O.f.il()?"on":"off";break;case "sfx":h="sfx_toggle";n=this.$s;l=O.f.il()?"on":"off";break;case "language":h="language_toggle";n=this.Ys;l=O.f.language();break;case "tutorial":h="default_text";k="optionsTutorial";n=this.Li;
break;case "highScores":h="default_text";k="optionsHighScore";n=this.hs;this.zm=this.Mx;break;case "moreGames":void 0!==O.A.mw?(h="default_image",w=O.A.mw):(h="default_text",k="optionsMoreGames");n=this.Nx;q=!0;break;case "resume":h="default_text";k="optionsResume";n=this.close;break;case "exit":h="default_text";k="optionsExit";n=O.Rg.customFunctions&&"function"===typeof O.Rg.customFunctions.exit?O.Rg.customFunctions.exit:function(){};break;case "quit":h="default_text";k="optionsQuit";n=this.ix;break;
case "restart":h="default_text";k="optionsRestart";n=this.rx;break;case "startScreen":h="default_text";k="optionsStartScreen";n=this.hs;this.zm=this.Px;break;case "about":h="default_text";k="optionsAbout";n=this.Kx;break;case "forfeitChallenge":h="default_text";k="optionsChallengeForfeit";n=this.gi;break;case "cancelChallenge":h="default_text",k="optionsChallengeCancel",n=this.kg}void 0!==h&&void 0!==n&&("image"===this.cc[h].type?this.buttons.push(new th(h,b,c,this.depth-20,w,d,{R:n,aa:this,Ub:q},
this.c)):"toggleText"===this.cc[h].type?this.buttons.push(new Dg(h,b,c,this.depth-20,l,d,{R:n,aa:this,Ub:q},this.c)):"text"===this.cc[h].type?this.buttons.push(new Hg(h,b,c,this.depth-20,k,d,{R:n,aa:this,Ub:q},this.c)):"toggle"===this.cc[h].type&&this.buttons.push(new uh(h,b,c,this.depth-20,l,{R:n,aa:this,Ub:q},this.c)),this.buttons[this.buttons.length-1].eb=g||!1)};
e.hs=function(){var a=this;Z(a.c,"y","inGame"!==this.type?-this.c.e.height:this.canvas.height,this.a.Kg,this.a.Lg,function(){K.p(a);void 0!==a.zm&&a.zm.call(a)});return!0};
e.Da=function(a,b){var c,d,g,h;z(this.c.e);r.clear();this.a.backgroundImage.o(0,0,0);c=O.i.r("optionsTitle","<OPTIONS_TITLE>");d=V.K();this.a.Yb&&C(d,this.a.Yb);void 0!==this.a.rd&&void 0!==this.a.ge&&(g=H(d,c,this.a.rd,this.a.ge,this.a.rd),d.fontSize>g&&D(d,g));g=O.b.ca(this.a.He,this.canvas.width,d.ba(c),d.align)-a;h=O.b.ca(this.a.Uc,this.canvas.height,d.V(c,d.h))-b+-1*O.oa;d.o(c,g,h);B(this.c.e)};
e.Re=function(a,b,c){var d,g,h,k,l,n,q;h=!1;var w=this.a.buttons[this.type];"inGame"===this.type&&O.a.n.wg.dw&&(w=O.a.n.wg.dw);if("function"!==typeof vh())for(d=0;d<w.length;d++){if("string"===typeof w[d]&&"moreGames"===w[d]){w.splice(d,1);break}for(g=0;g<w[d].length;g++)if("moreGames"===w[d][g]){w[d].splice(g,1);break}}if(!1===O.A.Bf||!1===O.f.Lk)for(d=0;d<w.length;d++)if(w[d]instanceof Array){for(g=0;g<w[d].length;g++)if("music"===w[d][g]){O.f.Mk?w[d]="sfx_big":w.splice(d,1);h=!0;break}if(h)break}else if("music_big"===
w[d]){w.splice(d,1);break}if(!O.f.Mk)for(d=0;d<w.length;d++)if(w[d]instanceof Array){for(g=0;g<w[d].length;g++)if("sfx"===w[d][g]){!1!==O.A.Bf&&O.f.Lk?w[d]="music_big":w.splice(d,1);h=!0;break}if(h)break}else if("sfx_big"===w[d]){w.splice(d,1);break}if(1===O.i.Uu().length)for(d=0;d<w.length;d++)if("language"===w[d]){w.splice(d,1);break}h=this.cc.default_text.s.height;k=this.a.Kj;a=O.b.g(this.a.Jj,this.canvas.width,k)-a;n=O.b.g(this.a.jg,this.c.e.height,h*w.length+this.a.vd*(w.length-1))-b+-1*O.oa;
for(d=0;d<w.length;d++){l=a;q=k;if("string"===typeof w[d])this.Nh(w[d],l,n,q,c);else for(b=w[d],q=(k-(b.length-1)*this.a.vd)/b.length,g=0;g<b.length;g++)this.Nh(b[g],l,n,q,c),l+=q+this.a.vd;n+=h+this.a.vd}};e.Zs=function(a){var b=!0;"off"===a?(b=!1,O.Aa.Qa("off","options:music")):O.Aa.Qa("on","options:music");O.f.Bf(b);return!0};e.$s=function(a){var b=!0;"off"===a?(b=!1,O.Aa.Qa("off","options:sfx")):O.Aa.Qa("on","options:sfx");O.f.il(b);return!0};
e.Ys=function(a){O.i.ms(a);O.Aa.Qa(a,"options:language");return!0};
e.Li=function(){function a(){l.vc+=1;l.Li();return!0}function b(){l.vc-=1;l.Li();return!0}function c(){var a;l.Da(n,q);l.Ze.eb=!0;for(a=0;a<l.buttons.length;a++)K.p(l.buttons[a]);l.buttons=[];l.Re(n,q,!0)}var d,g,h,k,l=this,n=O.b.g(l.a.Xb,l.canvas.width,l.a.backgroundImage.width),q=O.b.g(l.a.Db,l.canvas.height,l.a.backgroundImage.height)+-1*O.oa;void 0===l.vc&&(l.vc=0);l.Xi=void 0!==O.n.Eq?O.n.Eq():[];O.Aa.Qa((10>l.vc?"0":"")+l.vc,"options:tutorial");for(d=0;d<l.buttons.length;d++)K.p(l.buttons[d]);
l.buttons=[];this.ic?(z(l.c.e),r.clear(),l.Ze.eb=!1):l.Da(n,q);z(l.c.e);void 0!==l.a.sd&&(d=O.b.g(l.a.Ul,l.c.e.width,l.a.sd.width),g=O.b.g(l.a.Ie,l.c.e.height,l.a.sd.height),l.a.sd.o(0,d,g));k=l.Xi[l.vc].title;void 0!==k&&""!==k&&(h=V.K(),l.a.Zi&&C(h,l.a.Zi),d=H(h,k,l.a.Vl,l.a.Uo,l.a.Vl),h.fontSize>d&&D(h,d),d=O.b.ca(l.a.jt,l.c.e.width,h.ba(k,l.a.Vl),h.align),g=O.b.ca(l.a.Vo,l.c.e.height,h.V(k,l.a.Uo),h.h),h.o(k,d,g));l.vc<l.Xi.length&&(h=l.Xi[l.vc].e,d=O.b.g(l.a.gt,l.c.e.width,h.width),g=O.b.g(l.a.So,
l.c.e.height,h.height),h.o(0,d,g),k=l.Xi[l.vc].text,h=V.K(),l.a.Yi&&C(h,l.a.Yi),d=H(h,k,l.a.lh,l.a.ht,l.a.lh),h.fontSize>d&&D(h,d),d=O.b.ca(l.a.it,l.c.e.width,h.ba(k,l.a.lh),h.align),g=O.b.ca(l.a.To,l.c.e.height,h.V(k,l.a.lh),h.h),h.o(k,d,g,l.a.lh));B(l.c.e);h=Rc;d=O.b.g(l.a.ft,l.canvas.width,h.width)-l.c.x;g=O.b.g(l.a.Ro,l.canvas.height,h.height)-l.c.y-O.oa;0<=l.vc-1?l.buttons.push(new ng(d,g,l.depth-20,new Pb(h),[h],{R:b,aa:l},l.c)):(h=Pc,l.buttons.push(new ng(d,g,l.depth-20,new Pb(h),[h],{R:c,
aa:l},l.c)));h=Qc;d=O.b.g(this.a.et,l.canvas.width,h.width)-l.c.x;g=O.b.g(this.a.Qo,l.canvas.height,h.height)-l.c.y-O.oa;l.vc+1<l.Xi.length?l.buttons.push(new ng(d,g,l.depth-20,new Pb(h),[h],{R:a,aa:l},l.c)):(h=Pc,l.buttons.push(new ng(d,g,l.depth-20,new Pb(h),[h],{R:c,aa:l},l.c)));return!0};
e.Kx=function(){function a(a,b,c,g,h,k){var l;l=V.K();b&&C(l,b);b=H(l,a,h,k,h);l.fontSize>b&&D(l,b);c=O.b.ca(c,d.c.e.width,l.ba(a,h),l.align);g=O.b.ca(g,d.c.e.height,l.V(a,k),l.h);l.o(a,c,g,h);return g+k}function b(a,b,c){b=O.b.g(b,d.c.e.width,a.width);c=O.b.g(c,d.c.e.height,a.height);a.o(0,b,c);return c+a.height}var c,d=this,g=O.b.g(d.a.Xb,d.canvas.width,d.a.backgroundImage.width),h=O.b.g(d.a.Db,d.canvas.height,d.a.backgroundImage.height)+-1*O.oa;O.Aa.Qa("about","options");for(c=0;c<d.buttons.length;c++)K.p(d.buttons[c]);
d.buttons=[];this.ic?(z(d.c.e),r.clear(),d.Ze.eb=!1):d.Da(g,h);z(d.c.e);void 0!==d.a.sd&&b(d.a.sd,d.a.Ul,d.a.Ie);var k=null;"function"===typeof O.t.Au?k=O.t.Au(d.a,a,b,d.c.e):(c=O.i.r("optionsAbout_header","<OPTIONSABOUT_HEADER>"),a(c,d.a.tp,d.a.wp,d.a.lm,d.a.vp,d.a.up),b(Tc,d.a.mm,d.a.rj),c=O.i.r("optionsAbout_text","<OPTIONSABOUT_TEXT>"),a(c,d.a.xp,d.a.nm,d.a.Mh,d.a.sj,d.a.Lh));a(O.i.r("optionsAbout_version","<OPTIONSABOUT_VERSION>")+" "+qg()+("big"===O.size?"b":"s"),d.a.om,d.a.Ap,d.a.pm,d.a.zp,
d.a.yp);B(d.c.e);if(k)for(c=0;c<k.length;++c){var l=k[c];d.buttons.push(new ng(l.x,l.y,d.depth-10,Ob(0,0,l.width,l.height),null,{R:function(a){return function(){O.t.hd(a)}}(l.url),Ub:!0},d.c))}else void 0!==O.A.Tq&&(c=O.b.g(d.a.mm,d.c.e.width,Tc.width),k=O.b.g(d.a.rj,d.c.e.height,Tc.height),c=Math.min(c,O.b.g(d.a.nm,d.c.e.width,d.a.sj)),k=Math.min(k,O.b.g(d.a.Mh,d.c.e.height,d.a.Lh)),l=Math.max(d.a.sj,Tc.width),d.buttons.push(new ng(c,k,d.depth-10,Ob(0,0,l,O.b.g(d.a.Mh,d.c.e.height,d.a.Lh)+d.a.Lh-
k),null,{R:function(){O.t.hd(O.A.Tq)},Ub:!0},d.c)));d.buttons.push(new Hg("default_text",O.b.g(d.a.km,d.c.e.width,d.a.Kh),d.a.qj,d.depth-20,"optionsAbout_backBtn",d.a.Kh,{R:function(){var a;d.Da(g,h);d.Ze.eb=!0;for(a=0;a<d.buttons.length;a++)K.p(d.buttons[a]);d.buttons=[];d.Re(g,h,!0);d.os=!1},aa:d},d.c));return this.os=!0};
function wh(a){var b,c,d,g,h,k=O.b.g(a.a.Xb,a.canvas.width,a.a.backgroundImage.width),l=O.b.g(a.a.Db,a.canvas.height,a.a.backgroundImage.height)+-1*O.oa;O.Aa.Qa("versions","options");for(b=0;b<a.buttons.length;b++)K.p(a.buttons[b]);a.buttons=[];a.Da(k,l);z(a.c.e);void 0!==a.a.sd&&a.a.sd.o(0,O.b.g(a.a.Ul,a.c.width,a.a.sd.width),O.b.g(a.a.Ie,a.c.height,a.a.sd.height));h=V.K();C(h,a.a.om);F(h,"left");c=a.a.ut;d=a.a.vt;for(b in O.version)g=b+": "+O.version[b],h.o(g,c,d),d+=h.V(g)+a.a.tt;c=O.b.g(a.a.km,
a.c.e.width,a.a.Kh);d=a.a.qj;a.buttons.push(new Hg("default_text",c,d,a.depth-20,"optionsAbout_backBtn",a.a.Kh,{R:function(){var b;a.Da(k,l);for(b=0;b<a.buttons.length;b++)K.p(a.buttons[b]);a.buttons=[];a.Re(k,l,!0)},aa:a},a.c))}e.Mx=function(){return!0};e.Nx=function(){O.Aa.Qa("moreGames","options");var a=vh();"function"===typeof a&&a();return!0};
e.ix=function(){var a=this;xh(this,"optionsQuitConfirmationText","optionsQuitConfirmBtn_Yes","optionsQuitConfirmBtn_No",function(){O.Aa.Qa("confirm_yes","options:quit");K.p(a);ug(O.Aa,O.f.Vf,yh(O.f),"progression:levelQuit:"+zh());Ah();Bh(O.f);return!0})};
e.rx=function(){var a=this;xh(this,"optionsRestartConfirmationText","optionsQuitConfirmBtn_Yes","optionsQuitConfirmBtn_No",function(){O.Aa.Qa("confirm_yes","options:restart");K.p(a);var b=O.f;b.state="LEVEL_END";ug(O.Aa,O.f.Vf,yh(O.f),"progression:levelRestart:"+zh());b=O.j.cj?b.nb+1:Og(b)+1;O.f.la=!0;O.f.fr="retry";Ch(O.f,!0);b={failed:!0,level:b};O.t.pi(b);O.Pd.pi(b);return!0})};
e.gi=function(){var a,b=this;a=function(a){var d=a?"challengeForfeitMessage_success":"challengeForfeitMessage_error";b.ld(O.i.r(d,"<"+d.toUpperCase()+">"));a&&(b.Ze.eb=!1,b.zl||hh())};xh(this,"challengeForfeitConfirmText","challengeForfeitConfirmBtn_yes","challengeForfeitConfirmBtn_no",function(){O.f.gi(a);return!0})};
e.kg=function(){var a,b=this;a=function(a){var d=a?"challengeCancelMessage_success":"challengeCancel_error";b.ld(O.i.r(d,"<"+d.toUpperCase()+">"));a&&(b.Ze.eb=!1,b.zl||hh())};xh(this,"challengeCancelConfirmText","challengeCancelConfirmBtn_yes","challengeCancelConfirmBtn_no",function(){O.f.kg(a);return!0})};
function xh(a,b,c,d,g){var h,k,l,n;for(h=0;h<a.buttons.length;h++)K.p(a.buttons[h]);a.buttons=[];b=O.i.r(b,"<"+b.toUpperCase()+">");h=V.K();a.a.Em?C(h,a.a.Em):a.a.ol&&C(h,a.a.ol);k=H(h,b,a.a.Xh,a.a.Sj,!0);k<h.fontSize&&D(h,k);n=h.ba(b,a.a.Xh)+10;l=h.V(b,a.a.Xh)+10;k=O.b.ca(a.a.Yp,a.c.e.width,n,h.align);l=O.b.ca(a.a.Tj,a.c.e.height,l,h.h);z(a.c.e);h.o(b,k,l,n);B(a.c.e);k=O.b.g(a.a.Wp,a.canvas.width,a.a.Wh)-a.c.x;l=O.b.g(a.a.Qj,a.canvas.height,a.cc.default_text.s.height)-a.c.y-O.oa;a.buttons.push(new Hg("default_text",
k,l,a.depth-20,d,a.a.Wh,{R:function(){var b,c,d;c=O.b.g(a.a.Xb,a.canvas.width,a.a.backgroundImage.width);d=O.b.g(a.a.Db,a.canvas.height,a.a.backgroundImage.height)+-1*O.oa;a.Da(c,d);for(b=0;b<a.buttons.length;b++)K.p(a.buttons[b]);a.buttons=[];a.Re(c,d,!0);return!0},aa:a},a.c));k=O.b.g(a.a.Xp,a.canvas.width,a.a.Wh)-a.c.x;l=O.b.g(a.a.Rj,a.canvas.height,a.cc.default_text.s.height)-a.c.y-O.oa;a.buttons.push(new Hg("default_text",k,l,a.depth-20,c,a.a.Wh,{R:function(){return"function"===typeof g?g():!0},
aa:a},a.c))}
e.ld=function(a){var b,c,d,g;for(b=0;b<this.buttons.length;b++)K.p(this.buttons[b]);this.buttons=[];c=O.b.g(this.a.Xb,this.canvas.width,this.a.backgroundImage.width);d=O.b.g(this.a.Db,this.canvas.height,this.a.backgroundImage.height)+-1*O.oa;this.Da(c,d);b=V.K();this.a.vf&&C(b,this.a.vf);c=H(b,a,this.a.On,this.a.gw,!0);c<b.fontSize&&D(b,c);g=b.ba(a,this.a.On)+10;d=b.V(a,this.a.On)+10;c=O.b.ca(this.a.hw,this.c.e.width,g,b.align);d=O.b.ca(this.a.iw,this.c.e.height,d,b.h);z(this.c.e);b.o(a,c,d,g);B(this.c.e)};
e.Px=function(){O.Aa.Qa("startScreen","options");Bh(O.f);return!0};e.close=function(){K.p(this);return this.canvas.Z=!0};
e.Sb=function(){var a,b;this.zl&&hh(this);O.f.Qe=this;this.rq=this.qq=!1;a=this.a.backgroundImage;this.c=new ih(this.depth-10,this.Fa,new y(a.width,a.height));this.c.x=O.b.g(this.a.Xb,this.canvas.width,a.width);a=O.b.g(this.a.Db,this.canvas.height,a.height)+-1*O.oa;this.c.y=a;this.Da(this.c.x,this.c.y);this.buttons=[];this.Py?this.Li():this.Re(this.c.x,this.c.y);this.Ze=new ng(this.a.Th,this.a.mg,this.depth-20,new Ob(0,0,this.a.lg,this.a.$e),void 0,{R:this.close,aa:this},this.c);this.nh="versions";
this.Se=new Sb;O.b.Za(this.Se,O.qb);Hb(this.Se,this.depth-1);Tb(this.Se,"keyAreaLeft",this.c.x,this.c.y+this.a.Ie,this.a.eg,this.a.tj,76);Tb(this.Se,"keyAreaRight",this.c.x+this.c.width-this.a.eg,this.c.y+this.a.Ie,this.a.eg,this.a.tj,82);Tb(this.Se,"keyAreaCentre",O.Lv/2-this.a.eg/2,this.c.y+this.a.Ie,this.a.eg,this.a.tj,67);b=this;this.c.y="inGame"!==this.type?this.canvas.height:-this.c.e.height;Z(this.c,"y",a,this.a.xf,this.a.yf,function(){var a;for(a=0;a<b.buttons.length;a++)b.buttons[a].eb=!0})};
e.yb=function(){var a;this.zl&&mh();this.qq&&ka(O.nf,O.i.ln());this.rq&&ka(O.Ee);for(a=0;a<this.buttons.length;a++)K.p(this.buttons[a]);this.Se.clear();K.p(this.Se);K.p(this.Ze);K.p(this.c);O.f.Qe=null};e.Tb=function(){return!0};e.zb=function(){return!0};e.Bg=function(a){this.os&&(67===a?this.nh="":76===a?this.nh+="l":82===a&&(this.nh+="r"),"lrl"===this.nh&&wh(this))};e.gd=function(a){a===O.nf?(this.Da(this.c.x,this.c.y),this.qq=!0):a===O.Ee?this.rq=!0:a===O.Vt&&this.close()};
function Dh(){this.depth=-200;this.k=this.visible=!0;O.b.Za(this,O.ff);var a;this.a=O.a.C.ik;if("landscape"===O.orientation&&O.a.C.Ym)for(a in O.a.C.Ym)this.a[a]=O.a.C.Ym[a];this.cc=O.a.C.Ob;for(a in O.a.P.ik)this.a[a]=O.a.P.ik[a];L(this)}
Dh.prototype.Da=function(){var a,b,c,d;c=this.a.backgroundImage;d=(O.Iv-Math.abs(O.oa))/c.ng;this.c.e=new y(d*c.Vh,d*c.ng);z(this.c.e);this.c.y=Math.abs(O.oa);a=r.context;1E-4>Math.abs(d)||1E-4>Math.abs(d)||(a.save(),a.translate(0,0),a.rotate(-0*Math.PI/180),a.scale(d,d),a.globalAlpha=1,sa(c,0,0),a.restore());c=V.K();C(c,this.a.font);d=O.i.r("gameEndScreenTitle","<GAMEENDSCREENTITLE>");a=H(c,d,this.a.Ol-(c.stroke?c.Pc:0),this.a.xy-(c.stroke?c.Pc:0),!0);a<c.fontSize&&D(c,a);a=O.b.ca(this.a.Rs,this.canvas.width,
c.ba(d),c.align);b=O.b.ca(this.a.Ss,this.canvas.height,c.V(d),c.h);c.o(d,a,b,this.a.Ol);B(this.c.e);this.c.canvas.Z=!0};Dh.prototype.Sb=function(){var a=this,b=this.a.backgroundImage,b=new y(b.width,b.height);this.c=new ih(this.depth,O.qb,b);this.c.x=0;this.c.y=Math.abs(O.oa);this.Da();this.button=new Hg(this.a.Op,O.b.g(this.a.hu,this.canvas.width,this.a.Pp),O.b.g(this.a.Qp,this.canvas.height,this.cc[this.a.Op].s.height),this.depth-10,"gameEndScreenBtnText",this.a.Pp,function(){K.p(a);Bh(O.f)},this.c)};
Dh.prototype.yb=function(){K.p(this.c);K.p(this.button)};Dh.prototype.gd=function(a){a!==O.nf&&a!==O.Ee||this.Da()};
function ng(a,b,c,d,g,h,k){function l(a,b,c){var d,g;g=O.b.kn(q.canvas);a=Math.round(q.x+q.parent.x-q.fc*q.ta);d=Math.round(q.y+q.parent.y-q.gc*q.Ia);if(q.images&&0<q.lf||0<q.Ri)q.lf=0,q.Ri=0,q.canvas.Z=!0;if(q.Fi&&q.eb&&Qb(q.Kc,a,d,b-g.x,c-g.y))return q.Fi=!1,void 0!==q.aa?q.$k.call(q.aa,q):q.$k(q)}function n(a,b,c){var d,g,h;h=O.b.kn(q.canvas);d=Math.round(q.x+q.parent.x-q.fc*q.ta);g=Math.round(q.y+q.parent.y-q.gc*q.Ia);if(q.eb&&Qb(q.Kc,d,g,b-h.x,c-h.y))return q.Fi=!0,q.images&&(1<q.images.length?
(q.lf=1,q.canvas.Z=!0):1<q.images[0].F&&(q.Ri=1,q.canvas.Z=!0)),void 0!==typeof Of&&J.play(Of),q.ef=a,!0}this.depth=c;this.k=this.visible=!0;this.group="TG_Token";O.b.Za(this,O.qb);this.gc=this.fc=0;this.x=a;this.y=b;this.width=g?g[0].width:d.Wa-d.Ba;this.height=g?g[0].height:d.wb-d.Oa;this.alpha=this.Ia=this.ta=1;this.Na=0;this.Kc=d;this.images=g;this.Ri=this.lf=0;this.Fi=!1;this.eb=!0;this.parent=void 0!==k?k:{x:0,y:0};this.tl=this.sl=0;this.Rb=!0;this.$k=function(){};this.Ub=!1;"object"===typeof h?
(this.$k=h.R,this.aa=h.aa,this.Ub=h.Ub):"function"===typeof h&&(this.$k=h);var q=this;this.Ub?(this.zg=n,this.Ag=l):(this.zb=n,this.Tb=l);L(this)}function Gg(a,b,c,d,g,h){void 0===a.pe&&(a.pe=[]);a.pe.push({type:b,start:d,Pb:g,cb:c,duration:h,m:0})}
function Lg(a){var b,c;if(void 0!==a.pe){for(b=0;b<a.pe.length;b++)if(c=a.pe[b],c.k){switch(c.type){case "xScale":a.ta=c.start+c.Pb;break;case "yScale":a.Ia=c.start+c.Pb;break;case "alpha":a.alpha=c.start+c.Pb;break;case "angle":a.Na=c.start+c.Pb;break;case "x":a.x=c.start+c.Pb;break;case "y":a.y=c.start+c.Pb}c.k=!1}a.canvas.Z=!0}}function Sg(a,b){a.images=b;a.canvas.Z=!0}e=ng.prototype;e.wo=function(a){this.visible=this.k=a};e.yb=function(){this.images&&(this.canvas.Z=!0)};
e.pa=function(a){var b,c;if(void 0!==this.pe){for(b=0;b<this.pe.length;b++)switch(c=this.pe[b],c.m+=a,c.type){case "xScale":var d=this.ta,g=this.sl;this.ta=c.cb(c.m,c.start,c.Pb,c.duration);this.sl=-(this.images[0].width*this.ta-this.images[0].width*c.start)/2;if(isNaN(this.ta)||isNaN(this.sl))this.ta=d,this.sl=g;break;case "yScale":d=this.Ia;g=this.tl;this.Ia=c.cb(c.m,c.start,c.Pb,c.duration);this.tl=-(this.images[0].height*this.Ia-this.images[0].height*c.start)/2;if(isNaN(this.Ia)||isNaN(this.tl))this.Ia=
d,this.tl=g;break;case "alpha":this.alpha=c.cb(c.m,c.start,c.Pb,c.duration);break;case "angle":this.Na=c.cb(c.m,c.start,c.Pb,c.duration);break;case "x":d=this.x;this.x=c.cb(c.m,c.start,c.Pb,c.duration);isNaN(this.x)&&(this.x=d);break;case "y":d=this.y,this.y=c.cb(c.m,c.start,c.Pb,c.duration),isNaN(this.y)&&(this.y=d)}this.canvas.Z=!0}};
e.mc=function(){var a,b,c;c=O.b.kn(this.canvas);a=Math.round(this.x+this.parent.x-this.fc*this.ta);b=Math.round(this.y+this.parent.y-this.gc*this.Ia);this.Fi&&!Qb(this.Kc,a,b,K.ha[this.ef].x-c.x,K.ha[this.ef].y-c.y)&&(this.images&&(this.Ri=this.lf=0,this.canvas.Z=!0),this.Fi=!1)};
e.Pa=function(){var a,b;a=Math.round(this.x+this.parent.x-this.fc*this.ta);b=Math.round(this.y+this.parent.y-this.gc*this.Ia);this.images&&(this.images[this.lf]instanceof y?this.images[this.lf].za(a,b,this.ta,this.Ia,this.Na,this.alpha):this.images[this.lf].za(this.Ri,a,b,this.ta,this.Ia,this.Na,this.alpha));this.Rb=!1};
function Hg(a,b,c,d,g,h,k,l){this.X=O.a.C.Ob[a];a=void 0!==O.a.P.buttons?O.a.C.Ij[O.a.P.buttons[a]||O.a.P.buttons.default_color]:O.a.C.Ij[O.a.C.buttons.default_color];this.font=V.K();a.font&&C(this.font,a.font);this.X.fontSize&&D(this.font,this.X.fontSize);this.M=g;this.text=O.i.r(this.M,"<"+g.toUpperCase()+">");void 0!==h&&(this.width=h);this.height=this.X.s.height;this.e={source:this.X.s,qa:this.X.qa,ib:this.X.ib};g=this.Rd(this.e);h=new Ob(0,0,g[0].width,g[0].height);ng.call(this,b,c,d,h,g,k,l)}
O.b.ui(Hg);e=Hg.prototype;e.ql=function(a){this.text=O.i.r(this.M,"<"+this.M.toUpperCase()+">");a&&C(this.font,a);Sg(this,this.Rd(this.e))};e.aj=function(a,b){this.M=a;this.ql(b)};e.$i=function(a,b,c){"string"===typeof b&&(this.text=b);c&&C(this.font,c);a instanceof x?this.e.source=a:void 0!==a.qa&&void 0!==a.ib&&void 0!==a.source&&(this.e=a);Sg(this,this.Rd(this.e))};
e.Rd=function(a){var b,c,d,g,h,k,l=a.qa+a.ib;d=this.height-(this.X.Tc||0);var n=a.source;c=this.font.ba(this.text);void 0===this.width?b=c:"number"===typeof this.width?b=this.width-l:"object"===typeof this.width&&(void 0!==this.width.width?b=this.width.width-l:(void 0!==this.width.minWidth&&(b=Math.max(this.width.minWidth-l,c)),void 0!==this.width.maxWidth&&(b=Math.min(this.width.maxWidth-l,c))));c=H(this.font,this.text,b,d,!0);c<this.X.fontSize?D(this.font,c):D(this.font,this.X.fontSize);c=a.qa;
d=this.font.align;"center"===d?c+=Math.round(b/2):"right"===d&&(c+=b);d=Math.round(this.height/2);void 0!==this.X.Sc&&(d+=this.X.Sc);h=[];for(g=0;g<n.F;g++)k=new y(b+l,this.height),z(k),n.ka(g,0,0,a.qa,this.height,0,0,1),n.Yj(g,a.qa,0,n.width-l,this.height,a.qa,0,b,this.height,1),n.ka(g,a.qa+n.width-l,0,a.ib,this.height,a.qa+b,0,1),this.font.o(this.text,c,d,b),B(k),h.push(k);return h};e.gd=function(a){a===O.nf&&this.ql()};
function th(a,b,c,d,g,h,k,l){this.X=O.a.C.Ob[a];void 0!==h&&(this.width=h);this.height=this.X.s.height;this.ud={source:this.X.s,qa:this.X.qa,ib:this.X.ib};this.e=g;a=this.Rd();g=new Ob(0,0,a[0].width,a[0].height);ng.call(this,b,c,d,g,a,k,l)}O.b.ui(th);
th.prototype.Rd=function(){var a,b,c,d,g,h,k,l=this.ud.qa+this.ud.ib;b=this.height-(this.X.Tc||0);var n=this.ud.source;void 0===this.width?a=this.e.width:"number"===typeof this.width?a=this.width-l:"object"===typeof this.width&&(void 0!==this.width.width?a=this.width.width-l:(void 0!==this.width.minWidth&&(a=Math.max(this.width.minWidth-l,this.e.width)),void 0!==this.width.maxWidth&&(a=Math.min(this.width.maxWidth-l,this.e.width))));k=Math.min(a/this.e.width,b/this.e.height);k=Math.min(k,1);g=Math.round(this.ud.qa+
(a-this.e.width*k)/2);h=Math.round((b-this.e.height*k)/2);c=[];for(b=0;b<n.F;b++){d=new y(a+l,this.height);z(d);n.ka(b,0,0,this.ud.qa,this.height,0,0,1);n.Yj(b,this.ud.qa,0,n.width-l,this.height,this.ud.qa,0,a,this.height,1);n.ka(b,this.ud.qa+n.width-l,0,this.ud.ib,this.height,this.ud.qa+a,0,1);try{r.context.drawImage(this.e,g,h,this.e.width*k,this.e.height*k)}catch(q){}B(d);c.push(d)}return c};O.b.ui(function(a,b,c,d,g,h,k){ng.call(this,a,b,c,g,d,h,k)});
function Dg(a,b,c,d,g,h,k,l){var n;this.X=O.a.C.Ob[a];a=void 0!==O.a.P.buttons?O.a.C.Ij[O.a.P.buttons[a]||O.a.P.buttons.default_color]:O.a.C.Ij[O.a.C.buttons.default_color];this.font=V.K();a.font&&C(this.font,a.font);this.X.fontSize&&D(this.font,this.X.fontSize);void 0!==h&&(this.width=h);this.height=this.X.s.height;this.U=this.X.U;if(this.U.length){for(h=0;h<this.U.length;h++)if(this.U[h].id===g){this.Ca=h;break}void 0===this.Ca&&(this.Ca=0);this.text=O.i.r(this.U[this.Ca].M,"<"+this.U[this.Ca].id.toUpperCase()+
">");this.Xf=this.U[this.Ca].s;h=this.Rd();a=new Ob(0,0,h[0].width,h[0].height);n=this;"function"===typeof k?g=function(){n.Gf();return k(n.U[n.Ca].id)}:"object"===typeof k?(g={},g.Ub=k.Ub,g.aa=this,g.R=function(){n.Gf();return k.R.call(k.aa,n.U[n.Ca].id)}):g=function(){n.Gf()};ng.call(this,b,c,d,a,h,g,l)}}O.b.ui(Dg);e=Dg.prototype;
e.Gf=function(a){var b;if(void 0===a)this.Ca=(this.Ca+1)%this.U.length;else for(b=0;b<this.U.length;b++)if(this.U[b].id===a){this.Ca=b;break}this.$i(this.U[this.Ca].s,O.i.r(this.U[this.Ca].M,"<"+this.U[this.Ca].id.toUpperCase()+">"))};e.ql=function(a){a&&C(this.font,a);this.text=O.i.r(this.U[this.Ca].M,"<"+this.U[this.Ca].id.toUpperCase()+">");Sg(this,this.Rd())};e.$i=function(a,b,c){this.text=b;this.Xf=a;c&&C(this.font,c);Sg(this,this.Rd())};
e.Rd=function(){var a,b,c,d,g,h,k=this.X.qa,l=this.X.ib,n=k+l;g=Math.abs(k-l);d=this.height-(this.X.Tc||0);var q=this.X.s,w=this.font.K();b=w.ba(this.text);void 0===this.width?a=b:"number"===typeof this.width?a=this.width-n:"object"===typeof this.width&&(void 0!==this.width.width?a=this.width.width-n:(void 0!==this.width.minWidth&&(a=Math.max(this.width.minWidth-n,b)),void 0!==this.width.maxWidth&&(a=Math.min(this.width.maxWidth-n,b))));d=H(w,this.text,a,d,!0);d<w.fontSize&&D(w,d);b=w.ba(this.text,
a);d=k;c=w.align;"center"===c?d=a-g>=b?d+Math.round((a-g)/2):d+(this.X.Qf+Math.round(b/2)):"left"===c?d+=this.X.Qf:"right"===c&&(d+=a);g=Math.round(this.height/2);void 0!==this.X.Sc&&(g+=this.X.Sc);c=[];for(b=0;b<q.F;b++)h=new y(a+n,this.height),z(h),q.ka(b,0,0,k,this.height,0,0,1),q.Yj(b,k,0,q.width-n,this.height,k,0,a,this.height,1),q.ka(b,k+q.width-n,0,l,this.height,k+a,0,1),this.Xf.o(0,this.X.gh,this.X.hh),w.o(this.text,d,g,a),B(h),c.push(h);return c};e.gd=function(a){a===O.nf&&this.ql()};
function uh(a,b,c,d,g,h,k){var l;this.U=O.a.C.Ob[a].U;if(this.U.length){for(a=0;a<this.U.length;a++)if(this.U[a].id===g){this.Ca=a;break}void 0===this.Ca&&(this.Ca=0);this.Xf=this.U[this.Ca].s;a=new Pb(this.Xf);l=this;g="function"===typeof h?function(){l.Gf();return h(l.U[l.Ca].id)}:"object"===typeof h?{aa:this,R:function(){l.Gf();return h.R.call(h.aa,l.U[l.Ca].id)}}:function(){l.Gf()};ng.call(this,b,c,d,a,[this.Xf],g,k)}}O.b.ui(uh);
uh.prototype.Gf=function(a){var b;if(void 0===a)this.Ca=(this.Ca+1)%this.U.length;else for(b=0;b<this.U.length;b++)if(this.U[b].id===a){this.Ca=b;break}this.$i(this.U[this.Ca].s)};uh.prototype.$i=function(a){this.Xf=a;Sg(this,[].concat(this.Xf))};
function Eh(a,b,c){this.depth=10;this.visible=!1;this.k=!0;O.b.Za(this,O.qb);this.a=O.a.C.Nj;for(var d in O.a.P.Nj)this.a[d]=O.a.P.Nj[d];this.M=a;this.R=b;this.aa=c;this.cl="entering";this.ct=!1;this.ia=Cg(O.f);this.ia.Zc===this.ia.Ye&&(this.Oj=!0);L(this,!1);Ib(this,"LevelStartDialog")}function Fh(a){"leaving"!==a.cl&&(a.cl="leaving",Z(a.c,"y",-a.c.height,a.a.xj,a.a.yj,function(){K.p(a);a.aa?a.R.call(a.aa):a.R&&a.R()}))}e=Eh.prototype;
e.Sb=function(){var a,b,c,d,g,h,k;a=this;b=this.a.Lc;c=void 0!==b?b.width:P(600);d=void 0!==b?b.height:P(700);g=function(a,b,g,h,k,E,s){var t;t=V.K();void 0!==b&&C(t,b);b=H(t,a,g,h,k);t.fontSize>b&&D(t,b);E=O.b.ca(E,c,t.ba(a,k),t.align);s=O.b.ca(s,d,t.V(a,k),t.align);t.o(a,E,s,k?g:void 0)};this.c=new ih(this.depth+10,this.Fa,new y(c,d));z(this.c.e);void 0!==b&&b.o(0,0,0);b=this.Oj?this.ia.Fs?O.i.r("challengeStartScreenTitle_challenger_stranger","<CHALLENGESTARTSCREENTITLE_CHALLENGER>"):O.i.r("challengeStartScreenTitle_challenger_friend",
"<CHALLENGESTARTSCREENTITLE_CHALLENGER>"):this.ia.Fs?O.i.r("challengeStartScreenTitle_challengee_stranger","<CHALLENGESTARTSCREENTITLE_CHALLENGEE>"):O.i.r("challengeStartScreenTitle_challengee_friend","<CHALLENGESTARTSCREENTITLE_CHALLENGEE>");g(b,this.a.Yb,this.a.rd,this.a.ge,!0,this.a.He,this.a.Uc);if(this.Oj)for(b="",h=1;h<this.ia.jd.length;h++)k=this.ia.jd[h],b=13<k.length?b+(k.substr(0,10)+"..."):b+k,h+1<this.ia.jd.length&&(b+=", ");else k=this.ia.jd[this.ia.Ye],b=13<k.length?k.substr(0,10)+"...":
k;g(b,this.a.Lr,this.a.yw,this.a.xw,!1,this.a.Bw,this.a.Cw);this.Oj?b=O.i.r(this.M+"_challenger","<"+this.M.toUpperCase()+"_CHALLENGER>"):(b=O.i.r(this.M,"<"+this.M.toUpperCase()+">"),k=this.ia.jd[this.ia.Ye],b=b.replace("<NAME>",13<k.length?k.substr(0,10)+"...":k));g(b,this.a.fs,this.a.ux,this.a.tx,!1,this.a.vx,this.a.wx);this.Oj||(b=Gh(this.ia.Qg[0]),g(b,this.a.es,this.a.zx,this.a.yx,!1,this.a.Bx,this.a.Cx));b=O.i.r("challengeStartScreenToWin","<CHALLENGESTARTSCREENTOWIN>");g(b,this.a.At,this.a.Ty,
this.a.Sy,!0,this.a.Uy,this.a.Vy);b=this.ia.wt+"";g(b,this.a.zt,this.a.Xy,this.a.Wy,!1,this.a.Yy,this.a.Zy);B(this.c.e);this.c.x=O.b.g(this.a.Tr,this.canvas.width,c)+this.a.Af;this.c.y=-this.c.height;Z(this.c,"y",O.b.g(this.a.$n,this.canvas.height,this.c.e.height)+Math.abs(O.oa),this.a.ne,this.a.wj,function(){a.cl="paused"});J.play(Mf);this.m=0};e.yb=function(){K.p(this.c)};e.pa=function(a){"paused"!==this.state&&(this.m+=a,this.m>=this.a.Wr&&Fh(this))};e.zb=function(){return this.ct=!0};
e.Tb=function(){this.ct&&"paused"===this.cl&&Fh(this);return!0};function ih(a,b,c){this.depth=a;this.k=this.visible=!0;O.b.Za(this,b);this.e=c;this.Eb=0;this.width=c.width;this.height=c.height;this.gc=this.fc=this.y=this.x=0;this.Ia=this.ta=1;this.Na=0;this.alpha=1;this.lb=[];this.Ep=0;this.parent={x:0,y:0};this.Rb=!0;L(this,!1)}
function Z(a,b,c,d,g,h,k,l,n){var q,w=0<k;switch(b){case "x":q=a.x;break;case "y":q=a.y;break;case "xScale":q=a.ta;break;case "yScale":q=a.Ia;break;case "scale":b="xScale";q=a.ta;Z(a,"yScale",c,d,g,void 0,k,l,n);break;case "angle":q=a.Na;break;case "alpha":q=a.alpha;break;case "subImage":q=0}a.lb.push({id:a.Ep,m:0,k:!0,Vj:w,type:b,start:q,end:c,mb:h,duration:d,cb:g,ya:k,loop:l,Hv:n});a.Ep++}
function Xg(a){var b;for(b=a.lb.length-1;0<=b;b--){switch(a.lb[b].type){case "x":a.x=a.lb[b].end;break;case "y":a.y=a.lb[b].end;break;case "xScale":a.ta=a.lb[b].end;break;case "yScale":a.Ia=a.lb[b].end;break;case "angle":a.Na=a.lb[b].end;break;case "alpha":a.alpha=a.lb[b].end;break;case "subImage":a.Eb=a.lb[b].end}"function"===typeof a.lb[b].mb&&a.lb[b].mb.call(a)}}
ih.prototype.pa=function(a){var b,c,d;for(b=0;b<this.lb.length;b++)if(c=this.lb[b],c.k&&(c.m+=a,c.Vj&&c.m>=c.ya&&(c.m%=c.ya,c.Vj=!1),!c.Vj)){c.m>=c.duration?(d=c.end,c.loop?(c.Vj=!0,c.ya=c.Hv,c.m%=c.duration):("function"===typeof c.mb&&c.mb.call(this),this.lb[b]=void 0)):"subImage"===c.type?(d=this.e instanceof Array?this.e.length:this.e.F,d=Math.floor(c.m*d/c.duration)):d=c.cb(c.m,c.start,c.end-c.start,c.duration);switch(c.type){case "x":this.x=d;break;case "y":this.y=d;break;case "xScale":this.ta=
d;break;case "yScale":this.Ia=d;break;case "angle":this.Na=d;break;case "alpha":this.alpha=d;break;case "subImage":this.Eb=d}this.canvas.Z=!0}for(b=this.lb.length-1;0<=b;b--)void 0===this.lb[b]&&this.lb.splice(b,1)};
ih.prototype.Pa=function(){var a,b,c;b=Math.round(this.x-this.ta*this.fc)+this.parent.x;c=Math.round(this.y-this.Ia*this.gc)+this.parent.y;a=this.e;a instanceof Array&&(a=this.e[this.Eb%this.e.length]);a instanceof y?a.za(b,c,this.ta,this.Ia,this.Na,this.alpha):a.za(this.Eb,b,c,this.ta,this.Ia,this.Na,this.alpha);this.Rb=!1};
function bh(a,b,c,d,g,h,k,l,n,q,w){this.depth=g;this.visible=!0;this.k=!1;O.b.Za(this,O.qb);this.x=a;this.y=b;this.Jn=l;this.Kn="object"===typeof n?n.top:n;this.Mv="object"===typeof n?n.bottom:n;this.ba=c;this.V=d;this.width=this.ba+2*this.Jn;this.height=this.V+this.Kn+this.Mv;this.value=h||0;this.parent=q||{x:0,y:0};this.font=k;this.toString="function"===typeof w?w:function(a){return a+""};this.alpha=1;this.Ef=this.Df=this.gc=this.fc=0;c=new y(this.width,this.height);this.Yc=new ih(this.depth,this.Fa,
c);this.Yc.x=a-this.Jn;this.Yc.y=b-this.Kn;this.Yc.parent=q;this.Ma=this.Yc.e;this.De();L(this)}bh.prototype.yb=function(){K.p(this.Yc)};function lh(a,b,c){a.k=!0;a.Te=a.value;a.value=a.Te;a.end=b;a.duration=c;a.cb=M;a.m=0}
bh.prototype.De=function(){var a,b;a=this.font.align;b=this.font.h;var c=this.Jn,d=this.Kn;this.Ip||(this.Ma.clear(),this.canvas.Z=!0);z(this.Ma);this.Ip&&this.Ip.ka(0,this.rz,this.sz,this.qz,this.pz,0,0,1);"center"===a?c+=Math.round(this.ba/2):"right"===a&&(c+=this.ba);"middle"===b?d+=Math.round(this.V/2):"bottom"===b&&(d+=this.V);b=this.toString(this.value);a=H(this.font,b,this.ba,this.V,!0);a<this.font.fontSize&&D(this.font,a);this.font.o(b,c,d,this.ba);B(this.Ma);this.Yc.Rb=!0};
bh.prototype.pa=function(a){var b;b=Math.round(this.cb(this.m,this.Te,this.end-this.Te,this.duration));this.m>=this.duration?(this.value=this.end,this.k=!1,this.De()):b!==this.value&&(this.value=b,this.De());this.m+=a};function rh(a,b,c){this.depth=-100;this.visible=!1;this.k=!0;this.cx=a;O.b.Za(this,O.qb);this.a=O.a.C.$c;this.cc=O.a.C.Ob;this.Rp=b;for(var d in O.a.P.$c)this.a[d]=O.a.P.$c[d];this.ao=!1!==c;L(this)}e=rh.prototype;e.Ys=function(){};
e.Nh=function(a,b,c,d,g){b=new Hg("default_text",b,c,this.depth-20,a.M||"NO_TEXT_KEY_GIVEN",d,{R:function(){a.R&&(a.aa?a.R.call(a.aa,a):a.R(a))},aa:this},this.c);this.buttons.push(b);a.text&&b.$i(b.e,a.text);this.buttons[this.buttons.length-1].eb=g||!1};
e.Da=function(a,b,c){z(this.c.e);r.clear();this.a.backgroundImage.o(0,0,0);a=c?c:this.cx;b=V.K();this.a.fo&&C(b,this.a.fo);c=H(b,a,this.a.nl,this.a.ml,!0);c<b.fontSize&&D(b,c);c=b.ba(a,this.a.nl)+10;var d=b.V(a,this.a.ml)+10;b.o(a,O.b.ca(this.a.hx,this.c.e.width,c,b.align),O.b.ca(this.a.as,this.c.e.height-Hh(this),d,b.h),c);B(this.c.e)};function Hh(a){var b=a.Rp;return O.b.g(a.a.jg,a.c.e.height,a.cc.default_text.s.height*b.length+a.a.vd*(b.length-1))}
e.Re=function(a,b){var c,d,g,h,k,l,n,q,w,A=[],A=this.Rp;g=this.cc.default_text.s.height;h=this.a.Kj;k=O.b.g(this.a.Jj,this.canvas.width,h)-a;q=Hh(this);for(c=A.length-1;0<=c;c--){n=k;w=h;if("object"===typeof A[c]&&A[c].hasOwnProperty("length")&&A[c].length)for(l=A[c],w=(h-(l.length-1)*this.a.vd)/l.length,d=0;d<l.length;d++)this.Nh(l[d],n,q,w,b),n+=w+this.a.vd;else this.Nh(A[c],n,q,w,b);q-=g+this.a.vd}};
e.show=function(){var a,b;for(a=0;a<this.buttons.length;a++)b=this.buttons[a],b.wo(!0);this.c.visible=!0};e.close=function(){K.p(this);return this.canvas.Z=!0};function Ih(a){var b=O.f.me;b.Da(b.c.x,b.c.y,a);for(a=0;a<b.buttons.length;a++)K.p(b.buttons[a]);b.canvas.Z=!0}
e.Sb=function(){var a,b;this.ao&&hh(this);a=this.a.backgroundImage;this.c=new ih(this.depth-10,this.Fa,new y(a.width,a.height));this.c.x=O.b.g(this.a.Xb,this.canvas.width,a.width);a=O.b.g(this.a.Db,this.canvas.height,a.height)+-1*("landscape"===O.orientation?O.a.C.Dm:O.a.C.wd).Uk;this.c.y=a;this.Da(this.c.x,this.c.y);this.buttons=[];this.Re(this.c.x);b=this;this.c.y=-this.c.e.height;Z(this.c,"y",a,this.a.xf,this.a.yf,function(){var a;for(a=0;a<b.buttons.length;a++)b.buttons[a].eb=!0})};
e.yb=function(){var a;this.ao&&mh();for(a=0;a<this.buttons.length;a++)K.p(this.buttons[a]);K.p(this.c);O.f.Qe===this&&(O.f.Qe=null)};e.Tb=function(){return!0};e.zb=function(){return!0};
function Jh(a){if(null===a||"undefined"===typeof a)return"";a+="";var b="",c,d,g=0;c=d=0;for(var g=a.length,h=0;h<g;h++){var k=a.charCodeAt(h),l=null;if(128>k)d++;else if(127<k&&2048>k)l=String.fromCharCode(k>>6|192,k&63|128);else if(55296!==(k&63488))l=String.fromCharCode(k>>12|224,k>>6&63|128,k&63|128);else{if(55296!==(k&64512))throw new RangeError("Unmatched trail surrogate at "+h);l=a.charCodeAt(++h);if(56320!==(l&64512))throw new RangeError("Unmatched lead surrogate at "+(h-1));k=((k&1023)<<
10)+(l&1023)+65536;l=String.fromCharCode(k>>18|240,k>>12&63|128,k>>6&63|128,k&63|128)}null!==l&&(d>c&&(b+=a.slice(c,d)),b+=l,c=d=h+1)}d>c&&(b+=a.slice(c,g));return b}
function og(a){function b(a){var b="",c="",d;for(d=0;3>=d;d++)c=a>>>8*d&255,c="0"+c.toString(16),b+=c.substr(c.length-2,2);return b}function c(a,b,c,d,g,h,l){a=k(a,k(k(c^(b|~d),g),l));return k(a<<h|a>>>32-h,b)}function d(a,b,c,d,g,h,l){a=k(a,k(k(b^c^d,g),l));return k(a<<h|a>>>32-h,b)}function g(a,b,c,d,g,h,l){a=k(a,k(k(b&d|c&~d,g),l));return k(a<<h|a>>>32-h,b)}function h(a,b,c,d,g,h,l){a=k(a,k(k(b&c|~b&d,g),l));return k(a<<h|a>>>32-h,b)}function k(a,b){var c,d,g,h,k;g=a&2147483648;h=b&2147483648;
c=a&1073741824;d=b&1073741824;k=(a&1073741823)+(b&1073741823);return c&d?k^2147483648^g^h:c|d?k&1073741824?k^3221225472^g^h:k^1073741824^g^h:k^g^h}var l=[],n,q,w,A,E,s,t,u,v;a=Jh(a);l=function(a){var b,c=a.length;b=c+8;for(var d=16*((b-b%64)/64+1),g=Array(d-1),h=0,k=0;k<c;)b=(k-k%4)/4,h=k%4*8,g[b]|=a.charCodeAt(k)<<h,k++;b=(k-k%4)/4;g[b]|=128<<k%4*8;g[d-2]=c<<3;g[d-1]=c>>>29;return g}(a);s=1732584193;t=4023233417;u=2562383102;v=271733878;a=l.length;for(n=0;n<a;n+=16)q=s,w=t,A=u,E=v,s=h(s,t,u,v,l[n+
0],7,3614090360),v=h(v,s,t,u,l[n+1],12,3905402710),u=h(u,v,s,t,l[n+2],17,606105819),t=h(t,u,v,s,l[n+3],22,3250441966),s=h(s,t,u,v,l[n+4],7,4118548399),v=h(v,s,t,u,l[n+5],12,1200080426),u=h(u,v,s,t,l[n+6],17,2821735955),t=h(t,u,v,s,l[n+7],22,4249261313),s=h(s,t,u,v,l[n+8],7,1770035416),v=h(v,s,t,u,l[n+9],12,2336552879),u=h(u,v,s,t,l[n+10],17,4294925233),t=h(t,u,v,s,l[n+11],22,2304563134),s=h(s,t,u,v,l[n+12],7,1804603682),v=h(v,s,t,u,l[n+13],12,4254626195),u=h(u,v,s,t,l[n+14],17,2792965006),t=h(t,u,
v,s,l[n+15],22,1236535329),s=g(s,t,u,v,l[n+1],5,4129170786),v=g(v,s,t,u,l[n+6],9,3225465664),u=g(u,v,s,t,l[n+11],14,643717713),t=g(t,u,v,s,l[n+0],20,3921069994),s=g(s,t,u,v,l[n+5],5,3593408605),v=g(v,s,t,u,l[n+10],9,38016083),u=g(u,v,s,t,l[n+15],14,3634488961),t=g(t,u,v,s,l[n+4],20,3889429448),s=g(s,t,u,v,l[n+9],5,568446438),v=g(v,s,t,u,l[n+14],9,3275163606),u=g(u,v,s,t,l[n+3],14,4107603335),t=g(t,u,v,s,l[n+8],20,1163531501),s=g(s,t,u,v,l[n+13],5,2850285829),v=g(v,s,t,u,l[n+2],9,4243563512),u=g(u,
v,s,t,l[n+7],14,1735328473),t=g(t,u,v,s,l[n+12],20,2368359562),s=d(s,t,u,v,l[n+5],4,4294588738),v=d(v,s,t,u,l[n+8],11,2272392833),u=d(u,v,s,t,l[n+11],16,1839030562),t=d(t,u,v,s,l[n+14],23,4259657740),s=d(s,t,u,v,l[n+1],4,2763975236),v=d(v,s,t,u,l[n+4],11,1272893353),u=d(u,v,s,t,l[n+7],16,4139469664),t=d(t,u,v,s,l[n+10],23,3200236656),s=d(s,t,u,v,l[n+13],4,681279174),v=d(v,s,t,u,l[n+0],11,3936430074),u=d(u,v,s,t,l[n+3],16,3572445317),t=d(t,u,v,s,l[n+6],23,76029189),s=d(s,t,u,v,l[n+9],4,3654602809),
v=d(v,s,t,u,l[n+12],11,3873151461),u=d(u,v,s,t,l[n+15],16,530742520),t=d(t,u,v,s,l[n+2],23,3299628645),s=c(s,t,u,v,l[n+0],6,4096336452),v=c(v,s,t,u,l[n+7],10,1126891415),u=c(u,v,s,t,l[n+14],15,2878612391),t=c(t,u,v,s,l[n+5],21,4237533241),s=c(s,t,u,v,l[n+12],6,1700485571),v=c(v,s,t,u,l[n+3],10,2399980690),u=c(u,v,s,t,l[n+10],15,4293915773),t=c(t,u,v,s,l[n+1],21,2240044497),s=c(s,t,u,v,l[n+8],6,1873313359),v=c(v,s,t,u,l[n+15],10,4264355552),u=c(u,v,s,t,l[n+6],15,2734768916),t=c(t,u,v,s,l[n+13],21,
1309151649),s=c(s,t,u,v,l[n+4],6,4149444226),v=c(v,s,t,u,l[n+11],10,3174756917),u=c(u,v,s,t,l[n+2],15,718787259),t=c(t,u,v,s,l[n+9],21,3951481745),s=k(s,q),t=k(t,w),u=k(u,A),v=k(v,E);return(b(s)+b(t)+b(u)+b(v)).toLowerCase()}var jh;
function Kh(a,b){var c=O.A.xk.url+"api";try{var d=new XMLHttpRequest;d.open("POST",c);d.setRequestHeader("Content-Type","application/x-www-form-urlencoded");d.onload=function(){"application/json"===d.getResponseHeader("Content-Type")&&b(JSON.parse(d.responseText))};d.onerror=function(a){console.log("error: "+a)};d.send(a)}catch(g){}}function Lh(a){Kh("call=api_is_valid",function(b){a(b.is_valid)})}
function kh(a,b){Kh("call=is_highscore&score="+a,function(a){0<=a.position?(jh=a.code,b(void 0!==jh)):b(!1)})}
TG_StatObjectFactory={Ez:function(a){return new TG_StatObject("totalScore",a,"levelEndScreenTotalScore_"+a,0,0,!0,!0)},Cz:function(a){return new TG_StatObject("highScore",a,"levelEndScreenHighScore_"+a,Mh(),Mh(),!0)},Bz:function(a,b,c,d,g){return new TG_StatObject(a,b,c,0,d,g,!0,"max"===O.j.af?function(a){return a+d}:function(a){return a-d})},Dz:function(a,b,c,d,g){return new TG_StatObject(a,b,c,0,d,g,!0,"max"===O.j.af?function(a){return a-d}:function(a){return a+d})}};
TG_StatObject=function(a,b,c,d,g,h,k,l,n){this.id=a;this.type=b;this.key=c;this.kc=d;this.Lf=void 0!==g?g:this.kc;this.visible=void 0!==h?h:!0;this.oe=void 0!==k?k:this.kc!==this.Lf;this.Je=l;this.Hl=void 0!==n?n:"totalScore";switch(this.type){case "text":this.toString=function(a){return a};break;case "number":this.toString=function(a){return a+""};break;case "time":this.toString=function(a){return O.b.Hy(1E3*a)}}};
TG_StatObject.prototype.K=function(){return new TG_StatObject(this.id,this.type,this.key,this.kc,this.Lf,this.visible,this.oe,this.Je,this.Hl)};O.version=O.version||{};O.version.tg="2.13.0";function Nh(a){this.depth=-99;O.b.Za(this,O.qb);this.k=!0;this.visible=!1;this.f=a;L(this)}Nh.prototype.uk=function(){};Nh.prototype.Bg=function(){};Nh.prototype.zb=function(a,b,c){a:{var d=this.f,g;for(g=0;g<d.wc.length;++g)if(d.wc[g].zb&&d.wc[g].zb(a,b,c)){a=!0;break a}a=!1}return a};
Nh.prototype.Tb=function(a,b,c){var d;a:if(d=this.f,d.ab&&a===d.Xo)a=d.ab.a.x,b=d.ab.a.y,d.ab.Zn&&(a=d.ab.Zn.x,b=d.ab.Zn.y),GameUISettingsOffsets?console.log("Component:\n x: tgScale("+(a+d.ab.Zf.x-GameUISettingsOffsets.hz)+") + GameUISettingsOffsets.X,\n y: tgScale("+(b+d.ab.Zf.y-GameUISettingsOffsets.iz)+") + GameUISettingsOffsets.Y,"):console.log("Component:\n x: tgScale("+(a+d.ab.Zf.x)+"),\n y: tgScale("+(b+d.ab.Zf.y)+"),"),d.nt=!1,d=!0;else{for(var g=0;g<d.wc.length;++g)if(d.wc[g].Tb&&d.wc[g].Tb(a,
b,c)){d=!0;break a}d=!1}return d};function Oh(){this.Fa=this.depth=0;this.Jm=this.Kb=this.k=this.visible=!1;this.wc=[];this.fk={};this.fk.be=!1;this.pq={};this.paused=this.pq.be=!1;this.iy=new y(0,0);this.ky=this.jy=0;this.ab=null;this.Xo=this.pt=this.ot=-1;this.nt=!1;this.Cb=this.Bb=0;this.Dk=null}e=Oh.prototype;e.Sb=function(){this.Dk=new Nh(this)};e.yb=function(){this.Dk&&(K.p(this.Dk),this.Dk=null)};
function Ph(a,b,c){for(var d in b){var g=b[d];g.e?c[d]=new Qh(a,g):g.Ts?c[d]=new Rh(a,O.i.r(g.Ts,"<"+g.Ts+">"),g):g.M?c[d]=new Rh(a,O.i.r(g.M,"<"+g.M+">"),g):g.text&&(c[d]=new Rh(a,g.text,g))}}function Sh(a,b){a.be&&(a.m+=b,a.m>=a.duration&&(a.be=!1,a.mb&&a.mb()))}
e.pa=function(a){Sh(this.fk,a);Sh(this.pq,a);for(var b=0;b<this.wc.length;++b)this.wc[b].pa(a);if(this.ab&&this.nt){a=K.ha[this.Xo].x;b=K.ha[this.Xo].y;this.canvas===O.b.Xd(O.ji)&&this.ab.sk(this.Bb+O.jf,this.Cb+O.ue);var c=a-this.ot,d=b-this.pt;this.ab.x+=c;this.ab.y+=d;this.ab.Zf.x+=c;this.ab.Zf.y+=d;this.ot=a;this.pt=b;this.Kb=!0}};e.mc=function(){if(this.Kb){var a=O.b.Xd(O.ji);this.canvas!==a?this.canvas.Z=this.Kb:(r.jb(a),this.Pa())}};
e.$j=function(a,b){for(var c=O.b.Xd(O.ji)===this.canvas,d=0;d<this.wc.length;++d){var g=this.wc[d];g.visible&&(c&&g.sk(a,b),g.Pa(a,b))}};e.Pa=function(){var a=0,b=0;O.b.Xd(O.ok)!==this.canvas&&(a=O.jf,b=O.ue);this.paused?this.iy.o(this.jy+this.Bb+a,this.ky+this.Cb+b):this.$j(this.Bb+a,this.Cb+b);this.Kb=!1};function Th(){this.wk=[];this.Qm=[];this.yl=null;this.tm=void 0;this.hk=!0}
function Uh(a){function b(a,b){if(!b)return!1;var g=0;if("string"===typeof a){if(d(a))return!1}else for(g=0;g<a.length;++g)if(d(a[g]))return!1;if(b.$h){if("string"===typeof a){if(c(a))return!0}else for(g=0;g<a.length;++g)if(c(a[g]))return!0;return!1}return!0}function c(a){for(var b in k)if(b===a||k[b]===a)return!0;return!1}function d(a){for(var b in h)if(b===a||h[b]===a)return!0;return!1}var g;if(a instanceof Th){if(1!==arguments.length)throw"When using GameUIOptions as argument to GameUIController constructor you should not use extraComponents of gameUiSettings as parameters anymore.";
g=a}else g=new Th,g.wk=arguments[0],g.Qm=arguments[1],g.yl=arguments[2];var h=null,k=null,l=null,h=g.wk,k=g.Qm,l=g.yl;this.Tg=g;void 0===this.Tg.tm&&(this.Tg.tm=!Cg(O.f));Oh.apply(this,arguments);L(this);this.k=this.visible=!0;k=k||[];h=h||[];this.Uf=2;this.q=l||Vh;this.aq=O.ok;void 0!==this.q.Fa&&(this.aq=this.q.Fa);O.b.Za(this,this.aq);this.jj=this.ij=0;this.q.background.nv&&(this.ij=this.q.background.nv);this.q.background.ov&&(this.jj=this.q.background.ov);this.q.background.elements||(this.Vc=
this.q.background.e);this.q.background.oz?(Ph(this,this.q.background.elements,{}),this.Vc=this.q.background.e):(g=this.q.background.e,l=new Oh,Ph(l,this.q.background.elements,[]),g||this.Fa!==O.ji?(this.Vc=new y(g.width,g.height),z(this.Vc),g.o(0,0,0),l.$j(-this.ij,-this.jj),B(this.Vc)):(r.jb(O.b.Xd(this.Fa)),l.Pa()));this.Yq=0;b("score",this.q.ds)?(this.ul=new Wh(this,this.q.ds,"SCORE",0,!0),this.q.xx&&new Qh(this,this.q.xx)):this.ul=new Xh(0,0);this.kf=b("highScore",this.q.Pq)?new Wh(this,this.q.Pq,
"HIGHSCORE",0,!1):new Xh(0,0);b("highScore",this.q.Sq)&&new Qh(this,this.q.Sq);b(["stage","level"],this.q.Sx)&&new Wh(this,this.q.Sx,"STAGE",0,!1);b("lives",this.q.sr)&&new Wh(this,this.q.sr,"LIVES",0,!1);this.Ui=b("time",this.q.time)?new Wh(this,this.q.time,"TIME",0,!1,function(a){return Yh(a)}):new Xh(0,0);this.Ui.Hf(36E4);if(this.q.kd&&this.q.$r)throw"Don't define both progress and progressFill in your game_ui settings";b("progress",this.q.kd)?this.q.kd.round?new Zh(this,this.q.kd):new $h(this,
this.q.kd):b("progress",this.q.$r)&&new $h(this,this.q.$r);b("lives",this.q.Oq)&&new Qh(this,this.q.Oq);b("difficulty",this.q.I)?new Rh(this,ai().toUpperCase(),this.q.I):ai();b("difficulty",this.q.rg)&&(g=ad,g=(this.q.rg.images?this.q.rg.images:[bd,ad,$c])[Eg()],this.q.rg.e||(this.q.rg.e=g),this.yu=new Qh(this,this.q.rg),this.yu.ls(g));this.q.we&&!this.q.we.length&&(this.q.we=[this.q.we]);this.q.Dd&&!this.q.Dd.length&&(this.q.Dd=[this.q.Dd]);this.br=[];this.cr=[];this.br[0]=b(["item","item0"],this.q.we)?
new Qh(this,this.q.we[0]):new Xh(0,"");this.cr[0]=b(["item","item0"],this.q.Dd)?new Rh(this,"",this.q.Dd[0]):new Xh(0,"");if(this.q.we&&this.q.Dd)for(g=1;g<this.q.Dd.length;++g)b("item"+g,this.q.Dd[g])&&(this.cr[g]=new Rh(this,"0 / 0",this.q.Dd[g]),this.br[g]=new Qh(this,this.q.we[g]));for(var n in this.q)g=this.q[n],g.M&&new Rh(this,O.i.r(g.M,"<"+g.M+">")+(g.separator?g.separator:""),g);this.rr=this.Ws=0;this.buttons={};for(n in this.q.buttons)g=bi(this,this.q.buttons[n]),this.buttons[n]=g;this.q.Uw&&
(g=bi(this,this.q.Uw),this.buttons.pauseButton=g);this.Gm={};for(n in this.q.Gm)g=this.q.Gm[n],g=new ci[g.zz](this,g),this.Gm[n]=g;this.Cb=this.Bb=0}ig(Oh,Uh);var ci={};function bi(a,b){var c=new di(a,b,b.X);a.wc.push(c);c.Rz=b;return c}e=Uh.prototype;e.vo=function(a,b){this.buttons[b||"pauseButton"].vo(a)};function Yh(a){var b=Math.floor(a%6E4/1E3);return Math.floor(a/6E4)+(10>b?":0":":")+b}e.setTime=function(a){this.Ui.Hf(a);return this};e.getTime=function(){return this.Ui.da()};
e.qm=function(a){a=this.ul.da()+a;this.ul.Hf(a);this.Tg.tm&&(this.kf.da()<a?this.kf.Hf(a):a<this.kf.da()&&this.kf.Hf(Math.max(a,this.Yq)));return this};e.yb=function(){Oh.prototype.yb.apply(this,arguments);r.jb(this.canvas);r.clear();for(var a in this.buttons)K.p(this.buttons[a])};
e.pa=function(a){1===this.Uf&&this.setTime(this.getTime()+a);if(2===this.Uf){if(this.Ws&&1E3*this.Ws>=this.getTime()){var b=Math.floor(this.getTime()/1E3),c=Math.floor(Math.max(this.getTime()-a,0)/1E3);b!==c&&(b=this.Ui,b.nc.m=0,b.nc.Gl=!0,b.font.setFillColor(b.nc.color),b.De(),"undefined"!==typeof a_gameui_timewarning_second&&J.play(a_gameui_timewarning_second))}this.setTime(Math.max(this.getTime()-a,0))}Oh.prototype.pa.apply(this,arguments);this.rr+=a};
e.$j=function(a,b){this.Vc&&(this.Vc instanceof x?this.Vc.bd(0,a+this.ij,b+this.jj,1):this.Vc.bd(a+this.ij,b+this.jj,1));Oh.prototype.$j.apply(this,arguments);this.Jm&&this.Vc&&oa(a,b,this.Vc.width,this.Vc.height,"blue",!0)};
function ei(a,b,c,d,g,h){this.f=a;this.width=g;this.height=h;this.Ma=null;this.x=c;this.y=d;this.visible=!0;this.a=b;this.alpha=void 0!==b.alpha?b.alpha:1;this.scale=void 0!==b.scale?b.scale:1;this.O={};this.O.Bb=0;this.O.Cb=0;this.O.scale=this.scale;this.O.alpha=this.alpha;this.O.Na=0;this.D={};this.D.be=!1;this.D.origin={};this.D.target={};this.D.m=0;this.a.fk&&(fi(this,this.a.fk),this.D.be=!1);this.f.wc.push(this);gi||(gi={oc:function(a){a.value instanceof y?a.Ma=a.value:(a.e=a.value,a.Eb=0)},
update:$.Ud,dc:$.Sd,end:$.Td,Ec:M,Fc:M,Dc:function(a,b,c,d){return 1-Zb(a,b,c,d)},ak:function(a,b,c,d){return 1*Zb(a,b,c,d)+1},bk:function(a,b,c,d){return 1*Zb(a,b,c,d)+1}})}var gi;
function fi(a,b){a.D.origin.x=void 0===b.x?a.x:b.x;a.D.origin.y=void 0===b.y?a.y:b.y;a.D.origin.alpha=void 0!==b.alpha?b.alpha:1;a.D.origin.scale=void 0!==b.scale?b.scale:1;a.D.target.x=a.x;a.D.target.y=a.y;a.D.target.alpha=a.alpha;a.D.target.scale=a.scale;a.D.duration=b.duration;a.D.be=!0;a.D.se=b.se||Zb;a.D.m=0;a.D.ya=b.ya||0;hi(a)}
function hi(a){a.D.m>=a.D.duration&&(a.D.m=a.D.duration,a.D.be=!1);var b=a.D.se(a.D.m,a.D.origin.x,a.D.target.x-a.D.origin.x,a.D.duration),c=a.D.se(a.D.m,a.D.origin.y,a.D.target.y-a.D.origin.y,a.D.duration);a.O.Bb=b-a.x;a.O.Cb=c-a.y;a.O.alpha=a.D.se(a.D.m,a.D.origin.alpha,a.D.target.alpha-a.D.origin.alpha,a.D.duration);a.O.scale=a.D.se(a.D.m,a.D.origin.scale,a.D.target.scale-a.D.origin.scale,a.D.duration);a.f.Kb=!0}e=ei.prototype;
e.Pa=function(a,b){this.Ma&&this.Ma.za(this.x+this.O.Bb+a,this.y+this.O.Cb+b,this.O.scale,this.O.scale,0,this.O.alpha)};e.sk=function(a,b){ii(this.x+this.O.Bb+a,this.y+this.O.Cb+b,this.width*this.O.scale,this.height*this.O.scale)};e.Gk=function(a,b){return a>this.x+this.O.Bb&&a<this.x+this.O.Bb+this.width*this.O.scale&&b>this.y+this.O.Cb&&b<this.y+this.O.Cb+this.height*this.O.scale};e.wo=function(a){this.visible!==a&&(this.visible=a,this.f.Kb=!0)};
e.pa=function(a){this.D.be&&(0<this.D.ya?this.D.ya-=a:(this.D.m+=-this.D.ya,this.D.ya=0,this.D.m+=a,hi(this)))};function Xh(a,b){this.kd=this.value=this.Ck=b}e=Xh.prototype;e.Hf=function(a){this.value=a};e.da=function(){return this.value};e.ls=function(){};e.ks=function(){};e.js=function(){};
function Qh(a,b){this.Zn=b;this.a={};for(var c in b)this.a[c]=b[c];this.e=this.a.e;this.F=0;this.xd=this.a.xd;this.a.WA&&(this.a.x+=this.e.Gb,this.a.y+=this.e.Hb);ei.call(this,a,this.a,this.a.x,this.a.y,this.e?this.e.width:1,this.e?this.e.height:1)}ig(ei,Qh);ci.GameUIImage=Qh;function ji(a,b){a.F!==b&&(a.F=b,a.f.Kb=!0)}e=Qh.prototype;
e.Pa=function(a,b){this.e&&(this.xd&&(a+=-Math.floor(this.e.width/2),b+=-Math.floor(this.e.height/2)),this.e instanceof x?this.e.za(this.F,this.x+a+this.O.Bb,this.y+b+this.O.Cb,this.O.scale,this.O.scale,0,this.O.alpha):this.e.za(this.x+a+this.O.Bb,this.y+b+this.O.Cb,this.O.scale,this.O.scale,0,this.O.alpha),this.f.Jm&&oa(this.x+a-this.e.Gb+1,this.y+b-this.e.Hb+1,this.e.width-2,this.e.height-2,"black",!0))};
e.Gk=function(a,b){if(!this.e)return!1;var c=0,d=0;this.xd&&(c+=-Math.floor(this.e.width/2),d+=-Math.floor(this.e.height/2));c-=this.e.Gb;d-=this.e.Hb;return a>c+this.x+this.O.Bb&&a<c+this.x+this.O.Bb+this.width*this.O.scale&&b>d+this.y+this.O.Cb&&b<d+this.y+this.O.Cb+this.height*this.O.scale};e.sk=function(a,b){this.e&&(this.xd&&(a+=-Math.floor(this.e.width/2),b+=-Math.floor(this.e.height/2)),a-=this.e.Gb,b-=this.e.Hb,ii(this.x+this.O.Bb+a,this.y+this.O.Cb+b,this.width*this.O.scale,this.height*this.O.scale))};
e.mn=function(a){a||(a=new p(0,0));a.x=this.x+O.jf+this.f.Bb;a.y=this.y+O.ue+this.f.Cb;return a};e.ls=function(a){a!==this.e&&(this.e=a,this.f.Kb=!0,this.e&&(this.width=this.e.width,this.height=this.e.height))};
function Rh(a,b,c){"object"===typeof b&&(c=b,b=c.M?O.i.r(c.M,"<"+c.M+">"):c.text||"");this.text=b;this.font=c.font.K();c.te&&C(this.font,c.te);this.Rr=c.x;this.Sr=c.y;this.Qr=c.tb;this.Nw=this.font.fillColor;this.qd=void 0===c.qd?.2:c.qd;ei.call(this,a,c,Math.floor(c.x-.1*c.tb),Math.floor(c.y-.1*c.xb),Math.floor(1.2*c.tb),Math.floor(1.2*c.xb));this.Ma=new y(this.width,this.height);switch(this.font.align){case "left":this.Rf=Math.floor(.1*c.tb);break;case "right":this.Rf=Math.floor(1.1*c.tb);break;
case "center":this.Rf=Math.floor(.6*c.tb);break;default:throw"Unknown alignment: "+this.font.align;}a=Math.floor(this.qd*this.font.fontSize);switch(this.font.h){case "top":this.Sf=Math.floor(.1*c.xb);break;case "bottom":this.Sf=Math.floor(1.1*c.xb)+a;break;case "middle":this.Sf=Math.floor(.6*c.xb)+a;break;default:throw"Unknown baseline: "+this.font.h;}this.nc={};this.nc.color="red";this.nc.duration=200;this.nc.m=0;this.nc.Gl=!1;this.De()}ig(ei,Rh);ci.GameUIText=Rh;
Rh.prototype.pa=function(a){ei.prototype.pa.apply(this,arguments);this.nc.Gl&&(this.nc.m+=a,this.nc.duration<=this.nc.m&&(this.nc.Gl=!1,this.font.setFillColor(this.Nw),this.De()))};
Rh.prototype.De=function(){this.Ma.clear();z(this.Ma);var a=this.font.ba(this.text),b=1;a>this.Qr&&(b=this.Qr/a);this.font.za(this.text,this.Rf,this.Sf,b,b,0,1);this.f.Jm&&(oa(0,0,this.Ma.width,this.Ma.height,"black",!0),oa(this.Rr-this.x,this.Sr-this.y,this.Ma.width-2*(this.Rr-this.x),this.Ma.height-2*(this.Sr-this.y),"red",!0),pa(this.Rf-5,this.Sf,this.Rf+5,this.Sf),pa(this.Rf,this.Sf-5,this.Rf,this.Sf+5));this.f.Kb=!0;B(this.Ma)};function ki(a){return""+a}function li(a,b,c){return b+c}
function Wh(a,b,c,d,g,h){this.value=this.Ck=d||0;this.Wl=-1;this.st=c;this.a=b;this.rt=-99999;this.Oo=b.Oo||0;this.hi=b.hi?b.hi:h||ki;c=li;g&&0!==this.a.iq&&(c=$b);this.Ea=new jg(this.Ck,void 0===this.a.iq?500:this.a.iq,c);b.qg&&(this.qg="game_ui_"+b.qg);this.text=mi(this)+this.hi(this.Ck);Rh.call(this,a,this.text,b)}ig(Rh,Wh);ci.GameUIValue=Wh;e=Wh.prototype;e.Hf=function(a){this.value=a;lg(this.Ea,this.value)};e.ks=function(a){a||(a=ki);this.hi=a;this.aj(!0)};e.js=function(a){this.qg=a;this.aj(!0)};
e.da=function(){return this.value};e.aj=function(a){var b=this.Wl;if(a||K.nk-this.rt>this.Oo)b=this.hi(Math.floor(this.Ea.da()));this.Wl!==b&&(this.rt=K.nk,this.Wl=b,this.text=mi(this)+b,this.De())};e.pa=function(a){Rh.prototype.pa.apply(this,arguments);kg(this.Ea,a);Math.floor(this.Ea.da())!==this.Wl&&this.aj()};function mi(a){var b="";a.a.bj&&(b=a.qg?O.i.r(a.qg,"<"+a.qg.toUpperCase()+">"):O.i.r("game_ui_"+a.st,"<"+a.st+">"));return b+(a.a.separator?a.a.separator:"")}
function $h(a,b){this.xm=this.kd=0;this.a=b;this.Gi=this.Cf=0;this.e=b.e;this.qe=b.qe||b.e;this.xn=b.xn||null;this.a.Af=this.a.Af||0;this.a.Ng=this.a.Ng||0;this.sm=!0;this.ll=b.ll||0;this.L=[];this.Ea=new jg(0,200,N);this.zc=new jg(0,200,N);ei.call(this,a,b,b.x,b.y,this.e.width,this.e.height)}ig(ei,$h);ci.GameUIProgress=$h;
$h.prototype.pa=function(a){kg(this.Ea,a);var b=this.Ea.da();b!==this.Cf&&(this.f.Kb=!0,this.Cf=b);kg(this.zc,a);a=this.zc.da();a!==this.Gi&&(this.f.Kb=!0,this.Gi=a);b+=a;if(this.sm)for(a=0;a<this.L.length;++a){var c=b>=this.L[a].position&&this.kd+this.xm>=this.L[a].position;this.L[a].complete!==c&&(this.a.L&&(this.f.Kb=!0,this.Cf=b),this.L[a].complete=c)}};
$h.prototype.Pa=function(a,b){var c,d,g;if(0===this.ll&&(0<this.zc.da()&&this.qe.ka(0,this.width*this.Ea.da()/100,0,this.qe.width*this.zc.da()/100,this.qe.height,a+this.x+this.width*this.Ea.da()/100,b+this.y),this.e.ka(0,0,0,this.width*this.Ea.da()/100,this.height,a+this.x,b+this.y),this.a.L))for(c=0;c<this.L.length;++c)d=this.L[c],g=d.complete?s_ui_level_star_fill:s_ui_level_star_empty,g.o(0,a+this.x+this.width/100*d.position,b+this.y+this.a.L.y);if(1===this.ll&&(0<this.zc.da()&&this.qe.ka(0,0,this.height-
this.height*this.Ea.da()/100,this.width,this.height,a+this.x,b+this.y+(this.height-this.height*this.Ea.da()/100)),this.e.ka(0,0,this.height-this.height*this.Ea.da()/100,this.width,this.height,a+this.x,b+this.y+(this.height-this.height*this.Ea.da()/100)),this.a.L))for(c=0;c<this.L.length;++c)d=this.L[c],g=d.complete?s_ui_level_star_fill:s_ui_level_star_empty,g.o(0,a+this.x+this.a.L.x,b+this.y+this.height-this.height/100*d.position);if(2===this.ll&&(0<this.zc.da()&&this.qe.ka(0,0,this.height*this.Ea.da()/
100,this.qe.width,this.qe.height*this.zc.da()/100,a+this.x+this.width*this.Ea.da()/100,b+this.y),this.e.ka(0,0,0,this.width,this.height*this.Ea.da()/100,a+this.x,b+this.y),this.a.L))for(c=0;c<this.L.length;++c)d=this.L[c],g=d.complete?s_ui_level_star_fill:s_ui_level_star_empty,g.o(0,a+this.x+this.a.L.x,b+this.y+this.height/100*d.position);this.xn&&this.xn.o(0,a+this.x+this.a.Af,b+this.y+this.a.Ng)};function di(a,b,c){this.Tl=!1;this.Wi=-1;this.f=a;this.a=b;this.vo(c);Qh.call(this,a,b)}ig(Qh,di);
ci.GameUIButton=di;di.prototype.vo=function(a){var b=null,c=null,d=this.f,g=this.a;void 0===a&&(a=g.X?g.X:0);switch(a){case 0:b=d.Tg.hk?nd:od;c=function(){Cg(O.f)?O.f.Vg(!1,!0,d.Tg.hk):O.f.Vg();return!0};break;case 1:b=pd;c=function(){O.f.Vg();return!0};break;case 2:b=s_btn_small_quit;c=function(){ni(d.Tg.hk);return!0};break;case 3:b=g.e}this.mb=c;this.a.e=b};di.prototype.zb=function(a,b,c){return this.Gk(b-O.jf,c-O.ue)?(this.Tl=!0,this.Wi=a,ji(this,1),!0):!1};
di.prototype.pa=function(a){Qh.prototype.pa.apply(this,arguments);this.Tl&&(this.Gk(K.ha[this.Wi].x-O.jf,K.ha[this.Wi].y-O.ue)?ji(this,1):ji(this,0))};di.prototype.Tb=function(a,b,c){return this.Tl&&a===this.Wi?(ji(this,0),this.Gk(b-O.jf,c-O.ue)&&this.mb&&this.mb(),this.Tl=!1,this.Wi=-1,!0):!1};
function Zh(a,b){this.xm=this.kd=0;this.a=b;this.Gi=this.Cf=0;this.sm=!0;this.L=[];this.color=b.color||"#00AEEF";this.Mp=b.Mp||"#FF0F64";this.Lp=b.Lp||"#FFED93";this.fu=void 0===b.blink||b.blink;this.Lc=b.Lc;this.Rh=!1;this.Ue=0;this.Gj=1E3;this.Hj=0;this.Ea=new jg(0,200,N);this.zc=new jg(0,200,N);ei.call(this,a,b,b.x,b.y,1,1)}ig(ei,Zh);ci.GameUIRoundProgress=Zh;
Zh.prototype.pa=function(a){kg(this.Ea,a);var b=this.Ea.da();b!==this.Cf&&(this.f.Kb=!0,this.Cf=b);kg(this.zc,a);var c=this.zc.da();c!==this.Gi&&(this.f.Kb=!0,this.Gi=c);this.Rh&&(this.Ue+=a,this.Ue>=this.Gj?100===this.kd?(this.Rh=!1,this.fu&&(this.Rh?this.Ue-=this.Gj:(this.Rh=!0,this.Hj=this.Ue=0,lg(this.Ea,100)))):(this.Rh=!1,this.Hj=0,this.Ea.xg=0,this.Ea.Ql=0,lg(this.Ea,this.kd)):this.Hj=(-Math.cos(this.Ue/this.Gj*5*Math.PI*2)+1)/2,this.f.Kb=!0);b+=c;if(this.sm)for(a=0;a<this.L.length;++a)c=b>=
this.L[a].position&&this.kd+this.xm>=this.L[a].position,this.L[a].complete!==c&&(this.a.L&&(this.f.Kb=!0,this.Cf=b),this.L[a].complete=c)};Zh.prototype.sk=function(a,b){this.Lc&&ii(this.x+this.O.Bb+a-this.Lc.Gb,this.y+this.O.Cb+b-this.Lc.Hb,this.Lc.width*this.O.scale,this.Lc.height*this.O.scale)};
Zh.prototype.Pa=function(a,b){var c,d;if(this.Lc){d=this.Ea.da()/100;d=Math.max(d,0);d=Math.min(d,1);var g=r.context,h=this.Lc.width/2-P(4),k=g.fillStyle;if(0<this.zc.da()){var l=this.zc.da()/100;g.beginPath();g.arc(this.x+a,this.y+b,h,.5*-Math.PI+2*d*Math.PI,2*(d+l)*Math.PI-.5*Math.PI,!1);g.lineTo(this.x+a,this.y+b);g.fillStyle=this.Mp;g.fill()}g.beginPath();g.arc(this.x+a,this.y+b,h,.5*-Math.PI,2*d*Math.PI-.5*Math.PI,!1);g.lineTo(this.x+a,this.y+b);g.fillStyle=this.color;g.fill();this.Gj&&(l=g.globalAlpha,
g.globalAlpha*=this.Hj,g.beginPath(),g.arc(this.x+a,this.y+b,h,.5*-Math.PI,2*d*Math.PI-.5*Math.PI,!1),g.lineTo(this.x+a,this.y+b),g.fillStyle=this.Lp,g.fill(),g.globalAlpha=l);if(this.a.L){var l=g.strokeStyle,n=g.lineWidth;g.strokeStyle="white";g.lineWidth=P(2);for(d=0;d<this.L.length;++d){c=this.L[d];c=c.position/100*Math.PI*2;var q=Math.cos(-.5*Math.PI+c)*h;c=Math.sin(-.5*Math.PI+c)*h;g.beginPath();g.moveTo(Math.round(a+this.x),Math.round(b+this.y));g.lineTo(Math.round(a+this.x+q),Math.round(b+
this.y+c));g.stroke()}g.strokeStyle=l;g.lineWidth=n}this.Lc.o(0,a+this.x,b+this.y);if(this.a.L)for(d=0;d<this.L.length;++d)c=this.L[d],h=c.complete?s_star_filled:s_star_empty,c=c.position/100*Math.PI*2,h.o(0,Math.round(a+this.x+Math.cos(-.5*Math.PI+c)*this.a.L.jx*.5),Math.round(b+this.y+Math.sin(-.5*Math.PI+c)*this.a.L.jx*.5));g.fillStyle=k}};O.version=O.version||{};O.version.game_ui="2.1.0";
var oi=oi||{},pi={background:{e:Zc},buttons:{pauseButton:{x:P(530),y:P(12),X:0}},I:{x:P(416),y:P(80),tb:P(110),xb:P(28),qd:.2,bj:!0,separator:": ",font:of,te:{fillColor:"#5E83B0",fontSize:P(16),align:"left",h:"middle"}},rg:{x:P(400),y:P(92),e:ad,xd:!0},Pq:{x:P(152),y:P(80),tb:P(234),xb:P(28),qd:.2,bj:!0,separator:": ",font:of,te:{fillColor:"#5E83B0",fontSize:P(16),align:"left",h:"middle"}},Sq:{x:P(134),y:P(90),e:cd,xd:!0},sr:{x:P(58),y:P(72),tb:P(66),xb:P(30),qd:.2,bj:!1,separator:"x ",font:pf,te:{align:"left",
fontSize:P(26),fillColor:"#5E83B0"},$h:!0},Oq:{x:P(40),y:P(90),e:dd,$h:!0,xd:!0},ds:{x:P(16),y:P(14),tb:P(94),xb:P(66),Oo:50,qd:.2,bj:!0,separator:"\n",font:pf,te:{fillColor:"#5E83B0"}},time:{x:P(148),y:P(10),tb:P(350),xb:P(68),qd:.2,bj:!1,separator:"",font:qf},Dd:[{x:P(58),y:P(78),tb:P(66),xb:P(30),qd:.2,font:pf,te:{align:"left",fontSize:P(26),fillColor:"#5782AE"},$h:!0},{x:P(168),y:P(78),tb:P(66),xb:P(30),qd:.2,font:pf,te:{align:"left",fontSize:P(26),fillColor:"#5782AE"},$h:!0},{x:P(278),y:P(78),
tb:P(66),xb:P(30),qd:.2,font:pf,te:{align:"left",fontSize:P(26),fillColor:"#5782AE"},$h:!0}],we:[{x:P(40),y:P(90),e:null,xd:!0},{x:P(150),y:P(90),e:null,xd:!0},{x:P(260),y:P(90),e:null,xd:!0}]},Vh=pi,$={Nl:{},Os:{},Ps:{},Qs:{},Un:{},Vn:{},sy:{},jv:{},It:function(){$.Nl={oc:$.Uj,update:$.Ud,dc:$.Sd,end:$.Td,font:tf,margin:20,Ec:M,Fc:M,Dc:dc([Zb,Ub,Zb],[!1,!1,!0],[.1,.8,.1])};$.Os={oc:$.Uj,update:$.Ud,dc:$.Sd,end:$.Td,font:uf,margin:20,Ec:M,Fc:M,Dc:dc([Zb,Ub,Zb],[!1,!1,!0],[.1,.8,.1])};$.Ps={oc:$.Uj,
update:$.Ud,dc:$.Sd,end:$.Td,font:vf,margin:20,Ec:M,Fc:M,Dc:dc([Zb,Ub,Zb],[!1,!1,!0],[.1,.8,.1])};$.Qs={oc:$.Uj,update:$.Ud,dc:$.Sd,end:$.Td,font:wf,margin:20,Ec:M,Fc:M,Dc:dc([Zb,Ub,Zb],[!1,!1,!0],[.1,.8,.1])};$.Un={oc:$.su,update:$.Ud,dc:$.Sd,end:$.Td,fi:xf,ei:yf,margin:20,Ec:M,Fc:M,Dc:dc([Zb,Ub,Zb],[!1,!1,!0],[.1,.8,.1])};$.Vn={oc:$.tu,update:$.Ud,dc:$.Sd,end:$.Td,fi:xf,ei:yf,margin:20,Ec:M,Fc:M,Dc:dc([Zb,Ub,Zb],[!1,!1,!0],[.1,.8,.1])};$.sy={oc:$.uu,update:$.Ud,dc:$.Sd,end:$.Td,Ec:M,Fc:M,Dc:dc([Zb,
Ub,Zb],[!1,!1,!0],[.1,.8,.1])};$.jv={oc:$.ru,update:$.Ud,dc:$.Sd,end:$.Td,Ec:M,Fc:M,Dc:dc([Zb,Ub,Zb],[!1,!1,!0],[.1,.8,.1])}},Vp:function(a){function b(a){var d,g={};for(d in a)g[d]="object"===typeof a[d]&&null!==a[d]?b(a[d]):a[d];return g}return b(a)},NA:function(a){$.Nl.font.v=a;$.Os.font.v=a;$.Ps.font.v=a;$.Qs.font.v=a},MA:function(a){$.Un.fi.v=a;$.Un.ei.v=a;$.Vn.fi.v=a;$.Vn.ei.v=a},ph:!1,$b:[],is:function(a){$.ph=a},Tz:function(){return $.ph},ox:function(a){var b,c;for(b=0;b<$.$b.length;b+=1)c=
$.$b[b],void 0===c||void 0!==a&&c.kind!==a||0<c.Sg||($.$b[b]=void 0)},Ht:function(){$.ph=!1;$.$b=[]},rh:function(a,b,c,d){var g,h,k;void 0===d&&(d=$.ph);if(d)for(h=0;h<$.$b.length;h+=1)if(g=$.$b[h],void 0!==g&&g.xe&&g.kind===a&&g.font===b&&g.text===c)return g.Sg+=1,h;g={kind:a,font:b,text:c,Sg:1,xe:d};h=b.align;k=b.h;F(b,"center");G(b,"middle");d=b.ba(c)+2*a.margin;a=b.V(c)+2*a.margin;g.Ma=new y(d,a);z(g.Ma);b.o(c,d/2,a/2);B(g.Ma);F(b,h);G(b,k);for(h=0;h<$.$b.length;h+=1)if(void 0===$.$b[h])return $.$b[h]=
g,h;$.$b.push(g);return $.$b.length-1},Gt:function(a){var b=$.$b[a];b.Sg-=1;0>=b.Sg&&!b.xe&&($.$b[a]=void 0)},Uj:function(a){a.buffer=$.rh(a.kind,a.kind.font,a.value,a.xe)},su:function(a){var b=a.value.toString();a.buffer=0<=a.value?$.rh(a.kind,a.kind.fi,b,a.xe):$.rh(a.kind,a.kind.ei,b,a.xe)},tu:function(a){var b=a.value.toString();0<a.value&&(b="+"+b);a.buffer=0<=a.value?$.rh(a.kind,a.kind.fi,b,a.xe):$.rh(a.kind,a.kind.ei,b,a.xe)},uu:function(a){a.Ma=a.value},ru:function(a){a.e=a.value;a.Eb=0},Ud:function(a){a.x=
void 0!==a.kind.Ec?a.kind.Ec(a.time,a.El,a.mq-a.El,a.duration):a.El+a.time/a.duration*(a.mq-a.El);a.y=void 0!==a.kind.Fc?a.kind.Fc(a.time,a.Fl,a.nq-a.Fl,a.duration):a.Fl+a.time/a.duration*(a.nq-a.Fl);void 0!==a.kind.ak&&(a.Df=a.kind.ak(a.time,0,1,a.duration));void 0!==a.kind.bk&&(a.Ef=a.kind.bk(a.time,0,1,a.duration));void 0!==a.kind.Dc&&(a.alpha=a.kind.Dc(a.time,0,1,a.duration));void 0!==a.kind.Cu&&(a.Na=a.kind.Cu(a.time,0,360,a.duration)%360);void 0!==a.e&&(a.Eb=a.time*a.e.F/a.duration)},Sd:function(a){var b=
r.context,c;void 0!==a.e&&null!==a.images?1===a.Df&&1===a.Ef&&0===a.Na?a.e.bd(Math.floor(a.Eb),a.x,a.y,a.alpha):a.e.za(Math.floor(a.Eb),a.x,a.y,a.Df,a.Ef,a.Na,a.alpha):(c=void 0!==a.Ma&&null!==a.Ma?a.Ma:$.$b[a.buffer].Ma,1===a.Df&&1===a.Ef&&0===a.Na?c.bd(a.x-c.width/2,a.y-c.height/2,a.alpha):1E-4>Math.abs(a.Df)||1E-4>Math.abs(a.Ef)||(b.save(),b.translate(a.x,a.y),b.rotate(-a.Na*Math.PI/180),b.scale(a.Df,a.Ef),c.bd(-c.width/2,-c.height/2,a.alpha),b.restore()))},Td:function(a){void 0!==a.buffer&&$.Gt(a.buffer)},
mc:function(a){var b,c,d=!1;for(b=0;b<$.vb.length;b+=1)c=$.vb[b],void 0!==c&&(0<c.ya?(c.ya-=a,0>c.ya&&(c.time+=-c.ya,c.ya=0)):c.time+=a,0<c.ya||(c.time>=c.duration?(c.kind.end(c),$.vb[b]=void 0):c.kind.update(c),d=!0));d&&($.canvas.Z=!0)},Pa:function(){var a,b;for(a=0;a<$.vb.length;a+=1)b=$.vb[a],void 0!==b&&(0<b.ya||b.kind.dc(b))},vb:[],Xq:function(a,b,c){$.Hu();void 0===a&&(a=O.Xm);void 0===b&&(b=-1E6);void 0===c&&(c=["game"]);$.visible=!0;$.k=!0;O.b.Za($,a);$.depth=b;L($);Ib($,c);$.Ht();$.It()},
Nt:function(a,b,c,d,g,h,k,l,n){void 0===l&&(l=void 0!==a.ya?a.ya:0);void 0===n&&(n=$.ph);void 0===g&&void 0!==a.rw&&(g=c+a.rw);void 0===h&&void 0!==a.sw&&(h=d+a.sw);void 0===k&&void 0!==a.duration&&(k=a.duration);a={kind:a,value:b,El:c,Fl:d,mq:g,nq:h,x:c,y:d,Df:1,Ef:1,alpha:1,Na:0,time:0,duration:k,ya:l,xe:n};a.kind.oc(a);for(b=0;b<$.vb.length;b+=1)if(void 0===$.vb[b])return $.vb[b]=a,b;$.vb.push(a);return $.vb.length-1},HA:function(a){var b;0>a||a>=$.vb.length||(b=$.vb[a],void 0!==b&&(b.kind.end(b),
$.vb[a]=void 0))},nx:function(){var a,b;for(a=0;a<$.vb.length;a+=1)b=$.vb[a],void 0!==b&&(b.kind.end(b),$.vb[a]=void 0);$.vb=[]},Hu:function(){$.nx();$.ox();K.p($)}},qi=P(12),ri=P(8),si=P(84),ti=P(84);LevelMapIcons={Tu:function(a,b){var c=new y(hd.width,hd.height),d=si/ti,g=a.width/a.height;z(c);d<g?(d=g*si,g=ti):(d=si,g=ti/g);a.hq(0,qi-(d-si)/2,ri-(g-ti)/2,d,g,1);b?gd.o(0,0,0):hd.o(0,0,0);B(c);return c}};O.version=O.version||{};O.version.game="1.4.1";
function ui(a){this.depth=9E3;this.k=this.visible=!0;this.group=0;this.Gl=!1;this.w=void 0;L(this);var b=new Th,c,d=Cg(O.f);d?(O.j.Ff="time",O.j.af="min",b.hk=!1,b.Qm=["time"],b.yl=oi.gz,void 0!==d.eu?c=1E3*d.Qg[d.eu]:(c=0,b.wk=["highScore"])):(b.wk=["difficulty"],b.yl=pi,c=Mh(this.Kk));this.Ta=new Uh(b);d&&(this.Ta.kf.ks(Yh),this.Ta.kf.js("game_ui_TIME_TO_BEAT"));c||(c=0);b=this.Ta;b.kf.Hf(c);b.Yq=c;this.w=new vi(0,0,0,this);this.Kk=a;this.sc=!0;this.w.pause=!1;this.Ta.Uf=0;if(c=Cg(O.f)){this.Ta.setTime(0);
a=[];for(b=0;b<O.a.n.rf.length;++b)O.a.n.rf[b].I.I===Eg()&&a.push(b);this.Kk=c.lx%a.length}else this.Ta.setTime(O.a.n.rf[a].wa.time);a=this.w;c=O.a.n.rf[a.f.Kk];var g,h=null,k,l,n=c.Ja,q=c.Ka;for(k=0;k<c.height;++k)for(l=0;l<c.width;++l)if(d=l,g=k,h=n[k][l]," "!==h){var w=1;" "!==q[k][l]&&(w=parseInt(q[k][l],10));switch(h){case "F":g+=.5;break;case "Q":wi(a,d-.5,g-.5,w+1,h),h="N"}for(b=1;b<=w;b+=1)wi(a,d,g,b,h)}xi(a,1);if(!a.Yk)throw"Finished parsing with unequal amount of tiles. Level is playable, but unfinishable.";
a.vj=!0;a.Al();a.l=yi(a);zi(a);Ai(a);Bi(a,0);a.Rl=new Ci(0,0,-Number.MAX_VALUE,a,1);this.Mq=!1}ui.prototype.qm=function(a){this.Ta.qm(a)};ui.prototype.yb=function(){void 0!==this.w&&(Di(this.w),K.p(this.w));this.Ta&&(K.p(this.Ta),this.Ta=null);r.jb(O.b.Xd(O.gf));r.clear()};function Ei(a){a.sc&&(Cg(O.f)?Fi(O.f,a.Ta.getTime()/1E3):Gi(O.f,{totalScore:a.Ta.ul.da(),timeLeft:Yh(a.Ta.Ui.da()),timeBonus:Math.round(O.a.n.wa.gu*(a.Ta.getTime()/1E3))}),a.sc=!1)}
function Hi(a,b,c,d,g,h,k){this.depth=c;this.k=this.visible=!0;this.group=0;this.a=O.a.n.Ok;O.b.Za(this,O.gf);this.x=a;this.y=b;this.alpha=0;this.e=d;this.w=g;this.ad=-1;this.Ig=this.Ed=this.wf=this.Jg=void 0;this.type=h;this.pu=0;this.io=-1;this.yk=!1;this.Cg=0;this.scale=1;this.gs=!0;this.fb=k;this.Ji=this.Uh=0;L(this)}e=Hi.prototype;e.yb=function(){this.w.ti===this&&(this.w.ti=void 0)};
e.zb=function(a,b,c){if(-1===this.ad){var d;a=b-O.ni;c-=O.oi;b=this.a.Tf;d=this.a.eh;a>this.x&&a<this.x+b&&c>this.y&&c<this.y+d&&this.w.kh.push(this)}};
e.mc=function(a){0<this.ad&&(this.ad-=.001*a,this.gs&&(this.gs=!1),0>=this.ad&&this.w.p(this));if(this.yk)if(0>=this.zk){var b=Sd.F;this.yn=Math.floor(this.Cg/O.a.n.mf.Qd);this.Cg>=b*O.a.n.mf.Qd&&(this.yn=-1,this.Cg=0,this.zk=O.a.n.mf.Vq);this.Cg+=a}else this.zk-=a;this.w.Mc!==this||this.w.pause||(this.to+=a,this.Gx=Math.floor(this.to/O.a.n.uo.Qd%Td.F))};e.xl=function(){this.Cg=0;this.yk=!0;this.zk=O.a.n.mf.Vq};function Ii(a,b){var c;c=!1;b.e===a.e&&b!==a&&-1===a.ad&&-1===b.ad&&(c=!0);return c}
function Ji(a,b,c,d){a.ad=1;a.w.hA=-1;void 0!==a.Jg&&(a.Jg.wf=void 0);void 0!==a.wf&&(a.wf.Jg=void 0);void 0!==a.Ig&&(a.Ig.Ed=void 0);Ki(a.w,a);if(b){Ai(a.w);Li(a.w);var g=a.w;b=a.w.We+1;g.ug=g.a.Ku;g.We=b;3<g.We&&(g.We=3);if(0<g.We){var h=g.We;b=g.uq.x+O.ni;var g=g.uq.y+O.oi,k=Mi,l=null,n=null;switch(h){case 1:l="undefined"!==typeof Cf?Cf:null;h=O.i.r("floater_1","<floater_1>");n="undefined"!==typeof a_nice?a_nice:null;break;case 2:l="undefined"!==typeof Bf?Bf:null;h=O.i.r("floater_2","<floater_2>");
n="undefined"!==typeof a_great?a_great:null;break;case 3:l="undefined"!==typeof Af?Af:null;h=O.i.r("floater_3","<floater_3>");n="undefined"!==typeof a_awesome?a_awesome:null;break;default:throw"Unknown floater type: "+h;}n&&J.play(n,0);k.ec.font=l;k.a.offsetY&&(g+=k.a.offsetY);$.Nt(k.ec,h,b,g,b,g+k.dt,k.bt,0,!0)}}else Ai(a.w),a.w.uq=new p(a.x,a.y);a.w.f.qm(O.a.n.wa.By);void 0!==c&&new Ni(a.x,a.y,0,a.w,c,d)}
function Oi(a){var b,c=!1;void 0===b&&(b=0);void 0===a.rb(0,b)&&void 0===a.rb(2,b)&&void 0===a.rb(1,b)?(a.Jg=a.w.rb(0,a),a.wf=a.w.rb(1,a),a.Ed=a.w.rb(2,a),a.Ig=a.w.rb(3,a),void 0===a.rb(0,b)?c=!0:void 0===a.rb(2,b)&&(c=!0),void 0!==a.rb(1,b)&&(c=!1)):void 0!==a.rb(0,b)&&void 0!==a.rb(2,b)||void 0!==a.rb(1,b)||(c=!0);2!==a.w.l.length||0!==a.w.de.length||void 0===a.w.l[0].Ed&&void 0===a.w.l[1].Ed||(a.w.l[0].x=3*a.a.Tf,a.w.l[0].y=2*a.a.eh,a.w.l[1].x=4*a.a.Tf,a.w.l[1].y=2*a.a.eh,Ai(a.w));return c}
e.rb=function(a,b){var c;switch(a){case 0:c=this.Jg;break;case 1:c=this.Ed;break;case 2:c=this.wf;break;case 3:c=this.Ig;break;default:throw"Unknown dir: "+a;}return 0===b?c:void 0!==c?void 0!==c.e?c:void 0:void 0};
e.Pa=function(){var a;(a=1===this.fb)||"Q"!==this.type&&!this.Ig.wf||(a=!0);this.e&&(0>this.ad&&(this.e.gq(0,0,0,a?this.e.width:P(70),this.e.height,Math.round(this.x),Math.round(this.y),this.scale,this.scale,0,this.alpha),this.w.Mc!==this||this.w.pause||Td.o(this.Gx,Math.round(this.x-O.a.n.uo.fp),Math.round(this.y-O.a.n.uo.ip)),this.yk&&-1<this.yn&&!this.w.pause&&Sd.o(this.yn,Math.round(this.x-O.a.n.mf.fp),Math.round(this.y-O.a.n.mf.ip))),this.Ed&&"Q"!==this.Ed.type&&(a=.75*this.alpha,Rd.bd(0,Math.round(this.x),
Math.round(this.y),a)))};function vi(a,b,c,d){this.depth=c;this.k=this.visible=!0;this.group=0;this.x=a;this.y=b;this.f=d;this.uj=0;this.We=this.fg=-1;this.yd=1;this.Zh=void 0;this.tq=!0;this.hf=this.ug=-1;this.l=[];this.ti=this.e=void 0;this.Cd=[];this.Hk=0;this.pause=this.Yk=!0;this.rl=0;this.a=O.a.n.Ok;this.Mi=!1;this.Wg=-1;this.Jf=!0;this.de=[];this.kh=[];O.b.Za(this,O.gf);a=Cg(O.f);this.kx=new ea(a?a.lx:void 0);L(this)}e=vi.prototype;e.Sb=function(){};e.yb=function(){Di(this)};
e.pa=function(){this.canvas.Z=!0};
function Pi(a){var b,c;b=void 0;for(c=0;c<a.kh.length;c+=1)void 0===b?b=a.kh[c]:b.depth>a.kh[c].depth&&(b=a.kh[c]);if(void 0!==b){var d,g;c=!0;g=new Qi(0,0,0);if(!b.w.pause&&1>b.w.yd){if(void 0!==b.w.Mc&&0>b.ad&&Ii(b,b.w.Mc)&&Oi(b.w.Mc)&&Oi(b)){J.play(Hf);c=!1;d=Mb(K,b.w.Mc.e,0,0,b.w.Mc.x,b.w.Mc.y,b.w.Mc.depth,void 0);g.Bl=0;g.Oi=0;Ji(b,!1,b.w.Mc,d);Ji(b.w.Mc,!0,void 0,void 0);b.w.Mc=void 0;d=b.w;for(g=0;g<d.l.length;g+=1)d.l[g].yk=!1;d.ti=void 0}c&&Oi(b)&&0>b.ad&&(b.w.Mc=b,b.to=0,J.play(Gf))}}a.kh=
[]}
e.mc=function(a){this.pause||(this.uj+=.001*a,this.xl(),Ri(this,1,a),Pi(this));if(0<this.fg&&(this.fg-=.001*a,0>=this.fg)){this.fg=-1;var b=[{Nq:O.i.r("ShuffleConfirmBtnHeader","<SHUFFLE_CONFIRM_BTN_HEADER>"),text:O.i.r("ShuffleConfirmBtnText","<SHUFFLE_CONFIRM_BTN_TEXT>"),R:this.ey,aa:this}],c;if(void 0===Cg(O.f))c={Nq:O.i.r("ShuffleRestartBtnHeader","<SHUFFLE_RESTART_BTN_HEADER>"),text:O.i.r("ShuffleRestartBtnText","<SHUFFLE_RESTART_BTN_TEXT>"),R:function(){this.$c.close();K.p(this.f);O.fb=new ui(this.f.Kk)},aa:this};
else{var d=this,g=function(a){a?d.$c.close():d.$c.show()};c={Nq:O.i.r("optionsChallengeForfeit","<SHUFFLE_RESTART_BTN_HEADER>"),text:O.i.r("optionsChallengeForfeit","<SHUFFLE_RESTART_BTN_TEXT>"),R:function(){var a=d.$c,b,c;for(b=0;b<a.buttons.length;b++)c=a.buttons[b],c.wo(!1);a.c.visible=!1;ni(!1,g)},aa:this}}b.push(c);this.$c=new rh(O.i.r("ShuffleConfirmationText","<SHUFFLE_CONFIRM_TEXT>"),b,void 0===Cg(O.f))}0<this.hf&&(this.hf-=.001*a,0>=this.hf&&(this.hf=0,Ei(this.f)));0<this.ug&&(this.ug-=.001*
a,0>=this.ug&&(this.ug=this.We=-1));this.vj&&(2<this.Hk?(this.Hk=0,this.Al()):this.Hk+=a)};function wi(a,b,c,d,g){a.Yk?(void 0!==a.Zh&&(Si(a,a.Zh),Si(a,a.Zh)),a.Zh=Ti(a),a.Yk=!1):a.Yk=!0;var h=(d-1)*a.a.Cy,k=(d-1)*a.a.Dy,l=1*-(a.a.Tf+a.a.Ur),n=(O.hn-P(560))/2;d=new Hi(b*(a.a.Tf+a.a.Ur)+l+n+h+a.a.Ey,c*(a.a.eh+a.a.Rw)+k+a.a.Fy,-d*c*100-10*b,a.Zh,a,g,d);d.pu=0;d.Uh=b;d.Ji=c;a.l.push(d)}function Di(a){var b,c;a.mx=!1;for(b=a.l.length-1;0<=b;b-=1)c=a.l[b],a.l.splice(b,1),K.p(c);a.Rl&&K.p(a.Rl)}
e.Al=function(){function a(a,b){var c=h[a].pv;h[a].count-=b;0===h[a].count&&h.splice(a,1);return c}var b,c;if(this.l[0].e){xi(this,0);for(b=0;b<this.l.length;b++)this.l[b].e=void 0;Ai(this)}var d=[];for(b=0;b<this.l.length;b++)Oi(this.l[b])&&d.push(this.l[b]);var g;for(b=0;b<d.length;b++)g=Math.floor(Math.random()*d.length),c=d[g],d[g]=d[b],d[b]=c;for(var h=[];0<this.Cd.length;){c=Ti(this);for(g=0;Si(this,c);)g++;h.push({pv:c,count:g})}b=O.a.n.Hi.Ir;c=O.a.n.Hi.Ar;g=b+Math.round(Math.random()*(c-b));
g=Math.min(g,Math.floor(d.length/2));var k=h.length-1;for(b=0;b<g;b++)c=a(k,2),k--,0>k&&(k=h.length-1),d[2*b].e=c,d[2*b+1].e=c;for(b=2*g;b<d.length;b++)c=a(k--,1),0>k&&(k=h.length-1),d[b].e=c;for(b=0;b<this.l.length;b++)void 0===this.l[b].e&&(k=Math.floor(Math.random()*h.length),c=a(k,1),this.l[b].e=c);this.vj=!1};function zi(a){var b;r.jb(O.b.Xd(O.gf));r.clear();for(b=0;b<a.l.length;b+=1)Hb(a.l[b],-(a.l[b].x*O.Zm+a.l[b].y+O.hn*O.Zm*a.l[b].fb)),a.l[b].Rb=!0,a.l[b].alpha=1;Ai(a)}
function xi(a,b){var c;a.Cd=[];var d=[];if(1===b){for(c=0;6>c;c+=1)d.push(Be),d.push(Ce),d.push(De),d.push(Ee),d.push(Id),d.push(Jd),d.push(Kd),d.push(Ld),d.push(ye),d.push(ze),d.push(Ae),d.push(pe),d.push(qe),d.push(re),d.push(se),d.push(te),d.push(ue),d.push(ve),d.push(we),d.push(xe),d.push(ge),d.push(he),d.push(ie),d.push(je),d.push(ke),d.push(le),d.push(me),d.push(ne),d.push(oe),d.push(Yd),d.push(Zd),d.push($d),d.push(ae),d.push(be),d.push(ce),d.push(de),d.push(ee),d.push(fe),d.push(Md),d.push(Nd),
d.push(Od),d.push(Pd);for(c=0;c<a.l.length/2;++c)a.Cd.push(d[c]),a.Cd.push(d[c])}else for(c=0;c<a.l.length;c+=1)a.Cd.push(a.l[c].e)}function Si(a,b){var c;for(c=a.Cd.length-1;0<=c;c-=1)if(a.Cd[c]===b)return a.Cd.splice(c,1),!0;return!1}function Ti(a){var b;b=a.Cd.length-1;var c=1;void 0!==b&&(c=b);b=Math.floor(a.kx.random(c+1));return a.Cd[b]}e.p=function(a){Ki(this,a);K.p(a)};function Ki(a,b){var c=a.l.indexOf(b);0<=c&&a.l.splice(c,1)}
function Li(a){var b,c,d,g;d=[];g=0;a.uj=0;if(2<a.l.length){for(b=0;b<a.l.length;b+=1)Oi(a.l[b])&&d.push(a.l[b]);for(b=0;b<d.length;b+=1)for(c=b+1;c<d.length;c+=1)Ii(d[b],d[c])&&(g+=1);if(a.Jf){d=O.a.n.Hi.Ir;var h=O.a.n.Hi.Ar;for(b=c=0;b<a.l.length;b+=1)Oi(a.l[b])&&(c+=1);(g<Math.min(c,d)||g>h)&&10>a.yd&&(g=0)}if(1>g)a.Mi?(a.Jf=!0,a.yd+=1,a.tq?a.Dl():a.fg=a.a.qx):(a.Jf=!0,a.yd+=1,a.Al()),a.Mi=!1;else if(0<a.l.length&&a.Jf){a.yd=0;b=[];for(g=0;g<a.l.length;g+=1)Oi(a.l[g])&&(b.push(a.l[g]),a.l[g].Fk=
!1);for(g=0;g<b.length;g+=1)if(!b[g].Fk)for(c=0;c<b.length;c+=1)if(Ii(b[g],b[c])&&!b[c].Fk){a.de.push(b[g]);a.de.push(b[c]);b[g].Fk=!0;b[c].Fk=!0;break}for(g=a.l.length-1;0<=g;g-=1)for(c=0;c<a.de.length;c+=1)a.l[g]===a.de[c]&&a.l.splice(g,1);Li(a)}}else{for(b=0;b<a.de.length;b+=1)a.l.push(a.de[b]);a.de=[];zi(a);a.Mi=!0;a.yd=0;a.Jf=!1;a.tq=!1}a.Jf||0===a.l.length&&Ui(a)}
e.ey=function(){var a,b;this.$c&&this.$c.close();for(b=0;b<this.l.length;b+=1)this.l[b].io=0,a=new Vi(this.l[b],{io:1.5},100,Wb,this.dy,this),a.start()};e.dy=function(){this.n.rl+=1;this.n.rl>=this.n.l.length&&(this.n.rl=0,this.n.yd+=1,this.Rl=new Ci(0,0,-Number.MAX_VALUE,this,0))};e.Dl=function(){var a;for(a=0;a<this.l.length;a+=1)this.l[a].io=-1;Ri(this,0,0);this.vj=!0;this.Mi=!1;this.Jf=!0};function Ri(a,b,c){0===b&&(a.Wg=0);0<=a.Wg&&(a.Wg+=.001*c,a.Wg>=a.a.Qx&&(a.Wg=-1,J.play(Jf)))}
function Ai(a){var b;for(b=0;b<a.l.length;b+=1)a.l[b].Jg=a.rb(0,a.l[b]),a.l[b].wf=a.rb(1,a.l[b]),a.l[b].Ed=a.rb(2,a.l[b]),a.l[b].Ig=a.rb(3,a.l[b]);2!==a.l.length||0!==a.de.length||void 0===a.l[0].Ed&&void 0===a.l[1].Ed||(a.l[0].x=3*a.a.Tf,a.l[0].y=2*a.a.eh,a.l[0].Uh=3,a.l[0].Ji=2,a.l[0].fb=1,a.l[1].x=5*a.a.Tf,a.l[1].y=2*a.a.eh,a.l[1].Uh=5,a.l[1].Ji=2,a.l[1].fb=1,Ai(a))}
e.rb=function(a,b){var c,d,g,h;for(c=0;c<this.l.length;c++)if(d=this.l[c],d!==b)switch(g=d.Uh-b.Uh,h=d.Ji-b.Ji,a){case 0:if(d.fb===b.fb&&-1===g&&1>Math.abs(h))return d;break;case 1:if(d.fb===b.fb&&1===g&&1>Math.abs(h))return d;break;case 2:if(d.fb===b.fb+1&&-1<g&&1>g&&1>Math.abs(h))return d;break;case 3:if(d.fb===b.fb-1&&-1<g&&1>g&&1>Math.abs(h))return d;break;default:throw"Unknown pos: "+a;}};function Ui(a){a.pause=!0;0!==a.hf&&(a.hf=a.a.Su,a.f.Ta&&(a.f.Ta.Uf=0))}
e.xl=function(){var a=null,b,c=null,d=null,g;b=[];a=O.a.n.mf.ya;if(void 0===this.ti&&0<a&&this.uj>=a&&3<this.l.length){for(a=0;a<this.l.length;a+=1)Oi(this.l[a])&&b.push(this.l[a]);for(a=0;a<b.length;a+=1)for(g=0;g<b.length;g+=1)Ii(b[a],b[g])&&(c=b[a],d=b[g],g=a=b.length);c&&d&&(this.ti=c,c.xl(),d.xl())}};function yi(a){a.l.sort(function(a,c){return c.depth-a.depth});return a.l}function Bi(a,b){var c;for(c=0;c<a.l.length;c+=1)a.l[c].alpha=b}e.Pa=function(){this.e&&this.e.o(0,this.x,this.y)};
function Ci(a,b,c,d,g){this.depth=c;this.k=this.visible=!0;this.group=0;this.Im=!0;this.x=a;this.y=b;"undefined"!==typeof ImgRefreshMid&&(this.e=ImgRefreshMid);this.kv=Ie;this.mv=Je;this.lv=He;this.a=O.a.n.Hi;this.Jk=-Ie.width;this.oo=2*Je.width;this.po=this.m=0;this.dl=this.refresh=!1;O.b.Za(this,O.gf);this.type=g;this.Og=d;this.w=1===g?d:d.n;this.Ta=this.w.f.Ta;this.tc=O.a.n.Ok.zu;L(this)}Ci.prototype.Sb=function(){Wi(this);this.Og.pause=!0};
Ci.prototype.mc=function(a){var b;b=this.w.Mi;this.m>=.8*this.tc&&this.Og.vj&&(this.m=.3*this.tc);this.m>=.8*this.tc&&b&&!this.dl?(this.m=.8*this.tc,this.dl=!0,Bi(this.w,1),Xi(this)):this.m>=.8*this.tc&&!b&&Li(this.w);if(this.m<this.tc)this.m+=.001*a,this.m>this.tc&&(this.m=this.tc);else if(this.dl){if(Cg(O.f)){var c=this;O.fb.Mq?this.Ta.Uf=1:(Yi(function(){c.Ta.Uf=1},this),O.fb.Mq=!0)}else this.Ta.Uf=2;K.p(this);this.Og.Rl=void 0}this.canvas.Z=!0;this.po+=.001*a};
function Wi(a){var b,c;b=0===a.type?new Vi(a,{Jk:0},200*a.tc,Xb,function(){a.Im=!1;a.Og.Dl()},a.Og):new Vi(a,{Jk:0},200*a.tc,Xb,function(){a.Im=!1});c=new Vi(a,{oo:Je.width},200*a.tc,Xb,function(){});J.play(Lf);b.start();c.start()}function Xi(a){var b,c;c=200*a.tc;b=new Vi(a,{Jk:-Ie.width},c,Xb,function(){});c=new Vi(a,{oo:2*Je.width},c,Xb,function(){});J.play(Kf);a.Og.pause=!1;b.start();c.start()}
Ci.prototype.Pa=function(){var a,b,c;a=this.tc;c=20<this.m/(.01*a)&&80>this.m/(.01*a)?!0:!this.dl&&!this.Im;this.m<=.2*this.a.cs||this.m>=.8*this.a.cs||(this.refresh=!0);a=O.hn/2+1;b=O.Zm/2+1;this.kv.o(0,this.Jk,0);this.mv.o(0,this.oo,0);c&&(this.e&&this.e.o(0,a+O.ni,b+O.oi),this.lv.za(0,a,b,1,1,500*-this.po,1))};
function Vi(a,b,c,d,g,h){this.depth=9E3;this.visible=this.k=!1;this.group=0;this.node=a;this.attributes=b;this.duration=c;this.mb=g;this.Du=d;this.time=0;this.n=h;this.Te={};for(var k in this.attributes)this.Te[k]=a[k];this.Pb={};for(var l in this.attributes)this.Pb[l]=this.attributes[l]-this.Te[l];L(this)}e=Vi.prototype;
e.pa=function(a){var b,c,d;this.time+=a;if(this.time<this.duration)for(var g in this.attributes)a=this.Pb[g],b=this.time,c=this.Te[g],d=this.duration,this.node[g]=this.Du(b,c,a,d);else this.finish()};e.start=function(){this.k=!0};e.pause=function(){this.k=!1};e.Al=function(){};e.Dl=function(){this.n.Dl()};e.finish=function(){for(var a in this.attributes)this.node[a]=this.attributes[a];this.k=!1;K.p(this);"undefined"!==typeof this.mb&&this.mb()};
function Ni(a,b,c,d,g,h){this.depth=0;this.k=this.visible=!0;this.group=0;this.x=a;this.y=b;this.e=Fe;this.bl=g;this.Oh=this.Zp=0;this.Dp=!1;this.a=O.a.n.px;this.at=h;this.w=d;O.b.Za(this,O.Xm);L(this)}
Ni.prototype.mc=function(a){this.Oh+=a;this.Zp=Math.floor(this.Oh/this.a.Qd%this.e.F);if(this.Oh>=this.a.Fx&&(void 0===this.bl||this.Dp||(new Ni(this.bl.x,this.bl.y,0,this.w,void 0,void 0),this.Dp=!0),void 0!==this.at)){a=K;var b=a.ub.indexOf(this.at);0>b||(a.ub[b]=void 0);this.canvas.Z=!0}this.Oh>=this.a.Qd*this.e.F&&(void 0===this.bl&&1>this.w.l.length&&this.w.mx&&Ui(this.w),K.p(this),this.canvas.Z=!0)};Ni.prototype.Pa=function(){this.e&&this.e.o(this.Zp,this.x+O.ni,this.y+O.oi)};
function Qi(a,b,c){this.depth=c;this.k=this.visible=!0;this.group=0;this.x=a;this.y=b;this.e=void 0;this.Oi=this.Bl=-1;this.a=O.a.n.Ok;L(this)}Qi.prototype.mc=function(a){var b=null,c=null;switch(this.Bl){case 0:b=this.a.vu,c=If}0<=this.Bl&&(this.Oi+=.001*a,this.Oi>=b&&c&&(this.Bl=this.Oi=-1,J.play(c),K.p(this)))};function Zi(){}Zi.prototype.Dq=function(a,b,c,d){return O.a.n.rf.length<=a?null:(a=O.a.n.rf[a].icon)?LevelMapIcons.Tu(a,"locked"===d):null};
Zi.prototype.Eq=function(){var a,b,c;a=[];b=[Ud,Vd,Wd,Wd,Xd];for(c=0;c<b.length;c+=1)a.push({e:b[c],text:O.i.r("TutorialText_"+c,"<TutorialText_"+c+">"),title:O.i.r("TutorialTitle_"+c,"<TutorialTitle_"+c+">")});return a};
new function(){$.k||($.Xq(),$.is(!0));this.ec=$.Vp($.Nl);"undefined"!==typeof f_points&&(this.ec.font=f_points);this.a=O.a.n.sx;this.cd=this.a.eo;this.dd=this.a.pb;this.bt=this.cd+this.dd;this.dt=this.a.dq||0;this.ec.Ec=Ub;this.ec.Fc=dc([Ub,M],[!1,!1],[this.cd,this.dd]);var a=dc([Ub,M],[!1,!1],[this.cd,this.dd]);this.ec.Dc=function(b,c,d,g){return a(b,1,-1,g)};this.ec.ak=dc([N,Ub],[!1,!1],[this.cd,this.dd]);this.ec.bk=dc([N,Ub],[!1,!1],[this.cd,this.dd])};
var Mi=new function(){function a(a,b,g,h){return N(a,b,g,h)}$.k||($.Xq(),$.is(!0));this.ec=$.Vp($.Nl);this.a=O.a.n.wy;this.cd=this.a.eo;this.dd=this.a.pb;this.bt=this.cd+this.dd;this.dt=this.a.dq||0;this.ec.Ec=Ub;this.ec.Fc=dc([Ub,M],[!1,!1],[this.cd,this.dd]);var b=dc([Ub,M],[!1,!1],[this.cd,this.dd]);this.ec.Dc=function(a,d,g,h){return b(a,1,-1,h)};this.ec.ak=dc([a,Ub],[!1,!1],[this.cd,this.dd]);this.ec.bk=dc([a,Ub],[!1,!1],[this.cd,this.dd])};O.version=O.version||{};O.version.theme="1.4.2";
O.t=O.t||{};O.t.tk=function(){document.title=m.Ad.My||m.Ad.Mo||m.Ad.Qn?O.a.P.n.Cq?O.a.P.n.Cq+" \u2013 Coolmath Games Mobile":"Coolmath Games Mobile":"Coolmath Games";O.t.jo("startScreen");O.t.jo("levelMapScreen");O.t.jo("inGame");O.t.Iq=void 0;eg()};O.t.jo=function(a){if(a=O.a.C.options.buttons[a]){var b=a.indexOf("moreGames");0<=b&&a.splice(b,1)}};O.t.qk=function(){var a=new y(Wc.width,Wc.height);z(a);Wc.o(0,0,0);B(a);return a};O.t.hd=function(){};O.version=O.version||{};
O.version.configuration_coolmath="1.0";Y=Y||{};Y["nl-nl"]=Y["nl-nl"]||{};Y["nl-nl"].loadingScreenLoading="Laden...";Y["nl-nl"].startScreenPlay="SPELEN";Y["nl-nl"].levelMapScreenTotalScore="Totale score";Y["nl-nl"].levelEndScreenTitle_level="Level <VALUE>";Y["nl-nl"].levelEndScreenTitle_difficulty="Goed Gedaan!";Y["nl-nl"].levelEndScreenTitle_endless="Level <VALUE>";Y["nl-nl"].levelEndScreenTotalScore="Totale score";Y["nl-nl"].levelEndScreenSubTitle_levelFailed="Level niet gehaald";
Y["nl-nl"].levelEndScreenTimeLeft="Tijd over";Y["nl-nl"].levelEndScreenTimeBonus="Tijdbonus";Y["nl-nl"].levelEndScreenHighScore="High score";Y["nl-nl"].optionsStartScreen="Hoofdmenu";Y["nl-nl"].optionsQuit="Stop";Y["nl-nl"].optionsResume="Terug naar spel";Y["nl-nl"].optionsTutorial="Speluitleg";Y["nl-nl"].optionsHighScore="High scores";Y["nl-nl"].optionsMoreGames="Meer Spellen";Y["nl-nl"].optionsDifficulty_easy="Makkelijk";Y["nl-nl"].optionsDifficulty_medium="Gemiddeld";
Y["nl-nl"].optionsDifficulty_hard="Moeilijk";Y["nl-nl"].optionsMusic_on="Aan";Y["nl-nl"].optionsMusic_off="Uit";Y["nl-nl"].optionsSFX_on="Aan";Y["nl-nl"].optionsSFX_off="Uit";Y["nl-nl"]["optionsLang_en-us"]="Engels (US)";Y["nl-nl"]["optionsLang_en-gb"]="Engels (GB)";Y["nl-nl"]["optionsLang_nl-nl"]="Nederlands";Y["nl-nl"].gameEndScreenTitle="Gefeliciteerd!\nJe hebt gewonnen.";Y["nl-nl"].gameEndScreenBtnText="Ga verder";Y["nl-nl"].optionsTitle="Instellingen";Y["nl-nl"].optionsQuitConfirmationText="Pas op!\n\nAls je nu stopt verlies je alle voortgang in dit level. Weet je zeker dat je wilt stoppen?";
Y["nl-nl"].optionsQuitConfirmBtn_No="Nee";Y["nl-nl"].optionsQuitConfirmBtn_Yes="Ja, ik weet het zeker";Y["nl-nl"].levelMapScreenTitle="Kies een level";Y["nl-nl"].optionsRestartConfirmationText="Pas op!\n\nAls je nu herstart verlies je alle voortgang in dit level. Weet je zeker dat je wilt herstarten?";Y["nl-nl"].optionsRestart="Herstart";Y["nl-nl"].optionsSFXBig_on="Geluid aan";Y["nl-nl"].optionsSFXBig_off="Geluid uit";Y["nl-nl"].optionsAbout_title="Over ons";Y["nl-nl"].optionsAbout_text="CoolGames\nCopyright \u00a9 2016";
Y["nl-nl"].optionsAbout_backBtn="Terug";Y["nl-nl"].optionsAbout_version="versie:";Y["nl-nl"].optionsAbout="Over ons";Y["nl-nl"].levelEndScreenMedal="VERBETERD!";Y["nl-nl"].startScreenQuestionaire="Wat vind jij?";Y["nl-nl"].levelMapScreenWorld_0="Kies een level";Y["nl-nl"].startScreenByTinglyGames="door: CoolGames";Y["nl-nl"]["optionsLang_de-de"]="Duits";Y["nl-nl"]["optionsLang_tr-tr"]="Turks";Y["nl-nl"].optionsAbout_header="Ontwikkeld door:";Y["nl-nl"].levelEndScreenViewHighscoreBtn="Scores bekijken";
Y["nl-nl"].levelEndScreenSubmitHighscoreBtn="Score verzenden";Y["nl-nl"].challengeStartScreenTitle_challengee_friend="Je bent uitgedaagd door:";Y["nl-nl"].challengeStartTextScore="Punten van <NAME>:";Y["nl-nl"].challengeStartTextTime="Tijd van <NAME>:";Y["nl-nl"].challengeStartScreenToWin="Te winnen aantal Fairplay munten:";Y["nl-nl"].challengeEndScreenWinnings="Je hebt <AMOUNT> Fairplay munten gewonnen!";Y["nl-nl"].challengeEndScreenOutcomeMessage_WON="Je hebt de uitdaging gewonnen!";
Y["nl-nl"].challengeEndScreenOutcomeMessage_LOST="Je hebt de uitdaging verloren.";Y["nl-nl"].challengeEndScreenOutcomeMessage_TIED="Jullie hebben gelijk gespeeld.";Y["nl-nl"].challengeCancelConfirmText="Je staat op het punt de uitdaging te annuleren. Je inzet wordt teruggestort minus de uitdagingskosten. Weet je zeker dat je de uitdaging wilt annuleren? ";Y["nl-nl"].challengeCancelConfirmBtn_yes="Ja";Y["nl-nl"].challengeCancelConfirmBtn_no="Nee";Y["nl-nl"].challengeEndScreensBtn_submit="Verstuur uitdaging";
Y["nl-nl"].challengeEndScreenBtn_cancel="Annuleer uitdaging";Y["nl-nl"].challengeEndScreenName_you="Jij";Y["nl-nl"].challengeEndScreenChallengeSend_error="Er is een fout opgetreden bij het versturen van de uitdaging. Probeer het later nog een keer.";Y["nl-nl"].challengeEndScreenChallengeSend_success="Je uitdaging is verstuurd!";Y["nl-nl"].challengeCancelMessage_error="Er is een fout opgetreden bij het annuleren van de uitdaging. Probeer het later nog een keer.";
Y["nl-nl"].challengeCancelMessage_success="De uitdaging is geannuleerd.";Y["nl-nl"].challengeEndScreenScoreSend_error="Er is een fout opgetreden tijdens de communicatie met de server. Probeer het later nog een keer.";Y["nl-nl"].challengeStartScreenTitle_challengee_stranger="Jouw tegenstander:";Y["nl-nl"].challengeStartScreenTitle_challenger_friend="Jouw tegenstander:";Y["nl-nl"].challengeStartScreenTitle_challenger_stranger="Je zet een uitdaging voor:";
Y["nl-nl"].challengeStartTextTime_challenger="Speel het spel en zet een tijd neer.";Y["nl-nl"].challengeStartTextScore_challenger="Speel het spel en zet een score neer.";Y["nl-nl"].challengeForfeitConfirmText="Je staat op het punt de uitdaging op te geven. Weet je zeker dat je dit wilt doen?";Y["nl-nl"].challengeForfeitConfirmBtn_yes="Ja";Y["nl-nl"].challengeForfeitConfirmBtn_no="Nee";Y["nl-nl"].challengeForfeitMessage_success="Je hebt de uitdaging opgegeven.";
Y["nl-nl"].challengeForfeitMessage_error="Er is een fout opgetreden tijdens het opgeven van de uitdaging. Probeer het later nog een keer.";Y["nl-nl"].optionsChallengeForfeit="Geef op";Y["nl-nl"].optionsChallengeCancel="Stop";Y["nl-nl"].challengeLoadingError_notValid="Sorry, deze uitdaging kan niet meer gespeeld worden.";Y["nl-nl"].challengeLoadingError_notStarted="Kan de server niet bereiken. Probeer het later nog een keer.";Y["nl-nl"].levelEndScreenHighScore_time="Beste tijd:";
Y["nl-nl"].levelEndScreenTotalScore_time="Totale tijd:";Y["nl-nl"]["optionsLang_fr-fr"]="Frans";Y["nl-nl"]["optionsLang_ko-kr"]="Koreaans";Y["nl-nl"]["optionsLang_ar-eg"]="Arabisch";Y["nl-nl"]["optionsLang_es-es"]="Spaans";Y["nl-nl"]["optionsLang_pt-br"]="Braziliaans-Portugees";Y["nl-nl"]["optionsLang_ru-ru"]="Russisch";Y["nl-nl"].optionsExit="Stoppen";Y["nl-nl"].levelEndScreenTotalScore_number="Totale score:";Y["nl-nl"].levelEndScreenHighScore_number="Topscore:";
Y["nl-nl"].challengeEndScreenChallengeSend_submessage="<NAME> heeft 72 uur om de uitdaging aan te nemen of te weigeren. Als <NAME> je uitdaging weigert of niet accepteert binnen 72 uur worden je inzet en uitdagingskosten teruggestort.";Y["nl-nl"].challengeEndScreenChallengeSend_submessage_stranger="Als niemand binnen 72 uur je uitdaging accepteert, worden je inzet en uitdagingskosten teruggestort.";Y["nl-nl"].challengeForfeitMessage_winnings="<NAME> heeft <AMOUNT> Fairplay munten gewonnen!";
Y["nl-nl"].optionsAbout_header_publisher="Published by:";Y["nl-nl"]["optionsLang_jp-jp"]="Japans";Y["en-us"]=Y["en-us"]||{};Y["en-us"].loadingScreenLoading="Loading...";Y["en-us"].startScreenPlay="PLAY";Y["en-us"].levelMapScreenTotalScore="Total score";Y["en-us"].levelEndScreenTitle_level="Level <VALUE>";Y["en-us"].levelEndScreenTitle_difficulty="Well done!";Y["en-us"].levelEndScreenTitle_endless="Stage <VALUE>";Y["en-us"].levelEndScreenTotalScore="Total score";
Y["en-us"].levelEndScreenSubTitle_levelFailed="Level failed";Y["en-us"].levelEndScreenTimeLeft="Time remaining";Y["en-us"].levelEndScreenTimeBonus="Time bonus";Y["en-us"].levelEndScreenHighScore="High score";Y["en-us"].optionsStartScreen="Main menu";Y["en-us"].optionsQuit="Quit";Y["en-us"].optionsResume="Resume";Y["en-us"].optionsTutorial="How to play";Y["en-us"].optionsHighScore="High scores";Y["en-us"].optionsMoreGames="More Games";Y["en-us"].optionsDifficulty_easy="Easy";
Y["en-us"].optionsDifficulty_medium="Medium";Y["en-us"].optionsDifficulty_hard="Difficult";Y["en-us"].optionsMusic_on="On";Y["en-us"].optionsMusic_off="Off";Y["en-us"].optionsSFX_on="On";Y["en-us"].optionsSFX_off="Off";Y["en-us"]["optionsLang_en-us"]="English (US)";Y["en-us"]["optionsLang_en-gb"]="English (GB)";Y["en-us"]["optionsLang_nl-nl"]="Dutch";Y["en-us"].gameEndScreenTitle="Congratulations!\nYou have completed the game.";Y["en-us"].gameEndScreenBtnText="Continue";Y["en-us"].optionsTitle="Settings";
Y["en-us"].optionsQuitConfirmationText="Attention!\n\nIf you quit now you will lose all progress made during this level. Are you sure you want to quit?";Y["en-us"].optionsQuitConfirmBtn_No="No";Y["en-us"].optionsQuitConfirmBtn_Yes="Yes, I'm sure";Y["en-us"].levelMapScreenTitle="Select a level";Y["en-us"].optionsRestartConfirmationText="Attention!\n\nIf you restart now you will lose all progress made during this level. Are you sure you want to restart?";Y["en-us"].optionsRestart="Restart";
Y["en-us"].optionsSFXBig_on="Sound on";Y["en-us"].optionsSFXBig_off="Sound off";Y["en-us"].optionsAbout_title="About";Y["en-us"].optionsAbout_text="CoolGames\n\u00a9 2016";Y["en-us"].optionsAbout_backBtn="Back";Y["en-us"].optionsAbout_version="version:";Y["en-us"].optionsAbout="About";Y["en-us"].levelEndScreenMedal="IMPROVED!";Y["en-us"].startScreenQuestionaire="What do you think?";Y["en-us"].levelMapScreenWorld_0="Select a level";Y["en-us"].startScreenByTinglyGames="by: CoolGames";
Y["en-us"]["optionsLang_de-de"]="German";Y["en-us"]["optionsLang_tr-tr"]="Turkish";Y["en-us"].optionsAbout_header="Developed by:";Y["en-us"].levelEndScreenViewHighscoreBtn="View scores";Y["en-us"].levelEndScreenSubmitHighscoreBtn="Submit score";Y["en-us"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["en-us"].challengeStartTextScore="<NAME>'s score:";Y["en-us"].challengeStartTextTime="<NAME>'s time:";Y["en-us"].challengeStartScreenToWin="Amount to win:";
Y["en-us"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["en-us"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["en-us"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["en-us"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["en-us"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["en-us"].challengeCancelConfirmBtn_yes="Yes";Y["en-us"].challengeCancelConfirmBtn_no="No";Y["en-us"].challengeEndScreensBtn_submit="Submit challenge";Y["en-us"].challengeEndScreenBtn_cancel="Cancel challenge";Y["en-us"].challengeEndScreenName_you="You";Y["en-us"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["en-us"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
Y["en-us"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";Y["en-us"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["en-us"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["en-us"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["en-us"].challengeStartScreenTitle_challenger_friend="You are challenging:";
Y["en-us"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["en-us"].challengeStartTextTime_challenger="Play the game and set a time.";Y["en-us"].challengeStartTextScore_challenger="Play the game and set a score.";Y["en-us"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["en-us"].challengeForfeitConfirmBtn_yes="Yes";Y["en-us"].challengeForfeitConfirmBtn_no="No";Y["en-us"].challengeForfeitMessage_success="You have forfeited the challenge.";
Y["en-us"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Y["en-us"].optionsChallengeForfeit="Forfeit";Y["en-us"].optionsChallengeCancel="Quit";Y["en-us"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["en-us"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Y["en-us"].levelEndScreenHighScore_time="Best time:";Y["en-us"].levelEndScreenTotalScore_time="Total time:";
Y["en-us"]["optionsLang_fr-fr"]="French";Y["en-us"]["optionsLang_ko-kr"]="Korean";Y["en-us"]["optionsLang_ar-eg"]="Arabic";Y["en-us"]["optionsLang_es-es"]="Spanish";Y["en-us"]["optionsLang_pt-br"]="Brazilian-Portuguese";Y["en-us"]["optionsLang_ru-ru"]="Russian";Y["en-us"].optionsExit="Exit";Y["en-us"].levelEndScreenTotalScore_number="Total score:";Y["en-us"].levelEndScreenHighScore_number="High score:";Y["en-us"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["en-us"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["en-us"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["en-us"].optionsAbout_header_publisher="Published by:";Y["en-us"]["optionsLang_jp-jp"]="Japanese";Y["en-gb"]=Y["en-gb"]||{};Y["en-gb"].loadingScreenLoading="Loading...";Y["en-gb"].startScreenPlay="PLAY";
Y["en-gb"].levelMapScreenTotalScore="Total score";Y["en-gb"].levelEndScreenTitle_level="Level <VALUE>";Y["en-gb"].levelEndScreenTitle_difficulty="Well done!";Y["en-gb"].levelEndScreenTitle_endless="Stage <VALUE>";Y["en-gb"].levelEndScreenTotalScore="Total score";Y["en-gb"].levelEndScreenSubTitle_levelFailed="Level failed";Y["en-gb"].levelEndScreenTimeLeft="Time remaining";Y["en-gb"].levelEndScreenTimeBonus="Time bonus";Y["en-gb"].levelEndScreenHighScore="High score";
Y["en-gb"].optionsStartScreen="Main menu";Y["en-gb"].optionsQuit="Quit";Y["en-gb"].optionsResume="Resume";Y["en-gb"].optionsTutorial="How to play";Y["en-gb"].optionsHighScore="High scores";Y["en-gb"].optionsMoreGames="More Games";Y["en-gb"].optionsDifficulty_easy="Easy";Y["en-gb"].optionsDifficulty_medium="Medium";Y["en-gb"].optionsDifficulty_hard="Difficult";Y["en-gb"].optionsMusic_on="On";Y["en-gb"].optionsMusic_off="Off";Y["en-gb"].optionsSFX_on="On";Y["en-gb"].optionsSFX_off="Off";
Y["en-gb"]["optionsLang_en-us"]="English (US)";Y["en-gb"]["optionsLang_en-gb"]="English (GB)";Y["en-gb"]["optionsLang_nl-nl"]="Dutch";Y["en-gb"].gameEndScreenTitle="Congratulations!\nYou have completed the game.";Y["en-gb"].gameEndScreenBtnText="Continue";Y["en-gb"].optionsTitle="Settings";Y["en-gb"].optionsQuitConfirmationText="Attention!\n\nIf you quit now you will lose all progress made during this level. Are you sure you want to quit?";Y["en-gb"].optionsQuitConfirmBtn_No="No";
Y["en-gb"].optionsQuitConfirmBtn_Yes="Yes, I'm sure";Y["en-gb"].levelMapScreenTitle="Select a level";Y["en-gb"].optionsRestartConfirmationText="Attention!\n\nIf you restart now you will lose all progress made during this level. Are you sure you want to restart?";Y["en-gb"].optionsRestart="Restart";Y["en-gb"].optionsSFXBig_on="Sound on";Y["en-gb"].optionsSFXBig_off="Sound off";Y["en-gb"].optionsAbout_title="About";Y["en-gb"].optionsAbout_text="CoolGames\n\u00a9 2016";
Y["en-gb"].optionsAbout_backBtn="Back";Y["en-gb"].optionsAbout_version="version:";Y["en-gb"].optionsAbout="About";Y["en-gb"].levelEndScreenMedal="IMPROVED!";Y["en-gb"].startScreenQuestionaire="What do you think?";Y["en-gb"].levelMapScreenWorld_0="Select a level";Y["en-gb"].startScreenByTinglyGames="by: CoolGames";Y["en-gb"]["optionsLang_de-de"]="German";Y["en-gb"]["optionsLang_tr-tr"]="Turkish";Y["en-gb"].optionsAbout_header="Developed by:";Y["en-gb"].levelEndScreenViewHighscoreBtn="View scores";
Y["en-gb"].levelEndScreenSubmitHighscoreBtn="Submit score";Y["en-gb"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["en-gb"].challengeStartTextScore="<NAME>'s score:";Y["en-gb"].challengeStartTextTime="<NAME>'s time:";Y["en-gb"].challengeStartScreenToWin="Amount to win:";Y["en-gb"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["en-gb"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";
Y["en-gb"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["en-gb"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["en-gb"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";Y["en-gb"].challengeCancelConfirmBtn_yes="Yes";Y["en-gb"].challengeCancelConfirmBtn_no="No";Y["en-gb"].challengeEndScreensBtn_submit="Submit challenge";
Y["en-gb"].challengeEndScreenBtn_cancel="Cancel challenge";Y["en-gb"].challengeEndScreenName_you="You";Y["en-gb"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["en-gb"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["en-gb"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";Y["en-gb"].challengeCancelMessage_success="Your challenge has been cancelled.";
Y["en-gb"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["en-gb"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["en-gb"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["en-gb"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["en-gb"].challengeStartTextTime_challenger="Play the game and set a time.";
Y["en-gb"].challengeStartTextScore_challenger="Play the game and set a score.";Y["en-gb"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you wish to proceed?";Y["en-gb"].challengeForfeitConfirmBtn_yes="Yes";Y["en-gb"].challengeForfeitConfirmBtn_no="No";Y["en-gb"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["en-gb"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
Y["en-gb"].optionsChallengeForfeit="Forfeit";Y["en-gb"].optionsChallengeCancel="Quit";Y["en-gb"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["en-gb"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Y["en-gb"].levelEndScreenHighScore_time="Best time:";Y["en-gb"].levelEndScreenTotalScore_time="Total time:";Y["en-gb"]["optionsLang_fr-fr"]="French";Y["en-gb"]["optionsLang_ko-kr"]="Korean";Y["en-gb"]["optionsLang_ar-eg"]="Arabic";
Y["en-gb"]["optionsLang_es-es"]="Spanish";Y["en-gb"]["optionsLang_pt-br"]="Brazilian-Portuguese";Y["en-gb"]["optionsLang_ru-ru"]="Russian";Y["en-gb"].optionsExit="Exit";Y["en-gb"].levelEndScreenTotalScore_number="Total score:";Y["en-gb"].levelEndScreenHighScore_number="High score:";Y["en-gb"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["en-gb"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["en-gb"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["en-gb"].optionsAbout_header_publisher="Published by:";Y["en-gb"]["optionsLang_jp-jp"]="Japanese";Y["de-de"]=Y["de-de"]||{};Y["de-de"].loadingScreenLoading="Laden ...";Y["de-de"].startScreenPlay="SPIELEN";
Y["de-de"].levelMapScreenTotalScore="Gesamtpunkte";Y["de-de"].levelEndScreenTitle_level="Level <VALUE>";Y["de-de"].levelEndScreenTitle_difficulty="Sehr gut!";Y["de-de"].levelEndScreenTitle_endless="Stufe <VALUE>";Y["de-de"].levelEndScreenTotalScore="Gesamtpunkte";Y["de-de"].levelEndScreenSubTitle_levelFailed="Level nicht geschafft";Y["de-de"].levelEndScreenTimeLeft="Restzeit";Y["de-de"].levelEndScreenTimeBonus="Zeitbonus";Y["de-de"].levelEndScreenHighScore="Highscore";
Y["de-de"].optionsStartScreen="Hauptmen\u00fc";Y["de-de"].optionsQuit="Beenden";Y["de-de"].optionsResume="Weiterspielen";Y["de-de"].optionsTutorial="So wird gespielt";Y["de-de"].optionsHighScore="Highscores";Y["de-de"].optionsMoreGames="Weitere Spiele";Y["de-de"].optionsDifficulty_easy="Einfach";Y["de-de"].optionsDifficulty_medium="Mittel";Y["de-de"].optionsDifficulty_hard="Schwer";Y["de-de"].optionsMusic_on="EIN";Y["de-de"].optionsMusic_off="AUS";Y["de-de"].optionsSFX_on="EIN";
Y["de-de"].optionsSFX_off="AUS";Y["de-de"]["optionsLang_en-us"]="Englisch (US)";Y["de-de"]["optionsLang_en-gb"]="Englisch (GB)";Y["de-de"]["optionsLang_nl-nl"]="Holl\u00e4ndisch";Y["de-de"].gameEndScreenTitle="Gl\u00fcckwunsch!\nDu hast das Spiel abgeschlossen.";Y["de-de"].gameEndScreenBtnText="Weiter";Y["de-de"].optionsTitle="Einstellungen";Y["de-de"].optionsQuitConfirmationText="Achtung!\n\nWenn du jetzt aufh\u00f6rst, verlierst du alle in diesem Level gemachten Fortschritte. Willst du wirklich aufh\u00f6ren?";
Y["de-de"].optionsQuitConfirmBtn_No="NEIN";Y["de-de"].optionsQuitConfirmBtn_Yes="Ja, ich bin mir sicher";Y["de-de"].levelMapScreenTitle="W\u00e4hle ein Level";Y["de-de"].optionsRestartConfirmationText="Achtung!\n\nWenn du jetzt neu startest, verlierst du alle in diesem Level gemachten Fortschritte. Willst du wirklich neu starten?";Y["de-de"].optionsRestart="Neustart";Y["de-de"].optionsSFXBig_on="Sound EIN";Y["de-de"].optionsSFXBig_off="Sound AUS";Y["de-de"].optionsAbout_title="\u00dcber";
Y["de-de"].optionsAbout_text="CoolGames\n\u00a9 2016";Y["de-de"].optionsAbout_backBtn="Zur\u00fcck";Y["de-de"].optionsAbout_version="Version:";Y["de-de"].optionsAbout="\u00dcber";Y["de-de"].levelEndScreenMedal="VERBESSERT!";Y["de-de"].startScreenQuestionaire="Deine Meinung z\u00e4hlt!";Y["de-de"].levelMapScreenWorld_0="W\u00e4hle ein Level";Y["de-de"].startScreenByTinglyGames="von: CoolGames";Y["de-de"]["optionsLang_de-de"]="Deutsch";Y["de-de"]["optionsLang_tr-tr"]="T\u00fcrkisch";
Y["de-de"].optionsAbout_header="Entwickelt von:";Y["de-de"].levelEndScreenViewHighscoreBtn="Punktzahlen ansehen";Y["de-de"].levelEndScreenSubmitHighscoreBtn="Punktzahl senden";Y["de-de"].challengeStartScreenTitle_challengee_friend="Dein Gegner:";Y["de-de"].challengeStartTextScore="Punktzahl von <NAME>:";Y["de-de"].challengeStartTextTime="Zeit von <NAME>:";Y["de-de"].challengeStartScreenToWin="Einsatz:";Y["de-de"].challengeEndScreenWinnings="Du hast <AMOUNT> Fairm\u00fcnzen gewonnen!";
Y["de-de"].challengeEndScreenOutcomeMessage_WON="Du hast die Partie gewonnen!";Y["de-de"].challengeEndScreenOutcomeMessage_LOST="Leider hat Dein Gegner die Partie gewonnen.";Y["de-de"].challengeEndScreenOutcomeMessage_TIED="Gleichstand!";Y["de-de"].challengeCancelConfirmText="Willst Du Deine Wette wirklich zur\u00fcckziehen? Dein Wetteinsatz wird Dir zur\u00fcckgegeben minus die Einsatzgeb\u00fchr.";Y["de-de"].challengeCancelConfirmBtn_yes="Ja";Y["de-de"].challengeCancelConfirmBtn_no="Nein";
Y["de-de"].challengeEndScreensBtn_submit="Herausfordern";Y["de-de"].challengeEndScreenBtn_cancel="Zur\u00fcckziehen";Y["de-de"].challengeEndScreenName_you="Du";Y["de-de"].challengeEndScreenChallengeSend_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";Y["de-de"].challengeEndScreenChallengeSend_success="Herausforderung verschickt!";Y["de-de"].challengeCancelMessage_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";
Y["de-de"].challengeCancelMessage_success="Du hast die Wette erfolgreich zur\u00fcckgezogen.";Y["de-de"].challengeEndScreenScoreSend_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";Y["de-de"].challengeStartScreenTitle_challengee_stranger="Dein Gegner wird:";Y["de-de"].challengeStartScreenTitle_challenger_friend="Du hast den folgenden Spieler herausgefordert:";Y["de-de"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Y["de-de"].challengeStartTextTime_challenger="Spiel um die niedrigste Zeit!";Y["de-de"].challengeStartTextScore_challenger="Spiel um die hochste Punktzahl!";Y["de-de"].challengeForfeitConfirmText="Willst du Die Partie wirklich aufgeben?";Y["de-de"].challengeForfeitConfirmBtn_yes="Ja";Y["de-de"].challengeForfeitConfirmBtn_no="Nein";Y["de-de"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["de-de"].challengeForfeitMessage_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";
Y["de-de"].optionsChallengeForfeit="Aufgeben";Y["de-de"].optionsChallengeCancel="Zur\u00fcckziehen";Y["de-de"].challengeLoadingError_notValid="Leider ist diese Partie nicht mehr aktuel.";Y["de-de"].challengeLoadingError_notStarted="Leider ist ein Fehler\u00a0aufgetreten. Es konnte keiner Verbindung zum Server hergestellt werden. Versuche es bitte nochmal sp\u00e4ter.";Y["de-de"].levelEndScreenHighScore_time="Bestzeit:";Y["de-de"].levelEndScreenTotalScore_time="Gesamtzeit:";
Y["de-de"]["optionsLang_fr-fr"]="Franz\u00f6sisch";Y["de-de"]["optionsLang_ko-kr"]="Koreanisch";Y["de-de"]["optionsLang_ar-eg"]="Arabisch";Y["de-de"]["optionsLang_es-es"]="Spanisch";Y["de-de"]["optionsLang_pt-br"]="Portugiesisch (Brasilien)";Y["de-de"]["optionsLang_ru-ru"]="Russisch";Y["de-de"].optionsExit="Verlassen";Y["de-de"].levelEndScreenTotalScore_number="Gesamtpunktzahl:";Y["de-de"].levelEndScreenHighScore_number="Highscore:";Y["de-de"].challengeEndScreenChallengeSend_submessage="<NAME> hat 72 Stunden um die Wette anzunehmen oder abzulehnen. Sollte <NAME> nicht reagieren oder ablehnen werden Dir Dein Wetteinsatz und die Geb\u00fchr zur\u00fcckerstattet.";
Y["de-de"].challengeEndScreenChallengeSend_submessage_stranger="Als niemanden Deine Herausforderung innerhalb von 72 Stunden annimmt, werden Dir Deinen Wetteinsatz Einsatzgeb\u00fchr zur\u00fcckerstattet.";Y["de-de"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["de-de"].optionsAbout_header_publisher="Published by:";Y["de-de"]["optionsLang_jp-jp"]="Japanese";Y["fr-fr"]=Y["fr-fr"]||{};Y["fr-fr"].loadingScreenLoading="Chargement...";Y["fr-fr"].startScreenPlay="JOUER";
Y["fr-fr"].levelMapScreenTotalScore="Score total";Y["fr-fr"].levelEndScreenTitle_level="Niveau <VALUE>";Y["fr-fr"].levelEndScreenTitle_difficulty="Bien jou\u00e9 !";Y["fr-fr"].levelEndScreenTitle_endless="Sc\u00e8ne <VALUE>";Y["fr-fr"].levelEndScreenTotalScore="Score total";Y["fr-fr"].levelEndScreenSubTitle_levelFailed="\u00c9chec du niveau";Y["fr-fr"].levelEndScreenTimeLeft="Temps restant";Y["fr-fr"].levelEndScreenTimeBonus="Bonus de temps";Y["fr-fr"].levelEndScreenHighScore="Meilleur score";
Y["fr-fr"].optionsStartScreen="Menu principal";Y["fr-fr"].optionsQuit="Quitter";Y["fr-fr"].optionsResume="Reprendre";Y["fr-fr"].optionsTutorial="Comment jouer";Y["fr-fr"].optionsHighScore="Meilleurs scores";Y["fr-fr"].optionsMoreGames="Plus de jeux";Y["fr-fr"].optionsDifficulty_easy="Facile";Y["fr-fr"].optionsDifficulty_medium="Moyen";Y["fr-fr"].optionsDifficulty_hard="Difficile";Y["fr-fr"].optionsMusic_on="Avec";Y["fr-fr"].optionsMusic_off="Sans";Y["fr-fr"].optionsSFX_on="Avec";
Y["fr-fr"].optionsSFX_off="Sans";Y["fr-fr"]["optionsLang_en-us"]="Anglais (US)";Y["fr-fr"]["optionsLang_en-gb"]="Anglais (UK)";Y["fr-fr"]["optionsLang_nl-nl"]="N\u00e9erlandais";Y["fr-fr"].gameEndScreenTitle="F\u00e9licitations !\nVous avez termin\u00e9 le jeu.";Y["fr-fr"].gameEndScreenBtnText="Continuer";Y["fr-fr"].optionsTitle="Param\u00e8tres";Y["fr-fr"].optionsQuitConfirmationText="Attention !\n\nEn quittant maintenant, vous perdrez votre progression pour le niveau en cours. Quitter quand m\u00eame ?";
Y["fr-fr"].optionsQuitConfirmBtn_No="Non";Y["fr-fr"].optionsQuitConfirmBtn_Yes="Oui";Y["fr-fr"].levelMapScreenTitle="Choisir un niveau";Y["fr-fr"].optionsRestartConfirmationText="Attention !\n\nEn recommen\u00e7ant maintenant, vous perdrez votre progression pour le niveau en cours. Recommencer quand m\u00eame ?";Y["fr-fr"].optionsRestart="Recommencer";Y["fr-fr"].optionsSFXBig_on="Avec son";Y["fr-fr"].optionsSFXBig_off="Sans son";Y["fr-fr"].optionsAbout_title="\u00c0 propos";
Y["fr-fr"].optionsAbout_text="CoolGames\n\u00a9 2016";Y["fr-fr"].optionsAbout_backBtn="Retour";Y["fr-fr"].optionsAbout_version="Version :";Y["fr-fr"].optionsAbout="\u00c0 propos";Y["fr-fr"].levelEndScreenMedal="RECORD BATTU !";Y["fr-fr"].startScreenQuestionaire="Un avis sur le jeu ?";Y["fr-fr"].levelMapScreenWorld_0="Choisir un niveau";Y["fr-fr"].startScreenByTinglyGames="Un jeu CoolGames";Y["fr-fr"]["optionsLang_de-de"]="Allemand";Y["fr-fr"]["optionsLang_tr-tr"]="Turc";
Y["fr-fr"].optionsAbout_header="D\u00e9velopp\u00e9 par :";Y["fr-fr"].levelEndScreenViewHighscoreBtn="Voir les scores";Y["fr-fr"].levelEndScreenSubmitHighscoreBtn="Publier un score";Y["fr-fr"].challengeStartScreenTitle_challengee_friend="Votre adversaire\u00a0:";Y["fr-fr"].challengeStartTextScore="Son score :";Y["fr-fr"].challengeStartTextTime="Son temps\u00a0:";Y["fr-fr"].challengeStartScreenToWin="\u00c0 gagner\u00a0:";Y["fr-fr"].challengeEndScreenWinnings="Vous avez gagn\u00e9 <AMOUNT> fairpoints.";
Y["fr-fr"].challengeEndScreenOutcomeMessage_WON="Vainqueur\u00a0!";Y["fr-fr"].challengeEndScreenOutcomeMessage_LOST="Zut\u00a0!";Y["fr-fr"].challengeEndScreenOutcomeMessage_TIED="Ex-aequo\u00a0!";Y["fr-fr"].challengeCancelConfirmText="Si vous annulez, on vous remboursera le montant du pari moins les frais de pari. Voulez-vous continuer\u00a0? ";Y["fr-fr"].challengeCancelConfirmBtn_yes="Oui";Y["fr-fr"].challengeCancelConfirmBtn_no="Non";Y["fr-fr"].challengeEndScreensBtn_submit="Lancer le d\u00e9fi";
Y["fr-fr"].challengeEndScreenBtn_cancel="Annuler le d\u00e9fi";Y["fr-fr"].challengeEndScreenName_you="Moi";Y["fr-fr"].challengeEndScreenChallengeSend_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";Y["fr-fr"].challengeEndScreenChallengeSend_success="D\u00e9fi lanc\u00e9.";Y["fr-fr"].challengeCancelMessage_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";Y["fr-fr"].challengeCancelMessage_success="D\u00e9fi annul\u00e9.";
Y["fr-fr"].challengeEndScreenScoreSend_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";Y["fr-fr"].challengeStartScreenTitle_challengee_stranger="Votre adversaire\u00a0:";Y["fr-fr"].challengeStartScreenTitle_challenger_friend="Votre adversaire\u00a0:";Y["fr-fr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["fr-fr"].challengeStartTextTime_challenger="Finissez le plus vite possible !";Y["fr-fr"].challengeStartTextScore_challenger="Essayez d\u2019atteindre le plus haut score !";
Y["fr-fr"].challengeForfeitConfirmText="Voulez-vous vraiment abandonner la partie ?";Y["fr-fr"].challengeForfeitConfirmBtn_yes="Oui";Y["fr-fr"].challengeForfeitConfirmBtn_no="Non";Y["fr-fr"].challengeForfeitMessage_success="Vous avez abandonn\u00e9.";Y["fr-fr"].challengeForfeitMessage_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";Y["fr-fr"].optionsChallengeForfeit="Abandonner";Y["fr-fr"].optionsChallengeCancel="Annuler";Y["fr-fr"].challengeLoadingError_notValid="D\u00e9sol\u00e9, cette partie n'existe plus.";
Y["fr-fr"].challengeLoadingError_notStarted="Une erreur de connexion est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";Y["fr-fr"].levelEndScreenHighScore_time="Meilleur temps :";Y["fr-fr"].levelEndScreenTotalScore_time="Temps total :";Y["fr-fr"]["optionsLang_fr-fr"]="Fran\u00e7ais";Y["fr-fr"]["optionsLang_ko-kr"]="Cor\u00e9en";Y["fr-fr"]["optionsLang_ar-eg"]="Arabe";Y["fr-fr"]["optionsLang_es-es"]="Espagnol";Y["fr-fr"]["optionsLang_pt-br"]="Portugais - Br\u00e9silien";
Y["fr-fr"]["optionsLang_ru-ru"]="Russe";Y["fr-fr"].optionsExit="Quitter";Y["fr-fr"].levelEndScreenTotalScore_number="Score total :";Y["fr-fr"].levelEndScreenHighScore_number="Meilleur score :";Y["fr-fr"].challengeEndScreenChallengeSend_submessage="<NAME> a 72 heures pour accepter votre d\u00e9fi. Si <NAME> refuse ou n\u2019accepte pas dans ce d\u00e9lai vous serez rembours\u00e9 le montant de votre pari et les frais de pari.";Y["fr-fr"].challengeEndScreenChallengeSend_submessage_stranger="Si personne n\u2019accepte votre pari d\u2019ici 72 heures, on vous remboursera le montant du pari y compris les frais.";
Y["fr-fr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["fr-fr"].optionsAbout_header_publisher="Published by:";Y["fr-fr"]["optionsLang_jp-jp"]="Japanese";Y["pt-br"]=Y["pt-br"]||{};Y["pt-br"].loadingScreenLoading="Carregando...";Y["pt-br"].startScreenPlay="JOGAR";Y["pt-br"].levelMapScreenTotalScore="Pontua\u00e7\u00e3o";Y["pt-br"].levelEndScreenTitle_level="N\u00edvel <VALUE>";Y["pt-br"].levelEndScreenTitle_difficulty="Muito bem!";
Y["pt-br"].levelEndScreenTitle_endless="Fase <VALUE>";Y["pt-br"].levelEndScreenTotalScore="Pontua\u00e7\u00e3o";Y["pt-br"].levelEndScreenSubTitle_levelFailed="Tente novamente";Y["pt-br"].levelEndScreenTimeLeft="Tempo restante";Y["pt-br"].levelEndScreenTimeBonus="B\u00f4nus de tempo";Y["pt-br"].levelEndScreenHighScore="Recorde";Y["pt-br"].optionsStartScreen="Menu principal";Y["pt-br"].optionsQuit="Sair";Y["pt-br"].optionsResume="Continuar";Y["pt-br"].optionsTutorial="Como jogar";
Y["pt-br"].optionsHighScore="Recordes";Y["pt-br"].optionsMoreGames="Mais jogos";Y["pt-br"].optionsDifficulty_easy="F\u00e1cil";Y["pt-br"].optionsDifficulty_medium="M\u00e9dio";Y["pt-br"].optionsDifficulty_hard="Dif\u00edcil";Y["pt-br"].optionsMusic_on="Sim";Y["pt-br"].optionsMusic_off="N\u00e3o";Y["pt-br"].optionsSFX_on="Sim";Y["pt-br"].optionsSFX_off="N\u00e3o";Y["pt-br"]["optionsLang_en-us"]="Ingl\u00eas (EUA)";Y["pt-br"]["optionsLang_en-gb"]="Ingl\u00eas (GB)";Y["pt-br"]["optionsLang_nl-nl"]="Holand\u00eas";
Y["pt-br"].gameEndScreenTitle="Parab\u00e9ns!\nVoc\u00ea concluiu o jogo.";Y["pt-br"].gameEndScreenBtnText="Continuar";Y["pt-br"].optionsTitle="Configura\u00e7\u00f5es";Y["pt-br"].optionsQuitConfirmationText="Aten\u00e7\u00e3o!\n\nSe voc\u00ea sair agora, perder\u00e1 todo progresso realizado neste n\u00edvel. Deseja mesmo sair?";Y["pt-br"].optionsQuitConfirmBtn_No="N\u00e3o";Y["pt-br"].optionsQuitConfirmBtn_Yes="Sim, tenho certeza.";Y["pt-br"].levelMapScreenTitle="Selecione um n\u00edvel";
Y["pt-br"].optionsRestartConfirmationText="Aten\u00e7\u00e3o!\n\nSe voc\u00ea reiniciar agora, perder\u00e1 todo progresso realizado neste n\u00edvel. Deseja mesmo reiniciar?";Y["pt-br"].optionsRestart="Reiniciar";Y["pt-br"].optionsSFXBig_on="Com som";Y["pt-br"].optionsSFXBig_off="Sem som";Y["pt-br"].optionsAbout_title="Sobre";Y["pt-br"].optionsAbout_text="CoolGames\n\u00a9 2016";Y["pt-br"].optionsAbout_backBtn="Voltar";Y["pt-br"].optionsAbout_version="vers\u00e3o:";Y["pt-br"].optionsAbout="Sobre";
Y["pt-br"].levelEndScreenMedal="MELHOROU!";Y["pt-br"].startScreenQuestionaire="O que voc\u00ea achou?";Y["pt-br"].levelMapScreenWorld_0="Selecione um n\u00edvel";Y["pt-br"].startScreenByTinglyGames="da: CoolGames";Y["pt-br"]["optionsLang_de-de"]="Alem\u00e3o";Y["pt-br"]["optionsLang_tr-tr"]="Turco";Y["pt-br"].optionsAbout_header="Desenvolvido por:";Y["pt-br"].levelEndScreenViewHighscoreBtn="Ver pontua\u00e7\u00f5es";Y["pt-br"].levelEndScreenSubmitHighscoreBtn="Enviar recorde";
Y["pt-br"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["pt-br"].challengeStartTextScore="<NAME>'s score:";Y["pt-br"].challengeStartTextTime="<NAME>'s time:";Y["pt-br"].challengeStartScreenToWin="Amount to win:";Y["pt-br"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["pt-br"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["pt-br"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";
Y["pt-br"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["pt-br"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";Y["pt-br"].challengeCancelConfirmBtn_yes="Yes";Y["pt-br"].challengeCancelConfirmBtn_no="No";Y["pt-br"].challengeEndScreensBtn_submit="Submit challenge";Y["pt-br"].challengeEndScreenBtn_cancel="Cancel challenge";Y["pt-br"].challengeEndScreenName_you="You";
Y["pt-br"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["pt-br"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["pt-br"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";Y["pt-br"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["pt-br"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";
Y["pt-br"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["pt-br"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["pt-br"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["pt-br"].challengeStartTextTime_challenger="Play the game and set a time.";Y["pt-br"].challengeStartTextScore_challenger="Play the game and set a score.";Y["pt-br"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";
Y["pt-br"].challengeForfeitConfirmBtn_yes="Yes";Y["pt-br"].challengeForfeitConfirmBtn_no="No";Y["pt-br"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["pt-br"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Y["pt-br"].optionsChallengeForfeit="Desistir";Y["pt-br"].optionsChallengeCancel="Sair do Jogo";Y["pt-br"].challengeLoadingError_notValid="Desculpe, este desafio n\u00e3o \u00e9 mais v\u00e1lido.";
Y["pt-br"].challengeLoadingError_notStarted="Imposs\u00edvel conectar ao servidor. Por favor, tente novamente mais tarde.";Y["pt-br"].levelEndScreenHighScore_time="Tempo recorde:";Y["pt-br"].levelEndScreenTotalScore_time="Tempo total:";Y["pt-br"]["optionsLang_fr-fr"]="Franc\u00eas";Y["pt-br"]["optionsLang_ko-kr"]="Coreano";Y["pt-br"]["optionsLang_ar-eg"]="\u00c1rabe";Y["pt-br"]["optionsLang_es-es"]="Espanhol";Y["pt-br"]["optionsLang_pt-br"]="Portugu\u00eas do Brasil";
Y["pt-br"]["optionsLang_ru-ru"]="Russo";Y["pt-br"].optionsExit="Sa\u00edda";Y["pt-br"].levelEndScreenTotalScore_number="Pontua\u00e7\u00e3o total:";Y["pt-br"].levelEndScreenHighScore_number="Pontua\u00e7\u00e3o m\u00e1xima:";Y["pt-br"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["pt-br"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["pt-br"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["pt-br"].optionsAbout_header_publisher="Published by:";Y["pt-br"]["optionsLang_jp-jp"]="Japanese";Y["es-es"]=Y["es-es"]||{};Y["es-es"].loadingScreenLoading="Cargando...";Y["es-es"].startScreenPlay="JUGAR";
Y["es-es"].levelMapScreenTotalScore="Punt. total";Y["es-es"].levelEndScreenTitle_level="Nivel <VALUE>";Y["es-es"].levelEndScreenTitle_difficulty="\u00a1Muy bien!";Y["es-es"].levelEndScreenTitle_endless="Fase <VALUE>";Y["es-es"].levelEndScreenTotalScore="Punt. total";Y["es-es"].levelEndScreenSubTitle_levelFailed="Nivel fallido";Y["es-es"].levelEndScreenTimeLeft="Tiempo restante";Y["es-es"].levelEndScreenTimeBonus="Bonif. tiempo";Y["es-es"].levelEndScreenHighScore="R\u00e9cord";
Y["es-es"].optionsStartScreen="Men\u00fa principal";Y["es-es"].optionsQuit="Salir";Y["es-es"].optionsResume="Seguir";Y["es-es"].optionsTutorial="C\u00f3mo jugar";Y["es-es"].optionsHighScore="R\u00e9cords";Y["es-es"].optionsMoreGames="M\u00e1s juegos";Y["es-es"].optionsDifficulty_easy="F\u00e1cil";Y["es-es"].optionsDifficulty_medium="Normal";Y["es-es"].optionsDifficulty_hard="Dif\u00edcil";Y["es-es"].optionsMusic_on="S\u00ed";Y["es-es"].optionsMusic_off="No";Y["es-es"].optionsSFX_on="S\u00ed";
Y["es-es"].optionsSFX_off="No";Y["es-es"]["optionsLang_en-us"]="Ingl\u00e9s (EE.UU.)";Y["es-es"]["optionsLang_en-gb"]="Ingl\u00e9s (GB)";Y["es-es"]["optionsLang_nl-nl"]="Neerland\u00e9s";Y["es-es"].gameEndScreenTitle="\u00a1Enhorabuena!\nHas terminado el juego.";Y["es-es"].gameEndScreenBtnText="Continuar";Y["es-es"].optionsTitle="Ajustes";Y["es-es"].optionsQuitConfirmationText="\u00a1Aviso!\n\nSi sales ahora, perder\u00e1s el progreso que hayas realizado en el nivel. \u00bfSeguro que quieres salir?";
Y["es-es"].optionsQuitConfirmBtn_No="No";Y["es-es"].optionsQuitConfirmBtn_Yes="S\u00ed, seguro";Y["es-es"].levelMapScreenTitle="Elige un nivel";Y["es-es"].optionsRestartConfirmationText="\u00a1Aviso!\n\nSi reinicias ahora, perder\u00e1s el progreso que hayas realizado en el nivel. \u00bfSeguro que quieres reiniciar?";Y["es-es"].optionsRestart="Reiniciar";Y["es-es"].optionsSFXBig_on="Sonido s\u00ed";Y["es-es"].optionsSFXBig_off="Sonido no";Y["es-es"].optionsAbout_title="Acerca de";
Y["es-es"].optionsAbout_text="CoolGames\n\u00a9 2016";Y["es-es"].optionsAbout_backBtn="Atr\u00e1s";Y["es-es"].optionsAbout_version="versi\u00f3n:";Y["es-es"].optionsAbout="Acerca de";Y["es-es"].levelEndScreenMedal="\u00a1SUPERADO!";Y["es-es"].startScreenQuestionaire="\u00bfQu\u00e9 te parece?";Y["es-es"].levelMapScreenWorld_0="Elige un nivel";Y["es-es"].startScreenByTinglyGames="de: CoolGames";Y["es-es"]["optionsLang_de-de"]="Alem\u00e1n";Y["es-es"]["optionsLang_tr-tr"]="Turco";
Y["es-es"].optionsAbout_header="Desarrollado por:";Y["es-es"].levelEndScreenViewHighscoreBtn="Ver puntuaciones";Y["es-es"].levelEndScreenSubmitHighscoreBtn="Enviar puntuaci\u00f3n";Y["es-es"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["es-es"].challengeStartTextScore="<NAME>'s score:";Y["es-es"].challengeStartTextTime="<NAME>'s time:";Y["es-es"].challengeStartScreenToWin="Amount to win:";Y["es-es"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";
Y["es-es"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["es-es"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["es-es"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["es-es"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";Y["es-es"].challengeCancelConfirmBtn_yes="Yes";Y["es-es"].challengeCancelConfirmBtn_no="No";
Y["es-es"].challengeEndScreensBtn_submit="Submit challenge";Y["es-es"].challengeEndScreenBtn_cancel="Cancel challenge";Y["es-es"].challengeEndScreenName_you="You";Y["es-es"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["es-es"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["es-es"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Y["es-es"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["es-es"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["es-es"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["es-es"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["es-es"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Y["es-es"].challengeStartTextTime_challenger="Play the game and set a time.";Y["es-es"].challengeStartTextScore_challenger="Play the game and set a score.";Y["es-es"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["es-es"].challengeForfeitConfirmBtn_yes="Yes";Y["es-es"].challengeForfeitConfirmBtn_no="No";Y["es-es"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["es-es"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
Y["es-es"].optionsChallengeForfeit="Rendirse";Y["es-es"].optionsChallengeCancel="Abandonar";Y["es-es"].challengeLoadingError_notValid="Lo sentimos, este reto ya no es v\u00e1lido.";Y["es-es"].challengeLoadingError_notStarted="Imposible conectar con el servidor. Int\u00e9ntalo m\u00e1s tarde.";Y["es-es"].levelEndScreenHighScore_time="Mejor tiempo:";Y["es-es"].levelEndScreenTotalScore_time="Tiempo total:";Y["es-es"]["optionsLang_fr-fr"]="Franc\u00e9s";Y["es-es"]["optionsLang_ko-kr"]="Coreano";
Y["es-es"]["optionsLang_ar-eg"]="\u00c1rabe";Y["es-es"]["optionsLang_es-es"]="Espa\u00f1ol";Y["es-es"]["optionsLang_pt-br"]="Portugu\u00e9s brasile\u00f1o";Y["es-es"]["optionsLang_ru-ru"]="Ruso";Y["es-es"].optionsExit="Salir";Y["es-es"].levelEndScreenTotalScore_number="Puntos totales:";Y["es-es"].levelEndScreenHighScore_number="Mejor puntuaci\u00f3n:";Y["es-es"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["es-es"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["es-es"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["es-es"].optionsAbout_header_publisher="Published by:";Y["es-es"]["optionsLang_jp-jp"]="Japanese";Y["tr-tr"]=Y["tr-tr"]||{};Y["tr-tr"].loadingScreenLoading="Y\u00fckleniyor...";Y["tr-tr"].startScreenPlay="OYNA";
Y["tr-tr"].levelMapScreenTotalScore="Toplam skor";Y["tr-tr"].levelEndScreenTitle_level="Seviye <VALUE>";Y["tr-tr"].levelEndScreenTitle_difficulty="Bravo!";Y["tr-tr"].levelEndScreenTitle_endless="Seviye <VALUE>";Y["tr-tr"].levelEndScreenTotalScore="Toplam skor";Y["tr-tr"].levelEndScreenSubTitle_levelFailed="Seviye ba\u015far\u0131s\u0131z";Y["tr-tr"].levelEndScreenTimeLeft="Kalan S\u00fcre";Y["tr-tr"].levelEndScreenTimeBonus="S\u00fcre Bonusu";Y["tr-tr"].levelEndScreenHighScore="Y\u00fcksek skor";
Y["tr-tr"].optionsStartScreen="Ana men\u00fc";Y["tr-tr"].optionsQuit="\u00c7\u0131k";Y["tr-tr"].optionsResume="Devam et";Y["tr-tr"].optionsTutorial="Nas\u0131l oynan\u0131r";Y["tr-tr"].optionsHighScore="Y\u00fcksek skorlar";Y["tr-tr"].optionsMoreGames="Daha Fazla Oyun";Y["tr-tr"].optionsDifficulty_easy="Kolay";Y["tr-tr"].optionsDifficulty_medium="Orta";Y["tr-tr"].optionsDifficulty_hard="Zorluk";Y["tr-tr"].optionsMusic_on="A\u00e7\u0131k";Y["tr-tr"].optionsMusic_off="Kapal\u0131";
Y["tr-tr"].optionsSFX_on="A\u00e7\u0131k";Y["tr-tr"].optionsSFX_off="Kapal\u0131";Y["tr-tr"]["optionsLang_en-us"]="\u0130ngilizce (US)";Y["tr-tr"]["optionsLang_en-gb"]="\u0130ngilizce (GB)";Y["tr-tr"]["optionsLang_nl-nl"]="Hollandaca";Y["tr-tr"].gameEndScreenTitle="Tebrikler!\nOyunu tamamlad\u0131n.";Y["tr-tr"].gameEndScreenBtnText="Devam";Y["tr-tr"].optionsTitle="Ayarlar";Y["tr-tr"].optionsQuitConfirmationText="Dikkat!\n\u015eimdi \u00e7\u0131karsan bu seviyede yap\u0131lan t\u00fcm ilerleme kaybedilecek. \u00c7\u0131kmak istedi\u011finizden emin misiniz?";
Y["tr-tr"].optionsQuitConfirmBtn_No="Hay\u0131r";Y["tr-tr"].optionsQuitConfirmBtn_Yes="Evet, eminim";Y["tr-tr"].levelMapScreenTitle="Bir seviye se\u00e7";Y["tr-tr"].optionsRestartConfirmationText="Dikkat!\n\u015eimdi tekrar ba\u015flarsan bu seviyede yap\u0131lan t\u00fcm ilerleme kaybedilecek. Ba\u015ftan ba\u015flamak istedi\u011finden emin misin?";Y["tr-tr"].optionsRestart="Tekrar ba\u015flat";Y["tr-tr"].optionsSFXBig_on="Ses a\u00e7\u0131k";Y["tr-tr"].optionsSFXBig_off="Ses kapal\u0131";
Y["tr-tr"].optionsAbout_title="Hakk\u0131nda";Y["tr-tr"].optionsAbout_text="CoolGames\n\u00a9 2016";Y["tr-tr"].optionsAbout_backBtn="Geri";Y["tr-tr"].optionsAbout_version="s\u00fcr\u00fcm:";Y["tr-tr"].optionsAbout="Hakk\u0131nda";Y["tr-tr"].levelEndScreenMedal="\u0130Y\u0130LE\u015eT\u0130!";Y["tr-tr"].startScreenQuestionaire="Ne dersin?";Y["tr-tr"].levelMapScreenWorld_0="Bir seviye se\u00e7";Y["tr-tr"].startScreenByTinglyGames="taraf\u0131ndan: CoolGames";Y["tr-tr"]["optionsLang_de-de"]="Almanca";
Y["tr-tr"]["optionsLang_tr-tr"]="T\u00fcrk\u00e7e";Y["tr-tr"].optionsAbout_header="Haz\u0131rlayan:";Y["tr-tr"].levelEndScreenViewHighscoreBtn="Puanlar\u0131 g\u00f6ster:";Y["tr-tr"].levelEndScreenSubmitHighscoreBtn="Puan g\u00f6nder";Y["tr-tr"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["tr-tr"].challengeStartTextScore="<NAME>'s score:";Y["tr-tr"].challengeStartTextTime="<NAME>'s time:";Y["tr-tr"].challengeStartScreenToWin="Amount to win:";
Y["tr-tr"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["tr-tr"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["tr-tr"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["tr-tr"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["tr-tr"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["tr-tr"].challengeCancelConfirmBtn_yes="Yes";Y["tr-tr"].challengeCancelConfirmBtn_no="No";Y["tr-tr"].challengeEndScreensBtn_submit="Submit challenge";Y["tr-tr"].challengeEndScreenBtn_cancel="Cancel challenge";Y["tr-tr"].challengeEndScreenName_you="You";Y["tr-tr"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["tr-tr"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
Y["tr-tr"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";Y["tr-tr"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["tr-tr"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["tr-tr"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["tr-tr"].challengeStartScreenTitle_challenger_friend="You are challenging:";
Y["tr-tr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["tr-tr"].challengeStartTextTime_challenger="Play the game and set a time.";Y["tr-tr"].challengeStartTextScore_challenger="Play the game and set a score.";Y["tr-tr"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["tr-tr"].challengeForfeitConfirmBtn_yes="Yes";Y["tr-tr"].challengeForfeitConfirmBtn_no="No";Y["tr-tr"].challengeForfeitMessage_success="You have forfeited the challenge.";
Y["tr-tr"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Y["tr-tr"].optionsChallengeForfeit="Vazge\u00e7";Y["tr-tr"].optionsChallengeCancel="\u00c7\u0131k\u0131\u015f";Y["tr-tr"].challengeLoadingError_notValid="\u00dczg\u00fcn\u00fcz, bu zorluk art\u0131k ge\u00e7erli de\u011fil.";Y["tr-tr"].challengeLoadingError_notStarted="Sunucuya ba\u011flan\u0131lam\u0131yor. L\u00fctfen daha sonra tekrar deneyin.";
Y["tr-tr"].levelEndScreenHighScore_time="En \u0130yi Zaman:";Y["tr-tr"].levelEndScreenTotalScore_time="Toplam Zaman:";Y["tr-tr"]["optionsLang_fr-fr"]="Frans\u0131zca";Y["tr-tr"]["optionsLang_ko-kr"]="Korece";Y["tr-tr"]["optionsLang_ar-eg"]="Arap\u00e7a";Y["tr-tr"]["optionsLang_es-es"]="\u0130spanyolca";Y["tr-tr"]["optionsLang_pt-br"]="Brezilya Portekizcesi";Y["tr-tr"]["optionsLang_ru-ru"]="Rus\u00e7a";Y["tr-tr"].optionsExit="\u00c7\u0131k\u0131\u015f";Y["tr-tr"].levelEndScreenTotalScore_number="Toplam Puan:";
Y["tr-tr"].levelEndScreenHighScore_number="Y\u00fcksek Puan:";Y["tr-tr"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";Y["tr-tr"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";
Y["tr-tr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["tr-tr"].optionsAbout_header_publisher="Published by:";Y["tr-tr"]["optionsLang_jp-jp"]="Japanese";Y["ru-ru"]=Y["ru-ru"]||{};Y["ru-ru"].loadingScreenLoading="\u0417\u0430\u0433\u0440\u0443\u0437\u043a\u0430...";Y["ru-ru"].startScreenPlay="\u0418\u0413\u0420\u0410\u0422\u042c";Y["ru-ru"].levelMapScreenTotalScore="\u041e\u0431\u0449\u0438\u0439 \u0441\u0447\u0435\u0442";Y["ru-ru"].levelEndScreenTitle_level="\u0423\u0440\u043e\u0432\u0435\u043d\u044c <VALUE>";
Y["ru-ru"].levelEndScreenTitle_difficulty="\u0425\u043e\u0440\u043e\u0448\u0438\u0439 \u0440\u0435\u0437\u0443\u043b\u044c\u0442\u0430\u0442!";Y["ru-ru"].levelEndScreenTitle_endless="\u042d\u0442\u0430\u043f <VALUE>";Y["ru-ru"].levelEndScreenTotalScore="\u041e\u0431\u0449\u0438\u0439 \u0441\u0447\u0435\u0442";Y["ru-ru"].levelEndScreenSubTitle_levelFailed="\u0423\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u043f\u0440\u043e\u0439\u0434\u0435\u043d";Y["ru-ru"].levelEndScreenTimeLeft="\u041e\u0441\u0442\u0430\u0432\u0448\u0435\u0435\u0441\u044f \u0432\u0440\u0435\u043c\u044f";
Y["ru-ru"].levelEndScreenTimeBonus="\u0414\u043e\u043f\u043e\u043b\u043d\u0438\u0442\u0435\u043b\u044c\u043d\u043e\u0435 \u0432\u0440\u0435\u043c\u044f";Y["ru-ru"].levelEndScreenHighScore="\u0420\u0435\u043a\u043e\u0440\u0434";Y["ru-ru"].optionsStartScreen="\u0413\u043b\u0430\u0432\u043d\u043e\u0435 \u043c\u0435\u043d\u044e";Y["ru-ru"].optionsQuit="\u0412\u044b\u0439\u0442\u0438";Y["ru-ru"].optionsResume="\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u044c";Y["ru-ru"].optionsTutorial="\u041a\u0430\u043a \u0438\u0433\u0440\u0430\u0442\u044c";
Y["ru-ru"].optionsHighScore="\u0420\u0435\u043a\u043e\u0440\u0434\u044b";Y["ru-ru"].optionsMoreGames="\u0411\u043e\u043b\u044c\u0448\u0435 \u0438\u0433\u0440";Y["ru-ru"].optionsDifficulty_easy="\u041b\u0435\u0433\u043a\u0438\u0439";Y["ru-ru"].optionsDifficulty_medium="\u0421\u0440\u0435\u0434\u043d\u0438\u0439";Y["ru-ru"].optionsDifficulty_hard="\u0421\u043b\u043e\u0436\u043d\u044b\u0439";Y["ru-ru"].optionsMusic_on="\u0412\u043a\u043b.";Y["ru-ru"].optionsMusic_off="\u0412\u044b\u043a\u043b.";
Y["ru-ru"].optionsSFX_on="\u0412\u043a\u043b.";Y["ru-ru"].optionsSFX_off="\u0412\u044b\u043a\u043b.";Y["ru-ru"]["optionsLang_en-us"]="\u0410\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 (\u0421\u0428\u0410)";Y["ru-ru"]["optionsLang_en-gb"]="\u0410\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 (\u0412\u0411)";Y["ru-ru"]["optionsLang_nl-nl"]="\u041d\u0438\u0434\u0435\u0440\u043b\u0430\u043d\u0434\u0441\u043a\u0438\u0439";Y["ru-ru"].gameEndScreenTitle="\u041f\u043e\u0437\u0434\u0440\u0430\u0432\u043b\u044f\u0435\u043c!\n\u0412\u044b \u043f\u0440\u043e\u0448\u043b\u0438 \u0438\u0433\u0440\u0443.";
Y["ru-ru"].gameEndScreenBtnText="\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u044c";Y["ru-ru"].optionsTitle="\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438";Y["ru-ru"].optionsQuitConfirmationText="\u0412\u043d\u0438\u043c\u0430\u043d\u0438\u0435!\n\n\u0415\u0441\u043b\u0438 \u0432\u044b \u0432\u044b\u0439\u0434\u0435\u0442\u0435 \u0441\u0435\u0439\u0447\u0430\u0441, \u0443\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u0431\u0443\u0434\u0435\u0442 \u0437\u0430\u0441\u0447\u0438\u0442\u0430\u043d. \u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0432\u044b\u0439\u0442\u0438?";
Y["ru-ru"].optionsQuitConfirmBtn_No="\u041d\u0435\u0442";Y["ru-ru"].optionsQuitConfirmBtn_Yes="\u0414\u0430, \u0432\u044b\u0439\u0442\u0438";Y["ru-ru"].levelMapScreenTitle="\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0440\u043e\u0432\u0435\u043d\u044c";Y["ru-ru"].optionsRestartConfirmationText="\u0412\u043d\u0438\u043c\u0430\u043d\u0438\u0435!\n\n\u0415\u0441\u043b\u0438 \u0432\u044b \u0441\u0435\u0439\u0447\u0430\u0441 \u043d\u0430\u0447\u043d\u0435\u0442\u0435 \u0438\u0433\u0440\u0443 \u0437\u0430\u043d\u043e\u0432\u043e, \u0443\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u0431\u0443\u0434\u0435\u0442 \u0437\u0430\u0441\u0447\u0438\u0442\u0430\u043d. \u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u043d\u0430\u0447\u0430\u0442\u044c \u0437\u0430\u043d\u043e\u0432\u043e?";
Y["ru-ru"].optionsRestart="\u0417\u0430\u043d\u043e\u0432\u043e";Y["ru-ru"].optionsSFXBig_on="\u0417\u0432\u0443\u043a \u0432\u043a\u043b.";Y["ru-ru"].optionsSFXBig_off="\u0417\u0432\u0443\u043a \u0432\u044b\u043a\u043b.";Y["ru-ru"].optionsAbout_title="\u041e \u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0435";Y["ru-ru"].optionsAbout_text="\u00a9 CoolGames\n2016";Y["ru-ru"].optionsAbout_backBtn="\u041d\u0430\u0437\u0430\u0434";Y["ru-ru"].optionsAbout_version="\u0412\u0435\u0440\u0441\u0438\u044f:";
Y["ru-ru"].optionsAbout="\u041e \u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0435";Y["ru-ru"].levelEndScreenMedal="\u041d\u041e\u0412\u042b\u0419 \u0420\u0415\u041a\u041e\u0420\u0414!";Y["ru-ru"].startScreenQuestionaire="\u041a\u0430\u043a \u0432\u0430\u043c \u0438\u0433\u0440\u0430?";Y["ru-ru"].levelMapScreenWorld_0="\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0440\u043e\u0432\u0435\u043d\u044c";Y["ru-ru"].startScreenByTinglyGames="\u0420\u0430\u0437\u0440\u0430\u0431\u043e\u0442\u0447\u0438\u043a\u0438: CoolGames";
Y["ru-ru"]["optionsLang_de-de"]="\u041d\u0435\u043c\u0435\u0446\u043a\u0438\u0439";Y["ru-ru"]["optionsLang_tr-tr"]="\u0422\u0443\u0440\u0435\u0446\u043a\u0438\u0439";Y["ru-ru"].optionsAbout_header="Developed by:";Y["ru-ru"].levelEndScreenViewHighscoreBtn="View scores";Y["ru-ru"].levelEndScreenSubmitHighscoreBtn="Submit score";Y["ru-ru"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["ru-ru"].challengeStartTextScore="<NAME>'s score:";
Y["ru-ru"].challengeStartTextTime="<NAME>'s time:";Y["ru-ru"].challengeStartScreenToWin="Amount to win:";Y["ru-ru"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["ru-ru"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["ru-ru"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["ru-ru"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["ru-ru"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["ru-ru"].challengeCancelConfirmBtn_yes="Yes";Y["ru-ru"].challengeCancelConfirmBtn_no="No";Y["ru-ru"].challengeEndScreensBtn_submit="Submit challenge";Y["ru-ru"].challengeEndScreenBtn_cancel="Cancel challenge";Y["ru-ru"].challengeEndScreenName_you="You";Y["ru-ru"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["ru-ru"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
Y["ru-ru"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";Y["ru-ru"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["ru-ru"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["ru-ru"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["ru-ru"].challengeStartScreenTitle_challenger_friend="You are challenging:";
Y["ru-ru"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["ru-ru"].challengeStartTextTime_challenger="Play the game and set a time.";Y["ru-ru"].challengeStartTextScore_challenger="Play the game and set a score.";Y["ru-ru"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["ru-ru"].challengeForfeitConfirmBtn_yes="Yes";Y["ru-ru"].challengeForfeitConfirmBtn_no="No";Y["ru-ru"].challengeForfeitMessage_success="You have forfeited the challenge.";
Y["ru-ru"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Y["ru-ru"].optionsChallengeForfeit="Forfeit";Y["ru-ru"].optionsChallengeCancel="Quit";Y["ru-ru"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["ru-ru"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Y["ru-ru"].levelEndScreenHighScore_time="Best time:";Y["ru-ru"].levelEndScreenTotalScore_time="Total time:";
Y["ru-ru"]["optionsLang_fr-fr"]="\u0424\u0440\u0430\u043d\u0446\u0443\u0437\u0441\u043a\u0438\u0439";Y["ru-ru"]["optionsLang_ko-kr"]="\u041a\u043e\u0440\u0435\u0439\u0441\u043a\u0438\u0439";Y["ru-ru"]["optionsLang_ar-eg"]="\u0410\u0440\u0430\u0431\u0441\u043a\u0438\u0439";Y["ru-ru"]["optionsLang_es-es"]="\u0418\u0441\u043f\u0430\u043d\u0441\u043a\u0438\u0439";Y["ru-ru"]["optionsLang_pt-br"]="\u0411\u0440\u0430\u0437\u0438\u043b\u044c\u0441\u043a\u0438\u0439 \u043f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u044c\u0441\u043a\u0438\u0439";
Y["ru-ru"]["optionsLang_ru-ru"]="\u0420\u0443\u0441\u0441\u043a\u0438\u0439";Y["ru-ru"].optionsExit="Exit";Y["ru-ru"].levelEndScreenTotalScore_number="Total score:";Y["ru-ru"].levelEndScreenHighScore_number="High score:";Y["ru-ru"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["ru-ru"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["ru-ru"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["ru-ru"].optionsAbout_header_publisher="Published by:";Y["ru-ru"]["optionsLang_jp-jp"]="Japanese";Y["ar-eg"]=Y["ar-eg"]||{};Y["ar-eg"].loadingScreenLoading="\u064a\u062a\u0645 \u0627\u0644\u0622\u0646 \u0627\u0644\u062a\u062d\u0645\u064a\u0644...";
Y["ar-eg"].startScreenPlay="\u062a\u0634\u063a\u064a\u0644";Y["ar-eg"].levelMapScreenTotalScore="\u0627\u0644\u0646\u062a\u064a\u062c\u0629 \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a\u0629";Y["ar-eg"].levelEndScreenTitle_level="\u0627\u0644\u0645\u0633\u062a\u0648\u0649 <VALUE>";Y["ar-eg"].levelEndScreenTitle_difficulty="\u0623\u062d\u0633\u0646\u062a!";Y["ar-eg"].levelEndScreenTitle_endless="\u0627\u0644\u0645\u0631\u062d\u0644\u0629 <VALUE>";Y["ar-eg"].levelEndScreenTotalScore="\u0627\u0644\u0646\u062a\u064a\u062c\u0629 \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a\u0629";
Y["ar-eg"].levelEndScreenSubTitle_levelFailed="\u0644\u0642\u062f \u0641\u0634\u0644\u062a \u0641\u064a \u0627\u062c\u062a\u064a\u0627\u0632 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649";Y["ar-eg"].levelEndScreenTimeLeft="\u0627\u0644\u0648\u0642\u062a \u0627\u0644\u0645\u062a\u0628\u0642\u064a";Y["ar-eg"].levelEndScreenTimeBonus="\u0645\u0643\u0627\u0641\u0623\u0629 \u0627\u0644\u0648\u0642\u062a";Y["ar-eg"].levelEndScreenHighScore="\u0623\u0639\u0644\u0649 \u0646\u062a\u064a\u062c\u0629";
Y["ar-eg"].optionsStartScreen="\u0627\u0644\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629";Y["ar-eg"].optionsQuit="\u0627\u0644\u062e\u0631\u0648\u062c \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629";Y["ar-eg"].optionsResume="\u0627\u0633\u062a\u0626\u0646\u0627\u0641";Y["ar-eg"].optionsTutorial="\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u0644\u0639\u0628";Y["ar-eg"].optionsHighScore="\u0623\u0639\u0644\u0649 \u0627\u0644\u0646\u062a\u0627\u0626\u062c";
Y["ar-eg"].optionsMoreGames="\u0627\u0644\u0645\u0632\u064a\u062f \u0645\u0646 \u0627\u0644\u0623\u0644\u0639\u0627\u0628";Y["ar-eg"].optionsDifficulty_easy="\u0633\u0647\u0644";Y["ar-eg"].optionsDifficulty_medium="\u0645\u062a\u0648\u0633\u0637";Y["ar-eg"].optionsDifficulty_hard="\u0635\u0639\u0628";Y["ar-eg"].optionsMusic_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0645\u0648\u0633\u064a\u0642\u0649";Y["ar-eg"].optionsMusic_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0645\u0648\u0633\u064a\u0642\u0649";
Y["ar-eg"].optionsSFX_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0645\u0624\u062b\u0631\u0627\u062a \u0627\u0644\u0635\u0648\u062a\u064a\u0629";Y["ar-eg"].optionsSFX_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0645\u0624\u062b\u0631\u0627\u062a \u0627\u0644\u0635\u0648\u062a\u064a\u0629";Y["ar-eg"]["optionsLang_en-us"]="\u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 (\u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a \u0627\u0644\u0645\u062a\u062d\u062f\u0629)";
Y["ar-eg"]["optionsLang_en-gb"]="\u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 (\u0627\u0644\u0645\u0645\u0644\u0643\u0629 \u0627\u0644\u0645\u062a\u062d\u062f\u0629)";Y["ar-eg"]["optionsLang_nl-nl"]="\u0627\u0644\u0647\u0648\u0644\u0646\u062f\u064a\u0629";Y["ar-eg"].gameEndScreenTitle="\u062a\u0647\u0627\u0646\u064a\u0646\u0627!\n\u0644\u0642\u062f \u0623\u0643\u0645\u0644\u062a \u0627\u0644\u0644\u0639\u0628\u0629.";Y["ar-eg"].gameEndScreenBtnText="\u0645\u062a\u0627\u0628\u0639\u0629";
Y["ar-eg"].optionsTitle="\u0627\u0644\u0625\u0639\u062f\u0627\u062f\u0627\u062a";Y["ar-eg"].optionsQuitConfirmationText="\u0627\u0646\u062a\u0628\u0647!n\n\u0625\u0630\u0627 \u062e\u0631\u062c\u062a \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629 \u0627\u0644\u0622\u0646\u060c \u0641\u0633\u062a\u0641\u0642\u062f \u0643\u0644 \u0627\u0644\u062a\u0642\u062f\u0645 \u0627\u0644\u0630\u064a \u0623\u062d\u0631\u0632\u062a\u0647 \u062e\u0644\u0627\u0644 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649. \u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0627\u0644\u062e\u0631\u0648\u062c \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629\u061f";
Y["ar-eg"].optionsQuitConfirmBtn_No="\u0644\u0627";Y["ar-eg"].optionsQuitConfirmBtn_Yes="\u0646\u0639\u0645\u060c \u0645\u062a\u0623\u0643\u062f";Y["ar-eg"].levelMapScreenTitle="\u062a\u062d\u062f\u064a\u062f \u0645\u0633\u062a\u0648\u0649";Y["ar-eg"].optionsRestartConfirmationText="\u0627\u0646\u062a\u0628\u0647!\n\n\u0625\u0630\u0627 \u0642\u0645\u062a \u0628\u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0622\u0646\u060c \u0641\u0633\u062a\u0641\u0642\u062f \u0643\u0644 \u0627\u0644\u062a\u0642\u062f\u0645 \u0627\u0644\u0630\u064a \u0623\u062d\u0631\u0632\u062a\u0647 \u062e\u0644\u0627\u0644 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649. \u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644\u061f";
Y["ar-eg"].optionsRestart="\u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644";Y["ar-eg"].optionsSFXBig_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0635\u0648\u062a";Y["ar-eg"].optionsSFXBig_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0635\u0648\u062a";Y["ar-eg"].optionsAbout_title="\u062d\u0648\u0644";Y["ar-eg"].optionsAbout_text="CoolGames\n\u00a9 2016";Y["ar-eg"].optionsAbout_backBtn="\u0627\u0644\u0633\u0627\u0628\u0642";Y["ar-eg"].optionsAbout_version="\u0627\u0644\u0625\u0635\u062f\u0627\u0631:";
Y["ar-eg"].optionsAbout="\u062d\u0648\u0644";Y["ar-eg"].levelEndScreenMedal="\u0644\u0642\u062f \u062a\u062d\u0633\u0651\u0646\u062a!";Y["ar-eg"].startScreenQuestionaire="\u0645\u0627 \u0631\u0623\u064a\u0643\u061f";Y["ar-eg"].levelMapScreenWorld_0="\u062a\u062d\u062f\u064a\u062f \u0645\u0633\u062a\u0648\u0649";Y["ar-eg"].startScreenByTinglyGames="\u0628\u0648\u0627\u0633\u0637\u0629: CoolGames";Y["ar-eg"]["optionsLang_de-de"]="\u0627\u0644\u0623\u0644\u0645\u0627\u0646\u064a\u0629";
Y["ar-eg"]["optionsLang_tr-tr"]="\u0627\u0644\u062a\u0631\u0643\u064a\u0629";Y["ar-eg"].optionsAbout_header="Developed by:";Y["ar-eg"].levelEndScreenViewHighscoreBtn="View scores";Y["ar-eg"].levelEndScreenSubmitHighscoreBtn="Submit score";Y["ar-eg"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["ar-eg"].challengeStartTextScore="<NAME>'s score:";Y["ar-eg"].challengeStartTextTime="<NAME>'s time:";Y["ar-eg"].challengeStartScreenToWin="Amount to win:";
Y["ar-eg"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["ar-eg"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["ar-eg"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["ar-eg"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["ar-eg"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["ar-eg"].challengeCancelConfirmBtn_yes="Yes";Y["ar-eg"].challengeCancelConfirmBtn_no="No";Y["ar-eg"].challengeEndScreensBtn_submit="Submit challenge";Y["ar-eg"].challengeEndScreenBtn_cancel="Cancel challenge";Y["ar-eg"].challengeEndScreenName_you="You";Y["ar-eg"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["ar-eg"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
Y["ar-eg"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";Y["ar-eg"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["ar-eg"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["ar-eg"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["ar-eg"].challengeStartScreenTitle_challenger_friend="You are challenging:";
Y["ar-eg"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["ar-eg"].challengeStartTextTime_challenger="Play the game and set a time.";Y["ar-eg"].challengeStartTextScore_challenger="Play the game and set a score.";Y["ar-eg"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["ar-eg"].challengeForfeitConfirmBtn_yes="Yes";Y["ar-eg"].challengeForfeitConfirmBtn_no="No";Y["ar-eg"].challengeForfeitMessage_success="You have forfeited the challenge.";
Y["ar-eg"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Y["ar-eg"].optionsChallengeForfeit="Forfeit";Y["ar-eg"].optionsChallengeCancel="Quit";Y["ar-eg"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["ar-eg"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Y["ar-eg"].levelEndScreenHighScore_time="Best time:";Y["ar-eg"].levelEndScreenTotalScore_time="Total time:";
Y["ar-eg"]["optionsLang_fr-fr"]="\u0627\u0644\u0641\u0631\u0646\u0633\u064a\u0629";Y["ar-eg"]["optionsLang_ko-kr"]="\u0627\u0644\u0643\u0648\u0631\u064a\u0629";Y["ar-eg"]["optionsLang_ar-eg"]="\u0627\u0644\u0639\u0631\u0628\u064a\u0629";Y["ar-eg"]["optionsLang_es-es"]="\u0627\u0644\u0625\u0633\u0628\u0627\u0646\u064a\u0629";Y["ar-eg"]["optionsLang_pt-br"]="\u0627\u0644\u0628\u0631\u0627\u0632\u064a\u0644\u064a\u0629 - \u0627\u0644\u0628\u0631\u062a\u063a\u0627\u0644\u064a\u0629";
Y["ar-eg"]["optionsLang_ru-ru"]="\u0627\u0644\u0631\u0648\u0633\u064a\u0629";Y["ar-eg"].optionsExit="Exit";Y["ar-eg"].levelEndScreenTotalScore_number="Total score:";Y["ar-eg"].levelEndScreenHighScore_number="High score:";Y["ar-eg"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["ar-eg"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["ar-eg"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["ar-eg"].optionsAbout_header_publisher="Published by:";Y["ar-eg"]["optionsLang_jp-jp"]="Japanese";Y["ko-kr"]=Y["ko-kr"]||{};Y["ko-kr"].loadingScreenLoading="\ubd88\ub7ec\uc624\uae30 \uc911...";Y["ko-kr"].startScreenPlay="PLAY";
Y["ko-kr"].levelMapScreenTotalScore="\ucd1d \uc810\uc218";Y["ko-kr"].levelEndScreenTitle_level="\ub808\ubca8 <VALUE>";Y["ko-kr"].levelEndScreenTitle_difficulty="\uc798 \ud588\uc5b4\uc694!";Y["ko-kr"].levelEndScreenTitle_endless="\uc2a4\ud14c\uc774\uc9c0 <VALUE>";Y["ko-kr"].levelEndScreenTotalScore="\ucd1d \uc810\uc218";Y["ko-kr"].levelEndScreenSubTitle_levelFailed="\ub808\ubca8 \uc2e4\ud328";Y["ko-kr"].levelEndScreenTimeLeft="\ub0a8\uc740 \uc2dc\uac04";Y["ko-kr"].levelEndScreenTimeBonus="\uc2dc\uac04 \ubcf4\ub108\uc2a4";
Y["ko-kr"].levelEndScreenHighScore="\ucd5c\uace0 \uc810\uc218";Y["ko-kr"].optionsStartScreen="\uba54\uc778 \uba54\ub274";Y["ko-kr"].optionsQuit="\uc885\ub8cc";Y["ko-kr"].optionsResume="\uacc4\uc18d";Y["ko-kr"].optionsTutorial="\uac8c\uc784 \ubc29\ubc95";Y["ko-kr"].optionsHighScore="\ucd5c\uace0 \uc810\uc218";Y["ko-kr"].optionsMoreGames="\ub354 \ub9ce\uc740 \uac8c\uc784";Y["ko-kr"].optionsDifficulty_easy="\uac04\ub2e8";Y["ko-kr"].optionsDifficulty_medium="\uc911";
Y["ko-kr"].optionsDifficulty_hard="\uc0c1";Y["ko-kr"].optionsMusic_on="\ucf1c\uae30";Y["ko-kr"].optionsMusic_off="\ub044\uae30";Y["ko-kr"].optionsSFX_on="\ucf1c\uae30";Y["ko-kr"].optionsSFX_off="\ub044\uae30";Y["ko-kr"]["optionsLang_en-us"]="\uc601\uc5b4(US)";Y["ko-kr"]["optionsLang_en-gb"]="\uc601\uc5b4(GB)";Y["ko-kr"]["optionsLang_nl-nl"]="\ub124\ub35c\ub780\ub4dc\uc5b4";Y["ko-kr"].gameEndScreenTitle="\ucd95\ud558\ud569\ub2c8\ub2e4!\n\uac8c\uc784\uc744 \uc644\ub8cc\ud588\uc2b5\ub2c8\ub2e4.";
Y["ko-kr"].gameEndScreenBtnText="\uacc4\uc18d";Y["ko-kr"].optionsTitle="\uc124\uc815";Y["ko-kr"].optionsQuitConfirmationText="\uc8fc\uc758!\n\n\uc9c0\uae08 \uc885\ub8cc\ud558\uba74 \uc774 \ub808\ubca8\uc758 \ubaa8\ub4e0 \uc9c4\ud589 \ub0b4\uc6a9\uc744 \uc783\uac8c\ub429\ub2c8\ub2e4. \uc815\ub9d0 \uc885\ub8cc\ud558\uc2dc\uaca0\uc2b5\ub2c8\uae4c?";Y["ko-kr"].optionsQuitConfirmBtn_No="\uc544\ub2c8\uc624";Y["ko-kr"].optionsQuitConfirmBtn_Yes="\ub124, \ud655\uc2e4\ud569\ub2c8\ub2e4";
Y["ko-kr"].levelMapScreenTitle="\ub808\ubca8 \uc120\ud0dd";Y["ko-kr"].optionsRestartConfirmationText="\uc8fc\uc758!\n\n\uc9c0\uae08 \ub2e4\uc2dc \uc2dc\uc791\ud558\uba74 \uc774 \ub808\ubca8\uc758 \ubaa8\ub4e0 \uc9c4\ud589 \ub0b4\uc6a9\uc744 \uc783\uac8c\ub429\ub2c8\ub2e4. \uc815\ub9d0 \ub2e4\uc2dc \uc2dc\uc791\ud558\uc2dc\uaca0\uc2b5\ub2c8\uae4c?";Y["ko-kr"].optionsRestart="\ub2e4\uc2dc \uc2dc\uc791";Y["ko-kr"].optionsSFXBig_on="\uc74c\ud5a5 \ucf1c\uae30";Y["ko-kr"].optionsSFXBig_off="\uc74c\ud5a5 \ub044\uae30";
Y["ko-kr"].optionsAbout_title="\uad00\ub828 \uc815\ubcf4";Y["ko-kr"].optionsAbout_text="CoolGames\n\u00a9 2016";Y["ko-kr"].optionsAbout_backBtn="\ub4a4\ub85c";Y["ko-kr"].optionsAbout_version="\ubc84\uc804:";Y["ko-kr"].optionsAbout="\uad00\ub828 \uc815\ubcf4";Y["ko-kr"].levelEndScreenMedal="\ud5a5\uc0c1\ud588\uad70\uc694!";Y["ko-kr"].startScreenQuestionaire="\uc5b4\ub5bb\uac8c \uc0dd\uac01\ud558\uc138\uc694?";Y["ko-kr"].levelMapScreenWorld_0="\ub808\ubca8 \uc120\ud0dd";
Y["ko-kr"].startScreenByTinglyGames="\uc81c\uc791: CoolGames";Y["ko-kr"]["optionsLang_de-de"]="\ub3c5\uc77c\uc5b4";Y["ko-kr"]["optionsLang_tr-tr"]="\ud130\ud0a4\uc5b4";Y["ko-kr"].optionsAbout_header="Developed by:";Y["ko-kr"].levelEndScreenViewHighscoreBtn="View scores";Y["ko-kr"].levelEndScreenSubmitHighscoreBtn="Submit score";Y["ko-kr"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["ko-kr"].challengeStartTextScore="<NAME>'s score:";
Y["ko-kr"].challengeStartTextTime="<NAME>'s time:";Y["ko-kr"].challengeStartScreenToWin="Amount to win:";Y["ko-kr"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["ko-kr"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["ko-kr"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["ko-kr"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["ko-kr"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["ko-kr"].challengeCancelConfirmBtn_yes="Yes";Y["ko-kr"].challengeCancelConfirmBtn_no="No";Y["ko-kr"].challengeEndScreensBtn_submit="Submit challenge";Y["ko-kr"].challengeEndScreenBtn_cancel="Cancel challenge";Y["ko-kr"].challengeEndScreenName_you="You";Y["ko-kr"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["ko-kr"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
Y["ko-kr"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";Y["ko-kr"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["ko-kr"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["ko-kr"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["ko-kr"].challengeStartScreenTitle_challenger_friend="You are challenging:";
Y["ko-kr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["ko-kr"].challengeStartTextTime_challenger="Play the game and set a time.";Y["ko-kr"].challengeStartTextScore_challenger="Play the game and set a score.";Y["ko-kr"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["ko-kr"].challengeForfeitConfirmBtn_yes="Yes";Y["ko-kr"].challengeForfeitConfirmBtn_no="No";Y["ko-kr"].challengeForfeitMessage_success="You have forfeited the challenge.";
Y["ko-kr"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Y["ko-kr"].optionsChallengeForfeit="Forfeit";Y["ko-kr"].optionsChallengeCancel="Quit";Y["ko-kr"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["ko-kr"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Y["ko-kr"].levelEndScreenHighScore_time="Best time:";Y["ko-kr"].levelEndScreenTotalScore_time="Total time:";
Y["ko-kr"]["optionsLang_fr-fr"]="\ud504\ub791\uc2a4\uc5b4";Y["ko-kr"]["optionsLang_ko-kr"]="\ud55c\uad6d\uc5b4";Y["ko-kr"]["optionsLang_ar-eg"]="\uc544\ub77c\ube44\uc544\uc5b4";Y["ko-kr"]["optionsLang_es-es"]="\uc2a4\ud398\uc778\uc5b4";Y["ko-kr"]["optionsLang_pt-br"]="\ud3ec\ub974\ud22c\uac08\uc5b4(\ube0c\ub77c\uc9c8)";Y["ko-kr"]["optionsLang_ru-ru"]="\ub7ec\uc2dc\uc544\uc5b4";Y["ko-kr"].optionsExit="Exit";Y["ko-kr"].levelEndScreenTotalScore_number="Total score:";
Y["ko-kr"].levelEndScreenHighScore_number="High score:";Y["ko-kr"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";Y["ko-kr"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";
Y["ko-kr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["ko-kr"].optionsAbout_header_publisher="Published by:";Y["ko-kr"]["optionsLang_jp-jp"]="Japanese";Y["jp-jp"]=Y["jp-jp"]||{};Y["jp-jp"].loadingScreenLoading="\u30ed\u30fc\u30c9\u4e2d\u2026";Y["jp-jp"].startScreenPlay="\u30d7\u30ec\u30a4";Y["jp-jp"].levelMapScreenTotalScore="\u30c8\u30fc\u30bf\u30eb\u30b9\u30b3\u30a2";Y["jp-jp"].levelEndScreenTitle_level="\u30ec\u30d9\u30eb <VALUE>";
Y["jp-jp"].levelEndScreenTitle_difficulty="\u3084\u3063\u305f\u306d\uff01";Y["jp-jp"].levelEndScreenTitle_endless="\u30b9\u30c6\u30fc\u30b8 <VALUE>";Y["jp-jp"].levelEndScreenTotalScore="\u30c8\u30fc\u30bf\u30eb\u30b9\u30b3\u30a2";Y["jp-jp"].levelEndScreenSubTitle_levelFailed="\u30b2\u30fc\u30e0\u30aa\u30fc\u30d0\u30fc";Y["jp-jp"].levelEndScreenTimeLeft="\u6b8b\u308a\u6642\u9593";Y["jp-jp"].levelEndScreenTimeBonus="\u30bf\u30a4\u30e0\u30dc\u30fc\u30ca\u30b9";Y["jp-jp"].levelEndScreenHighScore="\u30cf\u30a4\u30b9\u30b3\u30a2";
Y["jp-jp"].optionsStartScreen="\u30e1\u30a4\u30f3\u30e1\u30cb\u30e5\u30fc";Y["jp-jp"].optionsQuit="\u3084\u3081\u308b";Y["jp-jp"].optionsResume="\u518d\u958b";Y["jp-jp"].optionsTutorial="\u3042\u305d\u3073\u65b9";Y["jp-jp"].optionsHighScore="\u30cf\u30a4\u30b9\u30b3\u30a2";Y["jp-jp"].optionsMoreGames="\u4ed6\u306e\u30b2\u30fc\u30e0";Y["jp-jp"].optionsDifficulty_easy="\u521d\u7d1a";Y["jp-jp"].optionsDifficulty_medium="\u4e2d\u7d1a";Y["jp-jp"].optionsDifficulty_hard="\u4e0a\u7d1a";
Y["jp-jp"].optionsMusic_on="\u30aa\u30f3";Y["jp-jp"].optionsMusic_off="\u30aa\u30d5";Y["jp-jp"].optionsSFX_on="\u30aa\u30f3";Y["jp-jp"].optionsSFX_off="\u30aa\u30d5";Y["jp-jp"]["optionsLang_en-us"]="\u82f1\u8a9e\uff08\u7c73\u56fd\uff09";Y["jp-jp"]["optionsLang_en-gb"]="\u82f1\u8a9e\uff08\u82f1\u56fd\uff09";Y["jp-jp"]["optionsLang_nl-nl"]="\u30aa\u30e9\u30f3\u30c0\u8a9e";Y["jp-jp"].gameEndScreenTitle="\u304a\u3081\u3067\u3068\u3046\uff01\n\u3059\u3079\u3066\u306e\u30ec\u30d9\u30eb\u3092\u30af\u30ea\u30a2\u3057\u307e\u3057\u305f\u3002";
Y["jp-jp"].gameEndScreenBtnText="\u7d9a\u3051\u308b";Y["jp-jp"].optionsTitle="\u8a2d\u5b9a";Y["jp-jp"].optionsQuitConfirmationText="\u6ce8\u610f\uff01\n\n\u3053\u3053\u3067\u3084\u3081\u308b\u3068\n\u8a18\u9332\u304c\u30ea\u30bb\u30c3\u30c8\u3055\u308c\u307e\u3059\u304c\n\u3088\u308d\u3057\u3044\u3067\u3059\u304b\uff1f";Y["jp-jp"].optionsQuitConfirmBtn_No="\u3044\u3044\u3048\u3001\u7d9a\u3051\u307e\u3059\u3002";Y["jp-jp"].optionsQuitConfirmBtn_Yes="\u306f\u3044\u3001\u3084\u3081\u307e\u3059\u3002";
Y["jp-jp"].levelMapScreenTitle="\u30ec\u30d9\u30eb\u9078\u629e";Y["jp-jp"].optionsRestartConfirmationText="\u6ce8\u610f\uff01\n\n\u3053\u3053\u3067\u518d\u30b9\u30bf\u30fc\u30c8\u3059\u308b\u3068\n\u8a18\u9332\u304c\u30ea\u30bb\u30c3\u30c8\u3055\u308c\u307e\u3059\u304c\n\u3088\u308d\u3057\u3044\u3067\u3059\u304b\uff1f";Y["jp-jp"].optionsRestart="\u518d\u30b9\u30bf\u30fc\u30c8";Y["jp-jp"].optionsSFXBig_on="\u30b5\u30a6\u30f3\u30c9 \u30aa\u30f3";Y["jp-jp"].optionsSFXBig_off="\u30b5\u30a6\u30f3\u30c9 \u30aa\u30d5";
Y["jp-jp"].optionsAbout_title="About";Y["jp-jp"].optionsAbout_text="CoolGames\n\u00a9 2016";Y["jp-jp"].optionsAbout_backBtn="\u3082\u3069\u308b";Y["jp-jp"].optionsAbout_version="version";Y["jp-jp"].optionsAbout="About";Y["jp-jp"].levelEndScreenMedal="\u8a18\u9332\u66f4\u65b0\uff01";Y["jp-jp"].startScreenQuestionaire="\u3053\u306e\u30b2\u30fc\u30e0\u3078\u306e\u611f\u60f3";Y["jp-jp"].levelMapScreenWorld_0="\u30ec\u30d9\u30eb\u9078\u629e";Y["jp-jp"].startScreenByTinglyGames="by: CoolGames";
Y["jp-jp"]["optionsLang_de-de"]="\u30c9\u30a4\u30c4\u8a9e";Y["jp-jp"]["optionsLang_tr-tr"]="\u30c8\u30eb\u30b3\u8a9e";Y["jp-jp"].optionsAbout_header="Developed by";Y["jp-jp"].levelEndScreenViewHighscoreBtn="\u30b9\u30b3\u30a2\u3092\u307f\u308b";Y["jp-jp"].levelEndScreenSubmitHighscoreBtn="\u30b9\u30b3\u30a2\u9001\u4fe1";Y["jp-jp"].challengeStartScreenTitle_challengee_friend="\u304b\u3089\u6311\u6226\u3092\u53d7\u3051\u307e\u3057\u305f";Y["jp-jp"].challengeStartTextScore="<NAME>\u306e\u30b9\u30b3\u30a2";
Y["jp-jp"].challengeStartTextTime="<NAME>\u306e\u6642\u9593";Y["jp-jp"].challengeStartScreenToWin="\u30dd\u30a4\u30f3\u30c8\u6570";Y["jp-jp"].challengeEndScreenWinnings="<AMOUNT>\u30dd\u30a4\u30f3\u30c8\u7372\u5f97";Y["jp-jp"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["jp-jp"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["jp-jp"].challengeEndScreenOutcomeMessage_TIED="\u540c\u70b9";Y["jp-jp"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["jp-jp"].challengeCancelConfirmBtn_yes="Yes";Y["jp-jp"].challengeCancelConfirmBtn_no="No";Y["jp-jp"].challengeEndScreensBtn_submit="\u3042";Y["jp-jp"].challengeEndScreenBtn_cancel="Cancel challenge";Y["jp-jp"].challengeEndScreenName_you="You";Y["jp-jp"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["jp-jp"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["jp-jp"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Y["jp-jp"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["jp-jp"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["jp-jp"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["jp-jp"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["jp-jp"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Y["jp-jp"].challengeStartTextTime_challenger="Play the game and set a time.";Y["jp-jp"].challengeStartTextScore_challenger="Play the game and set a score.";Y["jp-jp"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["jp-jp"].challengeForfeitConfirmBtn_yes="Yes";Y["jp-jp"].challengeForfeitConfirmBtn_no="No";Y["jp-jp"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["jp-jp"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
Y["jp-jp"].optionsChallengeForfeit="Forfeit";Y["jp-jp"].optionsChallengeCancel="Quit";Y["jp-jp"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["jp-jp"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Y["jp-jp"].levelEndScreenHighScore_time="Best time:";Y["jp-jp"].levelEndScreenTotalScore_time="Total time:";Y["jp-jp"]["optionsLang_fr-fr"]="French";Y["jp-jp"]["optionsLang_ko-kr"]="Korean";Y["jp-jp"]["optionsLang_ar-eg"]="Arabic";
Y["jp-jp"]["optionsLang_es-es"]="Spanish";Y["jp-jp"]["optionsLang_pt-br"]="Brazilian-Portuguese";Y["jp-jp"]["optionsLang_ru-ru"]="Russian";Y["jp-jp"].optionsExit="Exit";Y["jp-jp"].levelEndScreenTotalScore_number="Total score:";Y["jp-jp"].levelEndScreenHighScore_number="High score:";Y["jp-jp"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["jp-jp"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["jp-jp"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["jp-jp"].optionsAbout_header_publisher="Published by:";Y["jp-jp"]["optionsLang_jp-jp"]="\u65e5\u672c\u8a9e";
function $i(){this.depth=-1E6;this.k=this.visible=!0;this.Fa=O.Wd;this.end=this.la=this.Bn=this.An=this.load=this.oc=!1;this.Tm=0;this.Zo=this.ej=!1;this.state="GAME_INIT";this.screen=null;this.Or=this.nb=this.G=0;this.Um=!1;this.Lk=this.Mk=!0;this.uw=1;this.ic=!1;this.Oc={};this.ea={difficulty:1,playMusic:!0,playSFX:!0,language:O.i.ln()};window.addEventListener("gameSetPause",this.Jq,!1);window.addEventListener("gameResume",this.Kq,!1);document.addEventListener("visibilitychange",this.dv,!1);this.Vf=
"timedLevelEvent"}e=$i.prototype;e.Jq=function(){J.pause("master");K.pause()};e.Kq=function(){J.Ii("master");qb(K);wb(K);Ab(K);K.Ii()};e.dv=function(){document.hidden?O.f.Jq():O.f.Kq()};
e.dm=function(){var a,b=this;void 0!==O.a.P.background&&void 0!==O.a.P.background.color&&(document.body.style.background=O.a.P.background.color);O.Aa=new tg;O.A.xk&&O.A.xk.k&&(b.mt=Lh(function(a){b.mt=a}));O.j=O.a.n.wg||{};O.j.Bd=O.j.Bd||"level";O.j.If=void 0!==O.j.If?O.j.If:"level"===O.j.Bd;O.j.S=void 0!==O.j.S?O.j.S instanceof Array?O.j.S:[O.j.S]:[20];O.j.pg=void 0!==O.j.pg?O.j.pg:"locked";O.j.Ki=void 0!==O.j.Ki?O.j.Ki:"difficulty"===O.j.Bd;O.j.cj=void 0!==O.j.cj?O.j.cj:!1;O.j.yo=void 0!==O.j.yo?
O.j.yo:"level"===O.j.Bd;O.j.af=void 0!==O.j.af?O.j.af:"max";O.j.Ff=void 0!==O.j.Ff?O.j.Ff:"number";O.t.Vu(function(a){var d,g,h;a&&(b.Oc=a);b.ea=rg("preferences",{});b.ea.difficulty=void 0!==b.ea.difficulty?b.ea.difficulty:1;void 0!==O.j.Ms&&0>O.j.Ms.indexOf(Eg())&&(b.ea.difficulty=O.j.Ms[0]);b.ea.playMusic=void 0!==b.ea.playMusic?b.ea.playMusic:!0;b.Bf(b.ea.playMusic);b.ea.playSFX=void 0!==b.ea.playSFX?b.ea.playSFX:!0;b.il(b.ea.playSFX);b.ea.language=void 0!==b.ea.language&&O.i.rv(b.ea.language)?
b.ea.language:O.i.ln();O.i.ms(b.ea.language);void 0===Ng(b.G,0,"state",void 0)&&aj(b.G,0,"state","unlocked");if(O.j.If)if("locked"===O.j.pg)for(h=!1,d=0;d<O.j.S.length;d++){for(a=0;a<O.j.S[d];a++)if(g=Ng(d,a,"state","locked"),"locked"===g){b.G=0<=a-1?d:0<=d-1?d-1:0;h=!0;break}if(h)break}else void 0!==b.ea.lastPlayed&&(b.G=b.ea.lastPlayed.world||0)});b.mh=bj();void 0!==b.mh.authToken&&void 0!==b.mh.challengeId&&(b.ic=!0);O.A.ZA&&(this.Xa=this.XA?new TestBackendServiceProvider:new BackendServiceProvider,
this.Xa.Zq(function(a){a&&O.f.Xa.mA(b.mh.authToken)}));a=parseFloat(m.u.version);J.Ra&&(m.La.$o&&m.u.Xk||m.u.ah&&a&&4.4>a)&&(J.oj=1);this.oc=!0;this.Ak=0};function bj(){var a,b,c,d,g;b={};if(a=window.location.search.substring(1))for(a=a.split("&"),d=0,g=a.length;d<g;d++)c=a[d].split("="),b[c[0]]=c[1];return b}function cj(a){a.state="GAME_LOAD";a.screen=new zg(function(){O.f.load=!0;Ch(O.f,!0);O.Pd.qn();O.t.qn()},function(){},O.A.QA)}function Ch(a,b){a.ej=b||!1;a.Zo=!0;a.Tm++}
function dj(){var a=O.f;a.Tm--;switch(a.state){case "GAME_INIT":a.oc&&!a.$A&&(a.ic&&a.Xa&&a.Xa.SA(a.mh.challengeId,function(b){!b&&a.screen&&"function"===typeof a.screen.xo&&a.screen.xo("challengeLoadingError_notValid")}),cj(a));break;case "GAME_LOAD":if(a.load){if(a.ic&&a.Xa)if(a.Xa.qv())Cg(a),Fg(a.Jb.mode);else{a.screen.xo("challengeLoadingError_notStarted");break}K.p(a.screen);"function"===typeof Zi&&(O.n=new Zi);void 0!==O.A.bu&&!1!==O.A.bu.show&&O.b.Mt();Bh(a)}break;case "LEVEL_INIT":a.An&&ej(a);
break;case "LEVEL_LOAD":a.Bn&&fj(a);break;case "LEVEL_END":if(a.la)switch(Ah(),O.f.An=!1,O.f.Bn=!1,O.fb=void 0,O.b.Xd(O.gf).Z=!0,O.b.Xd(O.ok).Z=!0,O.f.fr){case "retry":Jg(O.f,O.f.nb);break;case "next":O.j.If?O.f.nb+1<O.j.S[O.f.G]?Jg(O.f,O.f.nb+1):O.f.G+1<O.j.S.length?Jg(O.f,0,O.f.G+1):O.j.yo?(O.f.state="GAME_END",O.f.end=!0,Ch(O.f,!1),O.t.$u()):O.f.screen=new Ig:Jg(O.f,0);break;case "exit":O.j.If?O.f.screen=new Ig:Bh(O.f)}break;case "GAME_END":a.end&&(a.end=!1,O.f.screen=null,O.f.screen=new Dh)}}
function eg(){O.f.Zo=!1}function vh(){var a;if(void 0!==O.f.mh.more_games)try{return a=decodeURIComponent(O.f.mh.more_games),function(){O.t.hd(a)}}catch(b){}if("string"===typeof O.Rg.moreGamesUrl&&""!==O.Rg.moreGamesUrl)return function(){O.t.hd(O.Rg.moreGamesUrl)};if(void 0!==O.A.ow)return function(){O.t.hd(O.A.ow)};if("function"===typeof O.t.Iq)return O.t.Iq}function Cg(a){if(a.ic&&void 0!==a.Xa)return void 0===a.Jb&&(a.Jb=a.Xa.Uz()),a.Jb}e.gi=function(a){O.f.ic&&O.f.Xa&&O.f.Xa.gi(a)};
e.kg=function(a){O.f.ic&&O.f.Xa&&O.f.Xa.kg(a)};function Eg(){return O.f.ea.difficulty}function zh(){switch(Eg()){case 0:return"easy";case 1:return"medium";case 2:return"hard";default:throw"Unknown difficulty: "+Eg();}}function ai(){var a="optionsDifficulty_"+zh();return O.i.r(a,"<"+a+">")}function Fg(a){O.f.ea.difficulty=a;sg("preferences",O.f.ea)}e.Bf=function(a){void 0!==a&&(O.f.ea.playMusic=a,sg("preferences",O.f.ea),a?hb("music"):gb("music"));return O.f.ea.playMusic};
e.il=function(a){void 0!==a&&(O.f.ea.playSFX=a,sg("preferences",O.f.ea),a?(hb("game"),hb("sfx")):(gb("game"),gb("sfx")));return O.f.ea.playSFX};e.language=function(a){void 0!==a&&(O.f.ea.language=a,sg("preferences",O.f.ea));return O.f.ea.language};function Gh(a){return"time"===O.j.Ff?(0>a?"-":"")+Math.floor(Math.abs(a)/60)+(10>Math.abs(a%60)?":0":":")+Math.abs(a%60):""+a}
function aj(a,b,c,d){var g="game";"game"!==g&&(g="tg");void 0===O.f.Oc["level_"+a+"_"+b]&&(O.f.Oc["level_"+a+"_"+b]={tg:{},game:{}});void 0===c?O.f.Oc["level_"+a+"_"+b][g]=d:O.f.Oc["level_"+a+"_"+b][g][c]=d;O.t.lt()}function Ng(a,b,c,d){var g="game";"game"!==g&&(g="tg");a=O.f.Oc["level_"+a+"_"+b];return void 0!==a&&(a=void 0===c?a[g]:a[g][c],void 0!==a)?a:d}function rg(a,b){var c,d;"game"!==c&&(c="tg");d=O.f.Oc.game;return void 0!==d&&(d=void 0===a?d[c]:d[c][a],void 0!==d)?d:b}
function sg(a,b){var c;"game"!==c&&(c="tg");void 0===O.f.Oc.game&&(O.f.Oc.game={tg:{},game:{}});void 0===a?O.f.Oc.game[c]=b:O.f.Oc.game[c][a]=b;O.t.lt()}function Ug(a,b,c,d){void 0===c&&(c=a.nb);void 0===d&&(d=a.G);return void 0===b?Ng(d,c,"stats",{}):Ng(d,c,"stats",{})[b]}
function Mh(a){var b,c,d=O.f;if(void 0===c&&void 0!==a){var g=a;for(c=0;c<O.j.S.length&&!(g<O.j.S[c]);c++)g-=O.j.S[c];c=g;if(void 0===b){var h=g=0;for(b=0;b<O.j.S.length;b++){h+=O.j.S[b];if(h>a)break;g+=1}b=g}}a=Ug(d,"highScore",c,b);return"number"!==typeof a?0:a}function gj(){var a,b,c,d=0;for(a=0;a<O.j.S.length;a++)for(b=0;b<O.j.S[a];b++)c=Ug(O.f,void 0,b,a),"object"===typeof c&&null!==c&&(d+=void 0!==c.highScore?c.highScore:0);return d}
function Bh(a){a.screen&&K.p(a.screen);a.screen=new Bg;a.nb=-1}
function ii(a,b,c,d){var g;g=void 0!==O.a.P.si&&void 0!==O.a.P.si.backgroundImage?O.a.P.si.backgroundImage:void 0!==O.a.C.si?O.a.C.si.backgroundImage:void 0;O.b.jb(O.ff);a=a||0;b=b||0;c=c||r.width;d=d||r.height;if(g)if(c=Math.min(Math.min(c,r.width),g.Vh),d=Math.min(Math.min(d,r.height),g.ng),void 0!==g){var h=a,k=b-O.Fj,l,n,q;for(l=0;l<g.F;l+=1)n=l%g.Pg*g.width,q=g.height*Math.floor(l/g.Pg),n>h+c||n+g.width<h||q>k+d||q+g.height<k||g.ka(l,h-n,k-q,c,d,a,b,1)}else oa(a,b,c,d,"white",!1)}
function Jg(a,b,c){a.state="LEVEL_INIT";void 0===c||(a.G=c);a.nb=b;a.An=!0;Ch(a,!1);O.t.av()}function ej(a){a.state="LEVEL_LOAD";a.Bn=!0;Ch(a,!1);O.t.bv()}
function fj(a){var b,c=0;if(a.G<O.j.S.length&&a.nb<O.j.S[a.G]){a.state="LEVEL_PLAY";a.Or+=1;a.la=!1;a.screen=null;ii(0,O.Fj);b=O.Aa;var d=yh(a,3),g="progression:levelStarted:"+zh(),h=a.Vf,k;for(k=0;k<b.$.length;k++)if(!b.$[k].k){b.$[k].m=0;b.$[k].paused=0;b.$[k].k=!0;b.$[k].oq=d;b.$[k].Vr=g;b.$[k].tag=h;break}k===b.$.length&&b.$.push({k:!0,m:0,paused:0,oq:d,Vr:g,tag:h});b.Qa(d,g);for(b=0;b<a.G;b++)c+=O.j.S[b];a.ea.lastPlayed={world:a.G,level:a.nb};O.fb=new ui(c+a.nb)}}
function Og(a,b,c){var d=0;void 0===b&&(b=a.G);void 0===c&&(c=a.nb);for(a=0;a<b;a++)d+=O.j.S[a];return d+c}function Yi(a,b){var c=O.f;c.ic&&(c.Jb.Zc!==c.Jb.Ye||O.A.nu&&O.A.nu.PA)?new Eh("challengeStartTextTime",a,b):"function"===typeof a&&(b?b.R():a())}function yh(a,b){var c,d=a.nb+"",g=b-d.length;if("number"===typeof b&&1<b)for(c=0;c<g;c++)d="0"+d;return d}
function Fi(a,b){var c,d,g,h,k;a.ic?(b=Math.floor(b),a.Jb.Ye===a.Jb.Zc?(d=function(b){a.Vb&&"function"===typeof a.Vb.ld&&(b?(a.Vb.ld(O.i.r("challengeEndScreenChallengeSend_success","<CHALLENGESENDTEXT>")),a.Jb.Fs?oh(a.Vb,O.i.r("challengeEndScreenChallengeSend_submessage_stranger","")):(k=a.Jb.jd[1],k=13<k.length?k.substr(0,10)+"...":k,oh(a.Vb,O.i.r("challengeEndScreenChallengeSend_submessage","<CHALLENGESENDSUBMESSAGE>").replace(/<NAME>/g,k)))):a.Vb.ld(O.i.r("challengeEndScreenChallengeSend_error",
"<CHALLENGESENDERROR>")))},h=function(b){b?a.Vb.ld(O.i.r("challengeCancelMessage_success","<CHALLENGECANCELSUCCESS>")):a.Vb.ld(O.i.r("challengeCancelMessage_error","<CHALLENGECANCELERROR>"))},c=function(){a.Xa&&a.Xa.kg(h)}):(d=function(b){a.Vb&&"function"===typeof a.Vb.ld&&(b||a.Vb.ld(O.i.r("challengeEndScreenScoreSend_error","<CHALLENGESCORESENDERROR>")))},g=function(b){a.Vb&&"function"===typeof a.Vb.kt&&a.Vb.kt(b)}),a.state="LEVEL_END",a.Vb=new nh(b,function(){a.Xa&&a.Xa.UA(b,O.j.Ff,d,g)},c)):Gi(a,
{totalScore:b})}
function Gi(a,b){function c(a,b){return"number"!==typeof a?!1:"number"!==typeof b||"max"===O.j.af&&a>b||"min"===O.j.af&&a<b?!0:!1}a.state="LEVEL_END";var d,g,h,k,l,n,q={},w=yh(a,3);b=b||{};b.level=O.j.cj?a.nb+1:Og(a)+1;b.Uq=!1;g=(d=Ng(a.G,a.nb,"stats",void 0))||{};if(void 0!==b.zd||void 0!==b.sb){void 0!==b.zd&&(q[b.zd.id]=b.zd.K(),"highScore"===b.zd.id&&(n=b.zd));if(void 0!==b.sb)for(k=0;k<b.sb.length;k++)q[b.sb[k].id]=b.sb[k].K(),"highScore"===b.sb[k].id&&(n=b.sb[k]);for(k in q)l=q[k],void 0!==
l.Je&&(q[l.Hl].kc=l.Je(q[l.Hl].kc));void 0!==q.totalScore&&(h=q.totalScore.kc)}else h=b.totalScore,void 0!==h&&void 0!==b.timeBonus&&(h+=b.timeBonus);if(!0!==b.failed){if(void 0!==h){O.Aa.Qa("points","progression:score:"+zh()+":"+w,h);if(void 0===d||c(h,d.highScore))g.highScore=h,b.Uq=!0,O.Aa.Qa("highScore","progression:score:"+zh()+":"+w,h);void 0!==n&&(n.kc=g.highScore);b.highScore=g.highScore}void 0!==b.stars&&(g.stars=b.stars,O.Aa.Qa("stars","progression:score:"+zh()+":"+w,b.stars));a.nb+1<O.j.S[a.G]?
"locked"===Ng(a.G,a.nb+1,"state","locked")&&aj(a.G,a.nb+1,"state","unlocked"):a.G+1<O.j.S.length&&"locked"===Ng(a.G+1,0,"state","locked")&&aj(a.G+1,0,"state","unlocked");aj(a.G,a.nb,void 0,{stats:g,state:"played"});void 0!==a.Xa&&(d=O.n&&O.n.Wu?O.n.Wu():gj(),void 0!==d&&a.Xa.VA(d,O.j.Ff));ug(O.Aa,a.Vf,w,"progression:levelCompleted:"+zh())}else ug(O.Aa,a.Vf,w,"progression:levelFailed:"+zh());a.Vb=new Vg(O.j.Bd,b,function(a){O.f.la=!0;O.f.fr=a;Ch(O.f,!0);a={totalScore:h,level:b.level,highScore:b.highScore,
failed:!0===b.failed,stars:b.stars,stage:b.stage};O.t.pi(a);O.Pd.pi(a)})}e.Li=function(){O.f.Vg(!0)};e.Vg=function(a,b,c){var d="inGame";O.f.screen instanceof Bg?d="startScreen":O.f.screen instanceof Ig?d="levelMapScreen":b&&(d=O.f.Jb.Zc===O.f.Jb.Ye?"inGame_challenger":"inGame_challengee");O.f.Qe||(O.f.Qe=new sh(d,!0===a,b,c))};
function ni(a,b){var c=[],d,g,h,k,l;O.f.Qe||O.f.me||(O.f.Jb.Zc===O.f.Jb.Ye?(d=O.i.r("challengeCancelConfirmText","<CHALLENGECANCELCONFIRMTEXT>"),g="challengeCancelConfirmBtn_yes",h="challengeCancelConfirmBtn_no",l=function(a){var b=a?"challengeCancelMessage_success":"challengeCancelMessage_error",b=O.i.r(b,"<"+b.toUpperCase()+"<");O.f.me&&Ih(b);a&&hh()},k=function(){"function"===typeof b&&b(!0);O.f.kg(l);return!0}):(d=O.i.r("challengeForfeitConfirmText","<CHALLENGEFORFEITCONFIRMTEXT>"),g="challengeForfeitConfirmBtn_yes",
h="challengeForfeitConfirmBtn_no",l=function(a){var b=a?"challengeForfeitMessage_success":"challengeForfeitMessage_error",b=O.i.r(b,"<"+b.toUpperCase()+"<");if(O.f.me&&(Ih(b),a)){var b=O.i.r("challengeForfeitMessage_winnings",""),b=b.replace("<NAME>",O.f.Jb.jd[O.f.Jb.Ye]),b=b.replace("<AMOUNT>",O.f.Jb.wt),c=O.f.me,d,g,h,k;d=V.K();c.a.Jo&&C(d,c.a.Jo);g=H(d,b,c.a.ex,c.a.dx,!0);g<d.fontSize&&D(d,g);g=d.ba(b,c.a.nl)+10;h=d.V(b,c.a.ml)+10;k=O.b.ca(c.a.fx,c.c.e.width,g,d.align);h=O.b.ca(c.a.gx,c.c.e.height-
Hh(c),h,d.h);z(c.c.e);d.o(b,k,h,g);B(c.c.e)}a&&hh()},k=function(){"function"===typeof b&&b(!0);O.f.gi(l);return!0}),c.push({M:g,R:k,aa:O.f}),c.push({M:h,R:function(){O.f.me.close();O.f.me=null;"function"===typeof b&&b(!1);return!0}}),O.f.me=new rh(d,c,a),O.f.Qe=O.f.me)}e.ao=function(){var a,b;b=Jb("game");for(a=0;a<b.length;a++)"function"===typeof b[a].wn&&b[a].wn();vg();Kb("game");Cb()};
function hh(a){var b,c;c=Jb();for(b=0;b<c.length;b++)"function"===typeof c[b].wn&&c[b].wn();Kb();Cb();vg();a&&(a.N=Math.max(0,a.N-1));Lb("system")}function mh(){var a,b;b=Jb();for(a=0;a<b.length;a++)"function"===typeof b[a].cv&&b[a].cv();Lb();a=K;for(b=0;b<a.je.length;b+=1)a.je[b].paused=Math.max(0,a.je[b].paused-1);a=O.Aa;b=O.f.Vf;var c;for(c=0;c<a.$.length;c++)void 0!==a.$[c]&&a.$[c].tag===b&&(a.$[c].paused-=1,a.$[c].paused=Math.max(a.$[c].paused,0))}
function Ah(){var a;O.fb&&K.p(O.fb);for(a=Jb("LevelStartDialog");0<a.length;)K.p(a.pop())}function qg(){var a="";O.version.builder&&(a=O.version.builder);O.version.tg&&(a+="-"+O.version.tg);O.version.game&&(a+="-"+O.version.game);O.version.config&&(a+="-"+O.version.config);return a}e.Sb=function(){this.oc||(this.dm(),Ch(O.f,!0),O.Pd.tk(),O.t.tk())};
e.pa=function(a){"function"===typeof this.xq&&(this.xq(),this.xq||eg());0<this.Tm&&(this.ej||this.Zo||dj());700>this.Ak&&(this.Ak+=a,700<=this.Ak&&(O.A.Ny&&void 0!==O.A.ii&&O.A.ii.jk&&O.A.ii.wl&&O.Aa.start([O.A.ii.jk,O.A.ii.wl]),void 0===Ng(this.G,0,"state",void 0)&&aj(this.G,0,"state","unlocked")))};e.gd=function(a,b){"languageSet"===a&&O.f.language(b)};e.mc=function(){var a,b;for(a=0;a<O.wd.length;a++)b=O.wd[a],b.Z&&(r.jb(b),r.clear())};
e.Pa=function(){var a;for(a=0;a<O.wd.length;a++)O.wd[a].Z=!1};O.Zx=function(){O.f=new $i;L(O.f);Ib(O.f,"system")};(void 0===O.Ut||O.Ut)&&O.Zx();
